@@ -182,8 +182,8 @@ static const cpu_state_entry state_array[] =
 	I8085_STATE_ENTRY(GENPC, "%04X", PC.w.l, 0xffff, CPUSTATE_NOSHOW)
 //  I8085_STATE_ENTRY(GENPCBASE, "%04X", prvpc.w.l, 0xffff, CPUSTATE_NOSHOW)
 
-	I8085_STATE_ENTRY(SP,  "%04X", PC.w.l, 0xffff, 0)
-	I8085_STATE_ENTRY(GENSP, "%04X", PC.w.l, 0xffff, CPUSTATE_NOSHOW)
+	I8085_STATE_ENTRY(SP,  "%04X", SP.w.l, 0xffff, 0)
+	I8085_STATE_ENTRY(GENSP, "%04X", SP.w.l, 0xffff, CPUSTATE_NOSHOW)
 
 	I8085_STATE_ENTRY(A, "%02X", AF.b.l, 0xff, CPUSTATE_NOSHOW)
 	I8085_STATE_ENTRY(B, "%02X", BC.b.h, 0xff, CPUSTATE_NOSHOW)
@@ -244,6 +244,16 @@ static void execute_one(i8085_state *cpustate, int opcode);
     INLINE FUNCTIONS
 ***************************************************************************/
 
+INLINE i8085_state *get_safe_token(const device_config *device)
+{
+	assert(device != NULL);
+	assert(device->token != NULL);
+	assert(device->type == CPU);
+	assert(cpu_get_type(device) == CPU_8080 ||
+		   cpu_get_type(device) == CPU_8085A);
+	return (i8085_state *)device->token;
+}
+
 INLINE void set_sod(i8085_state *cpustate, int state)
 {
 	if (state != 0 && cpustate->sod_state == 0)
@@ -473,7 +483,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->BC.w.l++;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->BC.b.l == 0x00) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->BC.w.l == 0x0000) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x04: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  B */
@@ -507,7 +517,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->BC.w.l--;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->BC.b.l == 0xff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->BC.w.l == 0xffff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x0c: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  C */
@@ -542,7 +552,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->DE.w.l++;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->DE.b.l == 0x00) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->DE.w.l == 0x0000) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x14: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  D */
@@ -579,7 +589,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->DE.w.l--;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->DE.b.l == 0xff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->DE.w.l == 0xffff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x1c: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  E */
@@ -621,7 +631,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->HL.w.l++;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->HL.b.l == 0x00) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->HL.w.l == 0x0000) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x24: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  H */
@@ -667,7 +677,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->HL.w.l--;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->HL.b.l == 0xff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->HL.w.l == 0xffff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x2c: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  L */
@@ -735,7 +745,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->SP.w.l++;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->SP.b.l == 0x00) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->SP.w.l == 0x0000) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x34: cpustate->icount -= 10;	/* INR  M */
@@ -776,7 +786,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 			cpustate->SP.w.l--;
 			if (IS_8085(cpustate))
 			{
-				if (cpustate->SP.b.l == 0xff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
+				if (cpustate->SP.w.l == 0xffff) cpustate->AF.b.l |= XF; else cpustate->AF.b.l &= ~XF;
 			}
 			break;
 		case 0x3c: cpustate->icount -= IS_8085(cpustate) ? 4 : 5;	/* INR  A */
@@ -1459,7 +1469,7 @@ static void execute_one(i8085_state *cpustate, int opcode)
 
 static CPU_EXECUTE( i808x )
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 
 	cpustate->icount = cycles;
 
@@ -1516,7 +1526,7 @@ static void init_tables (void)
 
 static void init_808x_common(const device_config *device, cpu_irq_callback irqcallback, int type)
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 
 	init_tables();
 
@@ -1569,7 +1579,7 @@ static CPU_INIT( i8085 )
 
 static CPU_RESET( i808x )
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 
 	cpustate->PC.d = 0;
 	cpustate->HALT = 0;
@@ -1590,7 +1600,7 @@ static CPU_RESET( i808x )
 
 static CPU_IMPORT_STATE( i808x )
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 
 	switch (entry->index)
 	{
@@ -1617,7 +1627,7 @@ static CPU_IMPORT_STATE( i808x )
 
 static CPU_EXPORT_STATE( i808x )
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 
 	switch (entry->index)
 	{
@@ -1671,7 +1681,7 @@ static void i808x_set_irq_line(i8085_state *cpustate, int irqline, int state)
 
 static CPU_SET_INFO( i808x )
 {
-	i8085_state *cpustate = device->token;
+	i8085_state *cpustate = get_safe_token(device);
 	switch (state)
 	{
 		/* --- the following bits of info are set as 64-bit signed integers --- */
@@ -1693,7 +1703,7 @@ static CPU_SET_INFO( i808x )
 
 CPU_GET_INFO( i8085 )
 {
-	i8085_state *cpustate = (device != NULL) ? device->token : NULL;
+	i8085_state *cpustate = (device != NULL && device->token != NULL) ? get_safe_token(device) : NULL;
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
