@@ -22,6 +22,7 @@
  *
  *****************************************************************************/
 
+
 #define SET_NZ(n)	if ((n) == 0) P = (P & ~F_N) | F_Z; else P = (P & ~(F_N | F_Z)) | ((n) & F_N)
 #define SET_Z(n)	if ((n) == 0) P |= F_Z; else P &= ~F_Z
 
@@ -124,7 +125,7 @@
 		else									\
 			pair.w.l++;							\
 		EAH = RDMEM(pair.d);							\
-		RDMEM(PCW-1);								\
+		/* RDMEM(PCW-1); */								\
 		EAW += Y;								\
 	}
 
@@ -134,7 +135,7 @@
 #define EA_IND										\
 	EA_ABS;										\
 	tmp = RDMEM(EAD);								\
-	EAD++;										\
+	EAL++;										\
 	EAH = RDMEM(EAD);								\
 	EAL = tmp
 
@@ -145,7 +146,7 @@
 	EA_ABS;										\
 	EAW += X;									\
 	tmp = RDMEM(EAD);								\
-	EAD++;										\
+	EAL++;										\
 	EAH = RDMEM(EAD);								\
 	EAL = tmp
 
@@ -288,7 +289,7 @@
 	t1=RDOPARG();									\
 	t2=RDOPARG();									\
 	t3=RDOPARG();									\
-	logerror("m65ce02 at pc:%.4x reserved op aug %.2x %.2x %.2x\n", t1,t2,t3);
+	logerror("m65ce02 at pc:%.4x reserved op aug %.2x %.2x %.2x\n", cpu_get_pc(cpustate->device),t1,t2,t3);
 
 /* 65ce02 ******************************************************
  *  BBR Branch if bit is reset
@@ -316,27 +317,32 @@
  *  BRA  branch relative
  ***************************************************************/
 #define BRA(cond)									\
-	tmp = RDOPARG();								\
 	if (cond)									\
 	{										\
-		EAW = PCW + (signed char)tmp;						\
+		tmp = RDOPARG();							\
+		EAW = PCW + (signed char)tmp;					\
 		PCD = EAD;								\
-		CHANGE_PC;								\
+	}										\
+	else										\
+	{										\
+		PCW += 1;								\
 	}
 
 /***************************************************************
  *  BRA  branch relative
  ***************************************************************/
-#define BRA_WORD(cond)									\
-	EAL = RDOPARG();								\
-	EAH = RDOPARG();								\
+#define BRA_WORD(cond)								\
 	if (cond)									\
 	{										\
-		EAW = PCW + (short)(EAW-1); 						\
+		EAL = RDOPARG();							\
+		EAH = RDOPARG();							\
+		EAW = PCW + (short)(EAW-1); 					\
 		PCD = EAD;								\
-		CHANGE_PC;								\
+	}										\
+	else										\
+	{										\
+		PCW += 2;							\
 	}
-
 /* 65ce02 ******************************************************
  *  BRK Break
  *  increment PC, push PC hi, PC lo, flags (with B bit set),
@@ -349,8 +355,7 @@
 	PUSH(P | F_B);									\
 	P = (P | F_I);									\
 	PCL = RDMEM(M6502_IRQ_VEC);							\
-	PCH = RDMEM(M6502_IRQ_VEC+1);							\
-	CHANGE_PC
+	PCH = RDMEM(M6502_IRQ_VEC+1);
 
 /* 65ce02 ********************************************************
  *  BSR Branch to subroutine
@@ -361,8 +366,7 @@
 	PUSH(PCL);									\
 	EAH = RDOPARG();								\
 	EAW = PCW + (INT16)(EAW-1);							\
-	PCD = EAD;									\
-	CHANGE_PC
+	PCD = EAD;
 
 /* 65ce02 ******************************************************
  * CLC  Clear carry flag
@@ -529,8 +533,7 @@
  *  set PC to the effective address
  ***************************************************************/
 #define JMP										\
-	PCD = EAD;									\
-	CHANGE_PC
+	PCD = EAD;
 
 /* 65ce02 ******************************************************
  *  JSR Jump to subroutine
@@ -542,8 +545,7 @@
 	PUSH(PCH);									\
 	PUSH(PCL);									\
 	EAH = RDOPARG();								\
-	PCD = EAD;									\
-	CHANGE_PC
+	PCD = EAD;
 
 /* 65ce02 ******************************************************
  *  JSR Jump to subroutine
@@ -556,8 +558,7 @@
 	PUSH(PCL);									\
 	EAH = RDOPARG();								\
 	PCL = RDMEM(EAD);								\
-	PCH = RDMEM(EAD);								\
-	CHANGE_PC
+	PCH = RDMEM(EAD+1);
 
 /* 65ce02 ******************************************************
  *  JSR Jump to subroutine
@@ -570,8 +571,7 @@
 	PUSH(PCL);									\
 	EAH = RDOPARG();								\
 	PCL = RDMEM(EAD);								\
-	PCH = RDMEM(EAD);								\
-	CHANGE_PC
+	PCH = RDMEM(EAD+1);
 
 /* 65ce02 ******************************************************
  *  LDA Load accumulator
@@ -676,7 +676,7 @@
 		PULL(temp);								\
 		P=(P&F_E)|F_B|(temp&~F_E);						\
 		if( IRQ_STATE != CLEAR_LINE && !(P & F_I) ) {			\
-			LOG(("M65ce02#%d PLP sets after_cli\n", cpu_getactivecpu()));	\
+			LOG(("M65ce02 '%s' PLP sets after_cli\n", cpustate->device->tag));	\
 			AFTER_CLI = 1;						\
 		}									\
 	} else {									\
@@ -756,10 +756,9 @@
 	PULL(PCH);									\
 	if( IRQ_STATE != CLEAR_LINE && !(P & F_I) )				\
 	{										\
-		LOG(("M65ce02#%d RTI sets after_cli\n", cpu_getactivecpu()));		\
+		LOG(("M65ce02 '%s' RTI sets after_cli\n", cpustate->device->tag));		\
 		AFTER_CLI = 1;							\
-	}										\
-	CHANGE_PC
+	}
 
 /* 65ce02 ******************************************************
  *  RTS Return from subroutine
@@ -768,8 +767,7 @@
 #define RTS										\
 	PULL(PCL);									\
 	PULL(PCH);									\
-	RDMEM(PCW); PCW++;								\
-	CHANGE_PC
+	RDMEM(PCW); PCW++;
 
 /* 65ce02 ******************************************************
  *  RTS imm
@@ -789,10 +787,9 @@
 	PULL(PCL);									\
 	PULL(PCH);									\
 	if( IRQ_STATE != CLEAR_LINE && !(P & F_I) ) {				\
-	LOG(("M65ce02#%d RTI sets after_cli\n", cpu_getactivecpu()));			\
+	LOG(("M65ce02 '%s' RTI sets after_cli\n", cpustate->device->tag));			\
 		AFTER_CLI = 1;							\
-	}										\
-	CHANGE_PC
+	}
 
 
 /* 65ce02 *******************************************************
@@ -832,6 +829,9 @@
 /* 65ce02 ******************************************************
  *  SEC Set carry flag
  ***************************************************************/
+#if defined(SEC)
+#undef SEC
+#endif
 #define SEC										\
 	P |= F_C
 
@@ -943,7 +943,7 @@
  * TSY  Transfer stack pointer to index y
  ***************************************************************/
 #define TSY										\
-	Y = SPL;									\
+	Y = SPH;									\
 	SET_NZ(Y)
 
 /* 65ce02 ******************************************************
@@ -960,9 +960,9 @@
  ***************************************************************/
 #define TXS										\
 	SPL = X;									\
-	if (PEEK_OP() == 0x2b /*TYS*/ ) {						\
-		UINT8 op = RDOP();							\
-		(*m65ce02.insn[op])();							\
+	if (PEEK_OP() == 0x2b /*TYS*/ ) {			\
+		UINT8 op = RDOP();						\
+		(*cpustate->insn[op])(cpustate);			\
 	}
 
 
@@ -985,4 +985,3 @@
 #define TZA										\
 	A = Z;										\
 	SET_NZ(A)
-
