@@ -55,10 +55,6 @@
 #include "pic16c5x.h"
 
 
-#ifndef INLINE
-#define INLINE static inline
-#endif
-
 
 #define M_RDRAM(A)		(((A) < 8) ? cpustate->internalram[A] : PIC16C5x_RAM_RDMEM(A))
 #define M_WRTRAM(A,V)	do { if ((A) < 8) cpustate->internalram[A] = (V); else PIC16C5x_RAM_WRMEM(A,V); } while (0)
@@ -108,6 +104,18 @@ struct _pic16c5x_state
 	const	address_space *io;
 };
 
+INLINE pic16c5x_state *get_safe_token(const device_config *device)
+{
+	assert(device != NULL);
+	assert(device->token != NULL);
+	assert(device->type == CPU);
+	assert(cpu_get_type(device) == CPU_PIC16C54 ||
+		   cpu_get_type(device) == CPU_PIC16C55 ||
+		   cpu_get_type(device) == CPU_PIC16C56 ||
+		   cpu_get_type(device) == CPU_PIC16C57 ||
+		   cpu_get_type(device) == CPU_PIC16C58);
+	return (pic16c5x_state *)device->token;
+}
 
 /* opcode table entry */
 typedef struct _pic16c5x_opcode pic16c5x_opcode;
@@ -738,7 +746,7 @@ static const pic16c5x_opcode_00x opcode_00x[16]=
 
 static CPU_INIT( pic16c5x )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	state_save_register_device_item(device, 0, cpustate->W);
 	state_save_register_device_item(device, 0, cpustate->ALU);
@@ -809,7 +817,7 @@ static void pic16c5x_soft_reset(pic16c5x_state *cpustate)
 
 void pic16c5x_set_config(const device_config *cpu, int data)
 {
-	pic16c5x_state *cpustate = cpu->token;
+	pic16c5x_state *cpustate = get_safe_token(cpu);
 
 	logerror("Writing %04x to the PIC16C5x config register\n",data);
 	cpustate->temp_config = (data & 0xfff);
@@ -893,7 +901,7 @@ static void pic16c5x_update_timer(pic16c5x_state *cpustate, int counts)
 
 static CPU_EXECUTE( pic16c5x )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 	int T0_in;
 	cpustate->icount = cycles;
 
@@ -968,7 +976,7 @@ static CPU_EXECUTE( pic16c5x )
 
 static CPU_SET_INFO( pic16c5x )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	switch (state)
 	{
@@ -1002,7 +1010,7 @@ static CPU_SET_INFO( pic16c5x )
 
 static CPU_GET_INFO( pic16c5x )
 {
-	pic16c5x_state *cpustate = (device != NULL) ? device->token : NULL;
+	pic16c5x_state *cpustate = (device != NULL && device->token != NULL) ? get_safe_token(device) : NULL;
 
 	switch (state)
 	{
@@ -1102,7 +1110,6 @@ static CPU_GET_INFO( pic16c5x )
 
 
 
-#if (HAS_PIC16C54)
 /****************************************************************************
  *  Internal Memory Map
  ****************************************************************************/
@@ -1122,7 +1129,7 @@ ADDRESS_MAP_END
 
 static CPU_RESET( pic16c54 )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	cpustate->picmodel = 0x16C54;
 	cpustate->picRAMmask = 0x1f;
@@ -1153,10 +1160,8 @@ CPU_GET_INFO( pic16c54 )
 		default:										CPU_GET_INFO_CALL(pic16c5x);			break;
 	}
 }
-#endif
 
 
-#if (HAS_PIC16C55)
 /****************************************************************************
  *  Internal Memory Map
  ****************************************************************************/
@@ -1176,7 +1181,7 @@ ADDRESS_MAP_END
 
 static CPU_RESET( pic16c55 )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	cpustate->picmodel = 0x16C55;
 	cpustate->picRAMmask = 0x1f;
@@ -1207,10 +1212,8 @@ CPU_GET_INFO( pic16c55 )
 		default:										CPU_GET_INFO_CALL(pic16c5x);			break;
 	}
 }
-#endif
 
 
-#if (HAS_PIC16C56)
 /****************************************************************************
  *  Internal Memory Map
  ****************************************************************************/
@@ -1230,7 +1233,7 @@ ADDRESS_MAP_END
 
 static CPU_RESET( pic16c56 )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	cpustate->picmodel = 0x16C56;
 	cpustate->picRAMmask = 0x1f;
@@ -1263,10 +1266,8 @@ CPU_GET_INFO( pic16c56 )
 		default:										CPU_GET_INFO_CALL(pic16c5x);			break;
 	}
 }
-#endif
 
 
-#if (HAS_PIC16C57)
 /****************************************************************************
  *  Internal Memory Map
  ****************************************************************************/
@@ -1289,7 +1290,7 @@ ADDRESS_MAP_END
 
 static CPU_RESET( pic16c57 )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	cpustate->picmodel = 0x16C57;
 	cpustate->picRAMmask = 0x7f;
@@ -1323,10 +1324,8 @@ CPU_GET_INFO( pic16c57 )
 		default:										CPU_GET_INFO_CALL(pic16c5x);			break;
 	}
 }
-#endif
 
 
-#if (HAS_PIC16C58)
 /****************************************************************************
  *  Internal Memory Map
  ****************************************************************************/
@@ -1349,7 +1348,7 @@ ADDRESS_MAP_END
 
 static CPU_RESET( pic16c58 )
 {
-	pic16c5x_state *cpustate = device->token;
+	pic16c5x_state *cpustate = get_safe_token(device);
 
 	cpustate->picmodel = 0x16C58;
 	cpustate->picRAMmask = 0x7f;
@@ -1383,4 +1382,3 @@ CPU_GET_INFO( pic16c58 )
 		default:										CPU_GET_INFO_CALL(pic16c5x);			break;
 	}
 }
-#endif
