@@ -22,10 +22,7 @@
 #endif
 
 
-// Atrocious hack that makes the soldivid music correct
-
-//static const int div_tab[4] = { 3, 5, 7, 0 };
-static const int div_tab[4] = { 3, 5, 3, 0 };
+static const int div_tab[4] = { 3, 5, 7, 0 };
 
 INLINE UINT32 RL(SH2 *sh2, offs_t A)
 {
@@ -111,7 +108,7 @@ static void sh2_timer_activate(SH2 *sh2)
 
 TIMER_CALLBACK( sh2_timer_callback )
 {
-	SH2 *sh2 = ptr;
+	SH2 *sh2 = (SH2 *)ptr;
 	UINT16 frc;
 
 	sh2_timer_resync(sh2);
@@ -139,7 +136,7 @@ TIMER_CALLBACK( sh2_timer_callback )
 TIMER_CALLBACK( sh2_dmac_callback )
 {
 	int dma = param & 1;
-	SH2 *sh2 = ptr;
+	SH2 *sh2 = (SH2 *)ptr;
 
 	LOG(("SH2.%s: DMA %d complete\n", sh2->device->tag, dma));
 	sh2->m[0x63+4*dma] |= 2;
@@ -278,7 +275,7 @@ static void sh2_dmac_check(SH2 *sh2, int dma)
 	{
 		if(sh2->dma_timer_active[dma])
 		{
-			logerror("SH2: DMA %d cancelled in-flight", dma);
+			logerror("SH2: DMA %d cancelled in-flight\n", dma);
 			timer_adjust_oneshot(sh2->dma_timer[dma], attotime_never, 0);
 			sh2->dma_timer_active[dma] = 0;
 		}
@@ -503,6 +500,12 @@ READ32_HANDLER( sh2_internal_r )
 	return sh2->m[offset];
 }
 
+void sh2_set_ftcsr_read_callback(const device_config *device, void (*callback)(UINT32))
+{
+	SH2 *sh2 = GET_SH2(device);
+	sh2->ftcsr_read_callback = callback;
+}
+
 void sh2_set_frt_input(const device_config *device, int state)
 {
 	SH2 *sh2 = GET_SH2(device);
@@ -698,7 +701,7 @@ void sh2_exception(SH2 *sh2, const char *message, int irqline)
 
 void sh2_common_init(SH2 *sh2, const device_config *device, cpu_irq_callback irqcallback)
 {
-	const sh2_cpu_core *conf = device->static_config;
+	const sh2_cpu_core *conf = (const sh2_cpu_core *)device->static_config;
 
 	sh2->timer = timer_alloc(device->machine, sh2_timer_callback, sh2);
 	timer_adjust_oneshot(sh2->timer, attotime_never, 0);
@@ -709,7 +712,7 @@ void sh2_common_init(SH2 *sh2, const device_config *device, cpu_irq_callback irq
 	sh2->dma_timer[1] = timer_alloc(device->machine, sh2_dmac_callback, sh2);
 	timer_adjust_oneshot(sh2->dma_timer[1], attotime_never, 0);
 
-	sh2->m = auto_malloc(0x200);
+	sh2->m = auto_alloc_array(device->machine, UINT32, 0x200/4);
 
 	if(conf)
 	{
