@@ -160,7 +160,7 @@ static int get_register_string_max_width(const device_config *device, void *base
 INLINE cpu_class_data *get_class_data(const device_config *device)
 {
 	assert(device != NULL);
-	assert(device->class == DEVICE_CLASS_CPU_CHIP);
+	assert(device->devclass == DEVICE_CLASS_CPU_CHIP);
 	assert(device->token != NULL);
 	return (cpu_class_data *)cpu_get_class_header(device) - 1;
 }
@@ -223,8 +223,7 @@ void cpuexec_init(running_machine *machine)
 	attotime min_quantum;
 
 	/* allocate global state */
-	machine->cpuexec_data = auto_malloc(sizeof(*machine->cpuexec_data));
-	memset(machine->cpuexec_data, 0, sizeof(*machine->cpuexec_data));
+	machine->cpuexec_data = auto_alloc_clear(machine, cpuexec_private);
 
 	/* set the core scheduling quantum */
 	min_quantum = machine->config->minimum_quantum;
@@ -423,7 +422,7 @@ const char *cpuexec_describe_context(running_machine *machine)
 
 	/* if we have an executing CPU, output data */
 	if (executingcpu != NULL)
-		sprintf(global->statebuf, "'%s'(%08X)", executingcpu->tag, cpu_get_pc(executingcpu));
+		sprintf(global->statebuf, "'%s' (%08X)", executingcpu->tag, cpu_get_pc(executingcpu));
 	else
 		strcpy(global->statebuf, "(no context)");
 
@@ -433,7 +432,7 @@ const char *cpuexec_describe_context(running_machine *machine)
 
 
 /***************************************************************************
-    VIDEO SCREEN DEVICE INTERFACE
+    CPU DEVICE INTERFACE
 ***************************************************************************/
 
 /*-------------------------------------------------
@@ -457,7 +456,7 @@ static DEVICE_START( cpu )
 	assert(device->machine->config != NULL);
 
 	/* get pointers to our data */
-	config = device->inline_config;
+	config = (const cpu_config *)device->inline_config;
 	header = cpu_get_class_header(device);
 	classdata = get_class_data(device);
 
@@ -536,15 +535,13 @@ static DEVICE_START( cpu )
 	/* if no state registered for saving, we can't save */
 	if (num_regs == 0)
 	{
-		logerror("CPU '%s' did not register any state to save!\n", cpu_get_name(device));
+		logerror("CPU '%s' did not register any state to save!\n", device->tag);
 		if (device->machine->gamedrv->flags & GAME_SUPPORTS_SAVE)
-			fatalerror("CPU '%s' did not register any state to save!", cpu_get_name(device));
+			fatalerror("CPU '%s' did not register any state to save!", device->tag);
 	}
 
 	/* register some internal states as well */
 	register_save_states(device);
-
-	return DEVICE_START_OK;
 }
 
 
@@ -555,7 +552,7 @@ static DEVICE_START( cpu )
 static DEVICE_RESET( cpu )
 {
 	cpu_class_data *classdata = get_class_data(device);
-	const cpu_config *config = device->inline_config;
+	const cpu_config *config = (const cpu_config *)device->inline_config;
 	cpu_reset_func reset;
 	int line;
 
@@ -590,7 +587,7 @@ static DEVICE_RESET( cpu )
 
 		/* new style - use screen tag directly */
 		if (config->vblank_interrupt_screen != NULL)
-			screen = devtag_get_device(device->machine, VIDEO_SCREEN, config->vblank_interrupt_screen);
+			screen = devtag_get_device(device->machine, config->vblank_interrupt_screen);
 
 		/* old style 'hack' setup - use screen #0 */
 		else
@@ -629,7 +626,7 @@ static DEVICE_STOP( cpu )
     cpu_set_info - device set info callback
 -------------------------------------------------*/
 
-static DEVICE_SET_INFO( cpu )
+void cpu_set_info(const device_config *device, UINT32 state, UINT64 value)
 {
 	cpu_class_header *header = cpu_get_class_header(device);
 	cpu_set_info_func set_info;
@@ -654,25 +651,17 @@ static DEVICE_SET_INFO( cpu )
 				{
 					if (state >= CPUINFO_INT_REGISTER && state <= CPUINFO_INT_REGISTER_LAST)
 					{
-						set_register_value(device, classdata->state->baseptr, classdata->regstate[state - CPUINFO_INT_REGISTER], info->i);
+						set_register_value(device, classdata->state->baseptr, classdata->regstate[state - CPUINFO_INT_REGISTER], value);
 						return;
 					}
 				}
 			}
 
 			/* integer data */
+			assert(state >= DEVINFO_INT_FIRST && state <= DEVINFO_INT_LAST);
 			if (state >= DEVINFO_INT_FIRST && state <= DEVINFO_INT_LAST)
 			{
-				cinfo.i = info->i;
-				(*set_info)(device, state, &cinfo);
-			}
-
-			/* pointer data */
-			else if ((state >= DEVINFO_PTR_FIRST && state <= DEVINFO_PTR_LAST) ||
-					 (state >= DEVINFO_FCT_FIRST && state <= DEVINFO_FCT_LAST) ||
-					 (state >= DEVINFO_STR_FIRST && state <= DEVINFO_STR_LAST))
-			{
-				cinfo.p = info->p;
+				cinfo.i = value;
 				(*set_info)(device, state, &cinfo);
 			}
 			break;
@@ -687,7 +676,7 @@ static DEVICE_SET_INFO( cpu )
 
 DEVICE_GET_INFO( cpu )
 {
-	const cpu_config *config = (device != NULL) ? device->inline_config : NULL;
+	const cpu_config *config = (device != NULL) ? (const cpu_config *)device->inline_config : NULL;
 	cpuinfo cinfo = { 0 };
 
 	switch (state)
@@ -703,12 +692,15 @@ DEVICE_GET_INFO( cpu )
 		case DEVINFO_INT_CLASS:					info->i = DEVICE_CLASS_CPU_CHIP;			break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:				info->set_info = DEVICE_SET_INFO_NAME(cpu); break;
 		case DEVINFO_FCT_START:					info->start = DEVICE_START_NAME(cpu); 		break;
 		case DEVINFO_FCT_STOP:					info->stop = DEVICE_STOP_NAME(cpu); 		break;
 		case DEVINFO_FCT_RESET:					info->reset = DEVICE_RESET_NAME(cpu); 		break;
 
 		default:
+			/* if we don't have a device pointer, ignore everything else */
+			if (device == NULL)
+				break;
+
 			/* if we have a state pointer, we can handle some stuff for free */
 			if (device->token != NULL)
 			{
@@ -1361,7 +1353,7 @@ static void on_vblank(const device_config *device, void *param, int vblank_state
 		/* find any CPUs that have this screen as their VBLANK interrupt source */
 		for (cpu = device->machine->cpu[0]; cpu != NULL; cpu = cpu->typenext)
 		{
-			const cpu_config *config = cpu->inline_config;
+			const cpu_config *config = (const cpu_config *)cpu->inline_config;
 			cpu_class_data *classdata = get_class_data(cpu);
 			int cpu_interested;
 
@@ -1408,8 +1400,8 @@ static void on_vblank(const device_config *device, void *param, int vblank_state
 
 static TIMER_CALLBACK( trigger_partial_frame_interrupt )
 {
-	const device_config *device = ptr;
-	const cpu_config *config = device->inline_config;
+	const device_config *device = (const device_config *)ptr;
+	const cpu_config *config = (const cpu_config *)device->inline_config;
 	cpu_class_data *classdata = get_class_data(device);
 
 	if (classdata->iloops == 0)
@@ -1434,8 +1426,8 @@ static TIMER_CALLBACK( trigger_partial_frame_interrupt )
 
 static TIMER_CALLBACK( trigger_periodic_interrupt )
 {
-	const device_config *device = ptr;
-	const cpu_config *config = device->inline_config;
+	const device_config *device = (const device_config *)ptr;
+	const cpu_config *config = (const cpu_config *)device->inline_config;
 
 	/* bail if there is no routine */
 	if (config->timed_interrupt != NULL && !cpu_is_suspended(device, SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
@@ -1460,7 +1452,7 @@ static TIMER_CALLBACK( triggertime_callback )
 
 static TIMER_CALLBACK( empty_event_queue )
 {
-	const device_config *device = ptr;
+	const device_config *device = (const device_config *)ptr;
 	cpu_class_data *classdata = get_class_data(device);
 	cpu_input_data *inputline = &classdata->input[param];
 	int curevent;
@@ -1513,17 +1505,17 @@ static TIMER_CALLBACK( empty_event_queue )
 			switch (state)
 			{
 				case PULSE_LINE:
-					device_set_info_int(device, CPUINFO_INT_INPUT_STATE + param, ASSERT_LINE);
-					device_set_info_int(device, CPUINFO_INT_INPUT_STATE + param, CLEAR_LINE);
+					cpu_set_info(device, CPUINFO_INT_INPUT_STATE + param, ASSERT_LINE);
+					cpu_set_info(device, CPUINFO_INT_INPUT_STATE + param, CLEAR_LINE);
 					break;
 
 				case HOLD_LINE:
 				case ASSERT_LINE:
-					device_set_info_int(device, CPUINFO_INT_INPUT_STATE + param, ASSERT_LINE);
+					cpu_set_info(device, CPUINFO_INT_INPUT_STATE + param, ASSERT_LINE);
 					break;
 
 				case CLEAR_LINE:
-					device_set_info_int(device, CPUINFO_INT_INPUT_STATE + param, CLEAR_LINE);
+					cpu_set_info(device, CPUINFO_INT_INPUT_STATE + param, CLEAR_LINE);
 					break;
 
 				default:
@@ -1560,7 +1552,7 @@ static IRQ_CALLBACK( standard_irq_callback )
 	if (inputline->curstate == HOLD_LINE)
 	{
 		LOG(("->set_irq_line('%s',%d,%d)\n", device->tag, irqline, CLEAR_LINE));
-		device_set_info_int(device, CPUINFO_INT_INPUT_STATE + irqline, CLEAR_LINE);
+		cpu_set_info(device, CPUINFO_INT_INPUT_STATE + irqline, CLEAR_LINE);
 		inputline->curstate = CLEAR_LINE;
 	}
 
