@@ -78,7 +78,7 @@ static const help_item static_help_list[] =
 		"\n"
 		"  help [<topic>] -- get help on a particular topic\n"
 		"  do <expression> -- evaluates the given expression\n"
-		"  symlist [<cpunum>] -- lists registered symbols\n"
+		"  symlist [<cpu>] -- lists registered symbols\n"
 		"  softreset -- executes a soft reset\n"
 		"  hardreset -- executes a hard reset\n"
 		"  print <item>[,...] -- prints one or more <item>s to the console\n"
@@ -95,16 +95,16 @@ static const help_item static_help_list[] =
 		"Memory Commands\n"
 		"Type help <command> for further details on each command\n"
 		"\n"
-		"  dasm <filename>,<address>,<length>[,<opcodes>[,<cpunum>]] -- disassemble to the given file\n"
+		"  dasm <filename>,<address>,<length>[,<opcodes>[,<cpu>]] -- disassemble to the given file\n"
 		"  f[ind] <address>,<length>[,<data>[,...]] -- search program memory for data\n"
 		"  f[ind]d <address>,<length>[,<data>[,...]] -- search data memory for data\n"
 		"  f[ind]i <address>,<length>[,<data>[,...]] -- search I/O memory for data\n"
-		"  dump <filename>,<address>,<length>[,<size>[,<ascii>[,<cpunum>]]] -- dump program memory as text\n"
-		"  dumpd <filename>,<address>,<length>[,<size>[,<ascii>[,<cpunum>]]] -- dump data memory as text\n"
-		"  dumpi <filename>,<address>,<length>[,<size>[,<ascii>[,<cpunum>]]] -- dump I/O memory as text\n"
-		"  save <filename>,<address>,<length>[,<cpunum>] -- save binary program memory to the given file\n"
-		"  saved <filename>,<address>,<length>[,<cpunum>] -- save binary data memory to the given file\n"
-		"  savei <filename>,<address>,<length>[,<cpunum>] -- save binary I/O memory to the given file\n"
+		"  dump <filename>,<address>,<length>[,<size>[,<ascii>[,<cpu>]]] -- dump program memory as text\n"
+		"  dumpd <filename>,<address>,<length>[,<size>[,<ascii>[,<cpu>]]] -- dump data memory as text\n"
+		"  dumpi <filename>,<address>,<length>[,<size>[,<ascii>[,<cpu>]]] -- dump I/O memory as text\n"
+		"  save <filename>,<address>,<length>[,<cpu>] -- save binary program memory to the given file\n"
+		"  saved <filename>,<address>,<length>[,<cpu>] -- save binary data memory to the given file\n"
+		"  savei <filename>,<address>,<length>[,<cpu>] -- save binary I/O memory to the given file\n"
 		"  map <address> -- map logical program address to physical address and bank\n"
 		"  mapd <address> -- map logical data address to physical address and bank\n"
 		"  mapi <address> -- map logical I/O address to physical address and bank\n"
@@ -116,19 +116,19 @@ static const help_item static_help_list[] =
 		"Execution Commands\n"
 		"Type help <command> for further details on each command\n"
 		"\n"
-		"  s[tep] [<count>=1] -- single steps for <count> instructions (F12)\n"
-		"  o[ver] [<count>=1] -- single steps over <count> instructions (F11)\n"
+		"  s[tep] [<count>=1] -- single steps for <count> instructions (F11)\n"
+		"  o[ver] [<count>=1] -- single steps over <count> instructions (F10)\n"
 		"  out -- single steps until the current subroutine/exception handler is exited (Shift-F11)\n"
 		"  g[o] [<address>] -- resumes execution, sets temp breakpoint at <address> (F5)\n"
 		"  gi[nt] [<irqline>] -- resumes execution, setting temp breakpoint if <irqline> is taken (F7)\n"
 		"  gt[ime] <milliseconds> -- resumes execution until the given delay has elapsed\n"
 		"  gv[blank] -- resumes execution, setting temp breakpoint on the next VBLANK (F8)\n"
 		"  n[ext] -- executes until the next CPU switch (F6)\n"
-		"  focus <cpunum> -- focuses debugger only on <cpunum>\n"
-		"  ignore [<cpunum>[,<cpunum>[,...]]] -- stops debugging on <cpunum>\n"
-		"  observe [<cpunum>[,<cpunum>[,...]]] -- resumes debugging on <cpunum>\n"
-		"  trace {<filename>|OFF}[,<cpunum>[,<action>]] -- trace the given CPU to a file (defaults to active CPU)\n"
-		"  traceover {<filename>|OFF}[,<cpunum>[,<action>]] -- trace the given CPU to a file, but skip subroutines (defaults to active CPU)\n"
+		"  focus <cpu> -- focuses debugger only on <cpu>\n"
+		"  ignore [<cpu>[,<cpu>[,...]]] -- stops debugging on <cpu>\n"
+		"  observe [<cpu>[,<cpu>[,...]]] -- resumes debugging on <cpu>\n"
+		"  trace {<filename>|OFF}[,<cpu>[,<action>]] -- trace the given CPU to a file (defaults to active CPU)\n"
+		"  traceover {<filename>|OFF}[,<cpu>[,<action>]] -- trace the given CPU to a file, but skip subroutines (defaults to active CPU)\n"
 		"  traceflush -- flushes all open trace files\n"
 	},
 	{
@@ -156,7 +156,7 @@ static const help_item static_help_list[] =
 		"  wpdisable [<wpnum>] -- disables a given watchpoint or all if no <wpnum> specified\n"
 		"  wpenable [<wpnum>] -- enables a given watchpoint or all if no <wpnum> specified\n"
 		"  wplist -- lists all the watchpoints\n"
-		"  hotspot [<cpunum>,[<depth>[,<hits>]]] -- attempt to find hotspots\n"
+		"  hotspot [<cpu>,[<depth>[,<hits>]]] -- attempt to find hotspots\n"
 	},
 	{
 		"expressions",
@@ -219,10 +219,10 @@ static const help_item static_help_list[] =
 	{
 		"symlist",
 		"\n"
-		"  symlist [<cpunum>]\n"
+		"  symlist [<cpu>]\n"
 		"\n"
-		"Lists registered symbols. If <cpunum> is not specified, then symbols in the global symbol table are "
-		"displayed; otherwise, the symbols for <cpunum>'s specific CPU are displayed. Symbols are listed "
+		"Lists registered symbols. If <cpu> is not specified, then symbols in the global symbol table are "
+		"displayed; otherwise, the symbols for <cpu>'s specific CPU are displayed. Symbols are listed "
 		"alphabetically. Read-only symbols are flagged with an asterisk.\n"
 		"\n"
 		"Examples:\n"
@@ -377,14 +377,14 @@ static const help_item static_help_list[] =
 	{
 		"dasm",
 		"\n"
-		"  dasm <filename>,<address>,<length>[,<opcodes>[,<cpunum>]]\n"
+		"  dasm <filename>,<address>,<length>[,<opcodes>[,<cpu>]]\n"
 		"\n"
 		"The dasm command disassembles program memory to the file specified in the <filename> parameter. "
 		"<address> indicates the address of the start of disassembly, and <length> indicates how much "
 		"memory to disassemble. The range <address> through <address>+<length>-1 inclusive will be "
 		"output to the file. By default, the raw opcode data is output with each line. The optional "
 		"<opcodes> parameter can be used to enable (1) or disable(0) this feature. Finally, you can "
-		"disassemble code from another CPU by specifying the <cpunum> parameter.\n"
+		"disassemble code from another CPU by specifying the <cpu> parameter.\n"
 		"\n"
 		"Examples:\n"
 		"\n"
@@ -431,7 +431,7 @@ static const help_item static_help_list[] =
 	{
 		"dump",
 		"\n"
-		"  dump[{d|i}] <filename>,<address>,<length>[,<size>[,<ascii>[,<cpunum>]]]\n"
+		"  dump[{d|i}] <filename>,<address>,<length>[,<size>[,<ascii>[,<cpu>]]]\n"
 		"\n"
 		"The dump/dumpd/dumpi commands dump memory to the text file specified in the <filename> "
 		"parameter. 'dump' will dump program space memory, while 'dumpd' will dump data space memory "
@@ -442,7 +442,7 @@ static const help_item static_help_list[] =
 		"<size> parameter, which can be used to group the data in 1, 2, 4 or 8-byte chunks. The optional "
 		"<ascii> parameter can be used to enable (1) or disable (0) the output of ASCII characters to the "
 		"right of each line; by default, this is enabled. Finally, you can dump memory from another CPU "
-		"by specifying the <cpunum> parameter.\n"
+		"by specifying the <cpu> parameter.\n"
 		"\n"
 		"Examples:\n"
 		"\n"
@@ -457,14 +457,14 @@ static const help_item static_help_list[] =
 	{
 		"save",
 		"\n"
-		"  save[{d|i}] <filename>,<address>,<length>[,<cpunum>]\n"
+		"  save[{d|i}] <filename>,<address>,<length>[,<cpu>]\n"
 		"\n"
 		"The save/saved/savei commands save raw memory to the binary file specified in the <filename> "
 		"parameter. 'save' will save program space memory, while 'saved' will save data space memory "
 		"and 'savei' will save I/O space memory. <address> indicates the address of the start of saving, "
 		"and <length> indicates how much memory to save. The range <address> through <address>+<length>-1 "
 		"inclusive will be output to the file. You can also save memory from another CPU by specifying the "
-		"<cpunum> parameter.\n"
+		"<cpu> parameter.\n"
 		"\n"
 		"Examples:\n"
 		"\n"
@@ -610,9 +610,9 @@ static const help_item static_help_list[] =
 	{
 		"focus",
 		"\n"
-		"  focus <cpunum>\n"
+		"  focus <cpu>\n"
 		"\n"
-		"Sets the debugger focus exclusively to the given <cpunum>. This is equivalent to specifying "
+		"Sets the debugger focus exclusively to the given <cpu>. This is equivalent to specifying "
 		"'ignore' on all other CPUs.\n"
 		"\n"
 		"Examples:\n"
@@ -623,11 +623,11 @@ static const help_item static_help_list[] =
 	{
 		"ignore",
 		"\n"
-		"  ignore [<cpunum>[,<cpunum>[,...]]]\n"
+		"  ignore [<cpu>[,<cpu>[,...]]]\n"
 		"\n"
-		"Ignores the specified <cpunum> in the debugger. This means that you won't ever see execution "
+		"Ignores the specified <cpu> in the debugger. This means that you won't ever see execution "
 		"on that CPU, nor will you be able to set breakpoints on that CPU. To undo this change use "
-		"the 'observe' command. You can specify multiple <cpunum>s in a single command. Note also that "
+		"the 'observe' command. You can specify multiple <cpu>s in a single command. Note also that "
 		"you are not permitted to ignore all CPUs; at least one must be active at all times.\n"
 		"\n"
 		"Examples:\n"
@@ -644,10 +644,10 @@ static const help_item static_help_list[] =
 	{
 		"observe",
 		"\n"
-		"  observe [<cpunum>[,<cpunum>[,...]]]\n"
+		"  observe [<cpu>[,<cpu>[,...]]]\n"
 		"\n"
-		"Re-enables interaction with the specified <cpunum> in the debugger. This command undoes the "
-		"effects of the 'ignore' command. You can specify multiple <cpunum>s in a single command.\n"
+		"Re-enables interaction with the specified <cpu> in the debugger. This command undoes the "
+		"effects of the 'ignore' command. You can specify multiple <cpu>s in a single command.\n"
 		"\n"
 		"Examples:\n"
 		"\n"
@@ -663,9 +663,9 @@ static const help_item static_help_list[] =
 	{
 		"trace",
 		"\n"
-		"  trace {<filename>|OFF}[,<cpunum>[,<action>]]\n"
+		"  trace {<filename>|OFF}[,<cpu>[,<action>]]\n"
 		"\n"
-		"Starts or stops tracing of the execution of the specified <cpunum>. If <cpunum> is omitted, "
+		"Starts or stops tracing of the execution of the specified <cpu>. If <cpu> is omitted, "
 		"the currently active CPU is specified. When enabling tracing, specify the filename in the "
 		"<filename> parameter. To disable tracing, substitute the keyword 'off' for <filename>. If you "
 		"wish to log additional information on each trace, you can append an <action> parameter which "
@@ -695,13 +695,13 @@ static const help_item static_help_list[] =
 	{
 		"traceover",
 		"\n"
-		"  traceover {<filename>|OFF}[,<cpunum>[,<action>]]\n"
+		"  traceover {<filename>|OFF}[,<cpu>[,<action>]]\n"
 		"\n"
-		"Starts or stops tracing of the execution of the specified <cpunum>. When tracing reaches "
+		"Starts or stops tracing of the execution of the specified <cpu>. When tracing reaches "
 		"a subroutine or call, tracing will skip over the subroutine. The same algorithm is used as is "
 		"used in the step over command. This means that traceover will not work properly when calls "
 		"are recusive or the return address is not immediately following the call instruction. If "
-		"<cpunum> is omitted, the currently active CPU is specified. When enabling tracing, specify the "
+		"<cpu> is omitted, the currently active CPU is specified. When enabling tracing, specify the "
 		"filename in the <filename> parameter. To disable tracing, substitute the keyword 'off' for "
 		"<filename>. If you wish to log additional information on each trace, you can append an <action> "
 		"parameter which is a command that is executed before each trace is logged. Generally, this is "
@@ -929,10 +929,10 @@ static const help_item static_help_list[] =
 	{
 		"hotspot",
 		"\n"
-		"  hotspot [<cpunum>,[<depth>[,<hits>]]]\n"
+		"  hotspot [<cpu>,[<depth>[,<hits>]]]\n"
 		"\n"
 		"The hotspot command attempts to help locate hotspots in the code where speedup opportunities "
-		"might be present. <cpunum>, which defaults to the currently active CPU, specified which "
+		"might be present. <cpu>, which defaults to the currently active CPU, specified which "
 		"processor's memory to track. <depth>, which defaults to 64, controls the depth of the search "
 		"buffer. The search buffer tracks the last <depth> memory reads from unique PCs. The <hits> "
 		"parameter, which defaults to 250, specifies the minimum number of hits to report.\n"
