@@ -120,7 +120,7 @@ static void duart68681_update_interrupts(duart68681_state *duart68681)
 
 static TIMER_CALLBACK( duart_timer_callback )
 {
-	const device_config *device = ptr;
+	const device_config *device = (const device_config *)ptr;
 	duart68681_state	*duart68681 = get_safe_token(device);
 
 	duart68681->ISR |= INT_COUNTER_READY;
@@ -275,7 +275,7 @@ static UINT8 duart68681_read_rx_fifo(duart68681_state *duart68681, int ch)
 
 static TIMER_CALLBACK( tx_timer_callback )
 {
-	const device_config *device = ptr;
+	const device_config *device = (const device_config *)ptr;
 	duart68681_state	*duart68681 = get_safe_token(device);
 	int ch = param & 1;
 
@@ -399,10 +399,10 @@ READ8_DEVICE_HANDLER(duart68681_r)
 			{
 				case 0x07: /* Timer, CLK/16 */
 					{
-						double hz;
+						//double hz;
 						//attotime rate = attotime_mul(ATTOTIME_IN_HZ(duart68681->clock), 16*duart68681->CTR.w.l);
 						attotime rate = ATTOTIME_IN_HZ(2*device->clock/(2*16*16*duart68681->CTR.w.l));
-						hz = ATTOSECONDS_TO_HZ(rate.attoseconds);
+						//hz = ATTOSECONDS_TO_HZ(rate.attoseconds);
 						timer_adjust_periodic(duart68681->duart_timer, rate, 0, rate);
 					}
 					break;
@@ -581,8 +581,6 @@ static DEVICE_START(duart68681)
 	state_save_register_device_item(device, 0, duart68681->channel[1].tx_enabled);
 	state_save_register_device_item(device, 0, duart68681->channel[1].tx_data);
 	state_save_register_device_item(device, 0, duart68681->channel[1].tx_ready);
-
-	return DEVICE_START_OK;
 }
 
 /*-------------------------------------------------
@@ -594,7 +592,7 @@ static DEVICE_RESET(duart68681)
 	duart68681_state *duart68681 = get_safe_token(device);
 
 	memset(duart68681, 0, sizeof(duart68681_state));
-	duart68681->duart_config = device->static_config;
+	duart68681->duart_config = (const duart68681_config *)device->static_config;
 	duart68681->device = device;
 	duart68681->IVR = 0x0f;
 
@@ -608,18 +606,6 @@ static DEVICE_RESET(duart68681)
 	duart68681->duart_timer = timer_alloc(device->machine, duart_timer_callback, (void*)device);
 }
 
-/*-------------------------------------------------
-    device set info callback
--------------------------------------------------*/
-
-static DEVICE_SET_INFO(duart68681)
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
 /*-------------------------------------------------
     device get info callback
 -------------------------------------------------*/
@@ -634,7 +620,6 @@ DEVICE_GET_INFO(duart68681)
 		case DEVINFO_INT_CLASS:					info->i = DEVICE_CLASS_PERIPHERAL;		break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:				info->set_info = DEVICE_SET_INFO_NAME(duart68681); break;
 		case DEVINFO_FCT_START:					info->start = DEVICE_START_NAME(duart68681); break;
 		case DEVINFO_FCT_STOP:					/* nothing */ break;
 		case DEVINFO_FCT_RESET:					info->reset = DEVICE_RESET_NAME(duart68681);break;
