@@ -15,7 +15,6 @@
 #define __LASERDSC_H__
 
 #include "chd.h"
-#include "sound/custom.h"
 
 
 
@@ -26,6 +25,7 @@
 /* types of players supported */
 enum
 {
+	LASERDISC_TYPE_UNKNOWN,
 	LASERDISC_TYPE_PIONEER_PR7820,			/* Pioneer PR-7820 */
 	LASERDISC_TYPE_PIONEER_PR8210,			/* Pioneer PR-8210 / LD-V1100 */
 	LASERDISC_TYPE_SIMUTREK_SPECIAL,		/* Pioneer PR-8210 with mods */
@@ -55,12 +55,6 @@ enum
 #define LASERDISC_CODE_LINE18		18			/* 24-bit line 18 code */
 #define LASERDISC_CODE_LINE1718		1718		/* 24-bit best of line 17/18 code */
 
-/* device configuration */
-enum
-{
-	LDINFO_INT_TYPE = DEVINFO_INT_DEVICE_SPECIFIC
-};
-
 
 
 /***************************************************************************
@@ -128,9 +122,6 @@ struct _laserdisc_config
 	MDRV_DEVICE_CONFIG_DATAFP32(laserdisc_config, overscalex, _scalex, 24) \
 	MDRV_DEVICE_CONFIG_DATAFP32(laserdisc_config, overscaley, _scaley, 24)
 
-#define MDRV_LASERDISC_REMOVE(_tag, _type) \
-	MDRV_DEVICE_REMOVE(_tag, _type)
-
 
 /* use these to add laserdisc screens with proper video update parameters */
 #define MDRV_LASERDISC_SCREEN_ADD_NTSC(_tag, _overlayformat) \
@@ -152,14 +143,6 @@ struct _laserdisc_config
 
 
 
-/***************************************************************************
-    GLOBAL VARIABLES
-***************************************************************************/
-
-extern const custom_sound_interface laserdisc_custom_interface;
-
-
-
 /***************************************************************************
     FUNCTION PROTOTYPES
 ***************************************************************************/
@@ -233,5 +216,13 @@ void laserdisc_set_config(const device_config *device, const laserdisc_config *c
 #define LASERDISC DEVICE_GET_INFO_NAME(laserdisc)
 DEVICE_GET_INFO( laserdisc );
 
+/* audio get info callback */
+#define SOUND_LASERDISC DEVICE_GET_INFO_NAME(laserdisc_sound)
+DEVICE_GET_INFO( laserdisc_sound );
+
+/* type setter */
+int laserdisc_get_type(const device_config *device);
+void laserdisc_set_type(const device_config *device, int type);
+
 
 #endif 	/* __LASERDSC_H__ */
