@@ -211,20 +211,18 @@ static DEVICE_START( pci_bus )
 	assert(device->machine->config != NULL);
 
 	/* store a pointer back to the device */
-	pcibus->config = device->inline_config;
+	pcibus->config = (const pci_bus_config *)device->inline_config;
 	pcibus->busdevice = device;
 	pcibus->devicenum = -1;
 
 	/* find all our devices */
 	for (devicenum = 0; devicenum < ARRAY_LENGTH(pcibus->device); devicenum++)
 		if (pcibus->config->device[devicenum].devtag != NULL)
-			pcibus->device[devicenum] = devtag_get_device(device->machine, pcibus->config->device[devicenum].devtype, pcibus->config->device[devicenum].devtag);
+			pcibus->device[devicenum] = devtag_get_device(device->machine, pcibus->config->device[devicenum].devtag);
 
 	/* register pci states */
 	state_save_register_device_item(device, 0, pcibus->address);
 	state_save_register_device_item(device, 0, pcibus->devicenum);
-
-	return DEVICE_START_OK;
 }
 
 
@@ -242,19 +240,6 @@ static DEVICE_RESET( pci_bus )
 }
 
 
-/*-------------------------------------------------
-    device set info callback
--------------------------------------------------*/
-
-static DEVICE_SET_INFO( pci_bus )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
 /*-------------------------------------------------
     device get info callback
 -------------------------------------------------*/
@@ -269,7 +254,6 @@ DEVICE_GET_INFO( pci_bus )
 		case DEVINFO_INT_CLASS:					info->i = DEVICE_CLASS_PERIPHERAL;		break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:				info->set_info = DEVICE_SET_INFO_NAME(pci_bus); break;
 		case DEVINFO_FCT_START:					info->start = DEVICE_START_NAME(pci_bus); break;
 		case DEVINFO_FCT_RESET:					info->reset = DEVICE_RESET_NAME(pci_bus);break;
 
