@@ -657,7 +657,7 @@ static void	update(const device_config *device, struct pit8253_timer *timer)
 
 static TIMER_CALLBACK( update_timer_cb )
 {
-	const device_config *device = ptr;
+	const device_config *device = (const device_config *)ptr;
 	pit8253_t	*pit8253 = get_safe_token(device);
 	struct pit8253_timer *timer = get_timer(pit8253,param);
 
@@ -1038,11 +1038,11 @@ void pit8253_set_clock_signal(const device_config *device, int timerno, int stat
 }
 
 
-static device_start_err common_start( const device_config *device, int device_type ) {
+static void common_start( const device_config *device, int device_type ) {
 	pit8253_t	*pit8253 = get_safe_token(device);
 	int			timerno;
 
-	pit8253->config = device->static_config;
+	pit8253->config = (const struct pit8253_config *)device->static_config;
 	pit8253->device_type = device_type;
 
 	/* register for state saving */
@@ -1077,18 +1077,16 @@ static device_start_err common_start( const device_config *device, int device_ty
 		state_save_register_device_item(device, timerno, timer->last_updated.attoseconds);
 		state_save_register_device_item(device, timerno, timer->clock);
 	}
-
-	return DEVICE_START_OK;
 }
 
 
 static DEVICE_START( pit8253 ) {
-	return common_start( device, TYPE_PIT8253 );
+	common_start( device, TYPE_PIT8253 );
 }
 
 
 static DEVICE_START( pit8254 ) {
-	return common_start( device, TYPE_PIT8254 );
+	common_start( device, TYPE_PIT8254 );
 }
 
 
@@ -1121,13 +1119,6 @@ static DEVICE_RESET( pit8253 ) {
 }
 
 
-static DEVICE_SET_INFO( pit8253 ) {
-	switch ( state ) {
-		/* no parameters to set */
-	}
-}
-
-
 DEVICE_GET_INFO( pit8253 ) {
 	switch ( state ) {
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
@@ -1136,7 +1127,6 @@ DEVICE_GET_INFO( pit8253 ) {
 		case DEVINFO_INT_CLASS:						info->i = DEVICE_CLASS_PERIPHERAL;			break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:					info->set_info = DEVICE_SET_INFO_NAME(pit8253);	break;
 		case DEVINFO_FCT_START:						info->start = DEVICE_START_NAME(pit8253);	break;
 		case DEVINFO_FCT_STOP:						/* nothing */								break;
 		case DEVINFO_FCT_RESET:						info->reset = DEVICE_RESET_NAME(pit8253);	break;
