@@ -42,10 +42,10 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 {
 	UINT8 *command;
 	int commandLength;
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 
 	cdrom_file *cdrom = our_this->cdrom;
-	int cddanum;
+	const device_config *cdda;
 	int trk;
 
 	SCSIGetCommand( scsiInstance, &command, &commandLength );
@@ -71,10 +71,10 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 			return SCSILengthFromUINT8( &command[ 4 ] );
 
 		case 0x1b: // START STOP UNIT
-			cddanum = cdda_num_from_cdrom(cdrom);
-			if (cddanum != -1)
+			cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+			if (cdda != NULL)
 			{
-				cdda_stop_audio(cddanum);
+				cdda_stop_audio(cdda);
 			}
 			SCSISetPhase( scsiInstance, SCSI_PHASE_STATUS );
 			return 0;
@@ -104,10 +104,10 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 				our_this->cur_subblock = 0;
 			}
 
-			cddanum = cdda_num_from_cdrom(cdrom);
-			if (cddanum != -1)
+			cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+			if (cdda != NULL)
 			{
-				cdda_stop_audio(cddanum);
+				cdda_stop_audio(cdda);
 			}
 
 			SCSISetPhase( scsiInstance, SCSI_PHASE_DATAIN );
@@ -144,10 +144,10 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 				length = 4;
 			}
 
-			cddanum = cdda_num_from_cdrom(cdrom);
-			if (cddanum != -1)
+			cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+			if (cdda != NULL)
 			{
-				cdda_stop_audio(cddanum);
+				cdda_stop_audio(cdda);
 			}
 
 			SCSISetPhase( scsiInstance, SCSI_PHASE_DATAIN );
@@ -174,9 +174,9 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 			if (cdrom_get_track_type(cdrom, trk) == CD_TRACK_AUDIO)
 			{
 				our_this->play_err_flag = 0;
-				cddanum = cdda_num_from_cdrom(cdrom);
-				if (cddanum != -1)
-					cdda_start_audio(cddanum, our_this->lba, our_this->blocks);
+				cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+				if (cdda != NULL)
+					cdda_start_audio(cdda, our_this->lba, our_this->blocks);
 			}
 			else
 			{
@@ -204,9 +204,9 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 
 			if (our_this->blocks && cdrom)
 			{
-				cddanum = cdda_num_from_cdrom(cdrom);
-				if (cddanum != -1)
-					cdda_start_audio(cddanum, our_this->lba, our_this->blocks);
+				cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+				if (cdda != NULL)
+					cdda_start_audio(cdda, our_this->lba, our_this->blocks);
 			}
 
 			logerror("SCSICD: PLAY AUDIO T/I: strk %d idx %d etrk %d idx %d frames %d\n", command[4], command[5], command[7], command[8], our_this->blocks);
@@ -216,9 +216,9 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 		case 0x4b: // PAUSE/RESUME
 			if (cdrom)
 			{
-				cddanum = cdda_num_from_cdrom(cdrom);
-				if (cddanum != -1)
-					cdda_pause_audio(cddanum, (command[8] & 0x01) ^ 0x01);
+				cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+				if (cdda != NULL)
+					cdda_pause_audio(cdda, (command[8] & 0x01) ^ 0x01);
 			}
 
 			logerror("SCSICD: PAUSE/RESUME: %s\n", command[8]&1 ? "RESUME" : "PAUSE");
@@ -255,9 +255,9 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 			if (cdrom_get_track_type(cdrom, trk) == CD_TRACK_AUDIO)
 			{
 				our_this->play_err_flag = 0;
-				cddanum = cdda_num_from_cdrom(cdrom);
-				if (cddanum != -1)
-					cdda_start_audio(cddanum, our_this->lba, our_this->blocks);
+				cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+				if (cdda != NULL)
+					cdda_start_audio(cdda, our_this->lba, our_this->blocks);
 			}
 			else
 			{
@@ -283,10 +283,10 @@ static int scsicd_exec_command( SCSIInstance *scsiInstance, UINT8 *statusCode )
 				our_this->cur_subblock = 0;
 			}
 
-			cddanum = cdda_num_from_cdrom(cdrom);
-			if (cddanum != -1)
+			cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+			if (cdda != NULL)
 			{
-				cdda_stop_audio(cddanum);
+				cdda_stop_audio(cdda);
 			}
 
 			SCSISetPhase( scsiInstance, SCSI_PHASE_DATAIN );
@@ -310,14 +310,14 @@ static void scsicd_read_data( SCSIInstance *scsiInstance, UINT8 *data, int dataL
 {
 	UINT8 *command;
 	int commandLength;
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 
 	int i;
 	UINT32 last_phys_frame;
 	cdrom_file *cdrom = our_this->cdrom;
 	UINT32 temp;
 	UINT8 tmp_buffer[2048];
-	int cddanum;
+	const device_config *cdda;
 
 	SCSIGetCommand( scsiInstance, &command, &commandLength );
 
@@ -330,8 +330,8 @@ static void scsicd_read_data( SCSIInstance *scsiInstance, UINT8 *data, int dataL
 
 			data[0] = 0x71;	// deferred error
 
-			cddanum = cdda_num_from_cdrom(cdrom);
-			if (cddanum != -1 && cdda_audio_active(cddanum))
+			cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+			if (cdda != NULL && cdda_audio_active(cdda))
 			{
 				data[12] = 0x00;
 				data[13] = 0x11;	// AUDIO PLAY OPERATION IN PROGRESS
@@ -423,11 +423,11 @@ static void scsicd_read_data( SCSIInstance *scsiInstance, UINT8 *data, int dataL
 
 					msf = command[1] & 0x2;
 
-					cddanum = cdda_num_from_cdrom(cdrom);
-					audio_active = cddanum != -1 && cdda_audio_active(cddanum);
+					cdda = cdda_from_cdrom(scsiInstance->machine, cdrom);
+					audio_active = cdda != NULL && cdda_audio_active(cdda);
 					if (audio_active)
 					{
-						if (cdda_audio_paused(cddanum))
+						if (cdda_audio_paused(cdda))
 						{
 							data[1] = 0x12;		// audio is paused
 						}
@@ -438,7 +438,7 @@ static void scsicd_read_data( SCSIInstance *scsiInstance, UINT8 *data, int dataL
 					}
 					else
 					{
-						if (cddanum != -1 && cdda_audio_ended(cddanum))
+						if (cdda != NULL && cdda_audio_ended(cdda))
 						{
 							data[1] = 0x13;	// ended successfully
 						}
@@ -452,7 +452,7 @@ static void scsicd_read_data( SCSIInstance *scsiInstance, UINT8 *data, int dataL
 					// if audio is playing, get the latest LBA from the CDROM layer
 					if (audio_active)
 					{
-						our_this->last_lba = cdda_get_audio_lba(cddanum);
+						our_this->last_lba = cdda_get_audio_lba(cdda);
 					}
 					else
 					{
@@ -629,7 +629,7 @@ static void scsicd_write_data( SCSIInstance *scsiInstance, UINT8 *data, int data
 {
 	UINT8 *command;
 	int commandLength;
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 	SCSIGetCommand( scsiInstance, &command, &commandLength );
 
 	switch (command[ 0 ])
@@ -673,7 +673,7 @@ static void scsicd_write_data( SCSIInstance *scsiInstance, UINT8 *data, int data
 static void scsicd_alloc_instance( SCSIInstance *scsiInstance, const char *diskregion )
 {
 	running_machine *machine = scsiInstance->machine;
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 
 	our_this->lba = 0;
 	our_this->blocks = 0;
@@ -693,7 +693,7 @@ static void scsicd_alloc_instance( SCSIInstance *scsiInstance, const char *diskr
 
 #ifdef MESS
 	/* TODO: get rid of this ifdef MESS section */
-	our_this->cdrom = mess_cd_get_cdrom_file( device_list_find_by_tag( machine->config->devicelist, CDROM, diskregion ) );
+	our_this->cdrom = mess_cd_get_cdrom_file( devtag_get_device( machine, diskregion ) );
 #else
 	our_this->cdrom = cdrom_open(get_disk_handle( diskregion ));
 
@@ -707,7 +707,7 @@ static void scsicd_alloc_instance( SCSIInstance *scsiInstance, const char *diskr
 static void scsicd_delete_instance( SCSIInstance *scsiInstance )
 {
 #ifndef MESS
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 	if( our_this->cdrom )
 	{
 		cdrom_close( our_this->cdrom );
@@ -717,13 +717,13 @@ static void scsicd_delete_instance( SCSIInstance *scsiInstance )
 
 static void scsicd_get_device( SCSIInstance *scsiInstance, cdrom_file **cdrom )
 {
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 	*cdrom = our_this->cdrom;
 }
 
 static void scsicd_set_device( SCSIInstance *scsiInstance, cdrom_file *cdrom )
 {
-	SCSICd *our_this = SCSIThis( &SCSIClassCDROM, scsiInstance );
+	SCSICd *our_this = (SCSICd *)SCSIThis( &SCSIClassCDROM, scsiInstance );
 	our_this->cdrom = cdrom;
 }
 
@@ -734,36 +734,36 @@ static int scsicd_dispatch(int operation, void *file, INT64 intparm, void *ptrpa
 	switch (operation)
 	{
 		case SCSIOP_EXEC_COMMAND:
-			return scsicd_exec_command( file, ptrparm );
+			return scsicd_exec_command( (SCSIInstance *)file, (UINT8 *)ptrparm );
 
 		case SCSIOP_READ_DATA:
-			scsicd_read_data( file, ptrparm, intparm );
+			scsicd_read_data( (SCSIInstance *)file, (UINT8 *)ptrparm, intparm );
 			return 0;
 
 		case SCSIOP_WRITE_DATA:
-			scsicd_write_data( file, ptrparm, intparm );
+			scsicd_write_data( (SCSIInstance *)file, (UINT8 *)ptrparm, intparm );
 			return 0;
 
 		case SCSIOP_ALLOC_INSTANCE:
-			params = ptrparm;
-			SCSIBase( &SCSIClassCDROM, operation, file, intparm, ptrparm );
+			params = (SCSIAllocInstanceParams *)ptrparm;
+			SCSIBase( &SCSIClassCDROM, operation, (SCSIInstance *)file, intparm, (UINT8 *)ptrparm );
 			scsicd_alloc_instance( params->instance, params->diskregion );
 			return 0;
 
 		case SCSIOP_DELETE_INSTANCE:
-			scsicd_delete_instance( file );
+			scsicd_delete_instance( (SCSIInstance *)file );
 			break;
 
 		case SCSIOP_GET_DEVICE:
-			scsicd_get_device( file, ptrparm );
+			scsicd_get_device( (SCSIInstance *)file, (cdrom_file **)ptrparm );
 			return 0;
 
 		case SCSIOP_SET_DEVICE:
-			scsicd_set_device( file, ptrparm );
+			scsicd_set_device( (SCSIInstance *)file, (cdrom_file *)ptrparm );
 			return 0;
 	}
 
-	return SCSIBase( &SCSIClassCDROM, operation, file, intparm, ptrparm );
+	return SCSIBase( &SCSIClassCDROM, operation, (SCSIInstance *)file, intparm, (UINT8 *)ptrparm );
 }
 
 const SCSIClass SCSIClassCDROM =
