@@ -20,9 +20,6 @@ DEVICE_GET_INFO(x2212);
 #define MDRV_X2212_ADD(_tag) \
 	MDRV_DEVICE_ADD(_tag, X2212, 0)
 
-#define MDRV_X2212_REMOVE(_tag) \
-	MDRV_DEVICE_REMOVE(_tag, X2212)
-
 
 extern void x2212_write( const device_config *device, int offset, int data );
 extern int x2212_read( const device_config *device, int offset );
