@@ -138,7 +138,7 @@ static void interrupt_check(const device_config *device)
 
 static TIMER_CALLBACK( timercallback )
 {
-	const device_config *device = ptr;
+	const device_config *device = (const device_config *)ptr;
 	z80ctc *ctc = get_safe_token(device);
 	ctc_channel *channel = &ctc->channel[param];
 
@@ -461,7 +461,7 @@ static void z80ctc_irq_reti(const device_config *device)
 
 static DEVICE_START( z80ctc )
 {
-	const z80ctc_interface *intf = device->static_config;
+	const z80ctc_interface *intf = (const z80ctc_interface *)device->static_config;
 	astring *tempstring = astring_alloc();
 	z80ctc *ctc = get_safe_token(device);
 	int ch;
@@ -494,7 +494,6 @@ static DEVICE_START( z80ctc )
 	}
 
 	astring_free(tempstring);
-	return DEVICE_START_OK;
 }
 
 
@@ -517,15 +516,6 @@ static DEVICE_RESET( z80ctc )
 }
 
 
-static DEVICE_SET_INFO( z80ctc )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
 DEVICE_GET_INFO( z80ctc )
 {
 	switch (state)
@@ -536,7 +526,6 @@ DEVICE_GET_INFO( z80ctc )
 		case DEVINFO_INT_CLASS:							info->i = DEVICE_CLASS_PERIPHERAL;		break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:						info->set_info = DEVICE_SET_INFO_NAME(z80ctc); break;
 		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(z80ctc);break;
 		case DEVINFO_FCT_STOP:							/* Nothing */							break;
 		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME(z80ctc);break;
