@@ -158,8 +158,8 @@ struct dsd_ls624_context
 
 static DISCRETE_STEP(dsd_555_astbl)
 {
-	const  discrete_555_desc     *info    = node->custom;
-	struct dsd_555_astbl_context *context = node->context;
+	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
+	struct dsd_555_astbl_context *context = (struct dsd_555_astbl_context *)node->context;
 
 	int		count_f = 0;
 	int		count_r = 0;
@@ -376,8 +376,8 @@ static DISCRETE_STEP(dsd_555_astbl)
 
 static DISCRETE_RESET(dsd_555_astbl)
 {
-	const  discrete_555_desc     *info    = node->custom;
-	struct dsd_555_astbl_context *context = node->context;
+	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
+	struct dsd_555_astbl_context *context = (struct dsd_555_astbl_context *)node->context;
 	node_description *v_charge_node;
 
 	context->use_ctrlv   = (node->input_is_node >> 4) & 1;
@@ -457,8 +457,8 @@ static DISCRETE_RESET(dsd_555_astbl)
 
 static DISCRETE_STEP(dsd_555_mstbl)
 {
-	const  discrete_555_desc     *info    = node->custom;
-	struct dsd_555_mstbl_context *context = node->context;
+	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
+	struct dsd_555_mstbl_context *context = (struct dsd_555_mstbl_context *)node->context;
 
 	double v_cap;			/* Current voltage on capacitor, before dt */
 	double v_cap_next = 0;	/* Voltage on capacitor, after dt */
@@ -542,8 +542,8 @@ static DISCRETE_STEP(dsd_555_mstbl)
 
 static DISCRETE_RESET(dsd_555_mstbl)
 {
-	const  discrete_555_desc     *info    = node->custom;
-	struct dsd_555_mstbl_context *context = node->context;
+	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
+	struct dsd_555_mstbl_context *context = (struct dsd_555_mstbl_context *)node->context;
 
 	context->output_type = info->options & DISC_555_OUT_MASK;
 	if ((context->output_type == DISC_555_OUT_COUNT_F) || (context->output_type == DISC_555_OUT_COUNT_R))
@@ -611,8 +611,8 @@ static DISCRETE_RESET(dsd_555_mstbl)
 
 static DISCRETE_STEP(dsd_555_cc)
 {
-	const  discrete_555_cc_desc *info    = node->custom;
-	struct dsd_555_cc_context   *context = node->context;
+	const  discrete_555_cc_desc *info    = (const  discrete_555_cc_desc *)node->custom;
+	struct dsd_555_cc_context   *context = (struct dsd_555_cc_context *)node->context;
 
 	int		count_f  = 0;
 	int		count_r  = 0;
@@ -931,8 +931,8 @@ static DISCRETE_STEP(dsd_555_cc)
 
 static DISCRETE_RESET(dsd_555_cc)
 {
-	const  discrete_555_cc_desc *info    = node->custom;
-	struct dsd_555_cc_context   *context = node->context;
+	const  discrete_555_cc_desc *info    = (const  discrete_555_cc_desc *)node->custom;
+	struct dsd_555_cc_context   *context = (struct dsd_555_cc_context *)node->context;
 
 	double	r_temp, r_discharge = 0, r_charge = 0;
 
@@ -1161,8 +1161,8 @@ static DISCRETE_RESET(dsd_555_cc)
 
 static DISCRETE_STEP(dsd_555_vco1)
 {
-	const  discrete_555_vco1_desc *info    = node->custom;
-	struct dsd_555_vco1_context   *context = node->context;
+	const  discrete_555_vco1_desc *info    = (const  discrete_555_vco1_desc *)node->custom;
+	struct dsd_555_vco1_context   *context = (struct dsd_555_vco1_context *)node->context;
 
 	int		count_f = 0;
 	int		count_r = 0;
@@ -1314,8 +1314,8 @@ static DISCRETE_STEP(dsd_555_vco1)
 
 static DISCRETE_RESET(dsd_555_vco1)
 {
-	const  discrete_555_vco1_desc *info    = node->custom;
-	struct dsd_555_vco1_context   *context = node->context;
+	const  discrete_555_vco1_desc *info    = (const  discrete_555_vco1_desc *)node->custom;
+	struct dsd_555_vco1_context   *context = (struct dsd_555_vco1_context *)node->context;
 
 	double v_ratio_r3, v_ratio_r4_1, r_in_1;
 
@@ -1392,8 +1392,8 @@ static DISCRETE_RESET(dsd_555_vco1)
 
 static DISCRETE_STEP(dsd_566)
 {
-	const  discrete_566_desc *info    = node->custom;
-	struct dsd_566_context   *context = node->context;
+	const  discrete_566_desc *info    = (const  discrete_566_desc *)node->custom;
+	struct dsd_566_context   *context = (struct dsd_566_context *)node->context;
 
 	double i;				/* Charging current created by vIn */
 	double dt;				/* change in time */
@@ -1513,8 +1513,8 @@ static DISCRETE_STEP(dsd_566)
 
 static DISCRETE_RESET(dsd_566)
 {
-	const  discrete_566_desc *info    = node->custom;
-	struct dsd_566_context   *context = node->context;
+	const  discrete_566_desc *info    = (const  discrete_566_desc *)node->custom;
+	struct dsd_566_context   *context = (struct dsd_566_context *)node->context;
 	node_description *v_charge_node;
 
 	double	v_diff, temp;
@@ -1582,32 +1582,40 @@ static DISCRETE_RESET(dsd_566)
 #define DSD_LS624__OUTTYPE	(*(node->input[4]))
 
 /*
- * These formulas are derived from diagrams in the datasheet!
- * They are not based on any law. The function is not
- * described anywhere.
+ * The datasheet mentions a 600 ohm discharge. It also gives
+ * equivalent circuits for VI and VR.
  */
 
 #define LS624_F1(x)			(0.19 + 20.0/90.0*(x))
-#define LS624_T(_C, _R, _F)		(-600.0 * (_C) * log(1.0-LS624_F1(_R)*0.12/LS624_F1(_F)))
+#define LS624_T(_C, _R, _F)		((-600.0 * (_C) * log(1.0-LS624_F1(_R)*0.12/LS624_F1(_F))) * 16.0 )
+
+/* The following formula was derived from figures 2 and 3 in LS624 datasheet. Coefficients
+ * where calculated using least square approximation.
+ * This approach gives a bit better results compared to the first approach.
+ */
+#define LS624_F(_C, _VI, _VR)	pow(10, -0.912029404 * log10(_C) + 0.243264328 * (_VI) \
+		          - 0.091695877 * (_VR) -0.014110946 * (_VI) * (_VR) - 3.207072925)
 
 static DISCRETE_STEP(dsd_ls624)
 {
-	struct dsd_ls624_context *context = node->context;
+	struct dsd_ls624_context *context = (struct dsd_ls624_context *)node->context;
 
 	if (DSD_LS624__ENABLE)
 	{
 		double	dt;	/* change in time */
 		double	sample_t;
 		double	t;
-		int		lst, cntf = 0, cntr = 0;
+		double  en = 0.0f;
+		int		cntf = 0, cntr = 0;
 
 		sample_t = discrete_current_context->sample_time;	/* Change in time */
-		dt  = LS624_T(DSD_LS624__C, DSD_LS624__VRNG, DSD_LS624__VMOD);
-		dt  = 16 * dt;
+		//dt  = LS624_T(DSD_LS624__C, DSD_LS624__VRNG, DSD_LS624__VMOD) / 2.0;
+		dt  = 1.0f / (2.0f * LS624_F(DSD_LS624__C, DSD_LS624__VMOD, DSD_LS624__VRNG));
 		t   = context->remain;
-		lst = context->state;
-		while (t + dt < sample_t)
+		en += (double) context->state * t;
+		while (t + dt <= sample_t)
 		{
+			en += (double) context->state * dt;
 			context->state = (1 - context->state);
 			if (context->state)
 				cntr++;
@@ -1615,15 +1623,20 @@ static DISCRETE_STEP(dsd_ls624)
 				cntf++;
 			t += dt;
 		}
+		en += (sample_t - t) * (double) context->state;
 		context->remain = t - sample_t;
 
 		switch (context->out_type)
 		{
 			case DISC_LS624_OUT_ENERGY:
-				node->output[0] = ((double)lst) * (1.0 + context->remain / sample_t) - ((double)context->state) * context->remain / sample_t;
+				node->output[0] = en / sample_t;
 				break;
 			case DISC_LS624_OUT_LOGIC:
-				node->output[0] = context->state;
+				/* filter out randomness */
+				if (cntf + cntr > 1)
+					node->output[0] = 1;
+				else
+					node->output[0] = context->state;
 				break;
 			case DISC_LS624_OUT_COUNT_F:
 				node->output[0] = cntf;
@@ -1640,7 +1653,7 @@ static DISCRETE_STEP(dsd_ls624)
 
 static DISCRETE_RESET(dsd_ls624)
 {
-	struct dsd_ls624_context *context = node->context;
+	struct dsd_ls624_context *context = (struct dsd_ls624_context *)node->context;
 
 	context->remain   = 0;
 	context->state    = 0;
