@@ -26,9 +26,9 @@
  * Core software takes care of traversing the netlist in the correct
  * order
  *
- * SND_START(discrete)      - Read Node list, initialise & reset
- * SND_STOP(discrete)       - Shutdown discrete sound system
- * SND_RESET(discrete)      - Put sound system back to time 0
+ * DEVICE_START(discrete)      - Read Node list, initialise & reset
+ * DEVICE_STOP(discrete)       - Shutdown discrete sound system
+ * DEVICE_RESET(discrete)      - Put sound system back to time 0
  * discrete_stream_update() - This does the real update to the sim
  *
  ************************************************************************/
@@ -69,7 +69,7 @@ static void init_nodes(discrete_info *info, discrete_sound_block *block_list, co
 static void find_input_nodes(discrete_info *info, discrete_sound_block *block_list);
 static void setup_output_nodes(const device_config *device, discrete_info *info);
 static void setup_disc_logs(discrete_info *info);
-static SND_RESET( discrete );
+static DEVICE_RESET( discrete );
 
 
 
@@ -232,7 +232,7 @@ static const discrete_module module_list[] =
 
 node_description *discrete_find_node(void *chip, int node)
 {
-	discrete_info *info = chip ? chip : discrete_current_context;
+	discrete_info *info = chip ? (discrete_info *)chip : discrete_current_context;
 	if (node < NODE_START || node > NODE_END) return NULL;
 	return info->indexed_node[NODE_INDEX(node)];
 }
@@ -245,28 +245,24 @@ node_description *discrete_find_node(void *chip, int node)
  *
  *************************************/
 
-static SND_START( discrete )
+static DEVICE_START( discrete )
 {
-	discrete_sound_block *intf = (discrete_sound_block *)config;
-	discrete_info *info;
+	discrete_sound_block *intf = (discrete_sound_block *)device->static_config;
+	discrete_info *info = get_safe_token(device);
 	char name[32];
 
-	info = auto_malloc(sizeof(*info));
-	memset(info, 0, sizeof(*info));
-
 	info->device = device;
-	info->sndindex = sndindex;
 
 	/* If a clock is specified we will use it, otherwise run at the audio sample rate. */
-	if (clock)
-		info->sample_rate = clock;
+	if (device->clock)
+		info->sample_rate = device->clock;
 	else
 		info->sample_rate = device->machine->sample_rate;
 	info->sample_time = 1.0 / info->sample_rate;
 	info->neg_sample_time = - info->sample_time;
 
 	/* create the logfile */
-	sprintf(name, "discrete%d.log", info->sndindex);
+	sprintf(name, "discrete%s.log", device->tag);
 	if (DISCRETE_DEBUGLOG && !info->disclogfile)
 		info->disclogfile = fopen(name, "w");
 
@@ -296,16 +292,13 @@ static SND_START( discrete )
 	discrete_log("discrete_start() - Sanity check counted %d nodes", info->node_count);
 
 	/* allocate memory for the array of actual nodes */
-	info->node_list = auto_malloc(info->node_count * sizeof(info->node_list[0]));
-	memset(info->node_list, 0, info->node_count * sizeof(info->node_list[0]));
+	info->node_list = auto_alloc_array_clear(device->machine, node_description, info->node_count);
 
 	/* allocate memory for the node execution order array */
-	info->running_order = auto_malloc(info->node_count * sizeof(info->running_order[0]));
-	memset(info->running_order, 0, info->node_count * sizeof(info->running_order[0]));
+	info->running_order = auto_alloc_array_clear(device->machine, node_description *, info->node_count);
 
 	/* allocate memory to hold pointers to nodes by index */
-	info->indexed_node = auto_malloc(DISCRETE_MAX_NODES * sizeof(info->indexed_node[0]));
-	memset(info->indexed_node, 0, DISCRETE_MAX_NODES * sizeof(info->indexed_node[0]));
+	info->indexed_node = auto_alloc_array_clear(device->machine, node_description *, DISCRETE_MAX_NODES);
 
 	/* initialize the node data */
 	init_nodes(info, intf, device);
@@ -319,7 +312,6 @@ static SND_START( discrete )
 	setup_disc_logs(info);
 
 	discrete_current_context = NULL;
-	return info;
 }
 
 
@@ -330,9 +322,9 @@ static SND_START( discrete )
  *
  *************************************/
 
-static SND_STOP( discrete )
+static DEVICE_STOP( discrete )
 {
-	discrete_info *info = device->token;
+	discrete_info *info = get_safe_token(device);
 	int log_num;
 
 #if (DISCRETE_PROFILING)
@@ -390,9 +382,9 @@ static SND_STOP( discrete )
  *
  *************************************/
 
-static SND_RESET( discrete )
+static DEVICE_RESET( discrete )
 {
-	discrete_info *info = device->token;
+	discrete_info *info = get_safe_token(device);
 	int nodenum;
 
 	discrete_current_context = info;
@@ -426,7 +418,7 @@ static SND_RESET( discrete )
 
 static STREAM_UPDATE( discrete_stream_update )
 {
-	discrete_info *info = param;
+	discrete_info *info = (discrete_info *)param;
 	int samplenum, nodenum, outputnum;
 	double val;
 	INT16 wave_data_l, wave_data_r;
@@ -601,7 +593,7 @@ static void init_nodes(discrete_info *info, discrete_sound_block *block_list, co
 		/* setup module if custom */
 		if (block->type == DST_CUSTOM)
 		{
-			const discrete_custom_info *custom = node->custom;
+			const discrete_custom_info *custom = (const discrete_custom_info *)node->custom;
 			node->module.reset = custom->reset;
 			node->module.step = custom->step;
 			node->module.contextsize = custom->contextsize;
@@ -610,10 +602,7 @@ static void init_nodes(discrete_info *info, discrete_sound_block *block_list, co
 
 		/* allocate memory if necessary */
 		if (node->module.contextsize)
-		{
-			node->context = auto_malloc(node->module.contextsize);
-			memset(node->context, 0, node->module.contextsize);
-		}
+			node->context = auto_alloc_array_clear(device->machine, UINT8, node->module.contextsize);
 
 		/* if we are an stream input node, track that */
 		if (block->type == DSS_INPUT_STREAM)
@@ -714,7 +703,7 @@ static void setup_disc_logs(discrete_info *info)
 
 	for (log_num = 0; log_num < info->num_csvlogs; log_num++)
 	{
-		sprintf(name, "discrete%d_%d.csv", info->sndindex, log_num);
+		sprintf(name, "discrete%s_%d.csv", info->device->tag, log_num);
 		info->disc_csv_file[log_num] = fopen(name, "w");
 		/* Output some header info */
 		fprintf(info->disc_csv_file[log_num], "\"MAME Discrete System Node Log\"\n");
@@ -731,7 +720,7 @@ static void setup_disc_logs(discrete_info *info)
 
 	for (log_num = 0; log_num < info->num_wavelogs; log_num++)
 	{
-		sprintf(name, "discrete%d_%d.wav", info->sndindex, log_num);
+		sprintf(name, "discrete%s_%d.wav", info->device->tag, log_num);
 		info->disc_wav_file[log_num] = wav_open(name, info->sample_rate, info->wavelog_node[log_num]->active_inputs/2);
 	}
 }
@@ -742,33 +731,24 @@ static void setup_disc_logs(discrete_info *info)
  * Generic get_info
  **************************************************************************/
 
-static SND_SET_INFO( discrete )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
-SND_GET_INFO( discrete )
+DEVICE_GET_INFO( discrete )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(discrete_info);					break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( discrete );		break;
-		case SNDINFO_PTR_START:							info->start = SND_START_NAME( discrete );			break;
-		case SNDINFO_PTR_STOP:							info->stop = SND_STOP_NAME( discrete );				break;
-		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( discrete );			break;
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME( discrete );			break;
+		case DEVINFO_FCT_STOP:							info->stop = DEVICE_STOP_NAME( discrete );				break;
+		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME( discrete );			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							strcpy(info->s, "Discrete");						break;
-		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Analog");							break;
-		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.1");								break;
-		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
-		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Discrete");						break;
+		case DEVINFO_STR_FAMILY:					strcpy(info->s, "Analog");							break;
+		case DEVINFO_STR_VERSION:					strcpy(info->s, "1.1");								break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);							break;
+		case DEVINFO_STR_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
