@@ -13,7 +13,8 @@
 
 static const INT16 default_levels[2] = {0,32767};
 
-struct speaker
+typedef struct _speaker_state speaker_state;
+struct _speaker_state
 {
 	sound_stream *channel;
 	const INT16 *levels;
@@ -22,10 +23,19 @@ struct speaker
 };
 
 
+INLINE speaker_state *get_safe_token(const device_config *device)
+{
+	assert(device != NULL);
+	assert(device->token != NULL);
+	assert(device->type == SOUND);
+	assert(sound_get_type(device) == SOUND_SPEAKER);
+	return (speaker_state *)device->token;
+}
+
 
 static STREAM_UPDATE( speaker_sound_update )
 {
-	struct speaker *sp = (struct speaker *) param;
+	speaker_state *sp = (speaker_state *) param;
 	stream_sample_t *buffer = outputs[0];
 	int volume = sp->levels[sp->level];
 
@@ -35,22 +45,21 @@ static STREAM_UPDATE( speaker_sound_update )
 
 
 
-static SND_START( speaker )
+static DEVICE_START( speaker )
 {
-	struct speaker *sp = auto_malloc(sizeof(*sp));
+	speaker_state *sp = get_safe_token(device);
 
 	sp->channel = stream_create(device, 0, 1, device->machine->sample_rate, sp, speaker_sound_update);
 	sp->num_levels = 2;
 	sp->levels = default_levels;
 	sp->level = 0;
-	return sp;
 }
 
 
 
-void speaker_level_w(int which, int new_level)
+void speaker_level_w(const device_config *device, int new_level)
 {
-	struct speaker *sp = sndti_token(SOUND_SPEAKER, which);
+	speaker_state *sp = get_safe_token(device);
 
     if( new_level < 0 )
 		new_level = 0;
@@ -73,32 +82,23 @@ void speaker_level_w(int which, int new_level)
  * Generic get_info
  **************************************************************************/
 
-static SND_SET_INFO( speaker )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
-SND_GET_INFO( speaker )
+DEVICE_GET_INFO( speaker )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(speaker_state); 				break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( speaker );	break;
-		case SNDINFO_PTR_START:							info->start = SND_START_NAME( speaker );		break;
-		case SNDINFO_PTR_STOP:							/* nothing */									break;
-		case SNDINFO_PTR_RESET:							/* nothing */									break;
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME( speaker );		break;
+		case DEVINFO_FCT_STOP:							/* nothing */									break;
+		case DEVINFO_FCT_RESET:							/* nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							strcpy(info->s, "Speaker");						break;
-		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Speaker");						break;
-		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
-		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
-		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright The MESS Team"); 	break;
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Speaker");						break;
+		case DEVINFO_STR_FAMILY:					strcpy(info->s, "Speaker");						break;
+		case DEVINFO_STR_VERSION:					strcpy(info->s, "1.0");							break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+		case DEVINFO_STR_CREDITS:					strcpy(info->s, "Copyright The MESS Team"); 	break;
 	}
 }
