@@ -7,7 +7,7 @@ void *tms5220_create(const device_config *device);
 void tms5220_destroy(void *chip);
 
 void tms5220_reset_chip(void *chip);
-void tms5220_set_irq(void *chip, void (*func)(running_machine *, int));
+void tms5220_set_irq(void *chip, void (*func)(const device_config *, int));
 
 void tms5220_data_write(void *chip, int data);
 int tms5220_status_read(void *chip);
@@ -18,9 +18,9 @@ int tms5220_int_read(void *chip);
 void tms5220_process(void *chip, INT16 *buffer, unsigned int size);
 
 /* three variables added by R Nabet */
-void tms5220_set_read(void *chip, int (*func)(int));
-void tms5220_set_load_address(void *chip, void (*func)(int));
-void tms5220_set_read_and_branch(void *chip, void (*func)(void));
+void tms5220_set_read(void *chip, int (*func)(const device_config *, int));
+void tms5220_set_load_address(void *chip, void (*func)(const device_config *, int));
+void tms5220_set_read_and_branch(void *chip, void (*func)(const device_config *));
 
 
 enum _tms5220_variant
