@@ -107,9 +107,9 @@ typedef struct
 	UINT8 ext_read;
 
 	const UINT8 *rom;
-	read8_space_func ext_mem_read;
-	write8_space_func ext_mem_write;
-	void (*irq_callback)(running_machine *, int);
+	devcb_resolved_read8 ext_mem_read;
+	devcb_resolved_write8 ext_mem_write;
+	void (*irq_callback)(const device_config *, int);
 
 	UINT32 clock;
 	sound_stream * stream;
@@ -162,8 +162,25 @@ static const double DCTime[] =
 
     There appears to be at least 2 errors in the table from the original manual.
 
-    Both 201 & 202 where listed as 3.74490.  202 has be changed to 3.92000 which is "about right"
-    232 was listed as 13.35547.  We use 14.35547 as it apears to be the correct value
+    Both 201 & 202 where listed as 3.74490.  202 has be changed to 3.91513 which was computed based on formulas by OG & Nicola
+    232 was listed as 13.35547.  We use 14.35547 as this is the correct value based on the formula listed below:
+
+LFO period seems easy to compute:
+
+int lfo_period(int entry)
+{
+  int ma, ex;
+  entry = 256-entry;
+  ma = entry & 15;
+  ex = entry >> 4;
+  if(ex)
+    return (ma | 16) << (ex+6);
+  else
+    return ma << 7;
+}
+
+lfo_freq = 44100 / lfo_period
+
 */
 
 static const double LFO_frequency_table[256] =
@@ -193,7 +210,7 @@ static const double LFO_frequency_table[256] =
 	1.34583,	1.38924,	1.43555,	1.48505,	1.53809,	1.59509,	1.65640,	1.72266,
 	1.79443,	1.87245,	1.95756,	2.05078,	2.15332,	2.26665,	2.39258,	2.53332,
 	2.69165,	2.77848,	2.87109,	2.97010,	3.07617,	3.19010,	3.31280,	3.44531,
-	3.58887,	3.74490,	3.92000,	4.10156,	4.30664,	4.53331,	4.78516,	5.06664,
+	3.58887,	3.74490,	3.91513,	4.10156,	4.30664,	4.53331,	4.78516,	5.06664,
 	5.38330,	5.55696,	5.74219,	5.94019,	6.15234,	6.38021,	6.62560,	6.89062,
 	7.17773,	7.48981,	7.83026,	8.20312,	8.61328,	9.06661,	9.57031,	10.13327,
 	10.76660,	11.11391,	11.48438,	11.88039,	12.30469,	12.76042,	13.25120,	13.78125,
@@ -252,6 +269,16 @@ static int channel_attenuation[16];
 static int total_level[128];
 static int env_volume_table[256];
 
+INLINE YMF271Chip *get_safe_token(const device_config *device)
+{
+	assert(device != NULL);
+	assert(device->token != NULL);
+	assert(device->type == SOUND);
+	assert(sound_get_type(device) == SOUND_YMF271);
+	return (YMF271Chip *)device->token;
+}
+
+
 INLINE int GET_KEYSCALED_RATE(int rate, int keycode, int keyscale)
 {
 	int newrate = rate + RKS_Table[keycode][keyscale];
@@ -680,7 +707,7 @@ static STREAM_UPDATE( ymf271_update )
 	int i, j;
 	int op;
 	INT32 *mixp;
-	YMF271Chip *chip = param;
+	YMF271Chip *chip = (YMF271Chip *)param;
 
 	memset(mix, 0, sizeof(mix[0])*samples*2);
 
@@ -1348,36 +1375,34 @@ static void ymf271_write_pcm(YMF271Chip *chip, int data)
 
 static TIMER_CALLBACK( ymf271_timer_a_tick )
 {
-	YMF271Chip *chip = ptr;
+	YMF271Chip *chip = (YMF271Chip *)ptr;
 
 	chip->status |= 1;
 
 	if (chip->enable & 4)
 	{
 		chip->irqstate |= 1;
-		if (chip->irq_callback) chip->irq_callback(machine, 1);
+		if (chip->irq_callback) chip->irq_callback(chip->device, 1);
 	}
 }
 
 static TIMER_CALLBACK( ymf271_timer_b_tick )
 {
-	YMF271Chip *chip = ptr;
+	YMF271Chip *chip = (YMF271Chip *)ptr;
 
 	chip->status |= 2;
 
 	if (chip->enable & 8)
 	{
 		chip->irqstate |= 2;
-		if (chip->irq_callback) chip->irq_callback(machine, 1);
+		if (chip->irq_callback) chip->irq_callback(chip->device, 1);
 	}
 }
 
 static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 {
-	/* temporary hack until this is converted to a device */
-	const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
-	if( chip->ext_mem_read ) {
-		return chip->ext_mem_read(space,address);
+	if( chip->ext_mem_read.read ) {
+		return devcb_call_read8(&chip->ext_mem_read, address);
 	} else {
 		if( address < 0x800000)
 			return chip->rom[address];
@@ -1387,11 +1412,7 @@ static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 
 static void ymf271_write_ext_memory(YMF271Chip *chip, UINT32 address, UINT8 data)
 {
-	/* temporary hack until this is converted to a device */
-	const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
-	if( chip->ext_mem_write ) {
-		chip->ext_mem_write(space, address, data);
-	}
+	devcb_call_write8(&chip->ext_mem_write, address, data);
 }
 
 static void ymf271_write_timer(YMF271Chip *chip, int data)
@@ -1399,7 +1420,6 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 	int slotnum;
 	YMF271Group *group;
 	attotime period;
-	running_machine *machine = chip->device->machine;
 
 	slotnum = fm_tab[chip->timerreg & 0xf];
 	group = &chip->groups[slotnum];
@@ -1457,7 +1477,7 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 					chip->irqstate &= ~1;
 					chip->status &= ~1;
 
-					if (chip->irq_callback) chip->irq_callback(machine, 0);
+					if (chip->irq_callback) chip->irq_callback(chip->device, 0);
 
 					//period = (double)(256.0 - chip->timerAVal ) * ( 384.0 * 4.0 / (double)CLOCK);
 					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * (1024 - chip->timerAVal));
@@ -1469,7 +1489,7 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 					chip->irqstate &= ~2;
 					chip->status &= ~2;
 
-					if (chip->irq_callback) chip->irq_callback(machine, 0);
+					if (chip->irq_callback) chip->irq_callback(chip->device, 0);
 
 					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * 16 * (256 - chip->timerBVal));
 
@@ -1501,9 +1521,9 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 	}
 }
 
-static void ymf271_w(int chipnum, int offset, int data)
+WRITE8_DEVICE_HANDLER( ymf271_w )
 {
-	YMF271Chip *chip = sndti_token(SOUND_YMF271, chipnum);
+	YMF271Chip *chip = get_safe_token(device);
 
 	switch (offset)
 	{
@@ -1546,10 +1566,10 @@ static void ymf271_w(int chipnum, int offset, int data)
 	}
 }
 
-static int ymf271_r(int chipnum, int offset)
+READ8_DEVICE_HANDLER( ymf271_r )
 {
 	UINT8 value;
-	YMF271Chip *chip = sndti_token(SOUND_YMF271, chipnum);
+	YMF271Chip *chip = get_safe_token(device);
 
 	switch(offset)
 	{
@@ -1565,13 +1585,13 @@ static int ymf271_r(int chipnum, int offset)
 	return 0;
 }
 
-static void init_tables(void)
+static void init_tables(running_machine *machine)
 {
 	int i,j;
 
 	for (i=0; i < ARRAY_LENGTH(wavetable); i++)
 	{
-		wavetable[i] = auto_malloc(SIN_LEN * sizeof(INT16));
+		wavetable[i] = auto_alloc_array(machine, INT16, SIN_LEN);
 	}
 
 	for (i=0; i < SIN_LEN; i++)
@@ -1649,7 +1669,7 @@ static void init_tables(void)
 		alfo_table[3][i] = (i < (LFO_LENGTH/2)) ? ALFO_MAX-tri_wave : tri_wave;
 	}
 
-	mix = auto_malloc(48000*2*sizeof(*mix));
+	mix = auto_alloc_array(machine, INT32, 48000*2);
 }
 
 static void init_state(YMF271Chip *chip, const device_config *device)
@@ -1727,7 +1747,7 @@ static void init_state(YMF271Chip *chip, const device_config *device)
 	state_save_register_device_item(device, 0, chip->ext_read);
 }
 
-static void ymf271_init(const device_config *device, YMF271Chip *chip, UINT8 *rom, void (*cb)(running_machine *,int), read8_space_func ext_read, write8_space_func ext_write)
+static void ymf271_init(const device_config *device, YMF271Chip *chip, UINT8 *rom, void (*cb)(const device_config *,int), const devcb_read8 *ext_read, const devcb_write8 *ext_write)
 {
 	chip->timA = timer_alloc(device->machine, ymf271_timer_a_tick, chip);
 	chip->timB = timer_alloc(device->machine, ymf271_timer_b_tick, chip);
@@ -1735,29 +1755,27 @@ static void ymf271_init(const device_config *device, YMF271Chip *chip, UINT8 *ro
 	chip->rom = rom;
 	chip->irq_callback = cb;
 
-	chip->ext_mem_read = ext_read;
-	chip->ext_mem_write = ext_write;
+	devcb_resolve_read8(&chip->ext_mem_read, ext_read, device);
+	devcb_resolve_write8(&chip->ext_mem_write, ext_write, device);
 
-	init_tables();
+	init_tables(device->machine);
 	init_state(chip, device);
 }
 
-static SND_START( ymf271 )
+static DEVICE_START( ymf271 )
 {
-	static const ymf271_interface defintrf = { 0 };
+	static const ymf271_interface defintrf = { DEVCB_NULL };
 	const ymf271_interface *intf;
 	int i;
-	YMF271Chip *chip;
+	YMF271Chip *chip = get_safe_token(device);
 
-	chip = auto_malloc(sizeof(*chip));
-	memset(chip, 0, sizeof(*chip));
 	chip->device = device;
-	chip->clock = clock;
+	chip->clock = device->clock;
 
-	intf = (config != NULL) ? config : &defintrf;
+	intf = (device->static_config != NULL) ? (const ymf271_interface *)device->static_config : &defintrf;
 
-	ymf271_init(device, chip, device->region, intf->irq_callback, intf->ext_read, intf->ext_write);
-	chip->stream = stream_create(device, 0, 2, clock/384, chip, ymf271_update);
+	ymf271_init(device, chip, device->region, intf->irq_callback, &intf->ext_read, &intf->ext_write);
+	chip->stream = stream_create(device, 0, 2, device->clock/384, chip, ymf271_update);
 
 	for (i = 0; i < 256; i++)
 	{
@@ -1773,34 +1791,12 @@ static SND_START( ymf271 )
 		double db = 0.75 * (double)i;
 		total_level[i] = (int)(65536.0 / pow(10.0, db / 20.0));
 	}
-
-	return chip;
 }
 
-READ8_HANDLER( ymf271_0_r )
-{
-	return ymf271_r(0, offset);
-}
-
-WRITE8_HANDLER( ymf271_0_w )
-{
-	ymf271_w(0, offset, data);
-}
-
-READ8_HANDLER( ymf271_1_r )
-{
-	return ymf271_r(1, offset);
-}
-
-WRITE8_HANDLER( ymf271_1_w )
-{
-	ymf271_w(1, offset, data);
-}
-
-static SND_RESET( ymf271 )
+static DEVICE_RESET( ymf271 )
 {
 	int i;
-	YMF271Chip *chip = device->token;
+	YMF271Chip *chip = get_safe_token(device);
 
 	for (i = 0; i < 48; i++)
 	{
@@ -1813,32 +1809,23 @@ static SND_RESET( ymf271 )
  * Generic get_info
  **************************************************************************/
 
-static SND_SET_INFO( ymf271 )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
-SND_GET_INFO( ymf271 )
+DEVICE_GET_INFO( ymf271 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(YMF271Chip); 					break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( ymf271 );	break;
-		case SNDINFO_PTR_START:							info->start = SND_START_NAME( ymf271 );			break;
-		case SNDINFO_PTR_STOP:							/* Nothing */									break;
-		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( ymf271 );			break;
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME( ymf271 );			break;
+		case DEVINFO_FCT_STOP:							/* Nothing */									break;
+		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME( ymf271 );			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							strcpy(info->s, "YMF271");						break;
-		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Yamaha FM");					break;
-		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
-		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
-		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
+		case DEVINFO_STR_NAME:							strcpy(info->s, "YMF271");						break;
+		case DEVINFO_STR_FAMILY:					strcpy(info->s, "Yamaha FM");					break;
+		case DEVINFO_STR_VERSION:					strcpy(info->s, "1.0");							break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+		case DEVINFO_STR_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
