@@ -300,8 +300,7 @@ void timer_init(running_machine *machine)
 	int i;
 
 	/* allocate global data */
-	global = machine->timer_data = auto_malloc(sizeof(*global));
-	memset(global, 0, sizeof(*global));
+	global = machine->timer_data = auto_alloc_clear(machine, timer_private);
 
 	/* we need to wait until the first call to timer_cyclestorun before using real CPU times */
 	global->exec.basetime = attotime_zero;
@@ -339,7 +338,7 @@ void timer_init(running_machine *machine)
 
 void timer_destructor(void *ptr, size_t size)
 {
-	timer_remove(ptr);
+	timer_remove((emu_timer *)ptr);
 }
 
 
@@ -704,7 +703,7 @@ void timer_adjust_oneshot(emu_timer *which, attotime duration, INT32 param)
 void timer_device_adjust_oneshot(const device_config *timer, attotime duration, INT32 param)
 {
 #ifdef MAME_DEBUG
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* doesn't make sense for scanline timers */
 	assert(config->type != TIMER_TYPE_SCANLINE);
@@ -757,7 +756,7 @@ void timer_device_adjust_periodic(const device_config *timer, attotime start_del
 {
 	timer_state *state = get_safe_token(timer);
 #ifdef MAME_DEBUG
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* doesn't make sense for scanline timers */
 	assert(config->type != TIMER_TYPE_SCANLINE);
@@ -821,7 +820,7 @@ void timer_device_reset(const device_config *timer)
 {
 	timer_state *state = get_safe_token(timer);
 #ifdef MAME_DEBUG
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* doesn't make sense for scanline timers */
 	assert(config->type != TIMER_TYPE_SCANLINE);
@@ -891,7 +890,7 @@ int timer_device_get_param(const device_config *timer)
 {
 	timer_state *state = get_safe_token(timer);
 #ifdef MAME_DEBUG
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* doesn't make sense for scanline timers */
 	assert(config->type != TIMER_TYPE_SCANLINE);
@@ -916,7 +915,7 @@ void timer_device_set_param(const device_config *timer, int param)
 {
 	timer_state *state = get_safe_token(timer);
 #ifdef MAME_DEBUG
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* doesn't make sense for scanline timers */
 	assert(config->type != TIMER_TYPE_SCANLINE);
@@ -1056,9 +1055,9 @@ attotime timer_device_firetime(const device_config *timer)
 
 static TIMER_CALLBACK( periodic_timer_device_timer_callback )
 {
-	const device_config *timer = ptr;
+	const device_config *timer = (const device_config *)ptr;
 	timer_state *state = get_safe_token(timer);
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* call the real callback */
 	config->callback(timer, state->ptr, state->param);
@@ -1074,12 +1073,12 @@ static TIMER_CALLBACK( periodic_timer_device_timer_callback )
 static TIMER_CALLBACK( scanline_timer_device_timer_callback )
 {
 	int next_vpos;
-	const device_config *timer = ptr;
+	const device_config *timer = (const device_config *)ptr;
 	timer_state *state = get_safe_token(timer);
-	timer_config *config = timer->inline_config;
+	timer_config *config = (timer_config *)timer->inline_config;
 
 	/* get the screen device and verify it */
-	const device_config *screen = device_list_find_by_tag(timer->machine->config->devicelist, VIDEO_SCREEN, config->screen);
+	const device_config *screen = devtag_get_device(timer->machine, config->screen);
 	assert(screen != NULL);
 
 	/* first time, start with the first scanline, but do not call the callback */
@@ -1173,7 +1172,7 @@ static DEVICE_START( timer )
 	assert(device->machine->config != NULL);
 
 	/* get and validate the configuration */
-	config = device->inline_config;
+	config = (timer_config *)device->inline_config;
 	assert(config->type == TIMER_TYPE_PERIODIC || config->type == TIMER_TYPE_SCANLINE || config->type == TIMER_TYPE_GENERIC);
 	assert(config->callback != NULL);
 
@@ -1269,21 +1268,6 @@ static DEVICE_START( timer )
 			fatalerror("Unknown timer device type");
 			break;
 	}
-
-	return DEVICE_START_OK;
-}
-
-
-/*-------------------------------------------------
-    timer_set_info - device set info callback
--------------------------------------------------*/
-
-static DEVICE_SET_INFO( timer )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
 }
 
 
@@ -1301,7 +1285,6 @@ DEVICE_GET_INFO( timer )
 		case DEVINFO_INT_CLASS:					info->i = DEVICE_CLASS_TIMER;			break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:				info->set_info = DEVICE_SET_INFO_NAME(timer); break;
 		case DEVINFO_FCT_START:					info->start = DEVICE_START_NAME(timer); break;
 		case DEVINFO_FCT_STOP:					/* Nothing */							break;
 		case DEVINFO_FCT_RESET:					/* Nothing */							break;
