@@ -379,8 +379,8 @@ static void palette_handle_keys(running_machine *machine, ui_gfx_state *state)
 	/* clamp within range */
 	if (state->palette.which < 0)
 		state->palette.which = 1;
-	if (state->palette.which > (machine->colortable != NULL))
-		state->palette.which = (machine->colortable != NULL);
+	if (state->palette.which > (int)(machine->colortable != NULL))
+		state->palette.which = (int)(machine->colortable != NULL);
 
 	/* cache some info in locals */
 	total = state->palette.which ? colortable_palette_get_size(machine->colortable) : machine->config->total_colors;
@@ -430,7 +430,7 @@ static void gfxset_handler(running_machine *machine, ui_gfx_state *state)
 	float cellwidth, cellheight;
 	float chwidth, chheight;
 	float titlewidth;
-	float cellaspect;
+	//float cellaspect;
 	float x0, y0;
 	render_bounds cellboxbounds;
 	render_bounds boxbounds;
@@ -497,7 +497,7 @@ static void gfxset_handler(running_machine *machine, ui_gfx_state *state)
 	/* compute the size of a single cell at this pixel scale factor, as well as the aspect ratio */
 	cellwidth = (cellboxwidth / (float)xcells) / (float)targwidth;
 	cellheight = (cellboxheight / (float)ycells) / (float)targheight;
-	cellaspect = cellwidth / cellheight;
+	//cellaspect = cellwidth / cellheight;
 
 	/* working from the new width/height, recompute the boxbounds */
 	fullwidth = (float)cellboxwidth / (float)targwidth + 6.5f * chwidth;
@@ -787,14 +787,14 @@ static void gfxset_draw_item(running_machine *machine, const gfx_element *gfx, i
 	for (y = 0; y < height; y++)
 	{
 		UINT32 *dest = (UINT32 *)bitmap->base + (dsty + y) * rowpixels + dstx;
-		UINT8 *src = gfx->gfxdata + index * gfx->char_modulo;
+		const UINT8 *src = gfx_element_get_data(gfx, index);
 
 		/* loop over columns in the cell */
 		for (x = 0; x < width; x++)
 		{
 			int effx = x, effy = y;
 			rgb_t pixel;
-			UINT8 *s;
+			const UINT8 *s;
 
 			/* compute effective x,y values after rotation */
 			if (!(rotate & ORIENTATION_SWAP_XY))
