@@ -16,6 +16,7 @@
 #include "rendutil.h"
 #include "ui.h"
 #include "aviio.h"
+#include "deprecat.h"
 
 #include "snap.lh"
 
@@ -60,7 +61,7 @@ struct _screen_state
 	bitmap_t *				bitmap[2];				/* 2x bitmaps for rendering */
 	UINT8					curbitmap;				/* current bitmap index */
 	UINT8					curtexture;				/* current texture index */
-	bitmap_format			texture_format;			/* texture format of bitmap for this screen */
+	INT32					texture_format;			/* texture format of bitmap for this screen */
 	UINT8					changed;				/* has this bitmap changed? */
 	INT32					last_partial_scan;		/* scanline of last partial update */
 
@@ -130,8 +131,8 @@ struct _video_global
 	INT32					snap_height;			/* height of snapshots (0 == auto) */
 
 	/* movie recording */
-	mame_file *				mng_file;				/* handle to the open movie file */
-	avi_file *				avi_file;				/* handle to the open movie file */
+	mame_file *				mngfile;				/* handle to the open movie file */
+	avi_file *				avifile;				/* handle to the open movie file */
 	attotime				movie_frame_period;		/* period of a single movie frame */
 	attotime				movie_next_frame_time;	/* time of next frame */
 	UINT32 					movie_frame;			/* current movie frame number */
@@ -340,12 +341,9 @@ void video_init(running_machine *machine)
 		(*machine->config->init_palette)(machine, memory_region(machine, "proms"));
 
 	/* actually decode the graphics */
-	if (machine->config->gfxdecodeinfo != NULL)
+	if (PREDECODE_GFX && machine->config->gfxdecodeinfo != NULL)
 		decode_graphics(machine, machine->config->gfxdecodeinfo);
 
-	/* reset video statics and get out of here */
-	pdrawgfx_shadow_lowpri = 0;
-
 	/* create a render target for snapshots */
 	viewname = options_get_string(mame_options(), OPTION_SNAPVIEW);
 	global.snap_native = (machine->primary_screen != NULL && (viewname[0] == 0 || strcmp(viewname, "native") == 0));
@@ -407,7 +405,7 @@ static void video_exit(running_machine *machine)
 
 	/* free all the graphics elements */
 	for (i = 0; i < MAX_GFX_ELEMENTS; i++)
-		freegfx(machine->gfx[i]);
+		gfx_element_free(machine->gfx[i]);
 
 	/* free the snapshot target */
 	if (global.snap_target != NULL)
@@ -436,7 +434,7 @@ static void init_buffered_spriteram(running_machine *machine)
 	assert_always(spriteram_size != 0, "Video buffers spriteram but spriteram_size is 0");
 
 	/* allocate memory for the back buffer */
-	buffered_spriteram = auto_malloc(spriteram_size);
+	buffered_spriteram = auto_alloc_array(machine, UINT8, spriteram_size);
 
 	/* register for saving it */
 	state_save_register_global_pointer(machine, buffered_spriteram, spriteram_size);
@@ -445,7 +443,7 @@ static void init_buffered_spriteram(running_machine *machine)
 	if (spriteram_2_size)
 	{
 		/* allocate memory */
-		buffered_spriteram_2 = auto_malloc(spriteram_2_size);
+		buffered_spriteram_2 = auto_alloc_array(machine, UINT8, spriteram_2_size);
 
 		/* register for saving it */
 		state_save_register_global_pointer(machine, buffered_spriteram_2, spriteram_2_size);
@@ -471,27 +469,29 @@ static void init_buffered_spriteram(running_machine *machine)
 
 static void allocate_graphics(running_machine *machine, const gfx_decode_entry *gfxdecodeinfo)
 {
-	int i;
+	int curgfx;
 
 	/* loop over all elements */
-	for (i = 0; i < MAX_GFX_ELEMENTS && gfxdecodeinfo[i].gfxlayout != NULL; i++)
+	for (curgfx = 0; curgfx < MAX_GFX_ELEMENTS && gfxdecodeinfo[curgfx].gfxlayout != NULL; curgfx++)
 	{
-		int region_length = 8 * memory_region_length(machine, gfxdecodeinfo[i].memory_region);
-		int xscale = (gfxdecodeinfo[i].xscale == 0) ? 1 : gfxdecodeinfo[i].xscale;
-		int yscale = (gfxdecodeinfo[i].yscale == 0) ? 1 : gfxdecodeinfo[i].yscale;
+		const gfx_decode_entry *gfxdecode = &gfxdecodeinfo[curgfx];
+		UINT32 region_length = 8 * memory_region_length(machine, gfxdecode->memory_region);
+		const UINT8 *region_base = memory_region(machine, gfxdecode->memory_region);
+		UINT32 xscale = (gfxdecode->xscale == 0) ? 1 : gfxdecode->xscale;
+		UINT32 yscale = (gfxdecode->yscale == 0) ? 1 : gfxdecode->yscale;
 		UINT32 *extpoffs, extxoffs[MAX_ABS_GFX_SIZE], extyoffs[MAX_ABS_GFX_SIZE];
-		gfx_layout glcopy;
-		const gfx_layout *gl = gfxdecodeinfo[i].gfxlayout;
+		const gfx_layout *gl = gfxdecode->gfxlayout;
 		int israw = (gl->planeoffset[0] == GFX_RAW);
 		int planes = gl->planes;
-		UINT16 width = gl->width;
-		UINT16 height = gl->height;
+		UINT32 width = gl->width;
+		UINT32 height = gl->height;
 		UINT32 total = gl->total;
 		UINT32 charincrement = gl->charincrement;
+		gfx_layout glcopy;
 		int j;
 
 		/* make a copy of the layout */
-		glcopy = *gfxdecodeinfo[i].gfxlayout;
+		glcopy = *gfxdecode->gfxlayout;
 
 		/* copy the X and Y offsets into temporary arrays */
 		memcpy(extxoffs, glcopy.xoffset, sizeof(glcopy.xoffset));
@@ -526,8 +526,7 @@ static void allocate_graphics(running_machine *machine, const gfx_decode_entry *
 		/* if the character count is a region fraction, compute the effective total */
 		if (IS_FRAC(total))
 		{
-			if (region_length == 0)
-				continue;
+			assert(region_length != 0);
 			total = region_length / charincrement * FRAC_NUM(total) / FRAC_DEN(total);
 		}
 
@@ -539,7 +538,10 @@ static void allocate_graphics(running_machine *machine, const gfx_decode_entry *
 			{
 				UINT32 value = extpoffs[j];
 				if (IS_FRAC(value))
+				{
+					assert(region_length != 0);
 					extpoffs[j] = FRAC_OFFSET(value) + region_length * FRAC_NUM(value) / FRAC_DEN(value);
+				}
 			}
 
 			/* loop over all the X/Y offsets, converting fractions */
@@ -547,21 +549,27 @@ static void allocate_graphics(running_machine *machine, const gfx_decode_entry *
 			{
 				UINT32 value = extxoffs[j];
 				if (IS_FRAC(value))
+				{
+					assert(region_length != 0);
 					extxoffs[j] = FRAC_OFFSET(value) + region_length * FRAC_NUM(value) / FRAC_DEN(value);
+				}
 			}
 
 			for (j = 0; j < height; j++)
 			{
 				UINT32 value = extyoffs[j];
 				if (IS_FRAC(value))
+				{
+					assert(region_length != 0);
 					extyoffs[j] = FRAC_OFFSET(value) + region_length * FRAC_NUM(value) / FRAC_DEN(value);
+				}
 			}
 		}
 
 		/* otherwise, just use the line modulo */
 		else
 		{
-			int base = gfxdecodeinfo[i].start;
+			int base = gfxdecode->start;
 			int end = region_length/8;
 			int linemod = gl->yoffset[0];
 			while (total > 0)
@@ -580,11 +588,7 @@ static void allocate_graphics(running_machine *machine, const gfx_decode_entry *
 		glcopy.total = total;
 
 		/* allocate the graphics */
-		machine->gfx[i] = allocgfx(machine, &glcopy);
-
-		/* if we have a remapped colortable, point our local colortable to it */
-		machine->gfx[i]->total_colors = gfxdecodeinfo[i].total_color_codes;
-		machine->gfx[i]->color_base = machine->config->gfxdecodeinfo[i].color_codes_start;
+		machine->gfx[curgfx] = gfx_element_alloc(machine, &glcopy, (region_base != NULL) ? region_base + gfxdecode->start : NULL, gfxdecode->total_color_codes, gfxdecode->color_codes_start);
 	}
 }
 
@@ -610,7 +614,6 @@ static void decode_graphics(running_machine *machine, const gfx_decode_entry *gf
 			/* if we have a valid region, decode it now */
 			if (gfxdecodeinfo[i].memory_region != NULL)
 			{
-				UINT8 *region_base = memory_region(machine, gfxdecodeinfo[i].memory_region);
 				gfx_element *gfx = machine->gfx[i];
 				int j;
 
@@ -619,7 +622,7 @@ static void decode_graphics(running_machine *machine, const gfx_decode_entry *gf
 				{
 					char buffer[200];
 					int num_to_decode = (j + 1024 < gfx->total_elements) ? 1024 : (gfx->total_elements - j);
-					decodegfx(gfx, region_base + gfxdecodeinfo[i].start, j, num_to_decode);
+					decodegfx(gfx, j, num_to_decode);
 					curgfx += num_to_decode;
 
 					/* display some startup text */
@@ -648,7 +651,7 @@ static void decode_graphics(running_machine *machine, const gfx_decode_entry *gf
 void video_screen_configure(const device_config *screen, int width, int height, const rectangle *visarea, attoseconds_t frame_period)
 {
 	screen_state *state = get_safe_token(screen);
-	screen_config *config = screen->inline_config;
+	screen_config *config = (screen_config *)screen->inline_config;
 
 	/* validate arguments */
 	assert(width > 0);
@@ -703,7 +706,7 @@ void video_screen_configure(const device_config *screen, int width, int height,
 static void realloc_screen_bitmaps(const device_config *screen)
 {
 	screen_state *state = get_safe_token(screen);
-	screen_config *config = screen->inline_config;
+	screen_config *config = (screen_config *)screen->inline_config;
 	if (config->type != SCREEN_TYPE_VECTOR)
 	{
 		int curwidth = 0, curheight = 0;
@@ -1199,7 +1202,7 @@ static DEVICE_START( video_screen )
 	assert(container != NULL);
 
 	/* get and validate the configuration */
-	config = screen->inline_config;
+	config = (screen_config *)screen->inline_config;
 	assert(config->width > 0);
 	assert(config->height > 0);
 	assert(config->refresh > 0);
@@ -1261,8 +1264,6 @@ static DEVICE_START( video_screen )
 	state_save_register_device_item(screen, 0, state->vblank_end_time.attoseconds);
 	state_save_register_device_item(screen, 0, state->frame_number);
 	state_save_register_postload(device->machine, video_screen_postload, (void *)device);
-
-	return DEVICE_START_OK;
 }
 
 
@@ -1273,8 +1274,9 @@ static DEVICE_START( video_screen )
 
 static STATE_POSTLOAD( video_screen_postload )
 {
-	const device_config *screen = param;
+	const device_config *screen = (const device_config *)param;
 	realloc_screen_bitmaps(screen);
+	global.movie_next_frame_time = timer_get_time(machine);
 }
 
 
@@ -1299,20 +1301,6 @@ static DEVICE_STOP( video_screen )
 }
 
 
-/*-------------------------------------------------
-    video_screen_set_info - device set info
-    callback
--------------------------------------------------*/
-
-static DEVICE_SET_INFO( video_screen )
-{
-	switch (state)
-	{
-		/* no parameters to set */
-	}
-}
-
-
 /*-------------------------------------------------
     video_screen_get_info - device get info
     callback
@@ -1328,7 +1316,6 @@ DEVICE_GET_INFO( video_screen )
 		case DEVINFO_INT_CLASS:					info->i = DEVICE_CLASS_VIDEO;			break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case DEVINFO_FCT_SET_INFO:				info->set_info = DEVICE_SET_INFO_NAME(video_screen); break;
 		case DEVINFO_FCT_START:					info->start = DEVICE_START_NAME(video_screen); break;
 		case DEVINFO_FCT_STOP:					info->stop = DEVICE_STOP_NAME(video_screen); break;
 		case DEVINFO_FCT_RESET:					/* Nothing */							break;
@@ -1356,7 +1343,7 @@ DEVICE_GET_INFO( video_screen )
 static TIMER_CALLBACK( vblank_begin_callback )
 {
 	int i;
-	device_config *screen = ptr;
+	const device_config *screen = (const device_config *)ptr;
 	screen_state *state = get_safe_token(screen);
 
 	/* reset the starting VBLANK time */
@@ -1376,7 +1363,7 @@ static TIMER_CALLBACK( vblank_begin_callback )
 
 	/* if no VBLANK period, call the VBLANK end callback immedietely, otherwise reset the timer */
 	if (state->vblank_period == 0)
-		vblank_end_callback(machine, screen, 0);
+		vblank_end_callback(machine, ptr, 0);
 	else
 		timer_adjust_oneshot(state->vblank_end_timer, video_screen_get_time_until_vblank_end(screen), 0);
 }
@@ -1390,7 +1377,7 @@ static TIMER_CALLBACK( vblank_begin_callback )
 static TIMER_CALLBACK( vblank_end_callback )
 {
 	int i;
-	const device_config *screen = ptr;
+	const device_config *screen = (const device_config *)ptr;
 	screen_state *state = get_safe_token(screen);
 
 	/* call the screen specific callbacks */
@@ -1425,7 +1412,7 @@ static TIMER_CALLBACK( screenless_update_callback )
 
 static TIMER_CALLBACK( scanline0_callback )
 {
-	const device_config *screen = ptr;
+	const device_config *screen = (const device_config *)ptr;
 	screen_state *state = get_safe_token(screen);
 
 	/* reset partial updates */
@@ -1443,7 +1430,7 @@ static TIMER_CALLBACK( scanline0_callback )
 
 static TIMER_CALLBACK( scanline_update_callback )
 {
-	const device_config *screen = ptr;
+	const device_config *screen = (const device_config *)ptr;
 	screen_state *state = get_safe_token(screen);
 	int scanline = param;
 
@@ -1555,7 +1542,7 @@ static int finish_screen_updates(running_machine *machine)
 		/* only update if live */
 		if (render_is_live_screen(screen))
 		{
-			const screen_config *config = screen->inline_config;
+			const screen_config *config = (const screen_config *)screen->inline_config;
 
 			/* only update if empty and not a vector game; otherwise assume the driver did it directly */
 			if (config->type != SCREEN_TYPE_VECTOR && (machine->config->video_attributes & VIDEO_SELF_RENDER) == 0)
@@ -2374,7 +2361,7 @@ static file_error mame_fopen_next(running_machine *machine, const char *pathopti
 
 int video_mng_is_movie_active(running_machine *machine)
 {
-	return (global.mng_file != NULL);
+	return (global.mngfile != NULL);
 }
 
 
@@ -2391,7 +2378,7 @@ void video_mng_begin_recording(running_machine *machine, const char *name)
 	int rate;
 
 	/* close any existing movie file */
-	if (global.mng_file != NULL)
+	if (global.mngfile != NULL)
 		video_mng_end_recording(machine);
 
 	/* look up the primary screen */
@@ -2403,13 +2390,13 @@ void video_mng_begin_recording(running_machine *machine, const char *name)
 
 	/* create a new movie file and start recording */
 	if (name != NULL)
-		filerr = mame_fopen(SEARCHPATH_MOVIE, name, OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS, &global.mng_file);
+		filerr = mame_fopen(SEARCHPATH_MOVIE, name, OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS, &global.mngfile);
 	else
-		filerr = mame_fopen_next(machine, SEARCHPATH_MOVIE, "mng", &global.mng_file);
+		filerr = mame_fopen_next(machine, SEARCHPATH_MOVIE, "mng", &global.mngfile);
 
 	/* start the capture */
 	rate = (state != NULL) ? ATTOSECONDS_TO_HZ(state->frame_period) : DEFAULT_FRAME_RATE;
-	pngerr = mng_capture_start(mame_core_file(global.mng_file), global.snap_bitmap, rate);
+	pngerr = mng_capture_start(mame_core_file(global.mngfile), global.snap_bitmap, rate);
 	if (pngerr != PNGERR_NONE)
 	{
 		video_mng_end_recording(machine);
@@ -2431,11 +2418,11 @@ void video_mng_begin_recording(running_machine *machine, const char *name)
 void video_mng_end_recording(running_machine *machine)
 {
 	/* close the file if it exists */
-	if (global.mng_file != NULL)
+	if (global.mngfile != NULL)
 	{
-		mng_capture_stop(mame_core_file(global.mng_file));
-		mame_fclose(global.mng_file);
-		global.mng_file = NULL;
+		mng_capture_stop(mame_core_file(global.mngfile));
+		mame_fclose(global.mngfile);
+		global.mngfile = NULL;
 		global.movie_frame = 0;
 	}
 }
@@ -2449,7 +2436,7 @@ void video_mng_end_recording(running_machine *machine)
 static void video_mng_record_frame(running_machine *machine)
 {
 	/* only record if we have a file */
-	if (global.mng_file != NULL)
+	if (global.mngfile != NULL)
 	{
 		attotime curtime = timer_get_time(machine);
 		png_info pnginfo = { 0 };
@@ -2478,7 +2465,7 @@ static void video_mng_record_frame(running_machine *machine)
 
 			/* write the next frame */
 			palette = (machine->palette != NULL) ? palette_entry_list_adjusted(machine->palette) : NULL;
-			error = mng_capture_frame(mame_core_file(global.mng_file), &pnginfo, global.snap_bitmap, machine->config->total_colors, palette);
+			error = mng_capture_frame(mame_core_file(global.mngfile), &pnginfo, global.snap_bitmap, machine->config->total_colors, palette);
 			png_free(&pnginfo);
 			if (error != PNGERR_NONE)
 			{
@@ -2515,7 +2502,7 @@ void video_avi_begin_recording(running_machine *machine, const char *name)
 	avi_error avierr;
 
 	/* close any existing movie file */
-	if (global.avi_file != NULL)
+	if (global.avifile != NULL)
 		video_avi_end_recording(machine);
 
 	/* look up the primary screen */
@@ -2560,7 +2547,7 @@ void video_avi_begin_recording(running_machine *machine, const char *name)
 		mame_fclose(tempfile);
 
 		/* create the file and free the string */
-		avierr = avi_create(astring_c(fullname), &info, &global.avi_file);
+		avierr = avi_create(astring_c(fullname), &info, &global.avifile);
 		astring_free(fullname);
 	}
 }
@@ -2574,10 +2561,10 @@ void video_avi_begin_recording(running_machine *machine, const char *name)
 void video_avi_end_recording(running_machine *machine)
 {
 	/* close the file if it exists */
-	if (global.avi_file != NULL)
+	if (global.avifile != NULL)
 	{
-		avi_close(global.avi_file);
-		global.avi_file = NULL;
+		avi_close(global.avifile);
+		global.avifile = NULL;
 		global.movie_frame = 0;
 	}
 }
@@ -2591,7 +2578,7 @@ void video_avi_end_recording(running_machine *machine)
 static void video_avi_record_frame(running_machine *machine)
 {
 	/* only record if we have a file */
-	if (global.avi_file != NULL)
+	if (global.avifile != NULL)
 	{
 		attotime curtime = timer_get_time(machine);
 		avi_error avierr;
@@ -2605,7 +2592,7 @@ static void video_avi_record_frame(running_machine *machine)
 		while (attotime_compare(global.movie_next_frame_time, curtime) <= 0)
 		{
 			/* write the next frame */
-			avierr = avi_append_video_frame_rgb32(global.avi_file, global.snap_bitmap);
+			avierr = avi_append_video_frame_rgb32(global.avifile, global.snap_bitmap);
 			if (avierr != AVIERR_NONE)
 			{
 				video_avi_end_recording(machine);
@@ -2630,16 +2617,16 @@ static void video_avi_record_frame(running_machine *machine)
 void video_avi_add_sound(running_machine *machine, const INT16 *sound, int numsamples)
 {
 	/* only record if we have a file */
-	if (global.avi_file != NULL)
+	if (global.avifile != NULL)
 	{
 		avi_error avierr;
 
 		profiler_mark(PROFILER_MOVIE_REC);
 
 		/* write the next frame */
-		avierr = avi_append_sound_samples(global.avi_file, 0, sound + 0, numsamples, 1);
+		avierr = avi_append_sound_samples(global.avifile, 0, sound + 0, numsamples, 1);
 		if (avierr == AVIERR_NONE)
-			avierr = avi_append_sound_samples(global.avi_file, 1, sound + 1, numsamples, 1);
+			avierr = avi_append_sound_samples(global.avifile, 1, sound + 1, numsamples, 1);
 		if (avierr != AVIERR_NONE)
 			video_avi_end_recording(machine);
 
@@ -2726,6 +2713,38 @@ int video_get_view_for_target(running_machine *machine, render_target *target, c
 
 
 
+/***************************************************************************
+    DEBUGGING HELPERS
+***************************************************************************/
+
+/*-------------------------------------------------
+    video_assert_out_of_range_pixels - assert if
+    any pixels in the given bitmap contain an
+    invalid palette index
+-------------------------------------------------*/
+
+void video_assert_out_of_range_pixels(running_machine *machine, bitmap_t *bitmap)
+{
+#ifdef MAME_DEBUG
+	int maxindex = palette_get_max_index(machine->palette);
+	int x, y;
+
+	/* this only applies to indexed16 bitmaps */
+	if (bitmap->format != BITMAP_FORMAT_INDEXED16)
+		return;
+
+	/* iterate over rows */
+	for (y = 0; y < bitmap->height; y++)
+	{
+		UINT16 *rowbase = BITMAP_ADDR16(bitmap, y, 0);
+		for (x = 0; x < bitmap->width; x++)
+			assert(rowbase[x] < maxindex);
+	}
+#endif
+}
+
+
+
 /***************************************************************************
     SOFTWARE RENDERING
 ***************************************************************************/
