@@ -52,7 +52,7 @@ enum
 #define video_screen_get_format(screen)	(((screen_config *)(screen)->inline_config)->format)
 
 /* allocates a bitmap that has the same dimensions and format as the passed in screen */
-#define video_screen_auto_bitmap_alloc(screen)	auto_bitmap_alloc(video_screen_get_width(screen), video_screen_get_height(screen), video_screen_get_format(screen))
+#define video_screen_auto_bitmap_alloc(screen)	auto_bitmap_alloc(screen->machine, video_screen_get_width(screen), video_screen_get_height(screen), video_screen_get_format(screen))
 
 
 
@@ -99,11 +99,8 @@ typedef void (*vblank_state_changed_func)(const device_config *device, void *par
 	MDRV_DEVICE_ADD(_tag, VIDEO_SCREEN, 0) \
 	MDRV_DEVICE_CONFIG_DATA32(screen_config, type, SCREEN_TYPE_##_type)
 
-#define MDRV_SCREEN_REMOVE(_tag) \
-	MDRV_DEVICE_REMOVE(_tag, VIDEO_SCREEN)
-
 #define MDRV_SCREEN_MODIFY(_tag) \
-	MDRV_DEVICE_MODIFY(_tag, VIDEO_SCREEN)
+	MDRV_DEVICE_MODIFY(_tag)
 
 #define MDRV_SCREEN_FORMAT(_format) \
 	MDRV_DEVICE_CONFIG_DATA32(screen_config, format, _format)
@@ -278,4 +275,11 @@ void video_avi_add_sound(running_machine *machine, const INT16 *sound, int numsa
 /* select a view for a given target */
 int video_get_view_for_target(running_machine *machine, render_target *target, const char *viewname, int targetindex, int numtargets);
 
+
+/* ----- debugging helpers ----- */
+
+/* assert if any pixels in the given bitmap contain an invalid palette index */
+void video_assert_out_of_range_pixels(running_machine *machine, bitmap_t *bitmap);
+
+
 #endif	/* __VIDEO_H__ */
