@@ -367,7 +367,7 @@ equal to the size of normal spriteram.
 
     Spriteram size _must_ be declared in the memory map:
 
-    { 0x120000, 0x1207ff, SMH_BANK2, &spriteram, &spriteram_size },
+    { 0x120000, 0x1207ff, SMH_BANK(2), &spriteram, &spriteram_size },
 
     Then the video driver must draw the sprites from the buffered_spriteram
 pointer.  The function buffer_spriteram_w() is used to simulate hardware
@@ -569,6 +569,21 @@ int flip_screen_y_get(running_machine *machine)
     COMMON PALETTE INITIALIZATION
 ***************************************************************************/
 
+/*-------------------------------------------------
+    black - completely black pelette
+-------------------------------------------------*/
+
+PALETTE_INIT( all_black )
+{
+	int i;
+
+	for (i = 0; i < machine->config->total_colors; i++)
+	{
+		palette_set_color(machine,i,RGB_BLACK); /* black */
+	}
+}
+
+
 /*-------------------------------------------------
     black_and_white - basic 2-color black & white
 -------------------------------------------------*/
@@ -706,6 +721,20 @@ WRITE8_HANDLER( paletteram_BBGGRRII_w )
 	                                   pal4bit(((data >> 4) & 0x0c) | i));
 }
 
+/*-------------------------------------------------
+    II-BB-GG-RR writes
+-------------------------------------------------*/
+
+WRITE8_HANDLER( paletteram_IIBBGGRR_w )
+{
+	int i = (data >> 6) & 3;
+
+	paletteram[offset] = data;
+	palette_set_color_rgb(space->machine, offset, pal4bit(((data << 2) & 0x0c) | i),
+	                                   pal4bit(((data >> 0) & 0x0c) | i),
+	                                   pal4bit(((data >> 2) & 0x0c) | i));
+}
+
 
 
 /***************************************************************************
@@ -815,6 +844,18 @@ WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_be_w )
 	set_color_444(space->machine, offset / 2, 8, 4, 0, paletteram16_be(offset));
 }
 
+WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split1_w )
+{
+	paletteram[offset] = data;
+	set_color_444(space->machine, offset, 8, 4, 0, paletteram16_split(offset));
+}
+
+WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split2_w )
+{
+	paletteram_2[offset] = data;
+	set_color_444(space->machine, offset, 8, 4, 0, paletteram16_split(offset));
+}
+
 WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
