@@ -131,6 +131,7 @@ int flip_screen_y_get(running_machine *machine);
 
 /* ----- generic palette init routines ----- */
 
+PALETTE_INIT( all_black );
 PALETTE_INIT( black_and_white );
 PALETTE_INIT( RRRR_GGGG_BBBB );
 PALETTE_INIT( RRRRR_GGGGG_BBBBB );
@@ -145,6 +146,7 @@ PALETTE_INIT( RRRRR_GGGGGG_BBBBB );
 WRITE8_HANDLER( paletteram_BBGGGRRR_w );
 WRITE8_HANDLER( paletteram_RRRGGGBB_w );
 WRITE8_HANDLER( paletteram_BBGGRRII_w );
+WRITE8_HANDLER( paletteram_IIBBGGRR_w );
 
 /* 4-4-4 RGB palette write handlers */
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_le_w );
@@ -164,6 +166,8 @@ WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w );	/* uses paletteram_2[] *
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_le_w );
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_be_w );
+WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split1_w );	/* uses paletteram[] */
+WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split2_w );	/* uses paletteram_2[] */
 WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w );
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_be_w );
