@@ -11,12 +11,25 @@
 
 static emu_timer *schaser_effect_555_timer;
 static attotime schaser_effect_555_time_remain;
+static INT32 schaser_effect_555_time_remain_savable;
 static int schaser_effect_555_is_low;
 static int schaser_explosion;
-static UINT8 port_1_last = 0;
-static UINT8 port_2_last = 0;
-static UINT8 port_3_last = 0;
+static UINT8 port_1_last_extra = 0;
+static UINT8 port_2_last_extra = 0;
+static UINT8 port_3_last_extra = 0;
 
+/*******************************************************/
+/*                                                     */
+/* Global state registration                           */
+/*                                                     */
+/*******************************************************/
+
+MACHINE_START( extra_8080bw_sh )
+{
+    state_save_register_global(machine, port_1_last_extra);
+    state_save_register_global(machine, port_2_last_extra);
+    state_save_register_global(machine, port_3_last_extra);
+}
 
 /*******************************************************/
 /*                                                     */
@@ -26,20 +39,22 @@ static UINT8 port_3_last = 0;
 
 WRITE8_HANDLER( invadpt2_sh_port_1_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	sn76477_enable_w(0, !(data & 0x01));			/* SAUCER SOUND */
+	sn76477_enable_w(sn, !(data & 0x01));			/* SAUCER SOUND */
 
-	if (rising_bits & 0x02) sample_start_n(0, 0, 0, 0);		/* MISSLE SOUND */
-	if (rising_bits & 0x04) sample_start_n(0, 1, 1, 0);		/* EXPLOSION */
-	if (rising_bits & 0x08) sample_start_n(0, 2, 2, 0);		/* INVADER HIT */
-	if (rising_bits & 0x10) sample_start_n(0, 5, 8, 0);		/* BONUS MISSILE BASE */
+	if (rising_bits & 0x02) sample_start(samples, 0, 0, 0);		/* MISSLE SOUND */
+	if (rising_bits & 0x04) sample_start(samples, 1, 1, 0);		/* EXPLOSION */
+	if (rising_bits & 0x08) sample_start(samples, 2, 2, 0);		/* INVADER HIT */
+	if (rising_bits & 0x10) sample_start(samples, 5, 8, 0);		/* BONUS MISSILE BASE */
 
     c8080bw_screen_red_w(data & 0x04);
 
 	sound_global_enable(data & 0x20);
 
-	port_1_last = data;
+	port_1_last_extra = data;
 
 }
 
@@ -52,17 +67,18 @@ WRITE8_HANDLER( invadpt2_sh_port_2_w )
        D2 = 82K
        D3 = 100K */
 
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (rising_bits & 0x01) sample_start_n(0, 4, 3, 0);		/* FLEET */
-	if (rising_bits & 0x02) sample_start_n(0, 4, 4, 0);		/* FLEET */
-	if (rising_bits & 0x04) sample_start_n(0, 4, 5, 0);		/* FLEET */
-	if (rising_bits & 0x08) sample_start_n(0, 4, 6, 0);		/* FLEET */
-	if (rising_bits & 0x10) sample_start_n(0, 3, 7, 0);		/* SAUCER HIT */
+	if (rising_bits & 0x01) sample_start(samples, 4, 3, 0);		/* FLEET */
+	if (rising_bits & 0x02) sample_start(samples, 4, 4, 0);		/* FLEET */
+	if (rising_bits & 0x04) sample_start(samples, 4, 5, 0);		/* FLEET */
+	if (rising_bits & 0x08) sample_start(samples, 4, 6, 0);		/* FLEET */
+	if (rising_bits & 0x10) sample_start(samples, 3, 7, 0);		/* SAUCER HIT */
 
     c8080bw_flip_screen_w(space, data & 0x20);
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
 
@@ -74,17 +90,20 @@ WRITE8_HANDLER( invadpt2_sh_port_2_w )
 
 WRITE8_HANDLER( spcewars_sh_port_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *speaker = devtag_get_device(space->machine, "speaker");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	sn76477_enable_w(0, !(data & 0x01));			/* Saucer Sound */
+	sn76477_enable_w(sn, !(data & 0x01));			/* Saucer Sound */
 
-	if (rising_bits & 0x02) sample_start(0, 0, 0);		/* Shot Sound */
-	if (rising_bits & 0x04) sample_start(1, 1, 0);		/* Base Hit */
-	if (rising_bits & 0x08) sample_start(2, 2, 0);		/* Invader Hit */
+	if (rising_bits & 0x02) sample_start(samples, 0, 0, 0);		/* Shot Sound */
+	if (rising_bits & 0x04) sample_start(samples, 1, 1, 0);		/* Base Hit */
+	if (rising_bits & 0x08) sample_start(samples, 2, 2, 0);		/* Invader Hit */
 
-	speaker_level_w(0, (data & 0x10) ? 1 : 0);		/* Various bitstream tunes */
+	speaker_level_w(speaker, (data & 0x10) ? 1 : 0);		/* Various bitstream tunes */
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 
@@ -117,37 +136,40 @@ const samples_interface lrescue_samples_interface =
 
 WRITE8_HANDLER( lrescue_sh_port_1_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(0, 3, 0);		/* Thrust */
-	if (rising_bits & 0x02) sample_start(1, 2, 0);		/* Shot Sound */
-	if (rising_bits & 0x04) sample_start(0, 1, 0);		/* Death */
-	if (rising_bits & 0x08) sample_start(1, 0, 0);		/* Alien Hit */
-	if (rising_bits & 0x10) sample_start(2, 5, 0);		/* Bonus Ship (not confirmed) */
+	if (rising_bits & 0x01) sample_start(samples, 0, 3, 0);		/* Thrust */
+	if (rising_bits & 0x02) sample_start(samples, 1, 2, 0);		/* Shot Sound */
+	if (rising_bits & 0x04) sample_start(samples, 0, 1, 0);		/* Death */
+	if (rising_bits & 0x08) sample_start(samples, 1, 0, 0);		/* Alien Hit */
+	if (rising_bits & 0x10) sample_start(samples, 2, 5, 0);		/* Bonus Ship (not confirmed) */
 
 	sound_global_enable(data & 0x20);
 
 	c8080bw_screen_red_w(data & 0x04);
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( lrescue_sh_port_2_w )
 {
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *speaker = devtag_get_device(space->machine, "speaker");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (rising_bits & 0x01) sample_start(1, 8, 0);		/* Footstep high tone */
-	if (rising_bits & 0x02) sample_start(1, 7, 0);		/* Footstep low tone */
-	if (rising_bits & 0x04) sample_start(1, 4, 0);		/* Bonus when counting men saved */
+	if (rising_bits & 0x01) sample_start(samples, 1, 8, 0);		/* Footstep high tone */
+	if (rising_bits & 0x02) sample_start(samples, 1, 7, 0);		/* Footstep low tone */
+	if (rising_bits & 0x04) sample_start(samples, 1, 4, 0);		/* Bonus when counting men saved */
 
-	speaker_level_w(0, (data & 0x08) ? 1 : 0);		/* Bitstream tunes - endlevel and bonus1 */
+	speaker_level_w(speaker, (data & 0x08) ? 1 : 0);		/* Bitstream tunes - endlevel and bonus1 */
 
-	if (rising_bits & 0x10) sample_start(3, 6, 0);		/* Shooting Star and Rescue Ship sounds */
-	if (~data & 0x10 && port_2_last & 0x10) sample_stop (3);	/* This makes the rescue ship sound beep on and off */
+	if (rising_bits & 0x10) sample_start(samples, 3, 6, 0);		/* Shooting Star and Rescue Ship sounds */
+	if (~data & 0x10 && port_2_last_extra & 0x10) sample_stop (samples, 3);	/* This makes the rescue ship sound beep on and off */
 
 	c8080bw_flip_screen_w(space, data & 0x20);
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
 
@@ -173,32 +195,34 @@ WRITE8_HANDLER( cosmo_sh_port_2_w )
 
 WRITE8_HANDLER( ballbomb_sh_port_1_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(1, 2, 0);		/* Hit a balloon */
-	if (rising_bits & 0x02) sample_start(2, 0, 0);		/* Shot Sound */
-	if (rising_bits & 0x04) sample_start(2, 1, 0);		/* Base Hit */
-	if (rising_bits & 0x08) sample_start(1, 7, 0);		/* Hit a Bomb */
-	if (rising_bits & 0x10) sample_start(3, 8, 0);		/* Bonus Base at 1500 points */
+	if (rising_bits & 0x01) sample_start(samples, 1, 2, 0);		/* Hit a balloon */
+	if (rising_bits & 0x02) sample_start(samples, 2, 0, 0);		/* Shot Sound */
+	if (rising_bits & 0x04) sample_start(samples, 2, 1, 0);		/* Base Hit */
+	if (rising_bits & 0x08) sample_start(samples, 1, 7, 0);		/* Hit a Bomb */
+	if (rising_bits & 0x10) sample_start(samples, 3, 8, 0);		/* Bonus Base at 1500 points */
 
 	sound_global_enable(data & 0x20);
 
 	c8080bw_screen_red_w(data & 0x04);
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( ballbomb_sh_port_2_w )
 {
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (data & 0x01) sample_start(0, 7, 0);		/* Indicates plane will drop bombs */
-	if (data & 0x04) sample_start(0, 4, 0);		/* Plane is dropping new balloons at start of level */
-	if (rising_bits & 0x10) sample_start(2, 2, 0);		/* Balloon hit and bomb drops */
+	if (data & 0x01) sample_start(samples, 0, 7, 0);		/* Indicates plane will drop bombs */
+	if (data & 0x04) sample_start(samples, 0, 4, 0);		/* Plane is dropping new balloons at start of level */
+	if (rising_bits & 0x10) sample_start(samples, 2, 2, 0);		/* Balloon hit and bomb drops */
 
 	c8080bw_flip_screen_w(space, data & 0x20);
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
 
@@ -249,35 +273,37 @@ WRITE8_HANDLER( indianbt_sh_port_1_w )
 {
 	/* bit 4 occurs every 5.25 seconds during gameplay */
 
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(1, 7, 0);	/* Death */
-	if (rising_bits & 0x02) sample_start(0, 1, 0);		/* Shot Sound */
-	if (rising_bits & 0x04) sample_start(2, 3, 0);		/* Move */
-	if (rising_bits & 0x08) sample_start(3, 2, 0);		/* Hit */
+	if (rising_bits & 0x01) sample_start(samples, 1, 7, 0);	/* Death */
+	if (rising_bits & 0x02) sample_start(samples, 0, 1, 0);		/* Shot Sound */
+	if (rising_bits & 0x04) sample_start(samples, 2, 3, 0);		/* Move */
+	if (rising_bits & 0x08) sample_start(samples, 3, 2, 0);		/* Hit */
 
 	sound_global_enable(data & 0x20);
 
 	c8080bw_screen_red_w(data & 0x01);
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( indianbt_sh_port_2_w )
 {
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (rising_bits & 0x01) sample_start(4, 0, 0);		/* Bird dropped an egg, Lasso used */
-	if (rising_bits & 0x02) sample_start(4, 2, 0);	/* Egg hatches, egg shot */
-	if (rising_bits & 0x08) sample_start(5, 0, 0);		/* Grabber, Lasso caught something */
-	if (rising_bits & 0x10) sample_start(3, 7, 0);		/* Lasso sound */
+	if (rising_bits & 0x01) sample_start(samples, 4, 0, 0);		/* Bird dropped an egg, Lasso used */
+	if (rising_bits & 0x02) sample_start(samples, 4, 2, 0);	/* Egg hatches, egg shot */
+	if (rising_bits & 0x08) sample_start(samples, 5, 0, 0);		/* Grabber, Lasso caught something */
+	if (rising_bits & 0x10) sample_start(samples, 3, 7, 0);		/* Lasso sound */
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
-WRITE8_HANDLER( indianbt_sh_port_3_w )
+WRITE8_DEVICE_HANDLER( indianbt_sh_port_3_w )
 {
-	discrete_sound_w(space, INDIANBT_MUSIC_DATA, data);
+	discrete_sound_w(device, INDIANBT_MUSIC_DATA, data);
 }
 
 
@@ -593,49 +619,49 @@ DISCRETE_SOUND_START(polaris)
 
 DISCRETE_SOUND_END
 
-WRITE8_HANDLER( polaris_sh_port_1_w )
+WRITE8_DEVICE_HANDLER( polaris_sh_port_1_w )
 {
-	discrete_sound_w(space, POLARIS_MUSIC_DATA, data);
+	discrete_sound_w(device, POLARIS_MUSIC_DATA, data);
 }
 
-WRITE8_HANDLER( polaris_sh_port_2_w )
+WRITE8_DEVICE_HANDLER( polaris_sh_port_2_w )
 {
 	/* 0x01 - SX0 - Shot */
-	discrete_sound_w(space, POLARIS_SX0_EN, data & 0x01);
+	discrete_sound_w(device, POLARIS_SX0_EN, data & 0x01);
 
 	/* 0x02 - SX1 - Ship Hit (Sub) */
-	discrete_sound_w(space, POLARIS_SX1_EN, data & 0x02);
+	discrete_sound_w(device, POLARIS_SX1_EN, data & 0x02);
 
 	/* 0x04 - SX2 - Ship */
-	discrete_sound_w(space, POLARIS_SX2_EN, data & 0x04);
+	discrete_sound_w(device, POLARIS_SX2_EN, data & 0x04);
 
 	/* 0x08 - SX3 - Explosion */
-	discrete_sound_w(space, POLARIS_SX3_EN, data & 0x08);
+	discrete_sound_w(device, POLARIS_SX3_EN, data & 0x08);
 
 	/* 0x10 - SX4 */
 
 	/* 0x20 - SX5 - Sound Enable */
-	discrete_sound_w(space, POLARIS_SX5_EN, data & 0x20);
+	discrete_sound_w(device, POLARIS_SX5_EN, data & 0x20);
 }
 
-WRITE8_HANDLER( polaris_sh_port_3_w )
+WRITE8_DEVICE_HANDLER( polaris_sh_port_3_w )
 {
 
 	coin_lockout_global_w(data & 0x04);  /* SX8 */
 
-	c8080bw_flip_screen_w(space, data & 0x20);  /* SX11 */
+	c8080bw_flip_screen_w(cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM), data & 0x20);  /* SX11 */
 
 	/* 0x01 - SX6 - Plane Down */
-	discrete_sound_w(space, POLARIS_SX6_EN, data & 0x01);
+	discrete_sound_w(device, POLARIS_SX6_EN, data & 0x01);
 
 	/* 0x02 - SX7 - Plane Up */
-	discrete_sound_w(space, POLARIS_SX7_EN, data & 0x02);
+	discrete_sound_w(device, POLARIS_SX7_EN, data & 0x02);
 
 	/* 0x08 - SX9 - Hit */
-	discrete_sound_w(space, POLARIS_SX9_EN, data & 0x08);
+	discrete_sound_w(device, POLARIS_SX9_EN, data & 0x08);
 
 	/* 0x10 - SX10 - Hit */
-	discrete_sound_w(space, POLARIS_SX10_EN, data & 0x10);
+	discrete_sound_w(device, POLARIS_SX10_EN, data & 0x10);
 }
 
 
@@ -773,6 +799,8 @@ static const double schaser_effect_rc[8] =
 
 WRITE8_HANDLER( schaser_sh_port_1_w )
 {
+	const device_config *discrete = devtag_get_device(space->machine, "discrete");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
 	static int last_effect = 0;
 	int effect;
 
@@ -783,8 +811,9 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
        bit 4 - Effect Sound C (SX4)
        bit 5 - Explosion (SX5) */
 
-	discrete_sound_w(space, SCHASER_DOT_EN, data & 0x01);
-	discrete_sound_w(space, SCHASER_DOT_SEL, data & 0x02);
+    //printf( "schaser_sh_port_1_w: %02x\n", data );
+	discrete_sound_w(discrete, SCHASER_DOT_EN, data & 0x01);
+	discrete_sound_w(discrete, SCHASER_DOT_SEL, data & 0x02);
 
 	/* The effect is a variable rate 555 timer.  A diode/resistor array is used to
      * select the frequency.  Because of the diode voltage drop, we can not use the
@@ -815,6 +844,7 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
 			if (!schaser_effect_555_is_low)
 			{
 				schaser_effect_555_time_remain = timer_timeleft(schaser_effect_555_timer);
+                schaser_effect_555_time_remain_savable = attotime_to_double(schaser_effect_555_time_remain);
 				timer_adjust_oneshot(schaser_effect_555_timer, attotime_never, 0);
 			}
 		}
@@ -824,15 +854,15 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
 	schaser_explosion = (data >> 5) & 0x01;
 	if (schaser_explosion)
 	{
-		sn76477_amplitude_res_w(0, 1.0 / (1.0/RES_K(200) + 1.0/RES_K(68)));
+		sn76477_amplitude_res_w(sn, 1.0 / (1.0/RES_K(200) + 1.0/RES_K(68)));
 	}
 	else
 	{
-		sn76477_amplitude_res_w(0, RES_K(200));
+		sn76477_amplitude_res_w(sn, RES_K(200));
 	}
-	sn76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
-	sn76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
-	sn76477_mixer_b_w(0, schaser_explosion);
+	sn76477_enable_w(sn, !(schaser_effect_555_is_low || schaser_explosion));
+	sn76477_one_shot_cap_voltage_w(sn, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
+	sn76477_mixer_b_w(sn, schaser_explosion);
 }
 
 WRITE8_HANDLER( schaser_sh_port_2_w )
@@ -844,9 +874,13 @@ WRITE8_HANDLER( schaser_sh_port_2_w )
        bit 4 - Field Control B (SX10)
        bit 5 - Flip Screen */
 
-	discrete_sound_w(space, SCHASER_MUSIC_BIT, data & 0x01);
+	const device_config *discrete = devtag_get_device(space->machine, "discrete");
 
-	discrete_sound_w(space, SCHASER_SND_EN, data & 0x02);
+    printf( "schaser_sh_port_2_w: %02x\n", data );
+
+	discrete_sound_w(discrete, SCHASER_MUSIC_BIT, data & 0x01);
+
+	discrete_sound_w(discrete, SCHASER_SND_EN, data & 0x02);
 	sound_global_enable(data & 0x02);
 
 	coin_lockout_global_w(data & 0x04);
@@ -854,16 +888,20 @@ WRITE8_HANDLER( schaser_sh_port_2_w )
 	schaser_background_control_w(data & 0x18);
 
 	c8080bw_flip_screen_w(space, data & 0x20);
+
+    port_2_last_extra = data;
 }
 
 
 static TIMER_CALLBACK( schaser_effect_555_cb )
 {
+	const device_config *sn = devtag_get_device(machine, "sn");
 	int effect = param;
 	attotime new_time;
 	/* Toggle 555 output */
 	schaser_effect_555_is_low = !schaser_effect_555_is_low;
 	schaser_effect_555_time_remain = attotime_zero;
+    schaser_effect_555_time_remain_savable = attotime_to_double(schaser_effect_555_time_remain);
 
 	if (schaser_effect_555_is_low)
 		new_time = attotime_div(PERIOD_OF_555_ASTABLE(0, RES_K(20), CAP_U(1)), 2);
@@ -875,8 +913,16 @@ static TIMER_CALLBACK( schaser_effect_555_cb )
 			new_time = attotime_never;
 	}
 	timer_adjust_oneshot(schaser_effect_555_timer, new_time, effect);
-	sn76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
-	sn76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
+	sn76477_enable_w(sn, !(schaser_effect_555_is_low || schaser_explosion));
+	sn76477_one_shot_cap_voltage_w(sn, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
+}
+
+
+static STATE_POSTLOAD( schaser_reinit_555_time_remain )
+{
+    const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+    schaser_effect_555_time_remain = double_to_attotime(schaser_effect_555_time_remain_savable);
+    schaser_sh_port_2_w(space, 0, port_2_last_extra);
 }
 
 
@@ -884,18 +930,26 @@ MACHINE_START( schaser )
 {
 	schaser_effect_555_timer = timer_alloc(machine, schaser_effect_555_cb, NULL);
 
+    state_save_register_global(machine, schaser_explosion);
+    state_save_register_global(machine, schaser_effect_555_is_low);
+    state_save_register_global(machine, schaser_effect_555_time_remain_savable);
+    state_save_register_global(machine, port_2_last_extra);
+    state_save_register_postload(machine, schaser_reinit_555_time_remain, NULL);
+
+    MACHINE_START_CALL(extra_8080bw_vh);
 	MACHINE_START_CALL(mw8080bw);
 }
 
 
 MACHINE_RESET( schaser )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	schaser_effect_555_is_low = 0;
 	timer_adjust_oneshot(schaser_effect_555_timer, attotime_never, 0);
 	schaser_sh_port_1_w(space, 0, 0);
 	schaser_sh_port_2_w(space, 0, 0);
 	schaser_effect_555_time_remain = attotime_zero;
+    schaser_effect_555_time_remain_savable = attotime_to_double(schaser_effect_555_time_remain);
 
 	MACHINE_RESET_CALL(mw8080bw);
 }
@@ -909,13 +963,14 @@ MACHINE_RESET( schaser )
 
 WRITE8_HANDLER( rollingc_sh_port_w )
 {
-	UINT8 rising_bits = data & ~port_3_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_3_last_extra;
 
-	if (rising_bits & 0x02) sample_start(4, 0, 0);	/* Steering */
-	if (rising_bits & 0x04) sample_start(0, 1, 0);	/* Collision */
-	if (rising_bits & 0x10) sample_start(1, 8, 0);	/* Computer car is starting to move */
+	if (rising_bits & 0x02) sample_start(samples, 4, 0, 0);	/* Steering */
+	if (rising_bits & 0x04) sample_start(samples, 0, 1, 0);	/* Collision */
+	if (rising_bits & 0x10) sample_start(samples, 1, 8, 0);	/* Computer car is starting to move */
 
-	port_3_last = data;
+	port_3_last_extra = data;
 }
 
 
@@ -932,27 +987,28 @@ WRITE8_HANDLER( rollingc_sh_port_w )
 
 WRITE8_HANDLER( invrvnge_sh_port_w )
 {
+	const device_config *samples = devtag_get_device(space->machine, "samples");
 	switch (data)
 	{
 		case 0x06:
-			sample_start(1, 0, 0);				/* Shoot */
+			sample_start(samples, 1, 0, 0);				/* Shoot */
 			break;
 
 		case 0x14:
-			sample_start(2, 2, 0);				/* Hit Alien */
+			sample_start(samples, 2, 2, 0);				/* Hit Alien */
 			break;
 
 		case 0x16:
-			sample_start(2, 5, 0);				/* Hit Asteroid */
+			sample_start(samples, 2, 5, 0);				/* Hit Asteroid */
 			break;
 
 		case 0x1e:
-			sample_start(3, 1, 0);				/* Death (followed by 0x0a byte), also bit 4 of port 5 */
+			sample_start(samples, 3, 1, 0);				/* Death (followed by 0x0a byte), also bit 4 of port 5 */
 			break;
 
 		case 0x18:						/* Fuel Low */
 		case 0x30:						/* Fuel bar filling up */
-			sample_start(4, 7, 0);
+			sample_start(samples, 4, 7, 0);
 			break;
 
 		case 0x02:						/* Coin */
@@ -962,7 +1018,7 @@ WRITE8_HANDLER( invrvnge_sh_port_w )
 			break;
 
 		case 0x3a:						/* Thrust, Docking, extra ship? */
-			sample_start(0, 8, 0);
+			sample_start(samples, 0, 8, 0);
 			break;
 	}
 }
@@ -975,32 +1031,35 @@ WRITE8_HANDLER( invrvnge_sh_port_w )
 
 WRITE8_HANDLER( lupin3_sh_port_1_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(0, 6, 0);		/* Walking, get money */
+	if (rising_bits & 0x01) sample_start(samples, 0, 6, 0);		/* Walking, get money */
 
-	sn76477_enable_w(0, data & 0x02 ? 0:1);			/* Helicopter */
+	sn76477_enable_w(sn, data & 0x02 ? 0:1);			/* Helicopter */
 
-	if (rising_bits & 0x04) sample_start(0, 7, 0);		/* Translocate */
-	if (rising_bits & 0x08) sample_start(0, 1, 0);		/* Jail */
-	if (rising_bits & 0x10) sample_start(3, 8, 0);		/* Bonus Man */
+	if (rising_bits & 0x04) sample_start(samples, 0, 7, 0);		/* Translocate */
+	if (rising_bits & 0x08) sample_start(samples, 0, 1, 0);		/* Jail */
+	if (rising_bits & 0x10) sample_start(samples, 3, 8, 0);		/* Bonus Man */
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( lupin3_sh_port_2_w )
 {
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (rising_bits & 0x01) sample_start(0, 3, 0);		/* Lands on top of building, wife kicks man */
-	if (rising_bits & 0x02) sample_start(1, 2, 0);		/* deposit money, start intermission, end game */
-	if (rising_bits & 0x04) sample_start(2, 5, 0);		/* deposit money, start intermission, Slides down rope */
-	if (rising_bits & 0x08) sample_start(3, 0, 0);		/* start intermission, end game */
-	//if (rising_bits & 0x10) sample_start(3, 9, 0);        /* Dog barking */
+	if (rising_bits & 0x01) sample_start(samples, 0, 3, 0);		/* Lands on top of building, wife kicks man */
+	if (rising_bits & 0x02) sample_start(samples, 1, 2, 0);		/* deposit money, start intermission, end game */
+	if (rising_bits & 0x04) sample_start(samples, 2, 5, 0);		/* deposit money, start intermission, Slides down rope */
+	if (rising_bits & 0x08) sample_start(samples, 3, 0, 0);		/* start intermission, end game */
+	//if (rising_bits & 0x10) sample_start(samples, 3, 9, 0);        /* Dog barking */
 
 	c8080bw_flip_screen_w(space, data & 0x20);
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
 
@@ -1016,17 +1075,20 @@ WRITE8_HANDLER( schasrcv_sh_port_1_w )
        bit 3 = 1st speedup
        Death is a stream of ff's with some fe's thrown in */
 
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x02) sample_start(1, 6, 0);		/* Ran over a dot */
-	if (rising_bits & 0x10) sample_start(0, 1, 0);		/* Death */
+	if (rising_bits & 0x02) sample_start(samples, 1, 6, 0);		/* Ran over a dot */
+	if (rising_bits & 0x10) sample_start(samples, 0, 1, 0);		/* Death */
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( schasrcv_sh_port_2_w )
 {
-	speaker_level_w(0, (data & 0x01) ? 1 : 0);		/* End-of-Level */
+	const device_config *speaker = devtag_get_device(space->machine, "speaker");
+
+	speaker_level_w(speaker, (data & 0x01) ? 1 : 0);		/* End-of-Level */
 
 	sound_global_enable(data & 0x10);
 
@@ -1041,33 +1103,36 @@ WRITE8_HANDLER( schasrcv_sh_port_2_w )
 
 WRITE8_HANDLER( yosakdon_sh_port_1_w )
 {
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(0, 3, 0);			/* Game Over */
-	if (rising_bits & 0x02) sample_start(2, 0, 0);			/* Bird dead */
-	if (rising_bits & 0x04) sample_start(0, 1, 0);			/* Rifle being fired */
-	if (rising_bits & 0x08) sample_start(1, 2, 0);			/* Man dead */
-	if (rising_bits & 0x10) sample_start(5, 8, 0);			/* Bonus Man? */
+	if (rising_bits & 0x01) sample_start(samples, 0, 3, 0);			/* Game Over */
+	if (rising_bits & 0x02) sample_start(samples, 2, 0, 0);			/* Bird dead */
+	if (rising_bits & 0x04) sample_start(samples, 0, 1, 0);			/* Rifle being fired */
+	if (rising_bits & 0x08) sample_start(samples, 1, 2, 0);			/* Man dead */
+	if (rising_bits & 0x10) sample_start(samples, 5, 8, 0);			/* Bonus Man? */
 
 	sound_global_enable(data & 0x20);
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( yosakdon_sh_port_2_w )
 {
-	UINT8 rising_bits = data & ~port_2_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
+	UINT8 rising_bits = data & ~port_2_last_extra;
 
-	if (rising_bits & 0x01) sample_start(1, 6, 0);			/* Ready? , Game Over */
-	if (rising_bits & 0x04) sample_start(3, 7, 0);			/* Big bird dead */
+	if (rising_bits & 0x01) sample_start(samples, 1, 6, 0);			/* Ready? , Game Over */
+	if (rising_bits & 0x04) sample_start(samples, 3, 7, 0);			/* Big bird dead */
 
-	sn76477_enable_w(0, data & 0x08 ? 0:1);				/* Big bird */
+	sn76477_enable_w(sn, data & 0x08 ? 0:1);				/* Big bird */
 
-	if (rising_bits & 0x10) sample_start(2, 7, 0);			/* Game Over */
+	if (rising_bits & 0x10) sample_start(samples, 2, 7, 0);			/* Game Over */
 
 	c8080bw_flip_screen_w(space, data & 0x20);
 
-	port_2_last = data;
+	port_2_last_extra = data;
 }
 
 
@@ -1080,34 +1145,37 @@ WRITE8_HANDLER( shuttlei_sh_port_1_w )
 {
 	/* bit 3 is high while you are alive and playing */
 
-	UINT8 rising_bits = data & ~port_1_last;
+	const device_config *samples = devtag_get_device(space->machine, "samples");
+	const device_config *sn = devtag_get_device(space->machine, "sn");
+	UINT8 rising_bits = data & ~port_1_last_extra;
 
-	if (rising_bits & 0x01) sample_start(4, 4, 0);			/* Fleet move */
-	if (rising_bits & 0x02) sample_start(5, 8, 0);			/* Extra Tank */
+	if (rising_bits & 0x01) sample_start(samples, 4, 4, 0);			/* Fleet move */
+	if (rising_bits & 0x02) sample_start(samples, 5, 8, 0);			/* Extra Tank */
 
-	sn76477_enable_w(0, data & 0x04 ? 0:1);				/* UFO */
+	sn76477_enable_w(sn, data & 0x04 ? 0:1);				/* UFO */
 
-	port_1_last = data;
+	port_1_last_extra = data;
 }
 
 WRITE8_HANDLER( shuttlei_sh_port_2_w )
 {
+	const device_config *samples = devtag_get_device(space->machine, "samples");
 	switch (data)
 	{
 		case 0x23:
-			sample_start(2, 2, 0);				/* Hit */
+			sample_start(samples, 2, 2, 0);				/* Hit */
 			break;
 
 		case 0x2b:
-			sample_start(0, 0, 0);				/* Shoot */
+			sample_start(samples, 0, 0, 0);				/* Shoot */
 			break;
 
 		case 0xa3:
-			sample_start(3, 7, 0);				/* Hit UFO */
+			sample_start(samples, 3, 7, 0);				/* Hit UFO */
 			break;
 
 		case 0xab:
-			sample_start(1, 1, 0);				/* Death */
+			sample_start(samples, 1, 1, 0);				/* Death */
 			break;
 	}
 }
