@@ -43,7 +43,7 @@ static int random_offset;
 
 static void gottlieb1_sh_w(const device_config *riot, UINT8 data);
 static void gottlieb2_sh_w(const address_space *space, UINT8 data);
-static void trigger_sample(running_machine *machine, UINT8 data);
+static void trigger_sample(const device_config *samples, UINT8 data);
 
 
 
@@ -55,7 +55,7 @@ static void trigger_sample(running_machine *machine, UINT8 data);
 
 WRITE8_HANDLER( gottlieb_sh_w )
 {
-	const device_config *riot = device_list_find_by_tag(space->machine->config->devicelist, RIOT6532, "riot");
+	const device_config *riot = devtag_get_device(space->machine, "riot");
 
 	/* identify rev1 boards by the presence of a 6532 RIOT device */
 	if (riot != NULL)
@@ -74,12 +74,13 @@ WRITE8_HANDLER( gottlieb_sh_w )
 
 static void gottlieb1_sh_w(const device_config *riot, UINT8 data)
 {
+	const device_config *samples = devtag_get_device(riot->machine, "samples");
 	int pa7 = (data & 0x0f) != 0xf;
 	int pa0_5 = ~data & 0x3f;
 
 	/* snoop the data looking for commands that need samples */
-	if (pa7 && sndti_exists(SOUND_SAMPLES, 0))
-		trigger_sample(riot->machine, pa0_5);
+	if (pa7 && samples != NULL)
+		trigger_sample(samples, pa0_5);
 
 	/* write the command data to the low 6 bits, and the trigger to the upper bit */
 	riot6532_porta_in_set(riot, pa0_5 | (pa7 << 7), 0xbf);
@@ -95,7 +96,7 @@ static void gottlieb1_sh_w(const device_config *riot, UINT8 data)
 
 static void snd_interrupt(const device_config *device, int state)
 {
-	cpu_set_input_line(device->machine->cpu[1], M6502_IRQ_LINE, state);
+	cputag_set_input_line(device->machine, "audiocpu", M6502_IRQ_LINE, state);
 }
 
 
@@ -108,7 +109,7 @@ static UINT8 r6532_portb_r(const device_config *device, UINT8 olddata)
 static void r6532_portb_w(const device_config *device, UINT8 newdata, UINT8 olddata)
 {
 	/* unsure if this is ever used, but the NMI is connected to the RIOT's PB7 */
-	cpu_set_input_line(device->machine->cpu[1], INPUT_LINE_NMI, (newdata & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, (newdata & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -129,27 +130,27 @@ static const riot6532_interface gottlieb_riot6532_intf =
  *
  *************************************/
 
-static void play_sample(const char *phonemes)
+static void play_sample(const device_config *samples, const char *phonemes)
 {
 	if (strcmp(phonemes, " HEH3LOOW     AH1EH3I3YMTERI2NDAHN") == 0)	  /* Q-Bert - Hello, I am turned on */
-		sample_start(0, 42, 0);
+		sample_start(samples, 0, 42, 0);
 	else if (strcmp(phonemes, "BAH1EH1Y") == 0)							  /* Q-Bert - Bye, bye */
-		sample_start(0, 43, 0);
+		sample_start(samples, 0, 43, 0);
 	else if (strcmp(phonemes, "A2YHT LEH2FTTH") == 0) 					  /* Reactor - Eight left */
-		sample_start(0, 0, 0);
+		sample_start(samples, 0, 0, 0);
 	else if (strcmp(phonemes, "SI3KS DTYN LEH2FTTH") == 0) 				  /* Reactor - Sixteen left */
-		sample_start(0, 1, 0);
+		sample_start(samples, 0, 1, 0);
 	else if (strcmp(phonemes, "WO2RNYNG KO2R UH1NSDTABUH1L") == 0) 		  /* Reactor - Warning core unstable */
-		sample_start(0, 5, 0);
+		sample_start(samples, 0, 5, 0);
 	else if (strcmp(phonemes, "CHAMBERR   AE1EH2KTI1VA1I3DTEH1DT ") == 0) /* Reactor - Chamber activated */
-		sample_start(0, 7, 0);
+		sample_start(samples, 0, 7, 0);
 }
 
 
-static void trigger_sample(running_machine *machine, UINT8 data)
+static void trigger_sample(const device_config *samples, UINT8 data)
 {
 	/* Reactor samples */
-	if (strcmp(machine->gamedrv->name, "reactor") == 0)
+	if (strcmp(samples->machine->gamedrv->name, "reactor") == 0)
 	{
 		switch (data)
 		{
@@ -157,7 +158,7 @@ static void trigger_sample(running_machine *machine, UINT8 data)
 			case 56:
 			case 57:
 			case 59:
-				sample_start(0, data - 53, 0);
+				sample_start(samples, 0, data - 53, 0);
 				break;
 
 			case 31:
@@ -167,7 +168,7 @@ static void trigger_sample(running_machine *machine, UINT8 data)
 			case 39:
 				score_sample++;
 				if (score_sample < 20)
-					sample_start(0, score_sample, 0);
+					sample_start(samples, 0, score_sample, 0);
 				break;
 		}
 	}
@@ -182,16 +183,16 @@ static void trigger_sample(running_machine *machine, UINT8 data)
 			case 19:
 			case 20:
 			case 21:
-				sample_start(0, (data - 17) * 8 + random_offset, 0);
+				sample_start(samples, 0, (data - 17) * 8 + random_offset, 0);
 				random_offset = (random_offset + 1) & 7;
 				break;
 
 			case 22:
-				sample_start(0,40,0);
+				sample_start(samples, 0,40,0);
 				break;
 
 			case 23:
-				sample_start(0,41,0);
+				sample_start(samples, 0,41,0);
 				break;
 		}
 	}
@@ -201,11 +202,12 @@ static void trigger_sample(running_machine *machine, UINT8 data)
 #ifdef UNUSED_FUNCTION
 void gottlieb_knocker(running_machine *machine)
 {
+	const device_config *samples = devtag_get_device(space->machine, "samples");
 	if (!strcmp(machine->gamedrv->name,"reactor"))	/* reactor */
 	{
 	}
-	else if (sndti_exists(SOUND_SAMPLES, 0))	/* qbert */
-		sample_start(0,44,0);
+	else if (samples != NULL)	/* qbert */
+		sample_start(samples, 0,44,0);
 }
 #endif
 
@@ -220,7 +222,7 @@ void gottlieb_knocker(running_machine *machine)
 /* callback for the timer */
 static TIMER_CALLBACK( gottlieb_nmi_generate )
 {
-	cpu_set_input_line(machine->cpu[1],INPUT_LINE_NMI,PULSE_LINE);
+	cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -248,6 +250,7 @@ logerror("Votrax: intonation %d, phoneme %02x %s\n",data >> 6,data & 0x3f,Phonem
 	{
 		if (votrax_queuepos > 1)
 		{
+			const device_config *samples = devtag_get_device(space->machine, "samples");
 			int last = -1;
 			int i;
 			char phonemes[200];
@@ -265,7 +268,7 @@ logerror("Votrax: intonation %d, phoneme %02x %s\n",data >> 6,data & 0x3f,Phonem
 			}
 
 			printf("Votrax played '%s'\n", phonemes);
-			play_sample(phonemes);
+			play_sample(samples, phonemes);
 #if 0
 			popmessage("%s", phonemes);
 #endif
@@ -314,8 +317,8 @@ static ADDRESS_MAP_START( gottlieb_sound1_map, ADDRESS_SPACE_PROGRAM, 8 )
 	/* A15 not decoded except in expansion socket */
 	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x007f) AM_MIRROR(0x0d80) AM_RAM
-	AM_RANGE(0x0200, 0x021f) AM_MIRROR(0x0de0) AM_DEVREADWRITE(RIOT6532, "riot", riot6532_r, riot6532_w)
-	AM_RANGE(0x1000, 0x1000) AM_MIRROR(0x0fff) AM_WRITE(dac_0_data_w)
+	AM_RANGE(0x0200, 0x021f) AM_MIRROR(0x0de0) AM_DEVREADWRITE("riot", riot6532_r, riot6532_w)
+	AM_RANGE(0x1000, 0x1000) AM_MIRROR(0x0fff) AM_DEVWRITE("dac", dac_w)
 	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x0fff) AM_WRITE(vortrax_data_w)
 	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x0fff) AM_WRITE(speech_clock_dac_w)
 	AM_RANGE(0x6000, 0x7fff) AM_ROM
@@ -334,8 +337,8 @@ MACHINE_DRIVER_START( gottlieb_soundrev1 )
 
 	MDRV_RIOT6532_ADD("riot", SOUND1_CLOCK/4, gottlieb_riot6532_intf)
 
-	MDRV_CPU_ADD("audio", M6502, SOUND1_CLOCK/4)	/* the board can be set to /2 as well */
-	MDRV_CPU_PROGRAM_MAP(gottlieb_sound1_map,0)
+	MDRV_CPU_ADD("audiocpu", M6502, SOUND1_CLOCK/4)	/* the board can be set to /2 as well */
+	MDRV_CPU_PROGRAM_MAP(gottlieb_sound1_map)
 
 	/* sound hardware */
 	MDRV_SOUND_ADD("dac", DAC, 0)
@@ -384,7 +387,7 @@ static void gottlieb2_sh_w(const address_space *space, UINT8 data)
 		/* if the previous data was 0xff, clock an IRQ on each */
 		if (last_command == 0xff)
 		{
-			cputag_set_input_line(space->machine, "audio", M6502_IRQ_LINE, ASSERT_LINE);
+			cputag_set_input_line(space->machine, "audiocpu", M6502_IRQ_LINE, ASSERT_LINE);
 			cputag_set_input_line(space->machine, "speech", M6502_IRQ_LINE, ASSERT_LINE);
 		}
 	}
@@ -401,15 +404,15 @@ static READ8_HANDLER( speech_data_r )
 
 static READ8_HANDLER( audio_data_r )
 {
-	cputag_set_input_line(space->machine, "audio", M6502_IRQ_LINE, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", M6502_IRQ_LINE, CLEAR_LINE);
 	return soundlatch2_r(space, offset);
 }
 
 
 static WRITE8_HANDLER( signal_audio_nmi_w )
 {
-	cputag_set_input_line(space->machine, "audio", INPUT_LINE_NMI, ASSERT_LINE);
-	cputag_set_input_line(space->machine, "audio", INPUT_LINE_NMI, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, ASSERT_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 
@@ -472,16 +475,16 @@ static WRITE8_HANDLER( nmi_rate_w )
 
 static CUSTOM_INPUT( speech_drq_custom_r )
 {
-	return sp0250_drq_r();
+	return sp0250_drq_r(devtag_get_device(field->port->machine, "sp"));
 }
 
 
-static WRITE8_HANDLER( dac_w )
+static WRITE8_DEVICE_HANDLER( gottlieb_dac_w )
 {
 	/* dual DAC; the first DAC serves as the reference voltage for the
        second, effectively scaling the output */
 	dac_data[offset] = data;
-	dac_data_16_w(0, dac_data[0] * dac_data[1]);
+	dac_data_16_w(device, dac_data[0] * dac_data[1]);
 }
 
 
@@ -499,33 +502,26 @@ static WRITE8_HANDLER( speech_control_w )
 	if ((previous & 0x04) != 0 && (data & 0x04) == 0)
 	{
 		/* bit 3 selects which of the two 8913 to enable */
-		if (data & 0x08)
-		{
-			/* bit 4 goes to the 8913 BC1 pin */
-			if (data & 0x10)
-				ay8910_control_port_0_w(space, 0, *psg_latch);
-			else
-				ay8910_write_port_0_w(space, 0, *psg_latch);
-		}
-		else
-		{
-			/* bit 4 goes to the 8913 BC1 pin */
-			if (data & 0x10)
-				ay8910_control_port_1_w(space, 0, *psg_latch);
-			else
-				ay8910_write_port_1_w(space, 0, *psg_latch);
-		}
+		/* bit 4 goes to the 8913 BC1 pin */
+		const device_config *ay = devtag_get_device(space->machine, (data & 0x08) ? "ay1" : "ay2");
+		ay8910_data_address_w(ay, data >> 4, *psg_latch);
 	}
 
 	/* bit 5 goes to the speech chip DIRECT DATA TEST pin */
 
 	/* bit 6 = speech chip DATA PRESENT pin; high then low to make the chip read data */
 	if ((previous & 0x40) == 0 && (data & 0x40) != 0)
-		sp0250_w(space, 0, *sp0250_latch);
+	{
+		const device_config *sp = devtag_get_device(space->machine, "sp");
+		sp0250_w(sp, 0, *sp0250_latch);
+	}
 
 	/* bit 7 goes to the speech chip RESET pin */
 	if ((previous ^ data) & 0x80)
-		sndti_reset(SOUND_SP0250, 0);
+	{
+		const device_config *sp = devtag_get_device(space->machine, "sp");
+		device_reset(sp);
+	}
 }
 
 
@@ -573,7 +569,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gottlieb_audio2_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_MIRROR(0x3c00) AM_RAM
-	AM_RANGE(0x4000, 0x4001) AM_MIRROR(0x3ffe) AM_WRITE(dac_w) AM_BASE(&dac_data)
+	AM_RANGE(0x4000, 0x4001) AM_MIRROR(0x3ffe) AM_DEVWRITE("dac1", gottlieb_dac_w) AM_BASE(&dac_data)
 	AM_RANGE(0x8000, 0x8000) AM_MIRROR(0x3fff) AM_READ(audio_data_r)
 	AM_RANGE(0xe000, 0xffff) AM_MIRROR(0x2000) AM_ROM
 ADDRESS_MAP_END
@@ -588,11 +584,11 @@ ADDRESS_MAP_END
 
 MACHINE_DRIVER_START( gottlieb_soundrev2 )
 	/* audio CPUs */
-	MDRV_CPU_ADD("audio", M6502, SOUND2_CLOCK/4)
-	MDRV_CPU_PROGRAM_MAP(gottlieb_audio2_map,0)
+	MDRV_CPU_ADD("audiocpu", M6502, SOUND2_CLOCK/4)
+	MDRV_CPU_PROGRAM_MAP(gottlieb_audio2_map)
 
 	MDRV_CPU_ADD("speech", M6502, SOUND2_CLOCK/4)
-	MDRV_CPU_PROGRAM_MAP(gottlieb_speech2_map,0)
+	MDRV_CPU_PROGRAM_MAP(gottlieb_speech2_map)
 
 	/* sound hardware */
 	MDRV_SOUND_START( gottlieb2 )
