@@ -53,7 +53,7 @@ void hdsnd_init(running_machine *machine)
 {
 	rombase = (UINT8 *)memory_region(machine, "serialroms");
 	romsize = memory_region_length(machine, "serialroms");
-	comram = (UINT16 *)auto_malloc(0x400);
+	comram = auto_alloc_array(machine, UINT16, 0x400/2);
 	last_bio_cycles = 0;
 }
 
@@ -319,11 +319,11 @@ READ16_HANDLER( hdsnddsp_get_bio )
  *
  *************************************/
 
-WRITE16_HANDLER( hdsnddsp_dac_w )
+WRITE16_DEVICE_HANDLER( hdsnddsp_dac_w )
 {
 	/* DAC L */
 	if (!dacmute)
-		dac_signed_data_16_w(offset, data ^ 0x8000);
+		dac_signed_data_16_w(device, data ^ 0x8000);
 }
 
 
