@@ -6,7 +6,7 @@
 #include "streams.h"
 #include "sound/filter.h"
 #include "machine/rescap.h"
-#include "sound/custom.h"
+#include "namco52.h"
 #include "namco54.h"
 #include "polepos.h"
 
@@ -63,7 +63,7 @@ static STREAM_UPDATE( engine_sound_update )
 	}
 
 	/* determine the effective clock rate */
-	clock = (cpu_get_clock(device->machine->cpu[0]) / 16) * ((sample_msb + 1) * 64 + sample_lsb + 1) / (64*64);
+	clock = (cputag_get_clock(device->machine, "maincpu") / 16) * ((sample_msb + 1) * 64 + sample_lsb + 1) / (64*64);
 	step = (clock << 12) / OUTPUT_RATE;
 
 	/* determine the volume */
@@ -99,7 +99,7 @@ static STREAM_UPDATE( engine_sound_update )
 /************************************/
 /* Sound handler start              */
 /************************************/
-CUSTOM_START( polepos_sh_start )
+static DEVICE_START( polepos_sound )
 {
 	stream = stream_create(device, 0, 1, OUTPUT_RATE, NULL, engine_sound_update);
 	sample_msb = sample_lsb = 0;
@@ -114,19 +114,32 @@ CUSTOM_START( polepos_sh_start )
      * a high pass filter. */
 	filter2_setup(device, FILTER_HIGHPASS, 950, Q_TO_DAMP(.707), 1,
 									&filter_engine[2]);
-
-	return auto_malloc(1);
 }
 
 /************************************/
 /* Sound handler reset              */
 /************************************/
-CUSTOM_RESET( polepos_sh_reset )
+static DEVICE_RESET( polepos_sound )
 {
 	int loop;
 	for (loop = 0; loop < 3; loop++) filter2_reset(&filter_engine[loop]);
 }
 
+DEVICE_GET_INFO( polepos_sound )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(polepos_sound);	break;
+		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME(polepos_sound);	break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Pole Position Custom");		break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+	}
+}
+
+
 /************************************/
 /* Write LSB of engine sound        */
 /************************************/
@@ -238,17 +251,17 @@ DISCRETE_SOUND_START(polepos)
 	/************************************************
      * Input register mapping
      ************************************************/
-	DISCRETE_INPUT_DATA(NAMCO_54XX_0_DATA)
-	DISCRETE_INPUT_DATA(NAMCO_54XX_1_DATA)
-	DISCRETE_INPUT_DATA(NAMCO_54XX_2_DATA)
-	DISCRETE_INPUT_DATA(NAMCO_52XX_P_DATA)
+	DISCRETE_INPUT_DATA(NAMCO_54XX_0_DATA(NODE_01))
+	DISCRETE_INPUT_DATA(NAMCO_54XX_1_DATA(NODE_01))
+	DISCRETE_INPUT_DATA(NAMCO_54XX_2_DATA(NODE_01))
+	DISCRETE_INPUT_DATA(NAMCO_52XX_P_DATA(NODE_04))
 
 	/************************************************
      * CHANL1 sound
      ************************************************/
 	DISCRETE_DAC_R1(NODE_20,
 					1,			/* ENAB */
-					NAMCO_54XX_2_DATA,
+					NAMCO_54XX_2_DATA(NODE_01),
 					4,			/* 4V - unmeasured*/
 					&polepos_54xx_dac)
 	DISCRETE_OP_AMP_FILTER(NODE_21,
@@ -266,7 +279,7 @@ DISCRETE_SOUND_START(polepos)
      ************************************************/
 	DISCRETE_DAC_R1(NODE_30,
 					1,			/* ENAB */
-					NAMCO_54XX_1_DATA,
+					NAMCO_54XX_1_DATA(NODE_01),
 					4,			/* 4V - unmeasured*/
 					&polepos_54xx_dac)
 	DISCRETE_OP_AMP_FILTER(NODE_31,
@@ -284,7 +297,7 @@ DISCRETE_SOUND_START(polepos)
      ************************************************/
 	DISCRETE_DAC_R1(NODE_40,
 					1,			/* ENAB */
-					NAMCO_54XX_0_DATA,
+					NAMCO_54XX_0_DATA(NODE_01),
 					4,			/* 4V - unmeasured*/
 					&polepos_54xx_dac)
 	DISCRETE_OP_AMP_FILTER(NODE_41,
@@ -300,25 +313,24 @@ DISCRETE_SOUND_START(polepos)
 	/************************************************
      * CHANL4 sound
      ************************************************/
-	/* disabled until 52XX is emulated */
 	/* this circuit was simulated in SPICE and an equivalent filter circuit generated */
 	DISCRETE_DAC_R1(NODE_50,
-					0,			/* ENAB */
-					NAMCO_52XX_P_DATA,
+					1,			/* ENAB */
+					NAMCO_52XX_P_DATA(NODE_04),
 					4,			/* 4V - unmeasured*/
 					&polepos_52xx_dac)
 	/* fake it so 0 is now vRef */
 	DISCRETE_ADDER2(NODE_51,
-					0,			/* ENAB */
+					1,			/* ENAB */
 					NODE_50, -POLEPOS_VREF)
 	DISCRETE_FILTER2(NODE_52,
-					0,			/* ENAB */
+					1,			/* ENAB */
 					NODE_51,	/* INP0 */
 					100,		/* FREQ */
 					1.0 / 0.3,	/* DAMP */
 					DISC_FILTER_HIGHPASS)
 	DISCRETE_FILTER2(NODE_53,
-					0,			/* ENAB */
+					1,			/* ENAB */
 					NODE_52,	/* INP0 */
 					1200,		/* FREQ */
 					1.0 / 0.8,	/* DAMP */
@@ -328,7 +340,7 @@ DISCRETE_SOUND_START(polepos)
 					0.5			/* overall filter GAIN */)
 	/* clamp to the maximum of the op-amp shifted by vRef */
 	DISCRETE_CLAMP(POLEPOS_CHANL4_SND,
-					0,			/* ENAB */
+					1,			/* ENAB */
 					NODE_54,	/* IN0 */
 					0,			/* MIN */
 					5.0 - OP_AMP_VP_RAIL_OFFSET - POLEPOS_VREF,	/* MAX */
@@ -340,5 +352,5 @@ DISCRETE_SOUND_START(polepos)
 	DISCRETE_OUTPUT(POLEPOS_CHANL1_SND, 32767/2)
 	DISCRETE_OUTPUT(POLEPOS_CHANL2_SND, 32767/2)
 	DISCRETE_OUTPUT(POLEPOS_CHANL3_SND, 32767/2)
-//  DISCRETE_OUTPUT(POLEPOS_CHANL4_SND, 32767/2)
+	DISCRETE_OUTPUT(POLEPOS_CHANL4_SND, 32767/2)
 DISCRETE_SOUND_END
