@@ -44,9 +44,9 @@ static const int scramble_timer[10] =
 	0x00, 0x10, 0x20, 0x30, 0x40, 0x90, 0xa0, 0xb0, 0xa0, 0xd0
 };
 
-READ8_HANDLER( scramble_portB_r )
+READ8_DEVICE_HANDLER( scramble_portB_r )
 {
-	return scramble_timer[(cpu_get_total_cycles(space->cpu)/512) % 10];
+	return scramble_timer[(cputag_get_total_cycles(device->machine, "audiocpu")/512) % 10];
 }
 
 
@@ -73,12 +73,11 @@ static const int frogger_timer[10] =
 	0x00, 0x10, 0x08, 0x18, 0x40, 0x90, 0x88, 0x98, 0x88, 0xd0
 };
 
-READ8_HANDLER( frogger_portB_r )
+READ8_DEVICE_HANDLER( frogger_portB_r )
 {
-	return frogger_timer[(cpu_get_total_cycles(space->cpu)/512) % 10];
+	return frogger_timer[(cputag_get_total_cycles(device->machine, "audiocpu")/512) % 10];
 }
 
-
 WRITE8_DEVICE_HANDLER( scramble_sh_irqtrigger_w )
 {
 	/* the complement of bit 3 is connected to the flip-flop's clock */
@@ -89,13 +88,6 @@ WRITE8_DEVICE_HANDLER( scramble_sh_irqtrigger_w )
 	sound_global_enable(~data & 0x10);
 }
 
-WRITE8_HANDLER( sfx_sh_irqtrigger_w )
-{
-	/* bit 1 is connected to the flip-flop's clock */
-	TTL7474_clock_w(3, data & 0x01);
-	TTL7474_update(space->machine, 3);
-}
-
 WRITE8_DEVICE_HANDLER( mrkougar_sh_irqtrigger_w )
 {
 	/* the complement of bit 3 is connected to the flip-flop's clock */
@@ -110,7 +102,6 @@ WRITE8_HANDLER( froggrmc_sh_irqtrigger_w )
 	TTL7474_update(space->machine, 2);
 }
 
-
 static IRQ_CALLBACK(scramble_sh_irq_callback)
 {
 	/* interrupt acknowledge clears the flip-flop --
@@ -125,47 +116,25 @@ static IRQ_CALLBACK(scramble_sh_irq_callback)
 	return 0xff;
 }
 
-static IRQ_CALLBACK(sfx_sh_irq_callback)
-{
-	/* interrupt acknowledge clears the flip-flop --
-       we need to pulse the CLR line because MAME's core never clears this
-       line, only asserts it */
-	TTL7474_clear_w(3, 0);
-	TTL7474_update(device->machine, 3);
-
-	TTL7474_clear_w(3, 1);
-	TTL7474_update(device->machine, 3);
-
-	return 0xff;
-}
-
-
 static void scramble_sh_7474_callback(running_machine *machine)
 {
 	/* the Q bar is connected to the Z80's INT line.  But since INT is complemented, */
 	/* we need to complement Q bar */
-	cpu_set_input_line(machine->cpu[1], 0, !TTL7474_output_comp_r(2) ? ASSERT_LINE : CLEAR_LINE);
-}
-
-static void sfx_sh_7474_callback(running_machine *machine)
-{
-	/* the Q bar is connected to the Z80's INT line.  But since INT is complemented, */
-	/* we need to complement Q bar */
-	cpu_set_input_line(machine->cpu[2], 0, !TTL7474_output_comp_r(3) ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "audiocpu", 0, !TTL7474_output_comp_r(2) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 WRITE8_HANDLER( hotshock_sh_irqtrigger_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], 0, ASSERT_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", 0, ASSERT_LINE);
 }
 
-READ8_HANDLER( hotshock_soundlatch_r )
+READ8_DEVICE_HANDLER( hotshock_soundlatch_r )
 {
-	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
-	return soundlatch_r(space,0);
+	cputag_set_input_line(device->machine, "audiocpu", 0, CLEAR_LINE);
+	return soundlatch_r(cputag_get_address_space(device->machine, "audiocpu", ADDRESS_SPACE_PROGRAM),0);
 }
 
-static void filter_w(int chip, int channel, int data)
+static void filter_w(const device_config *device, int data)
 {
 	int C;
 
@@ -175,42 +144,35 @@ static void filter_w(int chip, int channel, int data)
 		C += 220000;	/* 220000pF = 0.220uF */
 	if (data & 2)
 		C +=  47000;	/*  47000pF = 0.047uF */
-	if (sndti_exists(SOUND_FILTER_RC, 3*chip + channel))
-		filter_rc_set_RC(3*chip + channel,FLT_RC_LOWPASS,1000,5100,0,CAP_P(C));
+	if (device != NULL)
+		filter_rc_set_RC(device,FLT_RC_LOWPASS,1000,5100,0,CAP_P(C));
 }
 
 WRITE8_HANDLER( scramble_filter_w )
 {
-	filter_w(1, 0, (offset >>  0) & 3);
-	filter_w(1, 1, (offset >>  2) & 3);
-	filter_w(1, 2, (offset >>  4) & 3);
-	filter_w(0, 0, (offset >>  6) & 3);
-	filter_w(0, 1, (offset >>  8) & 3);
-	filter_w(0, 2, (offset >> 10) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.1.0"), (offset >>  0) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.1.1"), (offset >>  2) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.1.2"), (offset >>  4) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.0"), (offset >>  6) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.1"), (offset >>  8) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.2"), (offset >> 10) & 3);
 }
 
 WRITE8_HANDLER( frogger_filter_w )
 {
-	filter_w(0, 0, (offset >>  6) & 3);
-	filter_w(0, 1, (offset >>  8) & 3);
-	filter_w(0, 2, (offset >> 10) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.0"), (offset >>  6) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.1"), (offset >>  8) & 3);
+	filter_w(devtag_get_device(space->machine, "filter.0.2"), (offset >> 10) & 3);
 }
 
-
 static const struct TTL7474_interface scramble_sh_7474_intf =
 {
 	scramble_sh_7474_callback
 };
 
-static const struct TTL7474_interface sfx_sh_7474_intf =
-{
-	sfx_sh_7474_callback
-};
-
-
 void scramble_sh_init(running_machine *machine)
 {
-	cpu_set_irq_callback(machine->cpu[1], scramble_sh_irq_callback);
+	cpu_set_irq_callback(cputag_get_cpu(machine, "audiocpu"), scramble_sh_irq_callback);
 
 	TTL7474_config(machine, 2, &scramble_sh_7474_intf);
 
@@ -218,16 +180,6 @@ void scramble_sh_init(running_machine *machine)
 	TTL7474_d_w(2, 1);
 }
 
-void sfx_sh_init(running_machine *machine)
-{
-	cpu_set_irq_callback(machine->cpu[2], sfx_sh_irq_callback);
-
-	TTL7474_config(machine, 3, &sfx_sh_7474_intf);
-
-	/* PR is always 0, D is always 1 */
-	TTL7474_d_w(3, 1);
-}
-
 
 /***************************************************************************
     AD2083 TMS5110 implementation (still wrong!)
@@ -300,7 +252,7 @@ static UINT8 speech_cnt;
 
 static TIMER_CALLBACK( ad2083_step )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const device_config *tms = devtag_get_device(machine, "tms");
 
 	/* only 16 bytes needed ... The original dump is bad. This
      * is what is needed to get speech to work. The prom data has
@@ -328,8 +280,8 @@ static TIMER_CALLBACK( ad2083_step )
 	if (ctrl & 0x40)
 		speech_rom_address = 0;
 
-	tms5110_ctl_w(space, 0, ctrl & 0x04 ? TMS5110_CMD_SPEAK : TMS5110_CMD_RESET);
-	tms5110_pdc_w(space, 0, ctrl & 0x02 ? 0 : 1);
+	tms5110_ctl_w(tms, 0, ctrl & 0x04 ? TMS5110_CMD_SPEAK : TMS5110_CMD_RESET);
+	tms5110_pdc_w(tms, 0, ctrl & 0x02 ? 0 : 1);
 
 	if (!(ctrl & 0x80))
 		timer_set(machine, ATTOTIME_IN_HZ(AD2083_TMS5110_CLOCK / 2),NULL,1,ad2083_step);
@@ -383,20 +335,20 @@ static const ay8910_interface ad2083_ay8910_interface_1 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	scramble_portB_r,
-	NULL,
-	NULL,
-	NULL
+	DEVCB_HANDLER(scramble_portB_r),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static const ay8910_interface ad2083_ay8910_interface_2 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	hotshock_soundlatch_r,
-	NULL,
-	NULL,
-	NULL
+	DEVCB_HANDLER(hotshock_soundlatch_r),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static ADDRESS_MAP_START( ad2083_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
@@ -407,10 +359,10 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( ad2083_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01, 0x01) AM_WRITE(ad2083_tms5110_ctrl_w)
-	AM_RANGE(0x10, 0x10) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x20, 0x20) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
-	AM_RANGE(0x40, 0x40) AM_READWRITE(ay8910_read_port_1_r, ay8910_write_port_1_w)
-	AM_RANGE(0x80, 0x80) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x10, 0x10) AM_DEVWRITE("ay1", ay8910_address_w)
+	AM_RANGE(0x20, 0x20) AM_DEVREADWRITE("ay1", ay8910_r, ay8910_data_w)
+	AM_RANGE(0x40, 0x40) AM_DEVREADWRITE("ay2", ay8910_r, ay8910_data_w)
+	AM_RANGE(0x80, 0x80) AM_DEVWRITE("ay2", ay8910_address_w)
 ADDRESS_MAP_END
 
 static SOUND_START( ad2083 )
@@ -428,9 +380,9 @@ static SOUND_START( ad2083 )
 
 MACHINE_DRIVER_START( ad2083_audio )
 
-	MDRV_CPU_ADD("audio", Z80, 14318000/8)	/* 1.78975 MHz */
-	MDRV_CPU_PROGRAM_MAP(ad2083_sound_map,0)
-	MDRV_CPU_IO_MAP(ad2083_sound_io_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 14318000/8)	/* 1.78975 MHz */
+	MDRV_CPU_PROGRAM_MAP(ad2083_sound_map)
+	MDRV_CPU_IO_MAP(ad2083_sound_io_map)
 
 	MDRV_SOUND_START(ad2083)
 
