@@ -192,7 +192,7 @@ static WRITE8_HANDLER( speech_p2_w )
  *
  *************************************/
 
-static void speech_drq_w(int level)
+static void speech_drq_w(const device_config *device, int level)
 {
 	speech_drq = (level == ASSERT_LINE);
 }
@@ -214,7 +214,7 @@ static TIMER_CALLBACK( delayed_speech_w )
 	speech_latch = data;
 
 	/* the high bit goes directly to the INT line */
-	cpu_set_input_line(machine->cpu[1], 0, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(machine, "audiocpu", 0, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 
 	/* a clock on the high bit clocks a 1 into T0 */
 	if (!(old & 0x80) && (data & 0x80))
@@ -248,7 +248,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( speech_portmap, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x00, 0xff) AM_READ(speech_rom_r)
-	AM_RANGE(0x00, 0xff) AM_WRITE(sp0250_w)
+	AM_RANGE(0x00, 0xff) AM_DEVWRITE("speech", sp0250_w)
 	AM_RANGE(MCS48_PORT_P1, MCS48_PORT_P1) AM_READWRITE(speech_p1_r, speech_p1_w)
 	AM_RANGE(MCS48_PORT_P2, MCS48_PORT_P2) AM_WRITE(speech_p2_w)
 	AM_RANGE(MCS48_PORT_T0, MCS48_PORT_T0) AM_READ(speech_t0_r)
@@ -279,9 +279,9 @@ static const struct sp0250_interface sp0250_interface =
 MACHINE_DRIVER_START( sega_speech_board )
 
 	/* CPU for the speech board */
-	MDRV_CPU_ADD("audio", I8035, SPEECH_MASTER_CLOCK)		/* divide by 15 in CPU */
-	MDRV_CPU_PROGRAM_MAP(speech_map, 0)
-	MDRV_CPU_IO_MAP(speech_portmap, 0)
+	MDRV_CPU_ADD("audiocpu", I8035, SPEECH_MASTER_CLOCK)		/* divide by 15 in CPU */
+	MDRV_CPU_PROGRAM_MAP(speech_map)
+	MDRV_CPU_IO_MAP(speech_portmap)
 
 	/* sound hardware */
 	MDRV_SOUND_ADD("speech", SP0250, SPEECH_MASTER_CLOCK)
@@ -639,18 +639,18 @@ static STREAM_UPDATE( usb_stream_update )
 }
 
 
-static CUSTOM_START( usb_start )
+static DEVICE_START( usb_sound )
 {
 	running_machine *machine = device->machine;
 	filter_state temp;
 	int tchan, tgroup;
 
 	/* find the CPU we are associated with */
-	usb.cpu = cputag_get_cpu(machine, "usb");
+	usb.cpu = cputag_get_cpu(machine, "usbcpu");
 	assert(usb.cpu != NULL);
 
 	/* allocate work RAM */
-	usb.work_ram = auto_malloc(0x400);
+	usb.work_ram = auto_alloc_array(machine, UINT8, 0x400);
 
 	/* create a sound stream */
 	usb.stream = stream_create(device, 0, 1, SAMPLE_RATE, NULL, usb_stream_update);
@@ -727,11 +727,25 @@ static CUSTOM_START( usb_start )
 	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[2].capval);
 	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[3].capval);
 	state_save_register_item(machine, "usb", NULL, 0, usb.noise_filters[4].capval);
-
-	return usb.stream;
 }
 
 
+static DEVICE_GET_INFO( usb_sound )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(usb_sound);		break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Sega Universal Sound Board");	break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+	}
+}
+
+#define SOUND_USB DEVICE_GET_INFO_NAME(usb_sound)
+
+
 
 /*************************************
  *
@@ -896,19 +910,6 @@ ADDRESS_MAP_END
 
 
 
-/*************************************
- *
- *  USB sound definitions
- *
- *************************************/
-
-static const custom_sound_interface usb_custom_interface =
-{
-    usb_start
-};
-
-
-
 /*************************************
  *
  *  USB machine drivers
@@ -918,13 +919,12 @@ static const custom_sound_interface usb_custom_interface =
 MACHINE_DRIVER_START( sega_universal_sound_board )
 
 	/* CPU for the usb board */
-	MDRV_CPU_ADD("usb", I8035, USB_MASTER_CLOCK)		/* divide by 15 in CPU */
-	MDRV_CPU_PROGRAM_MAP(usb_map, 0)
-	MDRV_CPU_IO_MAP(usb_portmap, 0)
+	MDRV_CPU_ADD("usbcpu", I8035, USB_MASTER_CLOCK)		/* divide by 15 in CPU */
+	MDRV_CPU_PROGRAM_MAP(usb_map)
+	MDRV_CPU_IO_MAP(usb_portmap)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD("usb", CUSTOM, 0)
-	MDRV_SOUND_CONFIG(usb_custom_interface)
+	MDRV_SOUND_ADD("usbsnd", USB, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -933,6 +933,6 @@ MACHINE_DRIVER_START( sega_universal_sound_board_rom )
 	MDRV_IMPORT_FROM( sega_universal_sound_board )
 
 	/* CPU for the usb board */
-	MDRV_CPU_MODIFY("usb")
-	MDRV_CPU_PROGRAM_MAP(usb_map_rom, 0)
+	MDRV_CPU_MODIFY("usbcpu")
+	MDRV_CPU_PROGRAM_MAP(usb_map_rom)
 MACHINE_DRIVER_END
