@@ -14,7 +14,7 @@ WRITE8_HANDLER( sega_speech_control_w );
 MACHINE_DRIVER_EXTERN( sega_universal_sound_board );
 MACHINE_DRIVER_EXTERN( sega_universal_sound_board_rom );
 
-void sega_usb_reset(UINT8 t1_clock_mask);
+void sega_usb_reset(running_machine *machine, UINT8 t1_clock_mask);
 
 READ8_HANDLER( sega_usb_status_r );
 WRITE8_HANDLER( sega_usb_data_w );
