@@ -47,7 +47,7 @@ WRITE16_HANDLER( f3_es5505_bank_w )
 
 	/* mask out unused bits */
 	data &= max_banks_this_game;
-	es5505_voice_bank_0_w(offset,data<<20);
+	es5505_voice_bank_w(devtag_get_device(space->machine, "ensoniq"),offset,data<<20);
 }
 
 WRITE16_HANDLER( f3_volume_w )
@@ -71,10 +71,11 @@ WRITE16_HANDLER( f3_volume_w )
 static TIMER_CALLBACK( taito_en_timer_callback )
 {
 	/* Only cause IRQ if the mask is set to allow it */
-	if (m68681_imr&8) {
-		cpu_set_input_line_vector(machine->cpu[1], 6, vector_reg);
-		cpu_set_input_line(machine->cpu[1], 6, ASSERT_LINE);
-		imr_status|=0x8;
+	if (m68681_imr & 0x08)
+	{
+		cpu_set_input_line_vector(cputag_get_cpu(machine, "audiocpu"), 6, vector_reg);
+		cputag_set_input_line(machine, "audiocpu", 6, ASSERT_LINE);
+		imr_status |= 0x08;
 	}
 }
 
@@ -85,18 +86,20 @@ void f3_68681_reset(running_machine *machine)
 
 READ16_HANDLER(f3_68681_r)
 {
-	if (offset==0x5) {
-		int ret=imr_status;
-		imr_status=0;
+	if (offset == 0x05)
+	{
+		int ret = imr_status;
+		imr_status = 0;
 		return ret;
 	}
 
-	if (offset==0xe)
+	if (offset == 0x0e)
 		return 1;
 
 	/* IRQ ack */
-	if (offset==0xf) {
-		cpu_set_input_line(space->machine->cpu[1], 6, CLEAR_LINE);
+	if (offset == 0x0f)
+	{
+		cputag_set_input_line(space->machine, "audiocpu", 6, CLEAR_LINE);
 		return 0;
 	}
 
@@ -233,7 +236,7 @@ static UINT16 *sound_ram;
 ADDRESS_MAP_START( f3_sound_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x00ffff) AM_RAM AM_MIRROR(0x30000) AM_SHARE(1) AM_BASE(&sound_ram)
 	AM_RANGE(0x140000, 0x140fff) AM_READWRITE(f3_68000_share_r, f3_68000_share_w)
-	AM_RANGE(0x200000, 0x20001f) AM_READWRITE(es5505_data_0_r, es5505_data_0_w)
+	AM_RANGE(0x200000, 0x20001f) AM_DEVREADWRITE("ensoniq", es5505_r, es5505_w)
 	AM_RANGE(0x260000, 0x2601ff) AM_READWRITE(es5510_dsp_r, es5510_dsp_w)
 	AM_RANGE(0x280000, 0x28001f) AM_READWRITE(f3_68681_r, f3_68681_w)
 	AM_RANGE(0x300000, 0x30003f) AM_WRITE(f3_es5505_bank_w)
@@ -247,7 +250,7 @@ ADDRESS_MAP_END
 void taito_f3_soundsystem_reset(running_machine *machine)
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
-	UINT16 *ROM = (UINT16 *)memory_region(machine, "audio");
+	UINT16 *ROM = (UINT16 *)memory_region(machine, "audiocpu");
 	memory_set_bankptr(machine, 1,&ROM[0x80000]);
 	memory_set_bankptr(machine, 2,&ROM[0x90000]);
 	memory_set_bankptr(machine, 3,&ROM[0xa0000]);
@@ -258,18 +261,13 @@ void taito_f3_soundsystem_reset(running_machine *machine)
 	sound_ram[3]=ROM[0x80003];
 
 	/* reset CPU to catch any banking of startup vectors */
-	device_reset(cputag_get_cpu(machine, "audio"));
-	//cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+	device_reset(cputag_get_cpu(machine, "audiocpu"));
+	//cputag_set_input_line(machine, "audiocpu", INPUT_LINE_RESET, ASSERT_LINE);
 }
 
 const es5505_interface es5505_taito_f3_config =
 {
 	"ensoniq.0",	/* Bank 0: Unused by F3 games? */
 	"ensoniq.0",	/* Bank 1: All games seem to use this */
-	0 /* irq */
+	NULL /* irq */
 };
-
-
-
-
-
