@@ -44,7 +44,7 @@ static void Interrupt_Controller(running_machine *machine)
 {
 	if ( tc0140syt.nmi_req && tc0140syt.nmi_enabled )
 	{
-		cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE );
+		cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
 		tc0140syt.nmi_req = 0;
 	}
 }
@@ -98,10 +98,10 @@ WRITE8_HANDLER( taitosound_comm_w )
 //#endif
 			/* this does a hi-lo transition to reset the sound cpu */
 			if (data)
-				cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+				cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, ASSERT_LINE);
 			else
 			{
-				cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
+				cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, CLEAR_LINE);
                 cpu_spin(space->cpu); /* otherwise no sound in driftout */
             }
 			break;
@@ -119,29 +119,24 @@ READ8_HANDLER( taitosound_comm_r )
 		case 0x00:		// mode #0
 			//logerror("taitosnd: Master cpu read portdata %01x\n", tc0140syt.masterdata[0]);
 			return tc0140syt.masterdata[tc0140syt.mainmode ++];
-			break;
 
 		case 0x01:		// mode #1
 			//logerror("taitosnd: Master cpu receives 0/1 : %01x%01x\n", tc0140syt.masterdata[1],tc0140syt.masterdata[0]);
 			tc0140syt.status &= ~TC0140SYT_PORT01_FULL_MASTER;
 			return tc0140syt.masterdata[tc0140syt.mainmode ++];
-			break;
 
 		case 0x02:		// mode #2
 			//logerror("taitosnd: Master cpu read masterdata %01x\n", tc0140syt.masterdata[2]);
 			return tc0140syt.masterdata[tc0140syt.mainmode ++];
-			break;
 
 		case 0x03:		// mode #3
 			//logerror("taitosnd: Master cpu receives 2/3 : %01x%01x\n", tc0140syt.masterdata[3],tc0140syt.masterdata[2]);
 			tc0140syt.status &= ~TC0140SYT_PORT23_FULL_MASTER;
 			return tc0140syt.masterdata[tc0140syt.mainmode ++];
-			break;
 
 		case 0x04:		// port status
 			//logerror("tc0140syt : Master cpu read status : %02x\n", tc0140syt.status);
 			return tc0140syt.status;
-			break;
 
 		default:
 			logerror("tc0140syt : Master cpu read in mode [%02x]\n", tc0140syt.mainmode);
@@ -253,43 +248,3 @@ READ8_HANDLER( taitosound_slave_comm_r )
 
     return res;
 }
-
-
-
-
-
-
-
-/* wrapper functions for 16bit handlers */
-
-WRITE16_HANDLER( taitosound_port16_lsb_w )
-{
-	if (ACCESSING_BITS_0_7)
-		taitosound_port_w(space,0,data & 0xff);
-}
-WRITE16_HANDLER( taitosound_comm16_lsb_w )
-{
-	if (ACCESSING_BITS_0_7)
-		taitosound_comm_w(space,0,data & 0xff);
-}
-READ16_HANDLER( taitosound_comm16_lsb_r )
-{
-	return taitosound_comm_r(space,0);
-}
-
-
-WRITE16_HANDLER( taitosound_port16_msb_w )
-{
-	if (ACCESSING_BITS_8_15)
-		taitosound_port_w(space,0,data >> 8);
-}
-WRITE16_HANDLER( taitosound_comm16_msb_w )
-{
-	if (ACCESSING_BITS_8_15)
-		taitosound_comm_w(space,0,data >> 8);
-}
-READ16_HANDLER( taitosound_comm16_msb_r )
-{
-	return taitosound_comm_r(space,0) << 8;
-}
-
