@@ -6,9 +6,9 @@
 
 #include "driver.h"
 #include "streams.h"
-#include "includes/tx1.h"
+#include "sound/ay8910.h"
 #include "video/resnet.h"
-#include "sound/custom.h"
+#include "includes/tx1.h"
 
 
 /*************************************
@@ -148,7 +148,7 @@ static int eng2[4];
 
 ***************************************************************************/
 
-WRITE8_HANDLER( tx1_ay8910_a_w )
+WRITE8_DEVICE_HANDLER( tx1_ay8910_a_w )
 {
 	stream_update(stream);
 
@@ -156,7 +156,7 @@ WRITE8_HANDLER( tx1_ay8910_a_w )
 	ay_outputa = ~data;
 }
 
-WRITE8_HANDLER( tx1_ay8910_b_w )
+WRITE8_DEVICE_HANDLER( tx1_ay8910_b_w )
 {
 	double gain;
 
@@ -166,9 +166,9 @@ WRITE8_HANDLER( tx1_ay8910_b_w )
 
 	/* It'll do until we get quadrophonic speaker support! */
 	gain = BIT(ay_outputb, 4) ? 1.5 : 2.0;
-	sndti_set_output_gain(SOUND_AY8910, 0, 0, gain);
-	sndti_set_output_gain(SOUND_AY8910, 0, 1, gain);
-	sndti_set_output_gain(SOUND_AY8910, 0, 2, gain);
+	sound_set_output_gain(device, 0, gain);
+	sound_set_output_gain(device, 1, gain);
+	sound_set_output_gain(device, 2, gain);
 }
 
 /***************************************************************************
@@ -270,7 +270,7 @@ static STREAM_UPDATE( tx1_stream_update )
 }
 
 
-CUSTOM_START( tx1_sh_start )
+static DEVICE_START( tx1_sound )
 {
 	running_machine *machine = device->machine;
 	static const int r0[4] = { 390e3, 180e3, 180e3, 180e3 };
@@ -287,15 +287,28 @@ CUSTOM_START( tx1_sh_start )
 			4, &r0[0], weights0, 0, 0,
 			3, &r1[0], weights1, 0, 0,
 			3, &r2[0], weights2, 0, 0);
-
-	return auto_malloc(1);
 }
 
-CUSTOM_RESET( tx1_sh_reset )
+static DEVICE_RESET( tx1_sound )
 {
 	step0 = step1 = step2 = 0;
 }
 
+DEVICE_GET_INFO( tx1_sound )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(tx1_sound);		break;
+		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME(tx1_sound);		break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "TX-1 Custom");					break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+	}
+}
+
+
 /*************************************
  *
  *  Buggy Boy
@@ -385,45 +398,51 @@ static const double bb_engine_gains[16] =
 
 ***************************************************************************/
 
-WRITE8_HANDLER( bb_ym1_a_w )
+WRITE8_DEVICE_HANDLER( bb_ym1_a_w )
 {
 	stream_update(stream);
 	ym1_outputa = data ^ 0xff;
 }
 
-WRITE8_HANDLER( bb_ym2_a_w )
+WRITE8_DEVICE_HANDLER( bb_ym2_a_w )
 {
 	stream_update(stream);
 	ym2_outputa = data ^ 0xff;
 }
 
-WRITE8_HANDLER( bb_ym2_b_w )
+WRITE8_DEVICE_HANDLER( bb_ym2_b_w )
 {
+	const device_config *ym1 = devtag_get_device(device->machine, "ym1");
+	const device_config *ym2 = devtag_get_device(device->machine, "ym2");
 	double gain;
 
 	stream_update(stream);
 
 	ym2_outputb = data ^ 0xff;
 
-	if (!strcmp(space->machine->gamedrv->name, "buggybjr"))
+	if (!strcmp(device->machine->gamedrv->name, "buggybjr"))
 	{
 		coin_counter_w(0, data & 0x01);
 		coin_counter_w(1, data & 0x02);
 	}
 
-	/* Until we support > 2 speakers, double the gain of the front speakers */
+	/*
+        Until we support > 2 speakers, double the gain of the front speakers
+
+        TODO: We do support more than 2 speakers but the output is downmixed to stereo.
+    */
 
 	/* Rear left speaker */
 	gain = data & 0x80 ? 1.0 : 2.0;
-	sndti_set_output_gain(SOUND_AY8910, 0, 0, gain);
-	sndti_set_output_gain(SOUND_AY8910, 0, 1, gain);
-	sndti_set_output_gain(SOUND_AY8910, 0, 2, gain);
+	sound_set_output_gain(ym1, 0, gain);
+	sound_set_output_gain(ym1, 1, gain);
+	sound_set_output_gain(ym1, 2, gain);
 
 	/* Rear right speaker */
 	gain = data & 0x40 ? 1.0 : 2.0;
-	sndti_set_output_gain(SOUND_AY8910, 1, 0, gain);
-	sndti_set_output_gain(SOUND_AY8910, 1, 1, gain);
-	sndti_set_output_gain(SOUND_AY8910, 1, 2, gain);
+	sound_set_output_gain(ym2, 0, gain);
+	sound_set_output_gain(ym2, 1, gain);
+	sound_set_output_gain(ym2, 2, gain);
 }
 
 /* This is admittedly a bit of a hack job... */
@@ -506,7 +525,7 @@ static STREAM_UPDATE( buggyboy_stream_update )
 	}
 }
 
-CUSTOM_START( buggyboy_sh_start )
+static DEVICE_START( buggyboy_sound )
 {
 	running_machine *machine = device->machine;
 	static const int resistors[4] = { 330000, 220000, 330000, 220000 };
@@ -528,11 +547,9 @@ CUSTOM_START( buggyboy_sh_start )
 	/* Allocate the stream */
 	stream = stream_create(device, 0, 2, machine->sample_rate, NULL, buggyboy_stream_update);
 	freq_to_step = (double)(1 << 24) / (double)machine->sample_rate;
-
-	return auto_malloc(1);
 }
 
-CUSTOM_RESET( buggyboy_sh_reset )
+static DEVICE_RESET( buggyboy_sound )
 {
 	step0 = step1 = 0;
 
@@ -542,3 +559,19 @@ CUSTOM_RESET( buggyboy_sh_reset )
 	noise_lfsrc = 0;
 	noise_lfsrd = 0;
 }
+
+DEVICE_GET_INFO( buggyboy_sound )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(buggyboy_sound);	break;
+		case DEVINFO_FCT_RESET:							info->reset = DEVICE_RESET_NAME(buggyboy_sound);	break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Buggy Boy Custom");			break;
+		case DEVINFO_STR_SOURCE_FILE:						strcpy(info->s, __FILE__);						break;
+	}
+}
+
+
