@@ -89,6 +89,75 @@
         NMI = latch on sound command
     ========================================================================
 
+
+Badlands
+Atari Games, 1989
+
+PCB Layout
+----------
+
+A047193-01 BADLANDS
+|-------------------------------------------------|
+|TDA2030 LM324                ROM.2N ROM.2S ROM.2U|
+|VOL     LM324                ROM.4N ROM.4S ROM.4U|
+|6264    YM3012                                   |
+|      YM2151          6116     PAL3              |
+|   ROM.9C   PAL2                 ROM.10R  10T    |
+|J    6502                        ROM.14R  ROM.14T|
+|A                            MB87316             |
+|M                     14.31818MHz    PAL4  VMA   |
+|M                                                |
+|A    VGC7205      ROM.17F          PAL5          |
+|  TEST_SW   68000 ROM.20F      SOS               |
+| NE556 PAL1       ROM.24F          PAL6     6264 |
+|LED    DIP20      ROM.27F 2816                   |
+|-------------------------------------------------|
+Notes:
+      68000  - clock 7.15909MHz [14.31818/2]
+      6502   - clock 1.7897725 [14.31818/8]
+      YM2151 - clock 3.579545MHz [14.31818/4]
+      VGC7205- VLSI VGC7205A0672 ATARI 137304-2002
+      2816   - 2k x8 EEPROM
+      DIP20  - socket not populated
+      SOS    - Motorola (rebadged) SOS-137550-001 ZKZKAA8946
+      VMA    - Motorola (rebadged) VMA-137552-001 ZKZKAB8948
+      MB87316- Fujitsu MB87316 137536-001 with clock input 7.15909MHz
+               Listed in Jed Margolin's Atari Approved Vendor List
+               (http://www.jmargolin.com/schem/atariavl.htm) as.....
+               137536-001 IC,Line_Buffer(LB),CMOS,672B_RAM,500_Gate,40pin FUJITSU MB87316
+
+      ROMs   -
+               location  label
+               ------------------------
+               9C        136074-1018 E1FF
+               17F       136074-1009 86DF
+               20F       136074-1008 87FF
+               24F       136074-1007 F2DE
+               27F       136074-1006 xxxx (byte checksum unreadable)
+               2N        136074-1013 A5A0
+               2S        136074-1014 567B
+               2U        136074-1017 BB88
+               4N        136074-1012 6B70
+               4S        136074-1014 4475
+               4U        136074-1016 42A5
+               10R       136074-1011 041C
+               10T       not populated
+               14R       136074-1010 5E67
+               14T       136074-1019 D4C4
+
+      PALs   -
+               PAL1 - Lattice GAL16V8 labelled '136074-1001'
+               PAL2 - Lattice GAL16V8 labelled '136074-1005'
+               PAL3 - Lattice GAL16V8 labelled '136074-1004'
+               PAL4 - Lattice GAL16V8 labelled '136074-1003'
+               PAL5 - Lattice GAL16V8 labelled '136074-1002'
+               PAL6 - Lattice GAL16V8 labelled '136074-2000'
+
+Measurements -
+              X1    - 14.31995MHz
+              VSync - 59.9310Hz
+              HSync - 15.4611kHz
+
 ****************************************************************************/
 
 
@@ -123,20 +192,20 @@ static UINT8 *bank_source_data;
 
 static void update_interrupts(running_machine *machine)
 {
-	cpu_set_input_line(machine->cpu[0], 1, atarigen_video_int_state ? ASSERT_LINE : CLEAR_LINE);
-	cpu_set_input_line(machine->cpu[0], 2, atarigen_sound_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 1, atarigen_video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 2, atarigen_sound_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void scanline_update(const device_config *screen, int scanline)
 {
-	const address_space *space = cpu_get_address_space(screen->machine->cpu[1], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(screen->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
 	/* sound IRQ is on 32V */
 	if (scanline & 32)
 		atarigen_6502_irq_ack_r(space, 0);
 	else if (!(input_port_read(screen->machine, "FE4000") & 0x40))
-		atarigen_6502_irq_gen(screen->machine->cpu[1]);
+		atarigen_6502_irq_gen(cputag_get_cpu(screen->machine, "audiocpu"));
 }
 
 
@@ -148,7 +217,7 @@ static MACHINE_RESET( badlands )
 	atarigen_interrupt_reset(update_interrupts);
 	atarigen_scanline_timer_reset(machine->primary_screen, scanline_update, 32);
 
-	atarigen_sound_io_reset(machine->cpu[1]);
+	atarigen_sound_io_reset(cputag_get_cpu(machine, "audiocpu"));
 	memcpy(bank_base, &bank_source_data[0x0000], 0x1000);
 }
 
@@ -337,8 +406,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x2000) AM_READWRITE(ym2151_status_port_0_r, ym2151_register_port_0_w)
-	AM_RANGE(0x2000, 0x2001) AM_READWRITE(ym2151_status_port_0_r, ym2151_data_port_0_w)
+	AM_RANGE(0x2000, 0x2001) AM_DEVREADWRITE("ym", ym2151_r, ym2151_w)
 	AM_RANGE(0x2800, 0x2bff) AM_READWRITE(audio_io_r, audio_io_w)
 	AM_RANGE(0x3000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -432,12 +500,12 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( badlands )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, ATARI_CLOCK_14MHz/2)
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT("main", vblank_int)
+	MDRV_CPU_ADD("maincpu", M68000, ATARI_CLOCK_14MHz/2)
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_VBLANK_INT("screen", vblank_int)
 
-	MDRV_CPU_ADD("audio", M6502, ATARI_CLOCK_14MHz/8)
-	MDRV_CPU_PROGRAM_MAP(audio_map,0)
+	MDRV_CPU_ADD("audiocpu", M6502, ATARI_CLOCK_14MHz/8)
+	MDRV_CPU_PROGRAM_MAP(audio_map)
 
 	MDRV_MACHINE_RESET(badlands)
 	MDRV_NVRAM_HANDLER(atarigen)
@@ -447,7 +515,7 @@ static MACHINE_DRIVER_START( badlands )
 	MDRV_GFXDECODE(badlands)
 	MDRV_PALETTE_LENGTH(256)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
@@ -473,13 +541,13 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( badlands )
-	ROM_REGION( 0x40000, "main", 0 )	/* 4*64k for 68000 code */
+	ROM_REGION( 0x40000, "maincpu", 0 )	/* 4*64k for 68000 code */
 	ROM_LOAD16_BYTE( "136074-1008.20f",  0x00000, 0x10000, CRC(a3da5774) SHA1(5ab1eb61d25594b2d7c40400cb57e7f47a717598) )
 	ROM_LOAD16_BYTE( "136074-1006.27f",  0x00001, 0x10000, CRC(aa03b4f3) SHA1(5eda60c715ffcefd4ad34bdb90579e8671dc384a) )
 	ROM_LOAD16_BYTE( "136074-1009.17f",  0x20000, 0x10000, CRC(0e2e807f) SHA1(5b61de066dca12c44335aa68a13c821845657866) )
 	ROM_LOAD16_BYTE( "136074-1007.24f",  0x20001, 0x10000, CRC(99a20c2c) SHA1(9b0a5a5dafb8816e72330d302c60339b600b49a8) )
 
-	ROM_REGION( 0x14000, "audio", 0 )	/* 64k for 6502 code */
+	ROM_REGION( 0x14000, "audiocpu", 0 )	/* 64k for 6502 code */
 	ROM_LOAD( "136074-1018.9c", 0x10000, 0x4000, CRC(a05fd146) SHA1(d97abbcf7897ca720cc18ff3a323f41cd3b23c34) )
 	ROM_CONTINUE(               0x04000, 0xc000 )
 
@@ -516,8 +584,8 @@ static DRIVER_INIT( badlands )
 	atarigen_eeprom_default = NULL;
 
 	/* initialize the audio system */
-	bank_base = &memory_region(machine, "audio")[0x03000];
-	bank_source_data = &memory_region(machine, "audio")[0x10000];
+	bank_base = &memory_region(machine, "audiocpu")[0x03000];
+	bank_source_data = &memory_region(machine, "audiocpu")[0x10000];
 }
 
 
@@ -608,7 +676,7 @@ GFXDECODE_END
 
 static void update_interrupts_bootleg(running_machine *machine)
 {
-	cpu_set_input_line(machine->cpu[0], 1, atarigen_video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 1, atarigen_video_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -618,7 +686,7 @@ static void scanline_update_bootleg(const device_config *screen, int scanline)
 //  if (scanline & 32)
 //      atarigen_6502_irq_ack_r(screen->machine, 0);
 //  else if (!(input_port_read(machine, "FE4000") & 0x40))
-//      atarigen_6502_irq_gen(screen->machine->cpu[1]);
+//      atarigen_6502_irq_gen(cputag_get_cpu(screen->machine, "audiocpu"));
 }
 
 
@@ -631,19 +699,19 @@ static MACHINE_RESET( badlandb )
 	atarigen_interrupt_reset(update_interrupts_bootleg);
 	atarigen_scanline_timer_reset(machine->primary_screen, scanline_update_bootleg, 32);
 
-//  atarigen_sound_io_reset(machine->cpu[1]);
+//  atarigen_sound_io_reset(cputag_get_cpu(machine, "audiocpu"));
 //  memcpy(bank_base, &bank_source_data[0x0000], 0x1000);
 }
 
 static MACHINE_DRIVER_START( badlandb )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 2800000/2)
-	MDRV_CPU_PROGRAM_MAP(bootleg_map,0)
-	MDRV_CPU_VBLANK_INT("main", vblank_int)
+	MDRV_CPU_ADD("maincpu", M68000, 2800000/2)
+	MDRV_CPU_PROGRAM_MAP(bootleg_map)
+	MDRV_CPU_VBLANK_INT("screen", vblank_int)
 
-//  MDRV_CPU_ADD("audio", Z80, 2800000/8)
-//  MDRV_CPU_PROGRAM_MAP(bootleg_soundmap,0)
+//  MDRV_CPU_ADD("audiocpu", Z80, 2800000/8)
+//  MDRV_CPU_PROGRAM_MAP(bootleg_soundmap)
 
 	MDRV_MACHINE_RESET(badlandb)
 	MDRV_NVRAM_HANDLER(atarigen)
@@ -653,7 +721,7 @@ static MACHINE_DRIVER_START( badlandb )
 	MDRV_GFXDECODE(badlandb)
 	MDRV_PALETTE_LENGTH(256)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
@@ -675,7 +743,7 @@ MACHINE_DRIVER_END
 /* bootleg by Playmark, uses Joystick controls */
 ROM_START( badlandb )
 	/* bootleg 68k Program */
-	ROM_REGION( 0x40000, "main", 0 )	/* 4*64k for 68000 code */
+	ROM_REGION( 0x40000, "maincpu", 0 )	/* 4*64k for 68000 code */
 	ROM_LOAD16_BYTE( "blb28.ic21",  0x00000, 0x10000, CRC(dffb025d) SHA1(f2c17607acbbeee7d5d3f3dd2e8dc768b755e991) )
 	ROM_LOAD16_BYTE( "blb22.ic22",  0x00001, 0x10000, CRC(ca3015c4) SHA1(72e1451498143d920239487704f4b4a8a71410e0) )
 	ROM_LOAD16_BYTE( "blb27.ic19",  0x20000, 0x10000, CRC(0e2e807f) SHA1(5b61de066dca12c44335aa68a13c821845657866) )
