@@ -73,33 +73,33 @@ static int speech_rom_address = 0;
 static UINT8 ls259_buf[8] = {0,0,0,0,0,0,0,0};
 
 
-static void start_talking (const address_space *space)
+static void start_talking (const device_config *tms)
 {
 	speech_rom_address = 0x0;
-	tms5110_ctl_w(space,0,TMS5110_CMD_SPEAK);
-	tms5110_pdc_w(space,0,0);
-	tms5110_pdc_w(space,0,1);
-	tms5110_pdc_w(space,0,0);
+	tms5110_ctl_w(tms,0,TMS5110_CMD_SPEAK);
+	tms5110_pdc_w(tms,0,0);
+	tms5110_pdc_w(tms,0,1);
+	tms5110_pdc_w(tms,0,0);
 }
 
-static void reset_talking (const address_space *space)
+static void reset_talking (const device_config *tms)
 {
 /*To be extremely accurate there should be a delays between each of
   the function calls below. In real they happen with the frequency of 160 kHz.
 */
 
-	tms5110_ctl_w(space,0,TMS5110_CMD_RESET);
-	tms5110_pdc_w(space,0,0);
-	tms5110_pdc_w(space,0,1);
-	tms5110_pdc_w(space,0,0);
+	tms5110_ctl_w(tms,0,TMS5110_CMD_RESET);
+	tms5110_pdc_w(tms,0,0);
+	tms5110_pdc_w(tms,0,1);
+	tms5110_pdc_w(tms,0,0);
 
-	tms5110_pdc_w(space,0,0);
-	tms5110_pdc_w(space,0,1);
-	tms5110_pdc_w(space,0,0);
+	tms5110_pdc_w(tms,0,0);
+	tms5110_pdc_w(tms,0,1);
+	tms5110_pdc_w(tms,0,0);
 
-	tms5110_pdc_w(space,0,0);
-	tms5110_pdc_w(space,0,1);
-	tms5110_pdc_w(space,0,0);
+	tms5110_pdc_w(tms,0,0);
+	tms5110_pdc_w(tms,0,1);
+	tms5110_pdc_w(tms,0,0);
 
 	speech_rom_address = 0x0;
 }
@@ -152,13 +152,14 @@ static WRITE8_HANDLER( bagman_ls259_w )
 
 		if (offset==3)
 		{
+			const device_config *tms = devtag_get_device(space->machine, "tms");
 			if (ls259_buf[3] == 0)	/* 1->0 transition */
 			{
-				reset_talking(space);
+				reset_talking(tms);
 			}
 			else
 			{
-				start_talking(space);	/* 0->1 transition */
+				start_talking(tms);	/* 0->1 transition */
 			}
 		}
 	}
@@ -179,9 +180,9 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	//AM_RANGE(0xa800, 0xa805) AM_READ(bagman_ls259_r) /*just for debugging purposes*/
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(interrupt_enable_w)
 	AM_RANGE(0xa001, 0xa002) AM_WRITE(bagman_flipscreen_w)
-	AM_RANGE(0xa003, 0xa003) AM_WRITE(SMH_RAM) AM_BASE(&bagman_video_enable)
-	AM_RANGE(0xc000, 0xffff) AM_WRITE(SMH_ROM)	/* Super Bagman only */
-	AM_RANGE(0x9800, 0x981f) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	/* hidden portion of color RAM */
+	AM_RANGE(0xa003, 0xa003) AM_WRITEONLY AM_BASE(&bagman_video_enable)
+	AM_RANGE(0xc000, 0xffff) AM_ROM /* Super Bagman only */
+	AM_RANGE(0x9800, 0x981f) AM_WRITEONLY AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	/* hidden portion of color RAM */
 									/* here only to initialize the pointer, */
 									/* writes are handled by bagman_colorram_w */
 	AM_RANGE(0xa800, 0xa805) AM_WRITE(bagman_ls259_w) /* TMS5110 driving state machine */
@@ -191,9 +192,9 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_ROM		/* Super Bagman only */
 
 #if 0
-	AM_RANGE(0xa007, 0xa007) AM_WRITE(SMH_NOP)	/* ???? */
-	AM_RANGE(0xb000, 0xb000) AM_WRITE(SMH_NOP)	/* ???? */
-	AM_RANGE(0xb800, 0xb800) AM_WRITE(SMH_NOP)	/* ???? */
+	AM_RANGE(0xa007, 0xa007) AM_WRITENOP	/* ???? */
+	AM_RANGE(0xb000, 0xb000) AM_WRITENOP	/* ???? */
+	AM_RANGE(0xb800, 0xb800) AM_WRITENOP	/* ???? */
 #endif
 ADDRESS_MAP_END
 
@@ -204,32 +205,31 @@ static ADDRESS_MAP_START( pickin_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x7000, 0x77ff) AM_RAM
 	AM_RANGE(0x8800, 0x8bff) AM_RAM_WRITE(bagman_videoram_w) AM_BASE(&videoram)
 	AM_RANGE(0x9800, 0x9bff) AM_RAM_WRITE(bagman_colorram_w) AM_BASE(&colorram)
-	AM_RANGE(0x9800, 0x981f) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	/* hidden portion of color RAM */
+	AM_RANGE(0x9800, 0x981f) AM_WRITEONLY AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	/* hidden portion of color RAM */
 									/* here only to initialize the pointer, */
 									/* writes are handled by bagman_colorram_w */
-	AM_RANGE(0x9c00, 0x9fff) AM_WRITE(SMH_NOP)	/* written to, but unused */
+	AM_RANGE(0x9c00, 0x9fff) AM_WRITENOP	/* written to, but unused */
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(interrupt_enable_w)
 	AM_RANGE(0xa001, 0xa002) AM_WRITE(bagman_flipscreen_w)
-	AM_RANGE(0xa003, 0xa003) AM_WRITE(SMH_RAM) AM_BASE(&bagman_video_enable)
+	AM_RANGE(0xa003, 0xa003) AM_WRITEONLY AM_BASE(&bagman_video_enable)
 	AM_RANGE(0xa004, 0xa004) AM_WRITE(bagman_coin_counter_w)
 	AM_RANGE(0xa800, 0xa800) AM_READ_PORT("DSW")
 
 
-	AM_RANGE(0xa005, 0xa005) AM_WRITE(SMH_NOP)	/* ???? */
-	AM_RANGE(0xa006, 0xa006) AM_WRITE(SMH_NOP)	/* ???? */
-	AM_RANGE(0xa007, 0xa007) AM_WRITE(SMH_NOP)	/* ???? */
+	AM_RANGE(0xa005, 0xa005) AM_WRITENOP	/* ???? */
+	AM_RANGE(0xa006, 0xa006) AM_WRITENOP	/* ???? */
+	AM_RANGE(0xa007, 0xa007) AM_WRITENOP	/* ???? */
 
 	/* guess */
-	AM_RANGE(0xb000, 0xb000) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0xb800, 0xb800) AM_READWRITE(ay8910_read_port_1_r, ay8910_write_port_1_w)
+	AM_RANGE(0xb000, 0xb000) AM_DEVWRITE("ay2", ay8910_address_w)
+	AM_RANGE(0xb800, 0xb800) AM_DEVREADWRITE("ay2", ay8910_r, ay8910_data_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( main_portmap, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x08, 0x08) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x09, 0x09) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x0c, 0x0c) AM_READ(ay8910_read_port_0_r)
-	//AM_RANGE(0x56, 0x56) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x08, 0x09) AM_DEVWRITE("ay", ay8910_address_data_w)
+	AM_RANGE(0x0c, 0x0c) AM_DEVREAD("ay", ay8910_r)
+	//AM_RANGE(0x56, 0x56) AM_WRITENOP
 ADDRESS_MAP_END
 
 
@@ -341,8 +341,8 @@ static INPUT_PORTS_START( squaitsa )
  	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
  	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
  	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
- 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY // these must be tied to a spinner somehow?
- 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY // ^
+ 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SPECIAL ) // special handling for the p1 dial
+ 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SPECIAL ) // ^
  	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 
  	PORT_START("P2")
@@ -351,8 +351,8 @@ static INPUT_PORTS_START( squaitsa )
  	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START2 )
  	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
  	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
- 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL // these must be tied to a spinner somehow?
- 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL // ^
+ 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SPECIAL ) // special handling for the p2 dial
+ 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SPECIAL ) // ^
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 
 	PORT_START("DSW")
@@ -378,6 +378,12 @@ static INPUT_PORTS_START( squaitsa )
     PORT_DIPNAME(    0x80, 0x00, "Protection?" )	/* Left empty in the dips scan */
     PORT_DIPSETTING( 0x80, DEF_STR( Off ) )
     PORT_DIPSETTING( 0x00, DEF_STR( On ) )
+
+	PORT_START("DIAL_P1")
+    PORT_BIT( 0xff, 0, IPT_DIAL ) PORT_SENSITIVITY(25) PORT_KEYDELTA(5)
+
+	PORT_START("DIAL_P2")
+    PORT_BIT( 0xff, 0, IPT_DIAL ) PORT_SENSITIVITY(25) PORT_KEYDELTA(5) PORT_COCKTAIL
 INPUT_PORTS_END
 
 static const gfx_layout charlayout =
@@ -423,20 +429,72 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	input_port_0_r,
-	input_port_1_r,
-	NULL,
-	NULL
+	DEVCB_INPUT_PORT("P1"),
+	DEVCB_INPUT_PORT("P2"),
+	DEVCB_NULL,
+	DEVCB_NULL
+};
+
+/* squaitsa doesn't map the dial directly, instead it polls the results of the dial thru an external circuitry.
+   I don't know if the following is correct, there can possbily be multiple solutions for the same problem. */
+static READ8_DEVICE_HANDLER( dial_input_p1_r )
+{
+	static UINT8 res,dial_val,old_val;
+
+	dial_val = input_port_read(device->machine, "DIAL_P1");
+
+	if(res != 0x60)
+		res = 0x60;
+	else if(dial_val > old_val)
+		res = 0x40;
+	else if(dial_val < old_val)
+		res = 0x20;
+	else
+		res = 0x60;
+
+	old_val = dial_val;
+
+	return (input_port_read(device->machine, "P1") & 0x9f) | (res);
+}
+
+static READ8_DEVICE_HANDLER( dial_input_p2_r )
+{
+	static UINT8 res,dial_val,old_val;
+
+	dial_val = input_port_read(device->machine, "DIAL_P2");
+
+	if(res != 0x60)
+		res = 0x60;
+	else if(dial_val > old_val)
+		res = 0x40;
+	else if(dial_val < old_val)
+		res = 0x20;
+	else
+		res = 0x60;
+
+	old_val = dial_val;
+
+	return (input_port_read(device->machine, "P2") & 0x9f) | (res);
+}
+
+static const ay8910_interface ay8910_dial_config =
+{
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	DEVCB_HANDLER(dial_input_p1_r),
+	DEVCB_HANDLER(dial_input_p2_r),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static const ay8910_interface ay8910_interface_2 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	NULL,
-	NULL,
-	NULL,
-	NULL
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static const tms5110_interface bagman_tms5110_interface =
@@ -447,15 +505,15 @@ static const tms5110_interface bagman_tms5110_interface =
 static MACHINE_DRIVER_START( bagman )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 3072000)	/* 3.072 MHz (?) */
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_IO_MAP(main_portmap,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80, 3072000)	/* 3.072 MHz (?) */
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_IO_MAP(main_portmap)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -483,15 +541,15 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( pickin )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 3072000)	/* 3.072 MHz (?) */
-	MDRV_CPU_PROGRAM_MAP(pickin_map,0)
-	MDRV_CPU_IO_MAP(main_portmap,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80, 3072000)	/* 3.072 MHz (?) */
+	MDRV_CPU_PROGRAM_MAP(pickin_map)
+	MDRV_CPU_IO_MAP(main_portmap)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -507,7 +565,7 @@ static MACHINE_DRIVER_START( pickin )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
+	MDRV_SOUND_ADD("ay", AY8910, 1500000)
 	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
@@ -538,15 +596,15 @@ z80
 static MACHINE_DRIVER_START( botanic )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 3072000)	/* 3.072 MHz (?) */
-	MDRV_CPU_PROGRAM_MAP(pickin_map,0)
-	MDRV_CPU_IO_MAP(main_portmap,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80, 3072000)	/* 3.072 MHz (?) */
+	MDRV_CPU_PROGRAM_MAP(pickin_map)
+	MDRV_CPU_IO_MAP(main_portmap)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_MACHINE_RESET(bagman)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -562,7 +620,7 @@ static MACHINE_DRIVER_START( botanic )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
+	MDRV_SOUND_ADD("ay", AY8910, 1500000)
 	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
@@ -571,6 +629,14 @@ static MACHINE_DRIVER_START( botanic )
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( squaitsa )
+	MDRV_IMPORT_FROM( botanic )
+	MDRV_SOUND_MODIFY("ay")
+	MDRV_SOUND_CONFIG(ay8910_dial_config)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+MACHINE_DRIVER_END
+
+
 /***************************************************************************
 
   Game driver(s)
@@ -578,7 +644,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( bagman )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "e9_b05.bin",   0x0000, 0x1000, CRC(e0156191) SHA1(bb5f16d49fbe48f3bac118acd1fea51ec4bc5355) )
 	ROM_LOAD( "f9_b06.bin",   0x1000, 0x1000, CRC(7b758982) SHA1(c8460023b43fed4aca9c6b987faea334832c5e30) )
 	ROM_LOAD( "f9_b07.bin",   0x2000, 0x1000, CRC(302a077b) SHA1(916c4a6ea1e631cc72bdb91ff9d263dcbaf08bb2) )
@@ -605,7 +671,7 @@ ROM_START( bagman )
 ROM_END
 
 ROM_START( bagnard )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "e9_b05.bin",   0x0000, 0x1000, CRC(e0156191) SHA1(bb5f16d49fbe48f3bac118acd1fea51ec4bc5355) )
 	ROM_LOAD( "f9_b06.bin",   0x1000, 0x1000, CRC(7b758982) SHA1(c8460023b43fed4aca9c6b987faea334832c5e30) )
 	ROM_LOAD( "f9_b07.bin",   0x2000, 0x1000, CRC(302a077b) SHA1(916c4a6ea1e631cc72bdb91ff9d263dcbaf08bb2) )
@@ -632,7 +698,7 @@ ROM_START( bagnard )
 ROM_END
 
 ROM_START( bagnarda )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "bagman.005",   0x0000, 0x1000, CRC(98fca49c) SHA1(60bf15d700cf4174ac531c11febf21d69ec02db5) )
 	ROM_LOAD( "bagman.006",   0x1000, 0x1000, CRC(8f447432) SHA1(71fee4feb92cdd35dcd3ad9e95ea9f186cb25e25) )
 	ROM_LOAD( "bagman.007",   0x2000, 0x1000, CRC(236203a6) SHA1(3d661c135a5036adeaf5fed2be38c97bbc72cd0a) )
@@ -659,7 +725,7 @@ ROM_START( bagnarda )
 ROM_END
 
 ROM_START( bagmans )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "a4_9e.bin",    0x0000, 0x1000, CRC(5fb0a1a3) SHA1(849cd60b58de9585a78a1c4c1747f666a4a4fcc3) )
 	ROM_LOAD( "a5-9f",        0x1000, 0x1000, CRC(2ddf6bb9) SHA1(151068dddc55163bb6f925f68e5d04e347ded6a5) )
 	ROM_LOAD( "a4_9j.bin",    0x2000, 0x1000, CRC(b2da8b77) SHA1(ea36cd6be42c5548a9a91054aeebb4b985ba15c9) )
@@ -686,7 +752,7 @@ ROM_START( bagmans )
 ROM_END
 
 ROM_START( bagmans2 )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "a4_9e.bin",    0x0000, 0x1000, CRC(5fb0a1a3) SHA1(849cd60b58de9585a78a1c4c1747f666a4a4fcc3) )
 	ROM_LOAD( "a4_9f.bin",    0x1000, 0x1000, CRC(7871206e) SHA1(14d9b7a0779d59a870e0d4b911797dff5435a16c) )
 	ROM_LOAD( "a4_9j.bin",    0x2000, 0x1000, CRC(b2da8b77) SHA1(ea36cd6be42c5548a9a91054aeebb4b985ba15c9) )
@@ -715,7 +781,7 @@ ROM_END
 
 
 ROM_START( sbagman )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "5.9e",         0x0000, 0x1000, CRC(1b1d6b0a) SHA1(549161f6adc88fa16339815e05af33ca57815660) )
 	ROM_LOAD( "6.9f",         0x1000, 0x1000, CRC(ac49cb82) SHA1(5affa0c03bedf2c9d5368c7f075818e1760c12ae) )
 	ROM_LOAD( "7.9j",         0x2000, 0x1000, CRC(9a1c778d) SHA1(a655e25dc9efdf60cc5b34e42c93c4acaa4a7922) )
@@ -752,7 +818,7 @@ ROM_START( sbagman )
 ROM_END
 
 ROM_START( sbagmans )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "sbag_9e.bin",  0x0000, 0x1000, CRC(c19696f2) SHA1(3a40202a97201a123033358f7afcb06f8ac15063) )
 	ROM_LOAD( "6.9f",         0x1000, 0x1000, CRC(ac49cb82) SHA1(5affa0c03bedf2c9d5368c7f075818e1760c12ae) )
 	ROM_LOAD( "7.9j",         0x2000, 0x1000, CRC(9a1c778d) SHA1(a655e25dc9efdf60cc5b34e42c93c4acaa4a7922) )
@@ -789,7 +855,7 @@ ROM_START( sbagmans )
 ROM_END
 
 ROM_START( pickin )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "9e",           0x0000, 0x1000, CRC(efd0bd43) SHA1(b70a471a809c08286a82934046357fb46556f641) )
 	ROM_LOAD( "9f",           0x1000, 0x1000, CRC(b5785a23) SHA1(9eddda5695981cb0470dfea68d5e2e8e220382b1) )
 	ROM_LOAD( "9j",           0x2000, 0x1000, CRC(65ee9fd4) SHA1(2efa40c19a7b0644ef4f4b2ce6a025b2b880239d) )
@@ -809,7 +875,7 @@ ROM_START( pickin )
 ROM_END
 
 ROM_START( botanic )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "bota_05.9e",    0x0000, 0x1000, CRC(cc66e6f8) SHA1(251481b16f8925a11f02f49e5a79f6524460aa6c) )
 	ROM_LOAD( "bota_06.9f",    0x1000, 0x1000, CRC(59892f41) SHA1(eb01601a9163679560b878366aaf7cc0fb54a3e9) )
 	ROM_LOAD( "bota_07.9j",    0x2000, 0x1000, CRC(b7c544ef) SHA1(75b5224c313e97c2c02ca7e9bc3f682278cb7a5c) )
@@ -869,7 +935,7 @@ under licence from an Italian company! Let's call it melting pot!
 */
 
 ROM_START( squaitsa )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "sq5.3.9e",    0x0000, 0x1000,CRC(04128d92) SHA1(ca7b7c4be5f40bcefc92b231ce3bba859c9967ee) )
 	ROM_LOAD( "sq6.4.9f",    0x1000, 0x1000,CRC(4ff7dd56) SHA1(1955675a9ee3ad7b9185cd027bc42284e15c7451) )
 	ROM_LOAD( "sq7.5.9j",    0x2000, 0x1000,CRC(e46ecda6) SHA1(25cd94b6c9602cc00fe3459b524639fd3beb72be) )
@@ -902,5 +968,5 @@ GAME( 1984, sbagman,  0, 	   bagman,  sbagman, 0,        ROT270, "Valadon Automa
 GAME( 1984, sbagmans, sbagman, bagman,  sbagman, 0,        ROT270, "Valadon Automation (Stern license)", "Super Bagman (Stern)", 0 )
 GAME( 1983, pickin,	  0,	   pickin,  pickin,  0,        ROT270, "Valadon Automation", "Pickin'", 0 )
 GAME( 1984, botanic,  0,       botanic, botanic, 0,        ROT270, "Valadon Automation (Itisa license)", "Botanic", 0 )
-GAME( 1984, squaitsa,  0,       botanic, squaitsa, 0,        ROT0, "Itisa", "Squash (Itisa)", GAME_NOT_WORKING )
+GAME( 1984, squaitsa, 0,       squaitsa,squaitsa,0,        ROT0,   "Itisa",              "Squash (Itisa)", 0 )
 
