@@ -15,6 +15,7 @@ Preliminary driver by: Manuel Abadia <manu@teleline.es>
 #include "cpu/z80/z80.h"
 #include "video/konamiic.h"
 #include "sound/3812intf.h"
+#include "konamipt.h"
 
 /* from video */
 WRITE8_HANDLER( battlnts_spritebank_w );
@@ -29,12 +30,12 @@ static INTERRUPT_GEN( battlnts_interrupt )
 
 static WRITE8_HANDLER( battlnts_sh_irqtrigger_w )
 {
-	cpu_set_input_line_and_vector(space->machine->cpu[1], 0, HOLD_LINE, 0xff);
+	cputag_set_input_line_and_vector(space->machine, "audiocpu", 0, HOLD_LINE, 0xff);
 }
 
 static WRITE8_HANDLER( battlnts_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(space->machine, "main");
+	UINT8 *RAM = memory_region(space->machine, "maincpu");
 	int bankaddress;
 
 	/* bits 6 & 7 = bank number */
@@ -71,10 +72,8 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( battlnts_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM							/* ROM 777c01.rom */
 	AM_RANGE(0x8000, 0x87ff) AM_RAM							/* RAM */
-	AM_RANGE(0xa000, 0xa000) AM_READWRITE(ym3812_status_port_0_r, ym3812_control_port_0_w)	/* YM3812 (chip 1) */
-	AM_RANGE(0xa001, 0xa001) AM_WRITE(ym3812_write_port_0_w)		/* YM3812 (chip 1) */
-	AM_RANGE(0xc000, 0xc000) AM_READWRITE(ym3812_status_port_1_r, ym3812_control_port_1_w)	/* YM3812 (chip 2) */
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(ym3812_write_port_1_w)		/* YM3812 (chip 2) */
+	AM_RANGE(0xa000, 0xa001) AM_DEVREADWRITE("ym1", ym3812_r, ym3812_w)		/* YM3812 (chip 1) */
+	AM_RANGE(0xc000, 0xc001) AM_DEVREADWRITE("ym2", ym3812_r, ym3812_w)		/* YM3812 (chip 2) */
 	AM_RANGE(0xe000, 0xe000) AM_READ(soundlatch_r)			/* soundlatch_r */
 ADDRESS_MAP_END
 
@@ -86,40 +85,8 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( battlnts )
 	PORT_START("DSW1")
-	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )		PORT_DIPLOCATION("SW1:1,2,3,4")
-	PORT_DIPSETTING(	0x02, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(	0x05, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(	0x08, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(	0x04, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(	0x01, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(	0x0f, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(	0x03, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(	0x07, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(	0x0e, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(	0x06, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(	0x0d, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(	0x0b, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(	0x09, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )		PORT_DIPLOCATION("SW1:5,6,7,8")
-	PORT_DIPSETTING(	0x20, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(	0x50, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(	0x80, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(	0x40, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(	0x10, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(	0xf0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(	0x30, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(	0x70, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(	0xe0, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(	0x60, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(	0xd0, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(	0xc0, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-//  PORT_DIPSETTING(    0x00, "Invalid" )
+	KONAMI_COINAGE_LOC(DEF_STR( Free_Play ), "No Coin B", SW1)
+	/* "No Coin B" = coins produce sound, but no effect on coin counter */
 
 	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )		PORT_DIPLOCATION("SW2:1,2")
@@ -138,18 +105,14 @@ static INPUT_PORTS_START( battlnts )
 	PORT_DIPNAME( 0x60, 0x40, DEF_STR( Difficulty ) )	PORT_DIPLOCATION("SW2:6,7")
 	PORT_DIPSETTING(	0x60, DEF_STR( Easy ) )
 	PORT_DIPSETTING(	0x40, DEF_STR( Normal ) )
-	PORT_DIPSETTING(	0x20, "Difficult" )
-	PORT_DIPSETTING(	0x00, "Very Difficult" )
+	PORT_DIPSETTING(	0x20, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( Very_Difficult ) )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )	PORT_DIPLOCATION("SW2:8")
 	PORT_DIPSETTING(	0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 
 	PORT_START("DSW3")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
+	KONAMI8_SYSTEM_10
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Flip_Screen ) )	PORT_DIPLOCATION("SW3:1")
 	PORT_DIPSETTING(	0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
@@ -159,26 +122,13 @@ static INPUT_PORTS_START( battlnts )
 	PORT_SERVICE_DIPLOC(0x80, IP_ACTIVE_LOW, "SW3:3" )
 
 	PORT_START("P1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	KONAMI8_B1(1)
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Allow_Continue ) ) PORT_DIPLOCATION("SW3:4")
 	PORT_DIPSETTING(	0x80, "3 Times" )
 	PORT_DIPSETTING(	0x00, "5 Times" )
 
 	PORT_START("P2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_B1_UNK(2)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( thehustj )
@@ -200,11 +150,11 @@ static INPUT_PORTS_START( thehustj )
 	PORT_DIPUNUSED_DIPLOC( 0x40, 0x40, "SW3:2" )
 
 	PORT_MODIFY("P1")
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	KONAMI8_B12(1)
 	PORT_DIPUNUSED_DIPLOC( 0x80, 0x80, "SW3:4" )
 
 	PORT_MODIFY("P2")
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	KONAMI8_B12_UNK(2)
 INPUT_PORTS_END
 
 
@@ -245,15 +195,15 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( battlnts )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", HD6309, 3000000*4)		/* ? */
-	MDRV_CPU_PROGRAM_MAP(battlnts_map,0)
-	MDRV_CPU_VBLANK_INT("main", battlnts_interrupt)
+	MDRV_CPU_ADD("maincpu", HD6309, 3000000*4)		/* ? */
+	MDRV_CPU_PROGRAM_MAP(battlnts_map)
+	MDRV_CPU_VBLANK_INT("screen", battlnts_interrupt)
 
-	MDRV_CPU_ADD("audio", Z80, 3579545)
-	MDRV_CPU_PROGRAM_MAP(battlnts_sound_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 3579545)
+	MDRV_CPU_PROGRAM_MAP(battlnts_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -283,11 +233,11 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( battlnts )
-	ROM_REGION( 0x20000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "777_g02.7e", 0x08000, 0x08000, CRC(dbd8e17e) SHA1(586a22b714011c67a915c4a350ceca19ff875635) ) /* fixed ROM */
 	ROM_LOAD( "777_g03.8e", 0x10000, 0x10000, CRC(7bd44fef) SHA1(308ec5246f5537b34e368535672ac687f456750a) ) /* banked ROM */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for the sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for the sound CPU */
 	ROM_LOAD( "777_c01.10a",  0x00000, 0x08000, CRC(c21206e9) SHA1(7b133e04be67dc061a186ab0481d848b69b370d7) )
 
 	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
@@ -298,11 +248,11 @@ ROM_START( battlnts )
 ROM_END
 
 ROM_START( battlntj )
-	ROM_REGION( 0x20000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "777_e02.7e",  0x08000, 0x08000, CRC(d631cfcb) SHA1(7787da0dd8cd218abc27204e517e04d7a1913a3b) ) /* fixed ROM */
 	ROM_LOAD( "777_e03.8e",  0x10000, 0x10000, CRC(5ef1f4ef) SHA1(e3e6e1fc5a65328d94c23e2e76eef3504b70e58b) ) /* banked ROM */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for the sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for the sound CPU */
 	ROM_LOAD( "777_c01.10a",  0x00000, 0x08000, CRC(c21206e9) SHA1(7b133e04be67dc061a186ab0481d848b69b370d7) )
 
 	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
@@ -313,11 +263,11 @@ ROM_START( battlntj )
 ROM_END
 
 ROM_START( rackemup )
-	ROM_REGION( 0x20000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "765_l02.7e",  0x08000, 0x08000, CRC(3dfc48bd) SHA1(9ba98e9f27dd0a6efec145bea2a5ae7df8567437) ) /* fixed ROM */
 	ROM_LOAD( "765_j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for the sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for the sound CPU */
 	ROM_LOAD( "765_j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
@@ -328,11 +278,11 @@ ROM_START( rackemup )
 ROM_END
 
 ROM_START( thehustl )
-	ROM_REGION( 0x20000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "765_m02.7e",  0x08000, 0x08000, CRC(934807b9) SHA1(84e13a5c1587ee28330f369f9a1180219edbda9d) ) /* fixed ROM */
 	ROM_LOAD( "765_j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for the sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for the sound CPU */
 	ROM_LOAD( "765_j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
@@ -343,11 +293,11 @@ ROM_START( thehustl )
 ROM_END
 
 ROM_START( thehustj )
-	ROM_REGION( 0x20000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "765_j02.7e",  0x08000, 0x08000, CRC(2ac14c75) SHA1(b88f6279ab88719f4207e28486a0022554668382) ) /* fixed ROM */
 	ROM_LOAD( "765_j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for the sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for the sound CPU */
 	ROM_LOAD( "765_j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
@@ -399,4 +349,3 @@ GAME( 1987, battlntj, battlnts, battlnts, battlnts, 0,        ROT90, "Konami", "
 GAME( 1987, rackemup, 0,        battlnts, thehustj, rackemup, ROT90, "Konami", "Rack 'em Up", GAME_NO_COCKTAIL )
 GAME( 1987, thehustl, rackemup, battlnts, thehustj, 0,        ROT90, "Konami", "The Hustler (Japan version M)", GAME_NO_COCKTAIL )
 GAME( 1987, thehustj, rackemup, battlnts, thehustj, 0,        ROT90, "Konami", "The Hustler (Japan version J)", GAME_NO_COCKTAIL )
-
