@@ -472,17 +472,17 @@ static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static MACHINE_DRIVER_START( blackt96 )
-	MDRV_CPU_ADD("main", M68000, 18000000 /2)
-	MDRV_CPU_PROGRAM_MAP(blackt96_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 18000000 /2)
+	MDRV_CPU_PROGRAM_MAP(blackt96_map)
+	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audio", PIC16C57, 8000000)	/* ? */
+	MDRV_CPU_ADD("audiocpu", PIC16C57, 8000000)	/* ? */
 	MDRV_CPU_FLAGS(CPU_DISABLE)
-	MDRV_CPU_IO_MAP(sound_io_map, 0)
+	MDRV_CPU_IO_MAP(sound_io_map)
 
 	MDRV_GFXDECODE(blackt96)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -495,26 +495,26 @@ static MACHINE_DRIVER_START( blackt96 )
 	MDRV_VIDEO_START(blackt96)
 	MDRV_VIDEO_UPDATE(blackt96)
 
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("oki1", OKIM6295, 8000000/8)
 	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.47)
 
 	MDRV_SOUND_ADD("oki2", OKIM6295, 8000000/8)
 	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.47)
 MACHINE_DRIVER_END
 
 
 ROM_START( blackt96 )
-	ROM_REGION( 0x80000, "main", 0 ) /* 68000 Code */
+	ROM_REGION( 0x80000, "maincpu", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "3", 0x00001, 0x40000, CRC(fc2c1d79) SHA1(742478237819af16d3fd66039283202b3c07eedd) )
 	ROM_LOAD16_BYTE( "4", 0x00000, 0x40000, CRC(caff5b4a) SHA1(9a388cbb07211fa66f27082a8a5b847168c86a4f) )
 
-	ROM_REGION( 0x80000, "audio", 0 ) /* PIC16c57 Code */
+	ROM_REGION( 0x80000, "audiocpu", 0 ) /* PIC16c57 Code */
 	ROM_LOAD( "pic16c57", 0x00000, 0x1000, NO_DUMP )
 
 	ROM_REGION( 0x080000, "oki1", 0 ) /* Samples */
