@@ -370,7 +370,6 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 	int xsize, ysize, xzoom, yzoom;
 	int code, attr, color, size, pri, pri_mask, trans;
 	gfx_element *gfx = machine->gfx[region];
-	gfx_element mygfx = *gfx;
 
 	UINT32		*source	= sprram_top;
 	const UINT32	*finish	= sprram_top + (sprram_size - 0x10) / 4;
@@ -433,11 +432,6 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 			flipy = !flipy;
 		}
 
-		/* change GfxElement parameters to draw only the needed part of the 256x256 tile */
-		mygfx.width = xsize;
-		mygfx.height = ysize;
-		mygfx.gfxdata = gfx->gfxdata + tx + ty * gfx->line_modulo;
-
 		/* TODO: priority handling is completely wrong, but better than nothing */
 		if (pri == 0x0)
 			pri_mask = 0x00;
@@ -448,7 +442,8 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 		else
 			pri_mask = 0xfe;
 
-		pdrawgfxzoom(bitmap, &mygfx,
+		gfx_element_set_source_clip(gfx, tx, xsize, ty, ysize);
+		pdrawgfxzoom(bitmap, gfx,
 				code,
 				color,
 				flipx, flipy,
@@ -492,8 +487,8 @@ static VIDEO_START(bnstars)
 
 static VIDEO_UPDATE(bnstars)
 {
-	const device_config *left_screen  = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
-	const device_config *right_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "right");
+	const device_config *left_screen  = devtag_get_device(screen->machine, "lscreen");
+	const device_config *right_screen = devtag_get_device(screen->machine, "rscreen");
 
 	bitmap_fill(priority_bitmap,cliprect,0);
 
@@ -1242,18 +1237,18 @@ static ADDRESS_MAP_START( bnstars_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0xfcc00008, 0xfcc0000b) AM_READ( bnstars2_r )
 	AM_RANGE(0xfcc00010, 0xfcc00013) AM_READ( bnstars3_r )
 
-	AM_RANGE(0xfce00034, 0xfce00037) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xfce00034, 0xfce00037) AM_WRITENOP
 
-	AM_RANGE(0xfce00050, 0xfce00053) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xfce00058, 0xfce0005b) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xfce0005c, 0xfce0005f) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xfce00050, 0xfce00053) AM_WRITENOP
+	AM_RANGE(0xfce00058, 0xfce0005b) AM_WRITENOP
+	AM_RANGE(0xfce0005c, 0xfce0005f) AM_WRITENOP
 
-	AM_RANGE(0xfce00400, 0xfce0045f) AM_WRITE(SMH_RAM) AM_BASE(&ms32_roz_ctrl[0])
-	AM_RANGE(0xfce00700, 0xfce0075f) AM_WRITE(SMH_RAM) AM_BASE(&ms32_roz_ctrl[1]) // guess
-	AM_RANGE(0xfce00a00, 0xfce00a17) AM_WRITE(SMH_RAM) AM_BASE(&ms32_tx0_scroll)
-	AM_RANGE(0xfce00a20, 0xfce00a37) AM_WRITE(SMH_RAM) AM_BASE(&ms32_bg0_scroll)
-	AM_RANGE(0xfce00c00, 0xfce00c17) AM_WRITE(SMH_RAM) AM_BASE(&ms32_tx1_scroll)
-	AM_RANGE(0xfce00c20, 0xfce00c37) AM_WRITE(SMH_RAM) AM_BASE(&ms32_bg1_scroll)
+	AM_RANGE(0xfce00400, 0xfce0045f) AM_WRITEONLY AM_BASE(&ms32_roz_ctrl[0])
+	AM_RANGE(0xfce00700, 0xfce0075f) AM_WRITEONLY AM_BASE(&ms32_roz_ctrl[1]) // guess
+	AM_RANGE(0xfce00a00, 0xfce00a17) AM_WRITEONLY AM_BASE(&ms32_tx0_scroll)
+	AM_RANGE(0xfce00a20, 0xfce00a37) AM_WRITEONLY AM_BASE(&ms32_bg0_scroll)
+	AM_RANGE(0xfce00c00, 0xfce00c17) AM_WRITEONLY AM_BASE(&ms32_tx1_scroll)
+	AM_RANGE(0xfce00c20, 0xfce00c37) AM_WRITEONLY AM_BASE(&ms32_bg1_scroll)
 
 	AM_RANGE(0xfce00e00, 0xfce00e03) AM_WRITE(bnstars1_mahjong_select_w) // ?
 
@@ -1271,7 +1266,7 @@ static ADDRESS_MAP_START( bnstars_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0xfec08000, 0xfec0ffff) AM_RAM_WRITE(ms32_bg0_ram_w) AM_BASE(&ms32_bg0_ram)
 
 	AM_RANGE(0xfee00000, 0xfee1ffff) AM_RAM
-	AM_RANGE(0xffe00000, 0xffffffff) AM_READWRITE(SMH_BANK1, SMH_ROM)
+	AM_RANGE(0xffe00000, 0xffffffff) AM_ROMBANK(1)
 ADDRESS_MAP_END
 
 #if 0
@@ -1295,14 +1290,14 @@ static IRQ_CALLBACK(irq_callback)
 static void irq_init(running_machine *machine)
 {
 	irqreq = 0;
-	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
-	cpu_set_irq_callback(machine->cpu[0], irq_callback);
+	cputag_set_input_line(machine, "maincpu", 0, CLEAR_LINE);
+	cpu_set_irq_callback(cputag_get_cpu(machine, "maincpu"), irq_callback);
 }
 
 static void irq_raise(running_machine *machine, int level)
 {
 	irqreq |= (1<<level);
-	cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
+	cputag_set_input_line(machine, "maincpu", 0, ASSERT_LINE);
 }
 
 
@@ -1330,12 +1325,12 @@ static MACHINE_RESET( ms32 )
 static MACHINE_DRIVER_START( bnstars )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", V70, 20000000) // 20MHz
-	MDRV_CPU_PROGRAM_MAP(bnstars_map,0)
+	MDRV_CPU_ADD("maincpu", V70, 20000000) // 20MHz
+	MDRV_CPU_PROGRAM_MAP(bnstars_map)
 	MDRV_CPU_VBLANK_INT_HACK(ms32_interrupt,32)
 
-//  MDRV_CPU_ADD("audio", Z80, 4000000)
-//  MDRV_CPU_PROGRAM_MAP(bnstars_z80_map, 0)
+//  MDRV_CPU_ADD("audiocpu", Z80, 4000000)
+//  MDRV_CPU_PROGRAM_MAP(bnstars_z80_map)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
@@ -1346,14 +1341,14 @@ static MACHINE_DRIVER_START( bnstars )
 
 	MDRV_DEFAULT_LAYOUT(layout_dualhsxs)
 
-	MDRV_SCREEN_ADD("left", RASTER)
+	MDRV_SCREEN_ADD("lscreen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_SIZE(40*8, 28*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
 
-	MDRV_SCREEN_ADD("right", RASTER)
+	MDRV_SCREEN_ADD("rscreen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
@@ -1364,21 +1359,21 @@ static MACHINE_DRIVER_START( bnstars )
 	MDRV_VIDEO_UPDATE(bnstars)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("ymf1", YMF271, 16934400)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
 
 	MDRV_SOUND_ADD("ymf2", YMF271, 16934400)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
 
 MACHINE_DRIVER_END
 
 
 ROM_START( bnstars1 )
-	ROM_REGION( 0x200000, "main", 0 ) /* V70 code */
+	ROM_REGION( 0x200000, "maincpu", 0 ) /* V70 code */
 	ROM_LOAD32_BYTE( "mb-93142.36", 0x000003, 0x80000, CRC(2eb6a503) SHA1(27c02ab1b4321924fd4499844467ea4dc97de25d) )
 	ROM_LOAD32_BYTE( "mb-93142.37", 0x000002, 0x80000, CRC(49f60882) SHA1(2ff5b0989aaf970103304a453773e0b9517ebb8d) )
 	ROM_LOAD32_BYTE( "mb-93142.38", 0x000001, 0x80000, CRC(6e1312cd) SHA1(4c22f8f9f1574eefd96147453cf240f50c17f5dc) )
@@ -1444,7 +1439,7 @@ static DRIVER_INIT (bnstars)
 	decrypt_ms32_tx(machine, 0x00020,0x7e, "gfx7");
 	decrypt_ms32_bg(machine, 0x00001,0x9b, "gfx6");
 
-	memory_set_bankptr(machine, 1, memory_region(machine, "main"));
+	memory_set_bankptr(machine, 1, memory_region(machine, "maincpu"));
 }
 
 GAME( 1997, bnstars1, 0,        bnstars, bnstars, bnstars, ROT0,   "Jaleco", "Vs. Janshi Brandnew Stars", GAME_NO_SOUND )
