@@ -47,23 +47,11 @@ static WRITE8_HANDLER( bogeyman_8910_control_w )
 
 	// bit 5 goes to 8910 #0 BDIR pin
 	if ((last & 0x20) == 0x20 && (data & 0x20) == 0x00)
-	{
-		// bit 4 goes to the 8910 #0 BC1 pin
-		if (last & 0x10)
-			ay8910_control_port_0_w(space,0,psg_latch);
-		else
-			ay8910_write_port_0_w(space,0,psg_latch);
-	}
+		ay8910_data_address_w(devtag_get_device(space->machine, "ay1"), last >> 4, psg_latch);
 
 	// bit 7 goes to 8910 #1 BDIR pin
 	if ((last & 0x80) == 0x80 && (data & 0x80) == 0x00)
-	{
-		// bit 6 goes to the 8910 #1 BC1 pin
-		if (last & 0x40)
-			ay8910_control_port_1_w(space,0,psg_latch);
-		else
-			ay8910_write_port_1_w(space,0,psg_latch);
-	}
+		ay8910_data_address_w(devtag_get_device(space->machine, "ay2"), last >> 6, psg_latch);
 
 	last = data;
 }
@@ -229,14 +217,14 @@ GFXDECODE_END
 
 static MACHINE_DRIVER_START( bogeyman )
 	// basic machine hardware
-	MDRV_CPU_ADD("main", M6502, 2000000)	// 12 MHz clock on board
-	MDRV_CPU_PROGRAM_MAP(bogeyman_map, 0)
+	MDRV_CPU_ADD("maincpu", M6502, 2000000)	// 12 MHz clock on board
+	MDRV_CPU_PROGRAM_MAP(bogeyman_map)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold, 16) // Controls sound
 
 	// video hardware
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -263,7 +251,7 @@ MACHINE_DRIVER_END
 /* ROMs */
 
 ROM_START( bogeyman )
-	ROM_REGION( 0x58000, "main", 0 )
+	ROM_REGION( 0x58000, "maincpu", 0 )
  	ROM_LOAD( "j20.c14",  0x04000, 0x04000, CRC(ea90d637) SHA1(aa89bee806badb05119516d84e7674cd302aaf4e) )
 	ROM_LOAD( "j10.c15",  0x08000, 0x04000, CRC(0a8f218d) SHA1(5e5958cccfe634e3d274d187a0a7fe4789f3a9c3) )
 	ROM_LOAD( "j00.c17",  0x0c000, 0x04000, CRC(5d486de9) SHA1(40ea14a4a25f8f38d33a8844f627ba42503e1280) )
@@ -293,4 +281,4 @@ ROM_END
 
 /* Game Driver */
 
-GAME( 1985?, bogeyman, 0, bogeyman, bogeyman, 0, ROT0, "Technos Japan", "Bogey Manor", GAME_IMPERFECT_COLORS )
+GAME( 1985, bogeyman, 0, bogeyman, bogeyman, 0, ROT0, "Technos Japan", "Bogey Manor", GAME_IMPERFECT_COLORS )
