@@ -107,7 +107,7 @@ static ADDRESS_MAP_START( mem_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x2007, 0x2007) AM_WRITE(lamps_w)
 	AM_RANGE(0x2008, 0x2008) AM_NOP
 	AM_RANGE(0x2080, 0x213f) AM_NOP
-	AM_RANGE(0x2400, 0x2400) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
+	AM_RANGE(0x2400, 0x2400) AM_DEVREADWRITE("oki", okim6295_r, okim6295_w)
 	AM_RANGE(0x2800, 0x2801) AM_NOP
 	AM_RANGE(0x2840, 0x2840) AM_NOP
 	AM_RANGE(0x2880, 0x2880) AM_NOP
@@ -194,13 +194,13 @@ static PALETTE_INIT(cardline)
 static MACHINE_DRIVER_START( cardline )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", I80C32,12000000)
-	MDRV_CPU_PROGRAM_MAP(mem_prg,0)
-	MDRV_CPU_IO_MAP(mem_io,0)
-	//MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
+	MDRV_CPU_ADD("maincpu", I80C32,12000000)
+	MDRV_CPU_PROGRAM_MAP(mem_prg)
+	MDRV_CPU_IO_MAP(mem_io)
+	//MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -216,12 +216,12 @@ static MACHINE_DRIVER_START( cardline )
 	MDRV_DEFAULT_LAYOUT(layout_cardline)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
 	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
 MACHINE_DRIVER_END
 
@@ -232,7 +232,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( cardline )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "dns0401.u23",   0x0000, 0x10000, CRC(5bbaf5c1) SHA1(70972a744c5981b01a46799a7fd1b0a600489264) )
 
 	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )
