@@ -56,7 +56,7 @@ static TIMER_CALLBACK( interrupt_callback )
 {
 	int scanline = param;
 
-	generic_pulse_irq_line(machine->cpu[0], 0);
+	generic_pulse_irq_line(cputag_get_cpu(machine, "maincpu"), 0);
 
 	scanline = scanline + 32;
 
@@ -199,13 +199,13 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( cball )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6800, 12096000 / 16) /* ? */
-	MDRV_CPU_PROGRAM_MAP(cpu_map, 0)
+	MDRV_CPU_ADD("maincpu", M6800, 12096000 / 16) /* ? */
+	MDRV_CPU_PROGRAM_MAP(cpu_map)
 
 	MDRV_MACHINE_RESET(cball)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 262)
@@ -223,7 +223,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( cball )
-	ROM_REGION( 0x8000, "main", 0 )
+	ROM_REGION( 0x8000, "maincpu", 0 )
 	ROM_LOAD_NIB_LOW ( "canball.1e", 0x7400, 0x0400, CRC(0b34823b) SHA1(0db6b9f78f7c07ee7d35f2bf048ba61fe43b1e26) )
 	ROM_LOAD_NIB_HIGH( "canball.1l", 0x7400, 0x0400, CRC(b43ca275) SHA1(a03e03f6366877cfdcec71030a5fb2c5171c8d8a) )
 	ROM_LOAD_NIB_LOW ( "canball.1f", 0x7800, 0x0400, CRC(29b4e1f7) SHA1(8cef944b6e0153c304aa2d4cfdc530b8a4eef021) )
