@@ -30,41 +30,41 @@ static WRITE8_HANDLER( dambustr_noise_enable_w )
 }
 
 
-static ADDRESS_MAP_START( dambustr_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd000, 0xd3ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd400, 0xd7ff) AM_READ(galaxold_videoram_r)
-	AM_RANGE(0xd800, 0xd8ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN0")
-	AM_RANGE(0xe800, 0xefff) AM_READ_PORT("IN1")
-	AM_RANGE(0xf000, 0xf7ff) AM_READ_PORT("DSW")
-	AM_RANGE(0xf800, 0xffff) AM_READ(watchdog_reset_r)
-ADDRESS_MAP_END
+static ADDRESS_MAP_START( dambustr_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
 
-
-static ADDRESS_MAP_START( dambustr_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0x8000, 0x8000) AM_WRITE(dambustr_bg_color_w)
 	AM_RANGE(0x8001, 0x8001) AM_WRITE(dambustr_bg_split_line_w)
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(galaxold_videoram_w) AM_BASE(&galaxold_videoram)
-	AM_RANGE(0xd800, 0xd83f) AM_WRITE(galaxold_attributesram_w) AM_BASE(&galaxold_attributesram)
-	AM_RANGE(0xd840, 0xd85f) AM_WRITE(SMH_RAM) AM_BASE(&galaxold_spriteram) AM_SIZE(&galaxold_spriteram_size)
-	AM_RANGE(0xd860, 0xd87f) AM_WRITE(SMH_RAM) AM_BASE(&galaxold_bulletsram) AM_SIZE(&galaxold_bulletsram_size)
-	AM_RANGE(0xd880, 0xd8ff) AM_WRITE(SMH_RAM)
+
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
+
+	AM_RANGE(0xd000, 0xd3ff) AM_RAM_WRITE(galaxold_videoram_w) AM_BASE(&galaxold_videoram)
+	AM_RANGE(0xd400, 0xd7ff) AM_READ(galaxold_videoram_r)
+	AM_RANGE(0xd800, 0xd83f) AM_RAM_WRITE(galaxold_attributesram_w) AM_BASE(&galaxold_attributesram)
+	AM_RANGE(0xd840, 0xd85f) AM_RAM AM_BASE(&galaxold_spriteram) AM_SIZE(&galaxold_spriteram_size)
+	AM_RANGE(0xd860, 0xd87f) AM_RAM AM_BASE(&galaxold_bulletsram) AM_SIZE(&galaxold_bulletsram_size)
+
+	AM_RANGE(0xd880, 0xd8ff) AM_RAM
+
+	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN0")
 	AM_RANGE(0xe002, 0xe003) AM_WRITE(galaxold_coin_counter_w)
 	AM_RANGE(0xe004, 0xe007) AM_WRITE(galaxian_lfo_freq_w)
+
+	AM_RANGE(0xe800, 0xefff) AM_READ_PORT("IN1")
 	AM_RANGE(0xe800, 0xe802) AM_WRITE(galaxian_background_enable_w)
 	AM_RANGE(0xe803, 0xe803) AM_WRITE(dambustr_noise_enable_w)
 	AM_RANGE(0xe804, 0xe804) AM_WRITE(galaxian_shoot_enable_w)	// probably louder than normal shot
 	AM_RANGE(0xe805, 0xe805) AM_WRITE(galaxian_shoot_enable_w)	// normal shot (like Galaxian)
 	AM_RANGE(0xe806, 0xe807) AM_WRITE(galaxian_vol_w)
+
+	AM_RANGE(0xf000, 0xf7ff) AM_READ_PORT("DSW")
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(galaxold_nmi_enable_w)
 	AM_RANGE(0xf004, 0xf004) AM_WRITE(galaxold_stars_enable_w)
 	AM_RANGE(0xf006, 0xf006) AM_WRITE(galaxold_flip_screen_x_w)
 	AM_RANGE(0xf007, 0xf007) AM_WRITE(galaxold_flip_screen_y_w)
+
 	AM_RANGE(0xf800, 0xf800) AM_WRITE(galaxian_pitch_w)
+	AM_RANGE(0xf800, 0xffff) AM_READ(watchdog_reset_r)
 ADDRESS_MAP_END
 
 
@@ -145,7 +145,7 @@ static DRIVER_INIT(dambustr)
 {
 	int i, j, tmp;
 	int tmpram[16];
-	UINT8 *rom = memory_region(machine, "main");
+	UINT8 *rom = memory_region(machine, "maincpu");
 	UINT8 *usr = memory_region(machine, "user1");
 	UINT8 *gfx = memory_region(machine, "gfx1");
 
@@ -184,13 +184,13 @@ static DRIVER_INIT(dambustr)
 
 static MACHINE_DRIVER_START( dambustr )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 18432000/6)	/* 3.072 MHz */
-	MDRV_CPU_PROGRAM_MAP(dambustr_readmem, dambustr_writemem)
+	MDRV_CPU_ADD("maincpu", Z80, 18432000/6)	/* 3.072 MHz */
+	MDRV_CPU_PROGRAM_MAP(dambustr_map)
 
 	MDRV_MACHINE_RESET(galaxold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(16000.0/132/2)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
@@ -214,7 +214,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( dambustr )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "db8a",   0x4000, 0x1000, CRC(fd041ff4) SHA1(8d27da7bf0c655633711b960cbc23950c8a371ae) )
 	ROM_LOAD( "db6a",   0x5000, 0x1000, CRC(448db54b) SHA1(c9afbf02bf4d4ac2972ab7ac6adfa4e951ae79c2) )
 	ROM_LOAD( "db7a",   0x6000, 0x1000, CRC(675b1f5e) SHA1(6a386212a640fb467b6956a4dc5a68476af1cf97) )
@@ -239,7 +239,7 @@ ROM_END
 
 
 ROM_START( dambust )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "db08.bin",   0x4000, 0x1000, CRC(fd041ff4) SHA1(8d27da7bf0c655633711b960cbc23950c8a371ae) )
 	ROM_LOAD( "db06p.bin",  0x5000, 0x1000, CRC(35dcee01) SHA1(2c23c727d9b38322a6d0548dfe6a2a254f3530af) )
 	ROM_LOAD( "db07.bin",   0x6000, 0x1000, CRC(675b1f5e) SHA1(6a386212a640fb467b6956a4dc5a68476af1cf97) )
