@@ -156,7 +156,7 @@ static void parse_control( running_machine *machine )	/* assumes Z80 sandwiched
 	/* bit 0 enables cpu B */
 	/* however this fails when recovering from a save state
        if cpu B is disabled !! */
-	cpu_set_input_line(machine->cpu[2], INPUT_LINE_RESET, (cpua_ctrl &0x1) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(machine, "cpub", INPUT_LINE_RESET, (cpua_ctrl &0x1) ? CLEAR_LINE : ASSERT_LINE);
 
 }
 
@@ -247,47 +247,33 @@ logerror("CPU #0 PC %06x: warning - write unmapped ioc offset %06x with %04x\n",
                      MEMORY STRUCTURES
 ***********************************************************/
 
-static ADDRESS_MAP_START( darius_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x080000, 0x08ffff) AM_READ(SMH_RAM)		/* main RAM */
-	AM_RANGE(0xc00000, 0xc0001f) AM_READ(darius_ioc_r)	/* inputs, sound */
-	AM_RANGE(0xd00000, 0xd0ffff) AM_READ(PC080SN_word_0_r)	/* tilemaps */
-	AM_RANGE(0xd80000, 0xd80fff) AM_READ(SMH_RAM)	/* palette */
-	AM_RANGE(0xe00100, 0xe00fff) AM_RAM AM_SHARE(1) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xe01000, 0xe02fff) AM_RAM AM_SHARE(2)
-	AM_RANGE(0xe08000, 0xe0ffff) AM_RAM_WRITE(darius_fg_layer_w) AM_SHARE(3) AM_BASE(&darius_fg_ram)
-	AM_RANGE(0xe10000, 0xe10fff) AM_READ(SMH_RAM)		/* ??? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( darius_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x080000, 0x08ffff) AM_WRITE(SMH_RAM)
+static ADDRESS_MAP_START( darius_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x05ffff) AM_ROM
+	AM_RANGE(0x080000, 0x08ffff) AM_RAM												/* main RAM */
 	AM_RANGE(0x0a0000, 0x0a0001) AM_WRITE(cpua_ctrl_w)
 	AM_RANGE(0x0b0000, 0x0b0001) AM_WRITE(darius_watchdog_w)
-	AM_RANGE(0xc00000, 0xc0007f) AM_WRITE(darius_ioc_w)	/* coin ctr & lockout, sound */
-	AM_RANGE(0xd00000, 0xd0ffff) AM_WRITE(PC080SN_word_0_w)
+	AM_RANGE(0xc00000, 0xc0007f) AM_READWRITE(darius_ioc_r, darius_ioc_w)			/* inputs, sound */
+	AM_RANGE(0xd00000, 0xd0ffff) AM_READWRITE(PC080SN_word_0_r, PC080SN_word_0_w)	/* tilemaps */
 	AM_RANGE(0xd20000, 0xd20003) AM_WRITE(PC080SN_yscroll_word_0_w)
 	AM_RANGE(0xd40000, 0xd40003) AM_WRITE(PC080SN_xscroll_word_0_w)
 	AM_RANGE(0xd50000, 0xd50003) AM_WRITE(PC080SN_ctrl_word_0_w)
-	AM_RANGE(0xd80000, 0xd80fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0xe10000, 0xe10fff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xd80000, 0xd80fff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* palette */
+	AM_RANGE(0xe00100, 0xe00fff) AM_RAM AM_SHARE(1) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xe01000, 0xe02fff) AM_RAM AM_SHARE(2)
+	AM_RANGE(0xe08000, 0xe0ffff) AM_RAM_WRITE(darius_fg_layer_w) AM_SHARE(3) AM_BASE(&darius_fg_ram)
+	AM_RANGE(0xe10000, 0xe10fff) AM_RAM												/* ??? */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( darius_cpub_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x040000, 0x04ffff) AM_READ(SMH_RAM)	/* local RAM */
+static ADDRESS_MAP_START( darius_cpub_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x03ffff) AM_ROM
+	AM_RANGE(0x040000, 0x04ffff) AM_RAM				/* local RAM */
+	AM_RANGE(0xc00000, 0xc0007f) AM_WRITE(darius_ioc_w)	/* only writes $c00050 (?) */
+	AM_RANGE(0xd80000, 0xd80fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w)
 	AM_RANGE(0xe00100, 0xe00fff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0xe01000, 0xe02fff) AM_RAM AM_SHARE(2)
 	AM_RANGE(0xe08000, 0xe0ffff) AM_RAM_WRITE(darius_fg_layer_w) AM_SHARE(3)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( darius_cpub_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x040000, 0x04ffff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xc00000, 0xc0007f) AM_WRITE(darius_ioc_w)	/* only writes $c00050 (?) */
-	AM_RANGE(0xd80000, 0xd80fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w)
-ADDRESS_MAP_END
-
 
 /*****************************************************
                         SOUND
@@ -299,8 +285,8 @@ static UINT8 nmi_enable = 0;
 
 static void reset_sound_region(running_machine *machine)
 {
-	memory_set_bankptr(machine,  STATIC_BANK1, memory_region(machine, "audio") + (banknum * 0x8000) + 0x10000 );
-//  memory_set_bankptr(machine,  1, memory_region(machine, "audio") + (banknum * 0x8000) + 0x10000 );
+	memory_set_bankptr(machine,  STATIC_BANK1, memory_region(machine, "audiocpu") + (banknum * 0x8000) + 0x10000 );
+//  memory_set_bankptr(machine,  1, memory_region(machine, "audiocpu") + (banknum * 0x8000) + 0x10000 );
 
 }
 
@@ -337,136 +323,148 @@ static UINT32 darius_def_vol[0x10];
 static UINT8 darius_vol[DARIUS_VOL_MAX];
 static UINT8 darius_pan[DARIUS_PAN_MAX];
 
-static void update_fm0( void )
+static void update_fm0( running_machine *machine )
 {
+	const device_config *lvol = devtag_get_device(machine, "filter0.3l");
+	const device_config *rvol = devtag_get_device(machine, "filter0.3r");
 	int left, right;
 	left  = (        darius_pan[0]  * darius_vol[6])>>8;
 	right = ((0xff - darius_pan[0]) * darius_vol[6])>>8;
-	if (sndti_exists(SOUND_FILTER_VOLUME, 6))
-		flt_volume_set_volume(6, left / 100.0);
-	if (sndti_exists(SOUND_FILTER_VOLUME, 7))
-		flt_volume_set_volume(7, right / 100.0); /* FM #0 */
+	if (lvol != NULL)
+		flt_volume_set_volume(lvol, left / 100.0);
+	if (rvol != NULL)
+		flt_volume_set_volume(rvol, right / 100.0); /* FM #0 */
 }
 
-static void update_fm1( void )
+static void update_fm1( running_machine *machine )
 {
+	const device_config *lvol = devtag_get_device(machine, "filter1.3l");
+	const device_config *rvol = devtag_get_device(machine, "filter1.3r");
 	int left, right;
 	left  = (        darius_pan[1]  * darius_vol[7])>>8;
 	right = ((0xff - darius_pan[1]) * darius_vol[7])>>8;
-	if (sndti_exists(SOUND_FILTER_VOLUME, 14))
-		flt_volume_set_volume(14, left / 100.0);
-	if (sndti_exists(SOUND_FILTER_VOLUME, 15))
-		flt_volume_set_volume(15, right / 100.0); /* FM #1 */
+	if (lvol != NULL)
+		flt_volume_set_volume(lvol, left / 100.0);
+	if (rvol != NULL)
+		flt_volume_set_volume(rvol, right / 100.0); /* FM #1 */
 }
 
-static void update_psg0( int port )
+static void update_psg0( running_machine *machine, int port )
 {
+	static const char *const fltname[3][2] = { { "filter0.0l", "filter0.0r" }, { "filter0.1l", "filter0.1r" }, { "filter0.2l", "filter0.2r" } };
+	const device_config *lvol = devtag_get_device(machine, fltname[port][0]);
+	const device_config *rvol = devtag_get_device(machine, fltname[port][1]);
 	int left, right;
 	left  = (        darius_pan[2]  * darius_vol[port])>>8;
 	right = ((0xff - darius_pan[2]) * darius_vol[port])>>8;
-	if (sndti_exists(SOUND_FILTER_VOLUME, port*2+0))
-		flt_volume_set_volume(port*2+0, left / 100.0);
-	if (sndti_exists(SOUND_FILTER_VOLUME, port*2+1))
-		flt_volume_set_volume(port*2+1, right / 100.0);
+	if (lvol != NULL)
+		flt_volume_set_volume(lvol, left / 100.0);
+	if (rvol != NULL)
+		flt_volume_set_volume(rvol, right / 100.0);
 }
 
-static void update_psg1( int port )
+static void update_psg1( running_machine *machine, int port )
 {
+	static const char *const fltname[3][2] = { { "filter0.0l", "filter0.0r" }, { "filter0.1l", "filter0.1r" }, { "filter0.2l", "filter0.2r" } };
+	const device_config *lvol = devtag_get_device(machine, fltname[port][0]);
+	const device_config *rvol = devtag_get_device(machine, fltname[port][1]);
 	int left, right;
 	left  = (        darius_pan[3]  * darius_vol[port + 3])>>8;
 	right = ((0xff - darius_pan[3]) * darius_vol[port + 3])>>8;
-	if (sndti_exists(SOUND_FILTER_VOLUME, port*2+0+8))
-		flt_volume_set_volume(port*2+0+8, left / 100.0);
-	if (sndti_exists(SOUND_FILTER_VOLUME, port*2+1+8))
-		flt_volume_set_volume(port*2+1+8, right / 100.0);
+	if (lvol != NULL)
+		flt_volume_set_volume(lvol, left / 100.0);
+	if (rvol != NULL)
+		flt_volume_set_volume(rvol, right / 100.0);
 }
 
-static void update_da( void )
+static void update_da( running_machine *machine )
 {
+	const device_config *lvol = devtag_get_device(machine, "msm5205.l");
+	const device_config *rvol = devtag_get_device(machine, "msm5205.r");
 	int left, right;
 	left  = darius_def_vol[(darius_pan[4]>>4)&0x0f];
 	right = darius_def_vol[(darius_pan[4]>>0)&0x0f];
-	if (sndti_exists(SOUND_FILTER_VOLUME, 16))
-		flt_volume_set_volume(16, left / 100.0);
-	if (sndti_exists(SOUND_FILTER_VOLUME, 17))
-		flt_volume_set_volume(17, right / 100.0); /* FM #1 */
+	if (lvol != NULL)
+		flt_volume_set_volume(lvol, left / 100.0);
+	if (rvol != NULL)
+		flt_volume_set_volume(rvol, right / 100.0); /* FM #1 */
 }
 
 static WRITE8_HANDLER( darius_fm0_pan )
 {
 	darius_pan[0] = data&0xff;  /* data 0x00:right 0xff:left */
-	update_fm0();
+	update_fm0(space->machine);
 }
 
 static WRITE8_HANDLER( darius_fm1_pan )
 {
 	darius_pan[1] = data&0xff;
-	update_fm1();
+	update_fm1(space->machine);
 }
 
 static WRITE8_HANDLER( darius_psg0_pan )
 {
 	darius_pan[2] = data&0xff;
-	update_psg0( 0 );
-	update_psg0( 1 );
-	update_psg0( 2 );
+	update_psg0( space->machine, 0 );
+	update_psg0( space->machine, 1 );
+	update_psg0( space->machine, 2 );
 }
 
 static WRITE8_HANDLER( darius_psg1_pan )
 {
 	darius_pan[3] = data&0xff;
-	update_psg1( 0 );
-	update_psg1( 1 );
-	update_psg1( 2 );
+	update_psg1( space->machine, 0 );
+	update_psg1( space->machine, 1 );
+	update_psg1( space->machine, 2 );
 }
 
 static WRITE8_HANDLER( darius_da_pan )
 {
 	darius_pan[4] = data&0xff;
-	update_da();
+	update_da(space->machine);
 }
 
 /**** Mixer Control ****/
 
-static WRITE8_HANDLER( darius_write_portA0 )
+static WRITE8_DEVICE_HANDLER( darius_write_portA0 )
 {
 	// volume control FM #0 PSG #0 A
 	//popmessage(" pan %02x %02x %02x %02x %02x", darius_pan[0], darius_pan[1], darius_pan[2], darius_pan[3], darius_pan[4] );
 	//popmessage(" A0 %02x A1 %02x B0 %02x B1 %02x", port[0], port[1], port[2], port[3] );
 	darius_vol[0] = darius_def_vol[(data>>4)&0x0f];
 	darius_vol[6] = darius_def_vol[(data>>0)&0x0f];
-	update_fm0();
-	update_psg0( 0 );
+	update_fm0(device->machine);
+	update_psg0( device->machine, 0 );
 }
 
-static WRITE8_HANDLER( darius_write_portA1 )
+static WRITE8_DEVICE_HANDLER( darius_write_portA1 )
 {
 	// volume control FM #1 PSG #1 A
 	//popmessage(" pan %02x %02x %02x %02x %02x", darius_pan[0], darius_pan[1], darius_pan[2], darius_pan[3], darius_pan[4] );
 	darius_vol[3] = darius_def_vol[(data>>4)&0x0f];
 	darius_vol[7] = darius_def_vol[(data>>0)&0x0f];
-	update_fm1();
-	update_psg1( 0 );
+	update_fm1(device->machine);
+	update_psg1( device->machine, 0 );
 }
 
-static WRITE8_HANDLER( darius_write_portB0 )
+static WRITE8_DEVICE_HANDLER( darius_write_portB0 )
 {
 	// volume control PSG #0 B/C
 	//popmessage(" pan %02x %02x %02x %02x %02x", darius_pan[0], darius_pan[1], darius_pan[2], darius_pan[3], darius_pan[4] );
 	darius_vol[1] = darius_def_vol[(data>>4)&0x0f];
 	darius_vol[2] = darius_def_vol[(data>>0)&0x0f];
-	update_psg0( 1 );
-	update_psg0( 2 );
+	update_psg0( device->machine, 1 );
+	update_psg0( device->machine, 2 );
 }
 
-static WRITE8_HANDLER( darius_write_portB1 )
+static WRITE8_DEVICE_HANDLER( darius_write_portB1 )
 {
 	// volume control PSG #1 B/C
 	//popmessage(" pan %02x %02x %02x %02x %02x", darius_pan[0], darius_pan[1], darius_pan[2], darius_pan[3], darius_pan[4] );
 	darius_vol[4] = darius_def_vol[(data>>4)&0x0f];
 	darius_vol[5] = darius_def_vol[(data>>0)&0x0f];
-	update_psg1( 1 );
-	update_psg1( 2 );
+	update_psg1( device->machine, 1 );
+	update_psg1( device->machine, 2 );
 }
 
 
@@ -474,26 +472,13 @@ static WRITE8_HANDLER( darius_write_portB1 )
            Sound memory structures / ADPCM
 *****************************************************/
 
-static ADDRESS_MAP_START( darius_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_BANK1)
-	AM_RANGE(0x8000, 0x8fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x9000, 0x9000) AM_READ(ym2203_status_port_0_r)
-	AM_RANGE(0x9001, 0x9001) AM_READ(ym2203_read_port_0_r)
-	AM_RANGE(0xa000, 0xa000) AM_READ(ym2203_status_port_1_r)
-	AM_RANGE(0xa001, 0xa001) AM_READ(ym2203_read_port_1_r)
-	AM_RANGE(0xb000, 0xb000) AM_READ(SMH_NOP)
-	AM_RANGE(0xb001, 0xb001) AM_READ(taitosound_slave_comm_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( darius_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x9000, 0x9000) AM_WRITE(ym2203_control_port_0_w)
-	AM_RANGE(0x9001, 0x9001) AM_WRITE(ym2203_write_port_0_w)
-	AM_RANGE(0xa000, 0xa000) AM_WRITE(ym2203_control_port_1_w)
-	AM_RANGE(0xa001, 0xa001) AM_WRITE(ym2203_write_port_1_w)
-	AM_RANGE(0xb000, 0xb000) AM_WRITE(taitosound_slave_port_w)
-	AM_RANGE(0xb001, 0xb001) AM_WRITE(taitosound_slave_comm_w)
+static ADDRESS_MAP_START( darius_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROMBANK(1)
+	AM_RANGE(0x8000, 0x8fff) AM_RAM
+	AM_RANGE(0x9000, 0x9001) AM_DEVREADWRITE("ym1", ym2203_r, ym2203_w)
+	AM_RANGE(0xa000, 0xa001) AM_DEVREADWRITE("ym2", ym2203_r, ym2203_w)
+	AM_RANGE(0xb000, 0xb000) AM_READWRITE(SMH_NOP, taitosound_slave_port_w)
+	AM_RANGE(0xb001, 0xb001) AM_READWRITE(taitosound_slave_comm_r, taitosound_slave_comm_w)
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(darius_fm0_pan)
 	AM_RANGE(0xc400, 0xc400) AM_WRITE(darius_fm1_pan)
 	AM_RANGE(0xc800, 0xc800) AM_WRITE(darius_psg0_pan)
@@ -504,13 +489,8 @@ static ADDRESS_MAP_START( darius_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xdc00, 0xdc00) AM_WRITE(sound_bankswitch_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( darius_sound2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xffff) AM_READ(SMH_ROM)
-	/* yes, no RAM */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( darius_sound2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xffff) AM_WRITE(SMH_NOP)	/* writes rom whenever interrupt occurs - as no stack */
+static ADDRESS_MAP_START( darius_sound2_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xffff) AM_READWRITE(SMH_ROM, SMH_NOP)
 	/* yes, no RAM */
 ADDRESS_MAP_END
 
@@ -518,7 +498,7 @@ ADDRESS_MAP_END
 static void darius_adpcm_int (const device_config *device)
 {
 	if (nmi_enable)
-		cpu_set_input_line(device->machine->cpu[3], INPUT_LINE_NMI, PULSE_LINE);
+		cputag_set_input_line(device->machine, "adpcm", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static const msm5205_interface msm5205_config =
@@ -555,17 +535,17 @@ static WRITE8_HANDLER ( adpcm_nmi_enable )
 	/* logerror("write port 1: NMI ENABLE   PC=%4x\n", cpu_get_pc(space->cpu) ); */
 }
 
-static WRITE8_HANDLER( adpcm_data_w )
+static WRITE8_DEVICE_HANDLER( adpcm_data_w )
 {
-	msm5205_data_w (0,   data         );
-	msm5205_reset_w(0, !(data & 0x20) );	/* my best guess, but it could be output enable as well */
+	msm5205_data_w (device,   data         );
+	msm5205_reset_w(device, !(data & 0x20) );	/* my best guess, but it could be output enable as well */
 }
 
 static ADDRESS_MAP_START( darius_sound2_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READWRITE(adpcm_command_read, adpcm_nmi_disable)
 	AM_RANGE(0x01, 0x01) AM_WRITE(adpcm_nmi_enable)
-	AM_RANGE(0x02, 0x02) AM_READWRITE(readport2, adpcm_data_w)	/* readport2 ??? */
+	AM_RANGE(0x02, 0x02) AM_READ(readport2) AM_DEVWRITE("msm", adpcm_data_w)	/* readport2 ??? */
 	AM_RANGE(0x03, 0x03) AM_READ(readport3)	/* ??? */
 ADDRESS_MAP_END
 
@@ -793,9 +773,9 @@ GFXDECODE_END
 **************************************************************/
 
 /* handler called by the YM2203 emulator when the internal timers cause an IRQ */
-static void irqhandler(running_machine *machine, int irq)	/* assumes Z80 sandwiched between 68Ks */
+static void irqhandler(const device_config *device, int irq)	/* assumes Z80 sandwiched between 68Ks */
 {
-	cpu_set_input_line(machine->cpu[1],0,irq ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine, "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2203_interface ym2203_interface_1 =
@@ -803,10 +783,10 @@ static const ym2203_interface ym2203_interface_1 =
 	{
 		AY8910_LEGACY_OUTPUT,
 		AY8910_DEFAULT_LOADS,
-		NULL,					/* portA read */
-		NULL,
-		darius_write_portA0,	/* portA write */
-		darius_write_portB0,	/* portB write */
+		DEVCB_NULL,					/* portA read */
+		DEVCB_NULL,
+		DEVCB_HANDLER(darius_write_portA0),	/* portA write */
+		DEVCB_HANDLER(darius_write_portB0),	/* portB write */
 	},
 	irqhandler
 };
@@ -816,10 +796,10 @@ static const ym2203_interface ym2203_interface_2 =
 	{
 		AY8910_LEGACY_OUTPUT,
 		AY8910_DEFAULT_LOADS,
-		NULL,					/* portA read */
-		NULL,
-		darius_write_portA1,	/* portA write */
-		darius_write_portB1		/* portB write */
+		DEVCB_NULL,					/* portA read */
+		DEVCB_NULL,
+		DEVCB_HANDLER(darius_write_portA1),	/* portA write */
+		DEVCB_HANDLER(darius_write_portB1)		/* portB write */
 	},
 };
 
@@ -831,20 +811,20 @@ static const ym2203_interface ym2203_interface_2 =
 static MACHINE_DRIVER_START( darius )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000,16000000/2)	/* 8 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(darius_readmem,darius_writemem)
-	MDRV_CPU_VBLANK_INT("left", irq4_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000,16000000/2)	/* 8 MHz ? */
+	MDRV_CPU_PROGRAM_MAP(darius_map)
+	MDRV_CPU_VBLANK_INT("lscreen", irq4_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80,8000000/2)	/* 4 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(darius_sound_readmem,darius_sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)	/* 4 MHz ? */
+	MDRV_CPU_PROGRAM_MAP(darius_sound_map)
 
 	MDRV_CPU_ADD("cpub", M68000,16000000/2)	/* 8 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(darius_cpub_readmem,darius_cpub_writemem)
-	MDRV_CPU_VBLANK_INT("left", irq4_line_hold)
+	MDRV_CPU_PROGRAM_MAP(darius_cpub_map)
+	MDRV_CPU_VBLANK_INT("lscreen", irq4_line_hold)
 
 	MDRV_CPU_ADD("adpcm", Z80,8000000/2) /* 4 MHz ? */	/* ADPCM player using MSM5205 */
-	MDRV_CPU_PROGRAM_MAP(darius_sound2_readmem,darius_sound2_writemem)
-	MDRV_CPU_IO_MAP(darius_sound2_io_map,0)
+	MDRV_CPU_PROGRAM_MAP(darius_sound2_map)
+	MDRV_CPU_IO_MAP(darius_sound2_io_map)
 
 	MDRV_QUANTUM_TIME(HZ(600))	/* 10 CPU slices per frame ? */
 
@@ -856,21 +836,21 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_PALETTE_LENGTH(4096*2)
 	MDRV_DEFAULT_LAYOUT(layout_darius)
 
-	MDRV_SCREEN_ADD("left", RASTER)
+	MDRV_SCREEN_ADD("lscreen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_SIZE(36*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 1*8, 29*8-1)
 
-	MDRV_SCREEN_ADD("middle", RASTER)
+	MDRV_SCREEN_ADD("mscreen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_SIZE(36*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 1*8, 29*8-1)
 
-	MDRV_SCREEN_ADD("right", RASTER)
+	MDRV_SCREEN_ADD("rscreen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
@@ -881,7 +861,7 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_VIDEO_UPDATE(darius)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("ym1", YM2203, 4000000)
 	MDRV_SOUND_CONFIG(ym2203_interface_1)
@@ -911,43 +891,43 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "msm5205.r", 1.0)
 
 	MDRV_SOUND_ADD("filter0.0l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.0r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.1l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.1r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.2l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.2r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.3l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter0.3r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
 	MDRV_SOUND_ADD("filter1.0l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.0r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.1l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.1r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.2l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.2r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.3l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("filter1.3r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
 	MDRV_SOUND_ADD("msm5205.l", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 	MDRV_SOUND_ADD("msm5205.r", FILTER_VOLUME, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -956,7 +936,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( darius )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_FILL( 0x00000, 0x60000, 0xff )
 	ROM_LOAD16_BYTE( "da-59.bin",   0x00000, 0x10000, CRC(11aab4eb) SHA1(92f795e96a940e8d94abbf429ba4ac119992b991) )
 	ROM_LOAD16_BYTE( "da-58.bin",   0x00001, 0x10000, CRC(5f71e697) SHA1(bf959cf82e8e8ba950ab40d9c008ad5de01385aa) )
@@ -965,7 +945,7 @@ ROM_START( darius )
 	ROM_LOAD16_BYTE( "a96_31.187",  0x40000, 0x10000, CRC(e9bb5d89) SHA1(a5d08129c32b97e2cce84496945766fd32b6506e) )	/* 2 data roms */
 	ROM_LOAD16_BYTE( "a96_30.154",  0x40001, 0x10000, CRC(9eb5e127) SHA1(50e2fe5ec7f79ecf1fb5107298da13ef5ab37162) )
 
-   	ROM_REGION( 0x30000, "audio", 0 )	/* Z80 sound cpu */
+   	ROM_REGION( 0x30000, "audiocpu", 0 )	/* Z80 sound cpu */
 	ROM_LOAD( "a96_57.33",  0x00000, 0x10000, CRC(33ceb730) SHA1(05070ea503ac57ff8445145d6f97115f7aad90a5) )
 
 	ROM_REGION( 0x80000, "cpub", 0 )	/* 68000 code */
@@ -1015,7 +995,7 @@ ROM_START( darius )
 ROM_END
 
 ROM_START( dariusj )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_FILL( 0x00000, 0x60000, 0xff )
 	ROM_LOAD16_BYTE( "a96_29-1.185", 0x00000, 0x10000, CRC(75486f62) SHA1(818b095f2c6cc5764161c3e14ba70fe1c4b2f724) )
 	ROM_LOAD16_BYTE( "a96_28-1.152", 0x00001, 0x10000, CRC(fb34d400) SHA1(b14517384f5eadca8b73833bcd81374614b928d4) )
@@ -1023,7 +1003,7 @@ ROM_START( dariusj )
 	ROM_LOAD16_BYTE( "a96_31.187",   0x40000, 0x10000, CRC(e9bb5d89) SHA1(a5d08129c32b97e2cce84496945766fd32b6506e) )	/* 2 data roms */
 	ROM_LOAD16_BYTE( "a96_30.154",   0x40001, 0x10000, CRC(9eb5e127) SHA1(50e2fe5ec7f79ecf1fb5107298da13ef5ab37162) )
 
-   	ROM_REGION( 0x30000, "audio", 0 )	/* Z80 sound cpu */
+   	ROM_REGION( 0x30000, "audiocpu", 0 )	/* Z80 sound cpu */
 	ROM_LOAD( "a96_57.33",  0x00000, 0x10000, CRC(33ceb730) SHA1(05070ea503ac57ff8445145d6f97115f7aad90a5) )
 
 	ROM_REGION( 0x80000, "cpub", 0 )	/* 68000 code */
@@ -1070,7 +1050,7 @@ ROM_START( dariusj )
 ROM_END
 
 ROM_START( dariuso )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_FILL( 0x00000, 0x60000, 0xff )
 	ROM_LOAD16_BYTE( "a96-29.185",   0x00000, 0x10000, CRC(f775162b) SHA1(a17e570c2ba4daf0a3526b45c324c822faac0c8d) )
 	ROM_LOAD16_BYTE( "a96-28.152",   0x00001, 0x10000, CRC(4721d667) SHA1(fa9a109054a818f836452215204ce91f2b166ddb) )
@@ -1078,7 +1058,7 @@ ROM_START( dariuso )
 	ROM_LOAD16_BYTE( "a96_31.187",   0x40000, 0x10000, CRC(e9bb5d89) SHA1(a5d08129c32b97e2cce84496945766fd32b6506e) )	/* 2 data roms */
 	ROM_LOAD16_BYTE( "a96_30.154",   0x40001, 0x10000, CRC(9eb5e127) SHA1(50e2fe5ec7f79ecf1fb5107298da13ef5ab37162) )
 
-   	ROM_REGION( 0x30000, "audio", 0 )	/* Z80 sound cpu */
+   	ROM_REGION( 0x30000, "audiocpu", 0 )	/* Z80 sound cpu */
 	ROM_LOAD( "a96_57.33",  0x00000, 0x10000, CRC(33ceb730) SHA1(05070ea503ac57ff8445145d6f97115f7aad90a5) )
 
 	ROM_REGION( 0x80000, "cpub", 0 )	/* 68000 code */
@@ -1125,7 +1105,7 @@ ROM_START( dariuso )
 ROM_END
 
 ROM_START( dariuse )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_FILL( 0x00000, 0x60000, 0xff )
 	ROM_LOAD16_BYTE( "dae-68.bin",   0x00000, 0x10000, CRC(ed721127) SHA1(8127f4a9b26b5fb83a381235eef0577d60d1cfd7) )
 	ROM_LOAD16_BYTE( "dae-67.bin",   0x00001, 0x10000, CRC(b99aea8c) SHA1(859ada7c472ab2ac308faa775066e79ed1f4ad71) )
@@ -1133,7 +1113,7 @@ ROM_START( dariuse )
 	ROM_LOAD16_BYTE( "dae-70.bin",   0x40000, 0x10000, CRC(54590b31) SHA1(2b89846f14a5cb19b58ab4999bc5ae11671bbb5a) )	/* 2 data roms */
 	ROM_LOAD16_BYTE( "a96_30.154",   0x40001, 0x10000, CRC(9eb5e127) SHA1(50e2fe5ec7f79ecf1fb5107298da13ef5ab37162) )	// dae-69.bin
 
-   	ROM_REGION( 0x30000, "audio", 0 )	/* Z80 sound cpu */
+   	ROM_REGION( 0x30000, "audiocpu", 0 )	/* Z80 sound cpu */
 	ROM_LOAD( "a96_57.33",  0x00000, 0x10000, CRC(33ceb730) SHA1(05070ea503ac57ff8445145d6f97115f7aad90a5) )
 
 	ROM_REGION( 0x80000, "cpub", 0 )	/* 68000 code */
@@ -1215,7 +1195,7 @@ static MACHINE_RESET( darius )
 	int  i;
 
 	/**** setup sound bank image ****/
-	UINT8 *RAM = memory_region(machine, "audio");
+	UINT8 *RAM = memory_region(machine, "audiocpu");
 
 	for( i = 3; i >= 0; i-- ){
 		memcpy( RAM + 0x8000*i + 0x10000, RAM,            0x4000 );
@@ -1242,4 +1222,3 @@ GAME( 1986, darius,   0,        darius,   darius,   darius,   ROT0, "Taito Corpo
 GAME( 1986, dariusj,  darius,   darius,   dariusj,  darius,   ROT0, "Taito Corporation", "Darius (Japan)", 0 )
 GAME( 1986, dariuso,  darius,   darius,   dariusj,  darius,   ROT0, "Taito Corporation", "Darius (Japan old version)", 0 )
 GAME( 1986, dariuse,  darius,   darius,   dariuse,  darius,   ROT0, "Taito Corporation", "Darius (Extra) (Japan)", 0 )
-
