@@ -71,45 +71,23 @@ WRITE8_HANDLER( dday_sl_control_w );
 READ8_HANDLER( dday_countdown_timer_r );
 
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x5000, 0x5bff) AM_READ(SMH_RAM)
-	AM_RANGE(0x5c00, 0x5fff) AM_READ(dday_colorram_r)
-	AM_RANGE(0x6000, 0x63ff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( dday_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+	AM_RANGE(0x4000, 0x4000) AM_WRITE(dday_sl_control_w)
+	AM_RANGE(0x5000, 0x53ff) AM_RAM_WRITE(dday_textvideoram_w) AM_BASE(&dday_textvideoram)
+	AM_RANGE(0x5400, 0x57ff) AM_RAM_WRITE(dday_fgvideoram_w) AM_BASE(&dday_fgvideoram)
+	AM_RANGE(0x5800, 0x5bff) AM_RAM_WRITE(dday_bgvideoram_w) AM_BASE(&dday_bgvideoram)
+	AM_RANGE(0x5c00, 0x5fff) AM_READWRITE(dday_colorram_r, dday_colorram_w) AM_BASE(&dday_colorram)
+	AM_RANGE(0x6000, 0x63ff) AM_RAM
+	AM_RANGE(0x6400, 0x6401) AM_MIRROR(0x000e) AM_DEVWRITE("ay1", ay8910_address_data_w)
+	AM_RANGE(0x6800, 0x6801) AM_DEVWRITE("ay2", ay8910_address_data_w)
 	AM_RANGE(0x6c00, 0x6c00) AM_READ_PORT("BUTTONS")
 	AM_RANGE(0x7000, 0x7000) AM_READ_PORT("DSW0")
 	AM_RANGE(0x7400, 0x7400) AM_READ_PORT("DSW1")
-	AM_RANGE(0x7800, 0x7800) AM_READ(dday_countdown_timer_r)
+	AM_RANGE(0x7800, 0x7800) AM_READWRITE(dday_countdown_timer_r, dday_control_w)
 	AM_RANGE(0x7c00, 0x7c00) AM_READ_PORT("PADDLE")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x4000, 0x4000) AM_WRITE(dday_sl_control_w)
-	AM_RANGE(0x5000, 0x53ff) AM_WRITE(dday_textvideoram_w) AM_BASE(&dday_textvideoram)
-	AM_RANGE(0x5400, 0x57ff) AM_WRITE(dday_fgvideoram_w) AM_BASE(&dday_fgvideoram)
-	AM_RANGE(0x5800, 0x5bff) AM_WRITE(dday_bgvideoram_w) AM_BASE(&dday_bgvideoram)
-	AM_RANGE(0x5c00, 0x5fff) AM_WRITE(dday_colorram_w) AM_BASE(&dday_colorram)
-	AM_RANGE(0x6000, 0x63ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x6400, 0x6400) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6401, 0x6401) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x6402, 0x6402) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6403, 0x6403) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x6404, 0x6404) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6405, 0x6405) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x6406, 0x6406) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6407, 0x6407) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x6408, 0x6408) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6409, 0x6409) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x640a, 0x640a) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x640b, 0x640b) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x640c, 0x640c) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x640d, 0x640d) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x6800, 0x6800) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0x6801, 0x6801) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0x7800, 0x7800) AM_WRITE(dday_control_w)
-ADDRESS_MAP_END
-
 
 
 static INPUT_PORTS_START( dday )
@@ -257,11 +235,11 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( dday )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 2000000)     /* 2 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_ADD("maincpu", Z80, 2000000)     /* 2 MHz ? */
+	MDRV_CPU_PROGRAM_MAP(dday_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
@@ -295,7 +273,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( dday )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "e8_63co.bin",  0x0000, 0x1000, CRC(13d53793) SHA1(045f4b02803cb24305f90593777bb4a59f1bbb34) )
 	ROM_LOAD( "e7_64co.bin",  0x1000, 0x1000, CRC(e1ef2a70) SHA1(946ef20e2cd441ca858f969e7f25ab7c940671f8) )
 	ROM_LOAD( "e6_65co.bin",  0x2000, 0x1000, CRC(fe414a83) SHA1(1ca1d30b71b62af5230dfe862a67c4cff5a71f41) )
@@ -327,7 +305,7 @@ ROM_START( dday )
 ROM_END
 
 ROM_START( ddayc )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "e8_63-c.bin",  0x0000, 0x1000, CRC(d4fa3ae3) SHA1(587cfcd0bb3103c9875b8a5fd185a321212a86ab) )
 	ROM_LOAD( "e7_64-c.bin",  0x1000, 0x1000, CRC(9fb8b1a7) SHA1(abd935274745db28039f2e341e9be0490e307772) )
 	ROM_LOAD( "e6_65-c.bin",  0x2000, 0x1000, CRC(4c210686) SHA1(9d3110c4d1347f8a067c49b363a32d0f6a2c34c7) )
