@@ -2,54 +2,6 @@
 
     DECO Cassette System driver
 
-(01) Highway Chase (12/80)
-(02) Sengoku Ninja tai (12/80)
-(03) Manhattan (1/81)
-(04) Terranean (81)
-(??) Missile Sprinter (81)
-(06) Nebula (3/81)
-(07) Astro Fantasia (3/81)
-(08) The Tower (2/81)
-(09) Super Astro Fighter (5/81)
-(??) Buramzon (81)
-(11) Lock N Chase (4/81)
-(12) The DECO BOY (Flash Boy) (8/81)
-(13) Pro Golf (9/81)
-(14) DS TeleJang (6/81)
-(15) Lucky Poker (2/81)
-(16) Treasure Island (1/82)
-(18) Explorer (11/82)
-(19) Disco No. 1 (3/82)
-(20) Tornado (82)
-(21) Mission X (3/82)
-(22) Pro Tennis (5/82)
-(??) Fishing (7/82)
-(25) Angler Dandler
-(26) Burger Time (6/83)
-(27) Burnin' Rubber (11/82)
-(27) Bump N Jump (4/83)
-(28) Graplop (11/82)
-(28) Cluster Buster (9/83)
-(29) La-pa-pa (11/82)
-(30) Skater (3/83)
-(31) Pro Bowling (10/83)
-(32) Night Star (4/83)
-(33) Pro Soccer (11/83)
-(34) Super Doubles Tennis
-(??) Genesis (11/83) <I think this may be Boomer Rangr'>
-(??) Bambolin (83)
-(37) Zeroize (10/83)
-(38) Scrum Try (3/84)
-(39) Peter Pepper's Ice Cream Factory (2/84)
-(40) Fighting Ice Hockey (4/84)
-(41) Oh Zumou (5/84)
-(42) Hello Gate Ball (8/84)
-(??) Yellow Cab (84)
-(44) Boulder Dash (8/85)
-(??) Tokyo Mie Sinryohjyo (10/84)
-(??) Tokyo Mie Sinryohyo2 (1/85)
-(??) Geinohijin Sikaku Siken (5/85)
-
  ***********************************************************************/
 
 #include "driver.h"
@@ -138,10 +90,10 @@ static ADDRESS_MAP_START( decocass_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_RAM
 	AM_RANGE(0x1000, 0x17ff) AM_READWRITE(decocass_sound_nmi_enable_r, decocass_sound_nmi_enable_w)
 	AM_RANGE(0x1800, 0x1fff) AM_READWRITE(decocass_sound_data_ack_reset_r, decocass_sound_data_ack_reset_w)
-	AM_RANGE(0x2000, 0x2fff) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x4000, 0x4fff) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x6000, 0x6fff) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x2000, 0x2fff) AM_DEVWRITE("ay1", ay8910_data_w)
+	AM_RANGE(0x4000, 0x4fff) AM_DEVWRITE("ay1", ay8910_address_w)
+	AM_RANGE(0x6000, 0x6fff) AM_DEVWRITE("ay2", ay8910_data_w)
+	AM_RANGE(0x8000, 0x8fff) AM_DEVWRITE("ay2", ay8910_address_w)
 	AM_RANGE(0xa000, 0xafff) AM_READ(decocass_sound_command_r)
 	AM_RANGE(0xc000, 0xcfff) AM_WRITE(decocass_sound_data_w)
 	AM_RANGE(0xf800, 0xffff) AM_ROM
@@ -370,15 +322,15 @@ static PALETTE_INIT( decocass )
 static MACHINE_DRIVER_START( decocass )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6502, HCLK4)
-	MDRV_CPU_PROGRAM_MAP(decocass_map,0)
+	MDRV_CPU_ADD("maincpu", M6502, HCLK4)
+	MDRV_CPU_PROGRAM_MAP(decocass_map)
 
-	MDRV_CPU_ADD("audio", M6502, HCLK1/3/2)
-	MDRV_CPU_PROGRAM_MAP(decocass_sound_map,0)
-	MDRV_TIMER_ADD_SCANLINE("audionmi", decocass_audio_nmi_gen, "main", 0, 8)
+	MDRV_CPU_ADD("audiocpu", M6502, HCLK1/3/2)
+	MDRV_CPU_PROGRAM_MAP(decocass_sound_map)
+	MDRV_TIMER_ADD_SCANLINE("audionmi", decocass_audio_nmi_gen, "screen", 0, 8)
 
 	MDRV_CPU_ADD("mcu", I8041, HCLK)
-	MDRV_CPU_IO_MAP(decocass_mcu_portmap,0)
+	MDRV_CPU_IO_MAP(decocass_mcu_portmap)
 
 	MDRV_QUANTUM_TIME(HZ(4200))				/* interleave CPUs */
 
@@ -388,7 +340,7 @@ static MACHINE_DRIVER_START( decocass )
 	MDRV_DECOCASS_TAPE_ADD("cassette")
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(HCLK, 384, 8, 248, 272, 8, 248)
 
@@ -639,7 +591,7 @@ static MACHINE_DRIVER_START( czeroize )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(decocass)
 	MDRV_MACHINE_RESET(czeroize)
-	MDRV_SCREEN_MODIFY("main")
+	MDRV_SCREEN_MODIFY("screen")
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 32*8-1, 1*8, 31*8-1)
 MACHINE_DRIVER_END
 
@@ -649,7 +601,7 @@ MACHINE_DRIVER_END
 
 
 #define DECOCASS_BIOS \
-	ROM_REGION( 0x10000, "main", 0 ) \
+	ROM_REGION( 0x10000, "maincpu", 0 ) \
 	ROM_SYSTEM_BIOS( 0, "bios0", "rms8.cpu" ) \
 	ROM_LOAD_BIOS( 0, "rms8.cpu",     0xf000, 0x1000, CRC(23d929b7) SHA1(063f83020ba3d6f43ab8471f95ca919767b93aa4) ) \
 	ROM_SYSTEM_BIOS( 1, "bios1", "dsp3.p0b & dsp3.p1b" ) \
@@ -659,7 +611,7 @@ MACHINE_DRIVER_END
 #define DECOCASS_COMMON_ROMS	\
 	DECOCASS_BIOS \
 \
-	ROM_REGION( 0x10000, "audio", 0 )	  \
+	ROM_REGION( 0x10000, "audiocpu", 0 )	  \
 	ROM_LOAD( "rms8.snd",     0xf800, 0x0800, CRC(b66b2c2a) SHA1(0097f38beb4872e735e560148052e258a26b08fd) ) \
 \
 	ROM_REGION( 0x10000, "mcu", 0 )	  /* 4k for the MCU (actually 1K ROM + 64 bytes RAM @ 0x800) */ \
@@ -1091,12 +1043,12 @@ ROM_END
 
 static DRIVER_INIT( decocass )
 {
-	const address_space *space = cputag_get_address_space(machine, "main", ADDRESS_SPACE_PROGRAM);
-	UINT8 *rom = memory_region(machine, "main");
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	UINT8 *rom = memory_region(machine, "maincpu");
 	int A;
 
 	/* allocate memory and mark all RAM regions with their decrypted pointers */
-	decrypted = auto_malloc(0x10000);
+	decrypted = auto_alloc_array(machine, UINT8, 0x10000);
 	memory_set_decrypted_region(space, 0x0000, 0xc7ff, &decrypted[0x0000]);
 	memory_set_decrypted_region(space, 0xd000, 0xdbff, &decrypted[0xd000]);
 	memory_set_decrypted_region(space, 0xf000, 0xffff, &decrypted[0xf000]);
@@ -1115,7 +1067,7 @@ static DRIVER_INIT( decocrom )
 {
 	int romlength = memory_region_length(machine, "user3");
 	UINT8 *rom = memory_region(machine, "user3");
-	UINT8 *decrypted2 = auto_malloc(romlength);
+	UINT8 *decrypted2 = auto_alloc_array(machine, UINT8, romlength);
 	int i;
 
 	/* standard init */
@@ -1126,7 +1078,7 @@ static DRIVER_INIT( decocrom )
 		decrypted2[i] = swap_bits_5_6(rom[i]);
 
 	/* convert charram to a banked ROM */
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0xafff, 0, 0, SMH_BANK1, decocass_de0091_w);
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x6000, 0xafff, 0, 0, (read8_space_func)SMH_BANK(1), decocass_de0091_w);
 	memory_configure_bank(machine, 1, 0, 1, decocass_charram, 0);
 	memory_configure_bank(machine, 1, 1, 1, memory_region(machine, "user3"), 0);
 	memory_configure_bank_decrypted(machine, 1, 0, 1, &decrypted[0x6000], 0);
@@ -1134,7 +1086,7 @@ static DRIVER_INIT( decocrom )
 	memory_set_bank(machine, 1, 0);
 
 	/* install the bank selector */
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xe900, 0xe900, 0, 0, decocass_e900_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xe900, 0xe900, 0, 0, decocass_e900_w);
 }
 
 
