@@ -169,7 +169,7 @@ static VIDEO_UPDATE( discoboy )
 #ifdef UNUSED_FUNCTION
 void discoboy_setrombank(UINT8 data)
 {
-	UINT8 *ROM = memory_region(machine, "main");
+	UINT8 *ROM = memory_region(machine, "maincpu");
 	data &=0x2f;
 	memory_set_bankptr(space->machine, 1, &ROM[0x6000+(data*0x1000)] );
 }
@@ -189,7 +189,7 @@ static WRITE8_HANDLER( discoboy_port_00_w )
 
 static WRITE8_HANDLER( discoboy_port_01_w )
 {
-	UINT8 *ROM = memory_region(space->machine, "main");
+	UINT8 *ROM = memory_region(space->machine, "maincpu");
 	int rombank;
 
 	// 00 10 20 30 during gameplay  1,2,3 other times?? title screen bit 0x40 toggle
@@ -203,10 +203,10 @@ static WRITE8_HANDLER( discoboy_port_01_w )
 
 static WRITE8_HANDLER( discoboy_port_03_w ) // sfx? (to sound cpu)
 {
-//  printf("unk discoboy_port_03_w %02x\n",data);
-//  cpu_set_input_line(space->machine->cpu[1],INPUT_LINE_NMI,HOLD_LINE);
-	soundlatch_w(space,0,data);
-	cpu_set_input_line(space->machine->cpu[1],0,HOLD_LINE);
+//  printf("unk discoboy_port_03_w %02x\n", data);
+//  cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, HOLD_LINE);
+	soundlatch_w(space, 0, data);
+	cputag_set_input_line(space->machine, "audiocpu", 0, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( discoboy_port_06_w )
@@ -285,23 +285,14 @@ static WRITE8_HANDLER( discoboy_ram_att_w )
 	discoboy_ram_att[offset] = data;
 }
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(rambank_r)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(discoboy_ram_att_r)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(rambank2_r)
-	AM_RANGE(0xe000, 0xefff) AM_READ(SMH_RAM)
-	AM_RANGE(0xf000, 0xffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(rambank_w)
-	AM_RANGE(0xc800, 0xcfff) AM_WRITE(discoboy_ram_att_w)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE(rambank2_w)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xf000, 0xffff) AM_WRITE(SMH_RAM)
+static ADDRESS_MAP_START( discoboy_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xc7ff) AM_READWRITE(rambank_r, rambank_w)
+	AM_RANGE(0xc800, 0xcfff) AM_READWRITE(discoboy_ram_att_r, discoboy_ram_att_w)
+	AM_RANGE(0xd000, 0xdfff) AM_READWRITE(rambank2_r, rambank2_w)
+	AM_RANGE(0xe000, 0xefff) AM_RAM
+	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 
@@ -329,23 +320,17 @@ ADDRESS_MAP_END
 
 static void splash_msm5205_int(const device_config *device)
 {
-	msm5205_data_w(0,adpcm_data >> 4);
+	msm5205_data_w(device,adpcm_data >> 4);
 //  adpcm_data = (adpcm_data << 4) & 0xf0;
 }
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM
+	AM_RANGE(0xec00, 0xec01) AM_DEVWRITE("ym", ym3812_w)
 	AM_RANGE(0xf800, 0xf800) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xec00, 0xec00) AM_WRITE(ym3812_control_port_0_w)
-	AM_RANGE(0xec01, 0xec01) AM_WRITE(ym3812_write_port_0_w)
-ADDRESS_MAP_END
-
 
 static INPUT_PORTS_START( discoboy )
 	PORT_START("DSWA")
@@ -460,19 +445,19 @@ static MACHINE_RESET( discoboy )
 
 static MACHINE_DRIVER_START( discoboy )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80,12000000/2)		 /* 6 MHz? */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(io_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,12000000/2)		 /* 6 MHz? */
+	MDRV_CPU_PROGRAM_MAP(discoboy_map)
+	MDRV_CPU_IO_MAP(io_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80,10000000/2)		 /* 5 MHz? */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-//  MDRV_CPU_IO_MAP(sound_io_map,0)
-//  MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("audiocpu", Z80,10000000/2)		 /* 5 MHz? */
+	MDRV_CPU_PROGRAM_MAP(sound_map)
+//  MDRV_CPU_IO_MAP(sound_io_map)
+//  MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 	MDRV_CPU_VBLANK_INT_HACK(nmi_line_pulse,32)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
@@ -502,14 +487,14 @@ MACHINE_DRIVER_END
 
 static DRIVER_INIT( discoboy )
 {
-	UINT8 *ROM = memory_region(machine, "main");
+	UINT8 *ROM = memory_region(machine, "maincpu");
 
-	discoboy_ram_part1 = auto_malloc(0x800);
-	discoboy_ram_part2 = auto_malloc(0x800);
-	discoboy_ram_att = auto_malloc(0x800);
+	discoboy_ram_part1 = auto_alloc_array(machine, UINT8, 0x800);
+	discoboy_ram_part2 = auto_alloc_array(machine, UINT8, 0x800);
+	discoboy_ram_att = auto_alloc_array(machine, UINT8, 0x800);
 
-	discoboy_ram_part3 = auto_malloc(0x1000);
-	discoboy_ram_part4 = auto_malloc(0x1000);
+	discoboy_ram_part3 = auto_alloc_array(machine, UINT8, 0x1000);
+	discoboy_ram_part4 = auto_alloc_array(machine, UINT8, 0x1000);
 
 	memset(discoboy_ram_part1,0,0x800);
 	memset(discoboy_ram_part2,0,0x800);
@@ -530,11 +515,11 @@ static DRIVER_INIT( discoboy )
 }
 
 ROM_START( discoboy )
-	ROM_REGION( 0x30000, "main", 0 )
+	ROM_REGION( 0x30000, "maincpu", 0 )
 	ROM_LOAD( "u2",  0x00000, 0x10000, CRC(44a4fefa) SHA1(29b74bb739afffb7baefb5ed4da09cdb1559b011) )
 	ROM_LOAD( "u18", 0x10000, 0x20000, CRC(88d1282d) SHA1(1f11dad0f577198c54a1dc182ba7502e398b998f) )
 
-	ROM_REGION( 0x20000, "audio", 0 )
+	ROM_REGION( 0x20000, "audiocpu", 0 )
 	ROM_LOAD( "2.u28",  0x00000, 0x10000, CRC(7c2ed174) SHA1(ace209dc4cc7a4ffca062842defd84cefc5b10d2))
 	ROM_LOAD( "1.u45",  0x10000, 0x10000, CRC(c266c6df) SHA1(f76e38ded43f56a486cf6569c679ddb57a4165fb) )
 
@@ -557,4 +542,3 @@ ROM_END
 
 
 GAME( 1993, discoboy,  0,    discoboy, discoboy, discoboy, ROT270, "Soft Art Co.", "Disco Boy", 0 )
-
