@@ -103,13 +103,13 @@ static VIDEO_START(dunhuang)
 	tilemap_set_transparent_pen(tmap,   0);
 	tilemap_set_transparent_pen(tmap2,  0);
 
-	dunhuang_videoram = (UINT16*)auto_malloc(sizeof(UINT16) * 0x40 * 0x20);
-	dunhuang_colorram = (UINT8*) auto_malloc(sizeof(UINT8)  * 0x40 * 0x20);
+	dunhuang_videoram = auto_alloc_array(machine, UINT16, 0x40 * 0x20);
+	dunhuang_colorram = auto_alloc_array(machine, UINT8, 0x40 * 0x20);
 
-	dunhuang_videoram2 = (UINT16*)auto_malloc(sizeof(UINT16) * 0x40 * 0x8);
-	dunhuang_colorram2 = (UINT8*) auto_malloc(sizeof(UINT8)  * 0x40 * 0x8);
+	dunhuang_videoram2 = auto_alloc_array(machine, UINT16, 0x40 * 0x8);
+	dunhuang_colorram2 = auto_alloc_array(machine, UINT8, 0x40 * 0x8);
 
-	dunhuang_paldata  = (UINT8*)auto_malloc(sizeof(UINT8) * 3 * 256);
+	dunhuang_paldata  = auto_alloc_array(machine, UINT8, 3 * 256);
 }
 
 static VIDEO_UPDATE( dunhuang )
@@ -334,7 +334,7 @@ static WRITE8_HANDLER( dunhuang_layers_w )
 static ADDRESS_MAP_START( dunhuang_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE( 0x0000, 0x5fff ) AM_ROM
 	AM_RANGE( 0x6000, 0x7fff ) AM_RAM
-	AM_RANGE( 0x8000, 0xffff ) AM_READ( SMH_BANK1 )
+	AM_RANGE( 0x8000, 0xffff ) AM_READ( SMH_BANK(1) )
 ADDRESS_MAP_END
 
 // Inputs
@@ -351,14 +351,14 @@ static READ8_HANDLER( dunhuang_service_r )
 	;
 }
 
-static READ8_HANDLER( dunhuang_dsw_r )
+static READ8_DEVICE_HANDLER( dunhuang_dsw_r )
 {
-	if (!(dunhuang_input & 0x01))	return input_port_read(space->machine, "DSW1");
-	if (!(dunhuang_input & 0x02))	return input_port_read(space->machine, "DSW2");
-	if (!(dunhuang_input & 0x04))	return input_port_read(space->machine, "DSW3");
-	if (!(dunhuang_input & 0x08))	return input_port_read(space->machine, "DSW4");
-	if (!(dunhuang_input & 0x10))	return input_port_read(space->machine, "DSW5");
-	logerror("%06x: warning, unknown dsw bits read, dunhuang_input = %02x\n", cpu_get_pc(space->cpu), dunhuang_input);
+	if (!(dunhuang_input & 0x01))	return input_port_read(device->machine, "DSW1");
+	if (!(dunhuang_input & 0x02))	return input_port_read(device->machine, "DSW2");
+	if (!(dunhuang_input & 0x04))	return input_port_read(device->machine, "DSW3");
+	if (!(dunhuang_input & 0x08))	return input_port_read(device->machine, "DSW4");
+	if (!(dunhuang_input & 0x10))	return input_port_read(device->machine, "DSW5");
+	logerror("%s: warning, unknown dsw bits read, dunhuang_input = %02x\n", cpuexec_describe_context(device->machine), dunhuang_input);
 	return 0xff;
 }
 static READ8_HANDLER( dunhuang_input_r )
@@ -368,13 +368,13 @@ static READ8_HANDLER( dunhuang_input_r )
 	if (!(dunhuang_input & 0x04))	return input_port_read(space->machine, "IN2");
 	if (!(dunhuang_input & 0x08))	return input_port_read(space->machine, "IN3");
 	if (!(dunhuang_input & 0x10))	return input_port_read(space->machine, "IN4");
-	logerror("%06x: warning, unknown input bits read, dunhuang_input = %02x\n", cpu_get_pc(space->cpu), dunhuang_input);
+	logerror("%s: warning, unknown input bits read, dunhuang_input = %02x\n", cpuexec_describe_context(space->machine), dunhuang_input);
 	return 0xff;
 }
 
 static WRITE8_HANDLER( dunhuang_rombank_w )
 {
-	UINT8 *rom = memory_region(space->machine, "main");
+	UINT8 *rom = memory_region(space->machine, "maincpu");
 	memory_set_bankptr(space->machine,  1, rom + 0x10000 + 0x8000 * ((data >> 2) & 0x7) );
 
 	// ?                data & 0x01
@@ -417,8 +417,8 @@ static ADDRESS_MAP_START( dunhuang_io_map, ADDRESS_SPACE_IO, 8 )
 
 	AM_RANGE( 0x001b, 0x001b ) AM_WRITE( dunhuang_block_dest_w )
 
-	AM_RANGE( 0x0081, 0x0081 ) AM_WRITE( ym2413_register_port_0_w	)
-	AM_RANGE( 0x0089, 0x0089 ) AM_WRITE( ym2413_data_port_0_w		)
+	AM_RANGE( 0x0081, 0x0081 ) AM_DEVWRITE( "ym", ym2413_register_port_w	)
+	AM_RANGE( 0x0089, 0x0089 ) AM_DEVWRITE( "ym", ym2413_data_port_w		)
 
 //  AM_RANGE( 0x0082, 0x0082 ) AM_WRITE( dunhuang_82_w )
 
@@ -431,9 +431,9 @@ static ADDRESS_MAP_START( dunhuang_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE( 0x0086, 0x0086 ) AM_WRITE( dunhuang_rombank_w )
 	AM_RANGE( 0x0087, 0x0087 ) AM_WRITE( dunhuang_layers_w )
 
-	AM_RANGE( 0x0088, 0x0088 ) AM_READ( ay8910_read_port_0_r )
-	AM_RANGE( 0x0090, 0x0090 ) AM_WRITE( ay8910_write_port_0_w )
-	AM_RANGE( 0x0098, 0x0098 ) AM_WRITE( ay8910_control_port_0_w )
+	AM_RANGE( 0x0088, 0x0088 ) AM_DEVREAD( "ay8910", ay8910_r )
+	AM_RANGE( 0x0090, 0x0090 ) AM_DEVWRITE( "ay8910", ay8910_data_w )
+	AM_RANGE( 0x0098, 0x0098 ) AM_DEVWRITE( "ay8910", ay8910_address_w )
 ADDRESS_MAP_END
 
 
@@ -669,21 +669,21 @@ static const ay8910_interface dunhuang_ay8910_interface =
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
 	//  A                   B
-	NULL,					dunhuang_dsw_r,	// R
-	dunhuang_input_w,		NULL			// W
+	DEVCB_NULL,							DEVCB_HANDLER(dunhuang_dsw_r),	// R
+	DEVCB_MEMORY_HANDLER("maincpu", PROGRAM, dunhuang_input_w),	DEVCB_NULL						// W
 };
 
 static MACHINE_DRIVER_START( dunhuang )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80,12000000/2)
-	MDRV_CPU_PROGRAM_MAP(dunhuang_map,0)
-	MDRV_CPU_IO_MAP(dunhuang_io_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,12000000/2)
+	MDRV_CPU_PROGRAM_MAP(dunhuang_map)
+	MDRV_CPU_IO_MAP(dunhuang_io_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_WATCHDOG_TIME_INIT(SEC(5))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -717,7 +717,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( dunhuang )
-	ROM_REGION( 0x50000, "main", 0 )
+	ROM_REGION( 0x50000, "maincpu", 0 )
 	ROM_LOAD( "rom1.u9", 0x00000, 0x40000, CRC(843a0117) SHA1(26a838cb3552ea6a9ec55940fcbf83b06c068743) )
 	ROM_RELOAD(          0x10000, 0x40000 )
 
