@@ -88,7 +88,7 @@ INLINE int vysnc_chain_counter_to_vpos(UINT16 counter)
 
 static TIMER_CALLBACK( interrupt_clear_callback )
 {
-	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 0, CLEAR_LINE);
 }
 
 
@@ -101,7 +101,7 @@ static TIMER_CALLBACK( interrupt_assert_callback )
 	int vpos = video_screen_get_vpos(machine->primary_screen);
 	UINT16 counter = vpos_to_vysnc_chain_counter(vpos);
 	UINT8 vector = 0xc7 | ((counter & 0x80) >> 3) | ((~counter & 0x80) >> 4);
-	cpu_set_input_line_and_vector(machine->cpu[0], 0, ASSERT_LINE, vector);
+	cputag_set_input_line_and_vector(machine, "maincpu", 0, ASSERT_LINE, vector);
 
 	/* set up for next interrupt */
 	if (counter == INT_TRIGGER_COUNT_1)
@@ -139,7 +139,7 @@ static MACHINE_START( enigma2 )
 static MACHINE_RESET( enigma2 )
 {
 	last_sound_data = 0;
-	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
+	cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, CLEAR_LINE);
 
 	engima2_flip_screen = 0;
 
@@ -351,21 +351,21 @@ static WRITE8_HANDLER( sound_data_w )
 	if (!(data & 0x04) && (last_sound_data & 0x04))
 		sound_latch = (sound_latch << 1) | (~data & 0x01);
 
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
 
 	last_sound_data = data;
 }
 
 
-static READ8_HANDLER( sound_latch_r )
+static READ8_DEVICE_HANDLER( sound_latch_r )
 {
 	return BITSWAP8(sound_latch,0,1,2,3,4,5,6,7);
 }
 
 
-static WRITE8_HANDLER( protection_data_w )
+static WRITE8_DEVICE_HANDLER( protection_data_w )
 {
-if (LOG_PROT) logerror("Protection Data Write: %x at %x\n", data, cpu_get_pc(space->cpu));
+if (LOG_PROT) logerror("%s: Protection Data Write: %x\n", cpuexec_describe_context(device->machine), data);
 	protection_data = data;
 }
 
@@ -396,10 +396,10 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	sound_latch_r,
-	0,
-	0,
-	protection_data_w
+	DEVCB_HANDLER(sound_latch_r),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_HANDLER(protection_data_w)
 };
 
 
@@ -445,9 +445,8 @@ static ADDRESS_MAP_START( engima2_audio_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_MIRROR(0x1000) AM_ROM AM_WRITENOP
 	AM_RANGE(0x2000, 0x7fff) AM_NOP
 	AM_RANGE(0x8000, 0x83ff) AM_MIRROR(0x1c00) AM_RAM
-	AM_RANGE(0xa000, 0xa000) AM_MIRROR(0x1ffc) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0xa001, 0xa001) AM_MIRROR(0x1ffc) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x1ffc) AM_READ(ay8910_read_port_0_r)
+	AM_RANGE(0xa000, 0xa001) AM_MIRROR(0x1ffc) AM_DEVWRITE("ay", ay8910_address_data_w)
+	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x1ffc) AM_DEVREAD("ay", ay8910_r)
 	AM_RANGE(0xa003, 0xa003) AM_MIRROR(0x1ffc) AM_NOP
 	AM_RANGE(0xc000, 0xffff) AM_NOP
 ADDRESS_MAP_END
@@ -565,12 +564,12 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( enigma2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(engima2_main_cpu_map,0)
+	MDRV_CPU_ADD("maincpu", Z80, CPU_CLOCK)
+	MDRV_CPU_PROGRAM_MAP(engima2_main_cpu_map)
 
-	MDRV_CPU_ADD("audio", Z80, 2500000)
+	MDRV_CPU_ADD("audiocpu", Z80, 2500000)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
-	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map,0)
+	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map)
 
 	MDRV_MACHINE_START(enigma2)
 	MDRV_MACHINE_RESET(enigma2)
@@ -578,7 +577,7 @@ static MACHINE_DRIVER_START( enigma2 )
 	/* video hardware */
 	MDRV_VIDEO_UPDATE(enigma2)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
@@ -594,13 +593,13 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( enigma2a )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", 8080, CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(engima2a_main_cpu_map,0)
-	MDRV_CPU_IO_MAP(engima2a_main_cpu_io_map,0)
+	MDRV_CPU_ADD("maincpu", 8080, CPU_CLOCK)
+	MDRV_CPU_PROGRAM_MAP(engima2a_main_cpu_map)
+	MDRV_CPU_IO_MAP(engima2a_main_cpu_io_map)
 
-	MDRV_CPU_ADD("audio", Z80, 2500000)
+	MDRV_CPU_ADD("audiocpu", Z80, 2500000)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
-	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map,0)
+	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map)
 
 	MDRV_MACHINE_START(enigma2)
 	MDRV_MACHINE_RESET(enigma2)
@@ -608,7 +607,7 @@ static MACHINE_DRIVER_START( enigma2a )
 	/* video hardware */
 	MDRV_VIDEO_UPDATE(enigma2a)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
@@ -623,7 +622,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( enigma2 )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "1.5d",         0x0000, 0x0800, CRC(499749de) SHA1(401928ff41d3b4cbb68e6ad3bf3be4a10ae1781f) )
 	ROM_LOAD( "2.7d",         0x0800, 0x0800, CRC(173c1329) SHA1(3f1ad46d0e58ab236e4ff2b385d09fbf113627da) )
 	ROM_LOAD( "3.8d",         0x1000, 0x0800, CRC(c7d3e6b1) SHA1(43f7c3a02b46747998260d5469248f21714fe12b) )
@@ -631,7 +630,7 @@ ROM_START( enigma2 )
 	ROM_LOAD( "5.11d",   	  0x4000, 0x0800, CRC(098ac15b) SHA1(cce28a2540a9eabb473391fff92895129ae41751) )
 	ROM_LOAD( "6.13d",   	  0x4800, 0x0800, CRC(240a9d4b) SHA1(ca1c69fafec0471141ce1254ddfaef54fecfcbf0) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "enigma2.s",    0x0000, 0x1000, CRC(68fd8c54) SHA1(69996d5dfd996f0aacb26e397bef314204a2a88a) )
 
 	ROM_REGION( 0x1000, "proms", 0 )	/* color map/star map */
@@ -641,7 +640,7 @@ ROM_END
 
 
 ROM_START( enigma2a )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "36_en1.bin",   0x0000, 0x0800, CRC(15f44806) SHA1(4a2f7bc91d4edf7a069e0865d964371c97af0a0a) )
 	ROM_LOAD( "35_en2.bin",   0x0800, 0x0800, CRC(e841072f) SHA1(6ab02fd9fdeac5ab887cd25eee3d6b70ab01f849) )
 	ROM_LOAD( "34_en3.bin",   0x1000, 0x0800, CRC(43d06cf4) SHA1(495af05d54c0325efb67347f691e64d194645d85) )
@@ -649,7 +648,7 @@ ROM_START( enigma2a )
 	ROM_LOAD( "5.11d",        0x4000, 0x0800, CRC(098ac15b) SHA1(cce28a2540a9eabb473391fff92895129ae41751) )
 	ROM_LOAD( "6.13d",   	  0x4800, 0x0800, CRC(240a9d4b) SHA1(ca1c69fafec0471141ce1254ddfaef54fecfcbf0) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "sound.bin",    0x0000, 0x0800, BAD_DUMP CRC(5f092d3c) SHA1(17c70f6af1b5560a45e6b1bdb330a98b27570fe9) )
 ROM_END
 
@@ -658,7 +657,7 @@ ROM_END
 static DRIVER_INIT(enigma2)
 {
 	offs_t i;
-	UINT8 *rom = memory_region(machine, "audio");
+	UINT8 *rom = memory_region(machine, "audiocpu");
 
 	for(i = 0; i < 0x2000; i++)
 	{
