@@ -36,7 +36,7 @@ static UINT32 vidFIFO[256];
 
 static WRITE32_HANDLER(video_fifo_w)
 {
-	vidFIFO[data>>24]=data&0xffffff;
+	vidFIFO[data >> 24] = data & 0xffffff;
 }
 
 static READ32_HANDLER(IOCR_r)
@@ -52,18 +52,18 @@ static WRITE32_HANDLER(IOCR_w)
 
 static READ32_HANDLER(IRQSTA_r)
 {
-	return (IRQSTA&(~2))|0x80;
+	return (IRQSTA & (~2)) | 0x80;
 }
 
 static READ32_HANDLER(IRQRQA_r)
 {
-	return (IRQSTA&IRQMSKA)|0x80;
+	return (IRQSTA & IRQMSKA) | 0x80;
 }
 
 static WRITE32_HANDLER(IRQRQA_w)
 {
 	if(ACCESSING_BITS_0_7)
-		IRQSTA&=~data;
+		IRQSTA &= ~data;
 }
 
 static READ32_HANDLER(IRQMSKA_r)
@@ -74,12 +74,12 @@ static READ32_HANDLER(IRQMSKA_r)
 static WRITE32_HANDLER(IRQMSKA_w)
 {
 	if(ACCESSING_BITS_0_7)
-		IRQMSKA=(data&(~2))|0x80;
+		IRQMSKA = (data & (~2)) | 0x80;
 }
 
 static READ32_HANDLER(IRQRQB_r)
 {
-	return mame_rand(space->machine)&IRQMSKB; /* hack  0x20 - controls,  0x02 - ?sound? */
+	return mame_rand(space->machine) & IRQMSKB; /* hack  0x20 - controls,  0x02 - ?sound? */
 }
 
 static READ32_HANDLER(IRQMSKB_r)
@@ -90,7 +90,7 @@ static READ32_HANDLER(IRQMSKB_r)
 static WRITE32_HANDLER(IRQMSKB_w)
 {
 	if(ACCESSING_BITS_0_7)
-		IRQMSKB=data;
+		IRQMSKB = data;
 }
 
 static READ32_HANDLER(FIQMSK_r)
@@ -101,7 +101,7 @@ static READ32_HANDLER(FIQMSK_r)
 static WRITE32_HANDLER(FIQMSK_w)
 {
 	if(ACCESSING_BITS_0_7)
-		FIQMSK=(data&(~0x2c))|0x80;
+		FIQMSK = (data & (~0x2c)) | 0x80;
 }
 
 static READ32_HANDLER(T1low_r)
@@ -112,7 +112,7 @@ static READ32_HANDLER(T1low_r)
 static WRITE32_HANDLER(T1low_w)
 {
 	if(ACCESSING_BITS_0_7)
-		T1low=data;
+		T1low = data;
 }
 
 static READ32_HANDLER(T1high_r)
@@ -123,24 +123,24 @@ static READ32_HANDLER(T1high_r)
 static WRITE32_HANDLER(T1high_w)
 {
 	if(ACCESSING_BITS_0_7)
-		T1high=data;
+		T1high = data;
 }
 
 static void startTimer(running_machine *machine);
 
 static TIMER_CALLBACK( ertictacTimer )
 {
-	IRQSTA|=0x40;
-	if(IRQMSKA&0x40)
+	IRQSTA |= 0x40;
+	if(IRQMSKA & 0x40)
 	{
-		cpu_set_input_line(machine->cpu[0], ARM_IRQ_LINE, HOLD_LINE);
+		cputag_set_input_line(machine, "maincpu", ARM_IRQ_LINE, HOLD_LINE);
 	}
 	startTimer(machine);
 }
 
 static void startTimer(running_machine *machine)
 {
-	timer_set(machine, ATTOTIME_IN_USEC( ((T1low&0xff)|((T1high&0xff)<<8))>>4), NULL, 0, ertictacTimer);
+	timer_set(machine, ATTOTIME_IN_USEC(((T1low & 0xff) | ((T1high & 0xff) << 8)) >> 4), NULL, 0, ertictacTimer);
 }
 
 static WRITE32_HANDLER(T1GO_w)
@@ -220,8 +220,8 @@ static INPUT_PORTS_START( ertictac )
 	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0xc0, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x40, "Difficult" )
-	PORT_DIPSETTING(    0x00, "Very Difficult" )
+	PORT_DIPSETTING(    0x40, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Very_Difficult ) )
 
 	PORT_START("DSW2")
 	PORT_DIPNAME( 0x05, 0x00, DEF_STR( Coin_A ) )
@@ -381,14 +381,14 @@ static VIDEO_UPDATE( ertictac )
 
 static MACHINE_DRIVER_START( ertictac )
 
-	MDRV_CPU_ADD("main", ARM, 16000000) /* guess */
-	MDRV_CPU_PROGRAM_MAP(ertictac_map,0)
-	MDRV_CPU_VBLANK_INT("main", ertictac_interrupt)
+	MDRV_CPU_ADD("maincpu", ARM, 16000000) /* guess */
+	MDRV_CPU_PROGRAM_MAP(ertictac_map)
+	MDRV_CPU_VBLANK_INT("screen", ertictac_interrupt)
 
 	MDRV_MACHINE_RESET(ertictac)
 
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
