@@ -15,6 +15,7 @@ TODO:
 #include "cpu/hd6309/hd6309.h"
 #include "video/konamiic.h"
 #include "sound/k007232.h"
+#include "konamipt.h"
 
 /* from video/fastlane.c */
 extern UINT8 *fastlane_k007121_regs,*fastlane_videoram1,*fastlane_videoram2;
@@ -49,7 +50,7 @@ static WRITE8_HANDLER( k007121_registers_w )
 static WRITE8_HANDLER( fastlane_bankswitch_w )
 {
 	int bankaddress;
-	UINT8 *RAM = memory_region(space->machine, "main");
+	UINT8 *RAM = memory_region(space->machine, "maincpu");
 
 	/* bits 0 & 1 coin counters */
 	coin_counter_w(0,data & 0x01);
@@ -60,7 +61,7 @@ static WRITE8_HANDLER( fastlane_bankswitch_w )
 	memory_set_bankptr(space->machine, 1,&RAM[bankaddress]);
 
 	/* bit 4: bank # for the 007232 (chip 2) */
-	k007232_set_bank(1,0 + ((data & 0x10) >> 4),2 + ((data & 0x10) >> 4));
+	k007232_set_bank(devtag_get_device(space->machine, "konami2"),0 + ((data & 0x10) >> 4),2 + ((data & 0x10) >> 4));
 
 	/* other bits seems to be unused */
 }
@@ -68,55 +69,37 @@ static WRITE8_HANDLER( fastlane_bankswitch_w )
 /* Read and write handlers for one K007232 chip:
    even and odd register are mapped swapped */
 
-static READ8_HANDLER( fastlane_k007232_read_port_0_r )
+static READ8_DEVICE_HANDLER( fastlane_k007232_r )
 {
-	return k007232_read_port_0_r(space, offset ^ 1);
+	return k007232_r(device, offset ^ 1);
 }
-static WRITE8_HANDLER( fastlane_k007232_write_port_0_w )
+static WRITE8_DEVICE_HANDLER( fastlane_k007232_w )
 {
-	k007232_write_port_0_w(space, offset ^ 1, data);
-}
-static READ8_HANDLER( fastlane_k007232_read_port_1_r )
-{
-	return k007232_read_port_1_r(space, offset ^ 1);
-}
-static WRITE8_HANDLER( fastlane_k007232_write_port_1_w )
-{
-	k007232_write_port_1_w(space, offset ^ 1, data);
+	k007232_w(device, offset ^ 1, data);
 }
 
 
 
-static ADDRESS_MAP_START( fastlane_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x005f) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( fastlane_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x005f) AM_RAM_WRITE(k007121_registers_w) AM_BASE(&fastlane_k007121_regs)	/* 007121 registers */
 	AM_RANGE(0x0800, 0x0800) AM_READ_PORT("DSW3")
 	AM_RANGE(0x0801, 0x0801) AM_READ_PORT("P2")
 	AM_RANGE(0x0802, 0x0802) AM_READ_PORT("P1")
 	AM_RANGE(0x0803, 0x0803) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x0900, 0x0900) AM_READ_PORT("DSW1")
 	AM_RANGE(0x0901, 0x0901) AM_READ_PORT("DSW2")
-	AM_RANGE(0x0d00, 0x0d0d) AM_READ(fastlane_k007232_read_port_0_r)/* 007232 registers (chip 1) */
-	AM_RANGE(0x0e00, 0x0e0d) AM_READ(fastlane_k007232_read_port_1_r)/* 007232 registers (chip 2) */
-	AM_RANGE(0x0f00, 0x0f1f) AM_READ(K051733_r)			/* 051733 (protection) */
-	AM_RANGE(0x1000, 0x1fff) AM_READ(SMH_RAM)			/* Palette RAM/Work RAM */
-	AM_RANGE(0x2000, 0x3fff) AM_READ(SMH_RAM)			/* Video RAM + Sprite RAM */
-	AM_RANGE(0x4000, 0x7fff) AM_READ(SMH_BANK1)			/* banked ROM */
-	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)			/* ROM */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( fastlane_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x005f) AM_WRITE(k007121_registers_w) AM_BASE(&fastlane_k007121_regs)/* 007121 registers */
-	AM_RANGE(0x0b00, 0x0b00) AM_WRITE(watchdog_reset_w)		/* watchdog reset */
-	AM_RANGE(0x0c00, 0x0c00) AM_WRITE(fastlane_bankswitch_w)	/* bankswitch control */
-	AM_RANGE(0x0d00, 0x0d0d) AM_WRITE(fastlane_k007232_write_port_0_w)	/* 007232 registers (chip 1) */
-	AM_RANGE(0x0e00, 0x0e0d) AM_WRITE(fastlane_k007232_write_port_1_w)	/* 007232 registers (chip 2) */
-	AM_RANGE(0x0f00, 0x0f1f) AM_WRITE(K051733_w)				/* 051733 (protection) */
-	AM_RANGE(0x1000, 0x17ff) AM_WRITE(SMH_RAM) AM_BASE(&paletteram)/* palette RAM */
-	AM_RANGE(0x1800, 0x1fff) AM_WRITE(SMH_RAM)				/* Work RAM */
-	AM_RANGE(0x2000, 0x27ff) AM_WRITE(fastlane_vram1_w) AM_BASE(&fastlane_videoram1)
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(fastlane_vram2_w) AM_BASE(&fastlane_videoram2)
-	AM_RANGE(0x3000, 0x3fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)	/* Sprite RAM */
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(SMH_ROM)				/* ROM/banked ROM */
+	AM_RANGE(0x0b00, 0x0b00) AM_WRITE(watchdog_reset_w)											/* watchdog reset */
+	AM_RANGE(0x0c00, 0x0c00) AM_WRITE(fastlane_bankswitch_w)									/* bankswitch control */
+	AM_RANGE(0x0d00, 0x0d0d) AM_DEVREADWRITE("konami1", fastlane_k007232_r, fastlane_k007232_w)	/* 007232 registers (chip 1) */
+	AM_RANGE(0x0e00, 0x0e0d) AM_DEVREADWRITE("konami2", fastlane_k007232_r, fastlane_k007232_w)	/* 007232 registers (chip 2) */
+	AM_RANGE(0x0f00, 0x0f1f) AM_READWRITE(K051733_r, K051733_w)									/* 051733 (protection) */
+	AM_RANGE(0x1000, 0x17ff) AM_RAM AM_BASE(&paletteram)										/* Palette RAM */
+	AM_RANGE(0x1800, 0x1fff) AM_RAM																/* Work RAM */
+	AM_RANGE(0x2000, 0x27ff) AM_RAM_WRITE(fastlane_vram1_w) AM_BASE(&fastlane_videoram1) 		/* Video RAM (chip 1) */
+	AM_RANGE(0x2800, 0x2fff) AM_RAM_WRITE(fastlane_vram2_w) AM_BASE(&fastlane_videoram2) 		/* Video RAM (chip 2) */
+	AM_RANGE(0x3000, 0x3fff) AM_RAM AM_BASE(&spriteram)											/* Sprite RAM */
+	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK(1)														/* banked ROM */
+	AM_RANGE(0x8000, 0xffff) AM_ROM																/* ROM */
 ADDRESS_MAP_END
 
 /***************************************************************************
@@ -127,40 +110,8 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( fastlane )
 	PORT_START("DSW1")
-	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(	0x02, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(	0x05, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(	0x08, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(	0x04, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(	0x01, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(	0x0f, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(	0x03, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(	0x07, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(	0x0e, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(	0x06, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(	0x0d, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(	0x0b, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(	0x09, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(	0x20, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(	0x50, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(	0x80, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(	0x40, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(	0x10, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(	0xf0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(	0x30, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(	0x70, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(	0xe0, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(	0x60, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(	0xd0, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(	0xc0, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-//  PORT_DIPSETTING(    0x00, "Invalid" )
+	KONAMI_COINAGE(DEF_STR( Free_Play ), "No Coin B")
+	/* "No Coin B" = coins produce sound, but no effect on coin counter */
 
 	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -200,31 +151,13 @@ static INPUT_PORTS_START( fastlane )
 	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("SYSTEM")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* service */
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_SYSTEM_UNK
 
 	PORT_START("P1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_B12_UNK(1)
 
 	PORT_START("P2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_B12_UNK(2)
 INPUT_PORTS_END
 
 static const gfx_layout gfxlayout =
@@ -248,16 +181,16 @@ GFXDECODE_END
 
 ***************************************************************************/
 
-static void volume_callback0(int v)
+static void volume_callback0(const device_config *device, int v)
 {
-	k007232_set_volume(0,0,(v >> 4) * 0x11,0);
-	k007232_set_volume(0,1,0,(v & 0x0f) * 0x11);
+	k007232_set_volume(device,0,(v >> 4) * 0x11,0);
+	k007232_set_volume(device,1,0,(v & 0x0f) * 0x11);
 }
 
-static void volume_callback1(int v)
+static void volume_callback1(const device_config *device, int v)
 {
-	k007232_set_volume(1,0,(v >> 4) * 0x11,0);
-	k007232_set_volume(1,1,0,(v & 0x0f) * 0x11);
+	k007232_set_volume(device,0,(v >> 4) * 0x11,0);
+	k007232_set_volume(device,1,0,(v & 0x0f) * 0x11);
 }
 
 static const k007232_interface k007232_interface_1 =
@@ -273,12 +206,12 @@ static const k007232_interface k007232_interface_2 =
 static MACHINE_DRIVER_START( fastlane )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", HD6309, 3000000*4)		/* 24MHz/8? */
-	MDRV_CPU_PROGRAM_MAP(fastlane_readmem,fastlane_writemem)
+	MDRV_CPU_ADD("maincpu", HD6309, 3000000*4)		/* 24MHz/8? */
+	MDRV_CPU_PROGRAM_MAP(fastlane_map)
 	MDRV_CPU_VBLANK_INT_HACK(fastlane_interrupt,16)	/* 1 IRQ + ??? NMI (generated by the 007121) */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -314,7 +247,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( fastlane )
-	ROM_REGION( 0x21000, "main", 0 ) /* code + banked roms */
+	ROM_REGION( 0x21000, "maincpu", 0 ) /* code + banked roms */
 	ROM_LOAD( "752_m02.9h",  0x08000, 0x08000, CRC(e1004489) SHA1(615b608d22abc3611f1620503cd6a8c9a6218db8) )  /* fixed ROM */
 	ROM_LOAD( "752_e01.10h", 0x10000, 0x10000, CRC(ff4d6029) SHA1(b5c5d8654ce728300d268628bd3dd878570ba7b8) )  /* banked ROM */
 
@@ -332,5 +265,4 @@ ROM_START( fastlane )
 ROM_END
 
 
-
 GAME( 1987, fastlane, 0, fastlane, fastlane, 0, ROT90, "Konami", "Fast Lane", GAME_IMPERFECT_COLORS )
