@@ -102,7 +102,7 @@ static WRITE8_HANDLER( firefox_disc_lock_w )
 
 static WRITE8_HANDLER( audio_enable_w )
 {
-	sndti_set_output_gain(SOUND_CUSTOM, 0, ~offset & 1, (data & 0x80) ? 1.0 : 0.0);
+	sound_set_output_gain(devtag_get_device(space->machine, "ldsound"), ~offset & 1, (data & 0x80) ? 1.0 : 0.0);
 }
 
 static WRITE8_HANDLER( firefox_disc_reset_w )
@@ -202,7 +202,7 @@ static TIMER_DEVICE_CALLBACK( video_timer_callback )
 {
 	video_screen_update_now(timer->machine->primary_screen);
 
-	cputag_set_input_line( timer->machine, "main", M6809_IRQ_LINE, ASSERT_LINE );
+	cputag_set_input_line( timer->machine, "maincpu", M6809_IRQ_LINE, ASSERT_LINE );
 }
 
 static void set_rgba( running_machine *machine, int start, int index, unsigned char *palette_ram )
@@ -260,12 +260,12 @@ static WRITE8_HANDLER( main_to_sound_w )
 {
 	main_to_sound_flag = 1;
 	soundlatch_w(space, 0, data);
-	cputag_set_input_line(space->machine, "audio", INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( sound_reset_w )
 {
-	cputag_set_input_line(space->machine, "audio", INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
 	if ((data & 0x80) != 0)
 		sound_to_main_flag = main_to_sound_flag = 0;
 }
@@ -301,27 +301,28 @@ static UINT8 riot_porta_r(const device_config *device, UINT8 olddata)
 	/* bit 1 = TMS /read */
 	/* bit 0 = TMS /write */
 
-	return (main_to_sound_flag << 7) | (sound_to_main_flag << 6) | 0x10 | (!tms5220_ready_r() << 2);
+	const device_config *tms = devtag_get_device(device->machine, "tms");
+	return (main_to_sound_flag << 7) | (sound_to_main_flag << 6) | 0x10 | (!tms5220_ready_r(tms) << 2);
 }
 
 
 static void riot_porta_w(const device_config *device, UINT8 newdata, UINT8 olddata)
 {
-	const address_space *space = cpu_get_address_space(device->machine->cpu[1], ADDRESS_SPACE_PROGRAM);
+	const device_config *tms = devtag_get_device(device->machine, "tms");
 
 	/* handle 5220 read */
 	if ((olddata & 2) != 0 && (newdata & 2) == 0)
-		riot6532_portb_in_set(device, tms5220_status_r(space, 0), 0xff);
+		riot6532_portb_in_set(device, tms5220_status_r(tms, 0), 0xff);
 
 	/* handle 5220 write */
 	if ((olddata & 1) != 0 && (newdata & 1) == 0)
-		tms5220_data_w(space, 0, riot6532_portb_out_get(device));
+		tms5220_data_w(tms, 0, riot6532_portb_out_get(device));
 }
 
 
 static void riot_irq(const device_config *device, int state)
 {
-	cputag_set_input_line(device->machine, "audio", M6502_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine, "audiocpu", M6502_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -393,17 +394,17 @@ static WRITE8_HANDLER( rom_bank_w )
 
 static WRITE8_HANDLER( main_irq_clear_w )
 {
-    cputag_set_input_line( space->machine, "main", M6809_IRQ_LINE, CLEAR_LINE );
+    cputag_set_input_line( space->machine, "maincpu", M6809_IRQ_LINE, CLEAR_LINE );
 }
 
 static WRITE8_HANDLER( main_firq_clear_w )
 {
-    cputag_set_input_line( space->machine, "main", M6809_FIRQ_LINE, CLEAR_LINE );
+    cputag_set_input_line( space->machine, "maincpu", M6809_FIRQ_LINE, CLEAR_LINE );
 }
 
 static WRITE8_HANDLER( self_reset_w )
 {
-	cputag_set_input_line( space->machine, "main", INPUT_LINE_RESET, PULSE_LINE );
+	cputag_set_input_line( space->machine, "maincpu", INPUT_LINE_RESET, PULSE_LINE );
 }
 
 
@@ -429,17 +430,17 @@ static WRITE8_HANDLER( firefox_coin_counter_w )
 static void firq_gen(const device_config *device, int state)
 {
 	if (state)
-	    cputag_set_input_line( device->machine, "main", M6809_FIRQ_LINE, ASSERT_LINE );
+	    cputag_set_input_line( device->machine, "maincpu", M6809_FIRQ_LINE, ASSERT_LINE );
 }
 
 
 static MACHINE_START( firefox )
 {
-	memory_configure_bank(machine, 1, 0, 32, memory_region(machine, "main") + 0x10000, 0x1000);
-	nvram_1c = devtag_get_device(machine, X2212, "nvram_1c");
-	nvram_1d = devtag_get_device(machine, X2212, "nvram_1d");
+	memory_configure_bank(machine, 1, 0, 32, memory_region(machine, "maincpu") + 0x10000, 0x1000);
+	nvram_1c = devtag_get_device(machine, "nvram_1c");
+	nvram_1d = devtag_get_device(machine, "nvram_1d");
 
-	laserdisc = devtag_get_device(machine, LASERDISC, "laserdisc");
+	laserdisc = devtag_get_device(machine, "laserdisc");
 	vp931_set_data_ready_callback(laserdisc, firq_gen);
 
 	control_num = 0;
@@ -502,13 +503,13 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x0800, 0x087f) AM_MIRROR(0x0700) AM_RAM /* RIOT ram */
-	AM_RANGE(0x0880, 0x089f) AM_MIRROR(0x07e0) AM_DEVREADWRITE(RIOT6532,"riot",riot6532_r, riot6532_w)
+	AM_RANGE(0x0880, 0x089f) AM_MIRROR(0x07e0) AM_DEVREADWRITE("riot",riot6532_r, riot6532_w)
 	AM_RANGE(0x1000, 0x1000) AM_READ(main_to_sound_r)
 	AM_RANGE(0x1800, 0x1800) AM_WRITE(sound_to_main_w)
-	AM_RANGE(0x2000, 0x200f) AM_READWRITE(pokey1_r, pokey1_w)
-	AM_RANGE(0x2800, 0x280f) AM_READWRITE(pokey2_r, pokey2_w)
-	AM_RANGE(0x3000, 0x300f) AM_READWRITE(pokey3_r, pokey3_w)
-	AM_RANGE(0x3800, 0x380f) AM_READWRITE(pokey4_r, pokey4_w)
+	AM_RANGE(0x2000, 0x200f) AM_DEVREADWRITE("pokey1", pokey_r, pokey_w)
+	AM_RANGE(0x2800, 0x280f) AM_DEVREADWRITE("pokey2", pokey_r, pokey_w)
+	AM_RANGE(0x3000, 0x300f) AM_DEVREADWRITE("pokey3", pokey_r, pokey_w)
+	AM_RANGE(0x3800, 0x380f) AM_DEVREADWRITE("pokey4", pokey_r, pokey_w)
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -650,13 +651,13 @@ static const riot6532_interface riot_intf =
 static MACHINE_DRIVER_START( firefox )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6809E, MASTER_XTAL/2)
-	MDRV_CPU_PROGRAM_MAP(main_map, 0)
+	MDRV_CPU_ADD("maincpu", M6809E, MASTER_XTAL/2)
+	MDRV_CPU_PROGRAM_MAP(main_map)
 	/* interrupts count starting at end of VBLANK, which is 44, so add 44 */
-	MDRV_TIMER_ADD_SCANLINE("32v", video_timer_callback, "main", 96+44, 128)
+	MDRV_TIMER_ADD_SCANLINE("32v", video_timer_callback, "screen", 96+44, 128)
 
-	MDRV_CPU_ADD("audio", M6502, MASTER_XTAL/8)
-	MDRV_CPU_PROGRAM_MAP(audio_map, 0)
+	MDRV_CPU_ADD("audiocpu", M6502, MASTER_XTAL/8)
+	MDRV_CPU_PROGRAM_MAP(audio_map)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
@@ -664,14 +665,14 @@ static MACHINE_DRIVER_START( firefox )
 	MDRV_WATCHDOG_TIME_INIT(HZ((double)MASTER_XTAL/8/16/16/16/16))
 
 	/* video hardware */
-	MDRV_LASERDISC_SCREEN_ADD_NTSC("main", BITMAP_FORMAT_RGB32)
+	MDRV_LASERDISC_SCREEN_ADD_NTSC("screen", BITMAP_FORMAT_RGB32)
 
 	MDRV_GFXDECODE(firefox)
 	MDRV_PALETTE_LENGTH(512)
 
 	MDRV_VIDEO_START(firefox)
 
-	MDRV_LASERDISC_ADD("laserdisc", PHILLIPS_22VP931, "main", "ldsound")
+	MDRV_LASERDISC_ADD("laserdisc", PHILLIPS_22VP931, "screen", "ldsound")
 	MDRV_LASERDISC_OVERLAY(firefox, 64*8, 525, BITMAP_FORMAT_RGB32)
 	MDRV_LASERDISC_OVERLAY_CLIP(7*8, 53*8-1, 44, 480+44)
 
@@ -680,32 +681,31 @@ static MACHINE_DRIVER_START( firefox )
 	MDRV_RIOT6532_ADD("riot", MASTER_XTAL/8, riot_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("pokey1", POKEY, MASTER_XTAL/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
 	MDRV_SOUND_ADD("pokey2", POKEY, MASTER_XTAL/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
 	MDRV_SOUND_ADD("pokey3", POKEY, MASTER_XTAL/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
 	MDRV_SOUND_ADD("pokey4", POKEY, MASTER_XTAL/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
 	MDRV_SOUND_ADD("tms", TMS5220, MASTER_XTAL/2/11)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.75)
 
-	MDRV_SOUND_ADD("ldsound", CUSTOM, 0)
-	MDRV_SOUND_CONFIG(laserdisc_custom_interface)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(1, "right", 0.50)
+	MDRV_SOUND_ADD("ldsound", LASERDISC, 0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 0.50)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -717,7 +717,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( firefox )
-	ROM_REGION( 0x30000, "main", 0 ) /* 64k for code + data & 128k for banked roms */
+	ROM_REGION( 0x30000, "maincpu", 0 ) /* 64k for code + data & 128k for banked roms */
 	ROM_LOAD( "136026.209",     0x04000, 0x4000, CRC(9f559f1b) SHA1(142d14cb5158ea77f6fc6d9bf0ce723842f345e2) ) /* 8b/c */
 	ROM_LOAD( "136026.210",     0x08000, 0x4000, CRC(d769b40d) SHA1(2d354649a381f3399cb0161267bd1c36a8f2bb4b) ) /* 7b/c */
 	ROM_LOAD( "136026.211",     0x0c000, 0x4000, CRC(7293ab03) SHA1(73d0d173da295ad59e431bab0a9814a71146cbc2) ) /* 6b/c */
@@ -731,7 +731,7 @@ ROM_START( firefox )
 	/* empty 2a */
 	/* empty 1a */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for code */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for code */
 	/* empty 4k/l */
 	ROM_LOAD( "136026.128",     0x08000, 0x2000, CRC(5358d870) SHA1(e8f2983a7e612e1a050a3c0b9f19b1077de4c146) ) /* 4m */
 	ROM_RELOAD( 0x0a000, 0x2000 )
@@ -755,11 +755,11 @@ ROM_START( firefox )
 	ROM_LOAD( "136026.119",     0x2c000,  0x4000, CRC(959471b1) SHA1(a032209a209f51d34360d5c7ad32ec62150158d2)) /* 1a */
 
 	DISK_REGION( "laserdisc" )
-	DISK_IMAGE_READONLY( "firefox", 0, SHA1(b500a834fa505e4c0649d8e5e6b7d40d4deef48d) MD5(73fb69fd20adf2800b28dc1ab58be2d4) )
+	DISK_IMAGE_READONLY( "firefox", 0, SHA1(3c4be40f55b44d0352b64c0861b6d1b650451ce7) )
 ROM_END
 
 ROM_START( firefoxa )
-	ROM_REGION( 0x30000, "main", 0 ) /* 64k for code + data & 128k for banked roms */
+	ROM_REGION( 0x30000, "maincpu", 0 ) /* 64k for code + data & 128k for banked roms */
 	ROM_LOAD( "136026.109",     0x04000, 0x4000, CRC(7639270c) SHA1(1b8f53c516d26aecb4478ac99783a37e5b1a107f)) /* 8b/c */
 	ROM_LOAD( "136026.110",     0x08000, 0x4000, CRC(f3102944) SHA1(460f18180b19b6360c99c7e70f86d745f69ba95d)) /* 7b/c */
 	ROM_LOAD( "136026.111",     0x0c000, 0x4000, CRC(8a230bb5) SHA1(0cfa1e981e4a8ccaf5903b4e761a2085b5a56181)) /* 6b/c */
@@ -772,7 +772,7 @@ ROM_START( firefoxa )
 	/* empty 2a */
 	/* empty 1a */
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* 64k for code */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 64k for code */
 	/* empty 4k/l */
 	ROM_LOAD( "136026.113",     0x08000, 0x4000, CRC(90988b3b) SHA1(7571cf6b7e9e3e22f930d9ba991b730e734edfb7)) /* 4m */
 	ROM_LOAD( "136026.114",     0x0c000, 0x4000, CRC(1437ce14) SHA1(eef14172b3935a4afb3470852f93d30926b139e4)) /* 4n */
@@ -795,7 +795,7 @@ ROM_START( firefoxa )
 	ROM_LOAD( "136026.119",     0x2c000,  0x4000, CRC(959471b1) SHA1(a032209a209f51d34360d5c7ad32ec62150158d2)) /* 1a */
 
 	DISK_REGION( "laserdisc" )
-	DISK_IMAGE_READONLY( "firefox", 0, SHA1(b500a834fa505e4c0649d8e5e6b7d40d4deef48d) MD5(73fb69fd20adf2800b28dc1ab58be2d4) )
+	DISK_IMAGE_READONLY( "firefox", 0, SHA1(3c4be40f55b44d0352b64c0861b6d1b650451ce7) )
 ROM_END
 
 
