@@ -9,6 +9,9 @@ Notes:
 - Quite interestingly, Free Kick's sound ROM contains a Z80 program, but
   there isn't a sound CPU and that program isn't executed. Instead, the main
   CPU reads the sound program through an 8255 PPI and plays sounds directly.
+- Gigas: according to a photo of a genuine board:
+    Sega Game ID#: 834-6167
+    NEC MC-8123 with Sega security number 317-5002
 
 TODO:
 - Gigas cocktail mode / flipscreen
@@ -88,7 +91,7 @@ static READ8_HANDLER( spinner_r )
 
 static MACHINE_RESET( pbillrd )
 {
-	memory_configure_bank(machine, 1, 0, 2, memory_region(machine, "main") + 0x10000, 0x4000);
+	memory_configure_bank(machine, 1, 0, 2, memory_region(machine, "maincpu") + 0x10000, 0x4000);
 }
 
 static WRITE8_HANDLER( pbillrd_bankswitch_w )
@@ -175,99 +178,75 @@ static WRITE8_HANDLER (freekick_ff_w)
  *
  *************************************/
 
-static ADDRESS_MAP_START( pbillrd_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( pbillrd_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xcfff) AM_RAM
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)
+	AM_RANGE(0xd800, 0xd8ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xd900, 0xdfff) AM_RAM
 	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN0")
-	AM_RANGE(0xe800, 0xe800) AM_READ_PORT("IN1")
-	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("DSW1")
-	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("DSW2")
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( pbillrd_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)
-	AM_RANGE(0xd800, 0xd8ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xd900, 0xdfff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xe000, 0xe001) AM_WRITE(flipscreen_w)
 	AM_RANGE(0xe002, 0xe003) AM_WRITE(coin_w)
 	AM_RANGE(0xe004, 0xe004) AM_WRITE(nmi_enable_w)
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(pbillrd_bankswitch_w)
-	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(sn76496_0_w)
-	AM_RANGE(0xfc01, 0xfc01) AM_WRITE(sn76496_1_w)
-	AM_RANGE(0xfc02, 0xfc02) AM_WRITE(sn76496_2_w)
-	AM_RANGE(0xfc03, 0xfc03) AM_WRITE(sn76496_3_w)
+	AM_RANGE(0xe800, 0xe800) AM_READ_PORT("IN1")
+	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("DSW1") AM_WRITE(pbillrd_bankswitch_w)
+	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("DSW2")
+	AM_RANGE(0xfc00, 0xfc00) AM_DEVWRITE("sn1", sn76496_w)
+	AM_RANGE(0xfc01, 0xfc01) AM_DEVWRITE("sn2", sn76496_w)
+	AM_RANGE(0xfc02, 0xfc02) AM_DEVWRITE("sn3", sn76496_w)
+	AM_RANGE(0xfc03, 0xfc03) AM_DEVWRITE("sn4", sn76496_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( freekckb_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xcfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe000, 0xe7ff) AM_READ(SMH_RAM)	// tilemap
-	AM_RANGE(0xe800, 0xe8ff) AM_READ(SMH_RAM)	// sprites
-	AM_RANGE(0xec00, 0xec03) AM_DEVREAD(PPI8255, "ppi8255_0", ppi8255_r)
-	AM_RANGE(0xf000, 0xf003) AM_DEVREAD(PPI8255, "ppi8255_1", ppi8255_r)
-	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("IN0")
+static ADDRESS_MAP_START( freekckb_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xcfff) AM_ROM
+	AM_RANGE(0xd000, 0xdfff) AM_RAM
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)	// tilemap
+	AM_RANGE(0xe800, 0xe8ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)		// sprites
+	AM_RANGE(0xec00, 0xec03) AM_DEVREADWRITE("ppi8255_0", ppi8255_r, ppi8255_w)
+	AM_RANGE(0xf000, 0xf003) AM_DEVREADWRITE("ppi8255_1", ppi8255_r, ppi8255_w)
+	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("IN0") AM_WRITE(flipscreen_w)
 	AM_RANGE(0xf801, 0xf801) AM_READ_PORT("IN1")
-	AM_RANGE(0xf802, 0xf802) AM_READ(SMH_NOP)	//MUST return bit 0 = 0, otherwise game resets
+	AM_RANGE(0xf802, 0xf802) AM_READNOP	//MUST return bit 0 = 0, otherwise game resets
 	AM_RANGE(0xf803, 0xf803) AM_READ(spinner_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( freekckb_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xcfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)
-	AM_RANGE(0xe800, 0xe8ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xec00, 0xec03) AM_DEVWRITE(PPI8255, "ppi8255_0", ppi8255_w)
-	AM_RANGE(0xf000, 0xf003) AM_DEVWRITE(PPI8255, "ppi8255_1", ppi8255_w)
-	AM_RANGE(0xf800, 0xf801) AM_WRITE(flipscreen_w)
 	AM_RANGE(0xf802, 0xf803) AM_WRITE(coin_w)
 	AM_RANGE(0xf804, 0xf804) AM_WRITE(nmi_enable_w)
 	AM_RANGE(0xf806, 0xf806) AM_WRITE(spinner_select_w)
-	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(sn76496_0_w)
-	AM_RANGE(0xfc01, 0xfc01) AM_WRITE(sn76496_1_w)
-	AM_RANGE(0xfc02, 0xfc02) AM_WRITE(sn76496_2_w)
-	AM_RANGE(0xfc03, 0xfc03) AM_WRITE(sn76496_3_w)
+	AM_RANGE(0xfc00, 0xfc00) AM_DEVWRITE("sn1", sn76496_w)
+	AM_RANGE(0xfc01, 0xfc01) AM_DEVWRITE("sn2", sn76496_w)
+	AM_RANGE(0xfc02, 0xfc02) AM_DEVWRITE("sn3", sn76496_w)
+	AM_RANGE(0xfc03, 0xfc03) AM_DEVWRITE("sn4", sn76496_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gigas_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN0")
-	AM_RANGE(0xe800, 0xe800) AM_READ_PORT("IN1")
-	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("DSW1")
-	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("DSW2")
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( gigas_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)
-	AM_RANGE(0xd800, 0xd8ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xd900, 0xdfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xe000, 0xe001) AM_WRITE(SMH_NOP)// probably not flipscreen
+static ADDRESS_MAP_START( gigas_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xcfff) AM_RAM
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(freek_videoram_w) AM_BASE(&freek_videoram)
+	AM_RANGE(0xd800, 0xd8ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xd900, 0xdfff) AM_RAM
+	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("IN0") AM_WRITENOP // probably not flipscreen
 	AM_RANGE(0xe002, 0xe003) AM_WRITE(coin_w)
 	AM_RANGE(0xe004, 0xe004) AM_WRITE(nmi_enable_w)
-	AM_RANGE(0xe005, 0xe005) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(SMH_NOP) //bankswitch ?
-	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(sn76496_0_w)
-	AM_RANGE(0xfc01, 0xfc01) AM_WRITE(sn76496_1_w)
-	AM_RANGE(0xfc02, 0xfc02) AM_WRITE(sn76496_2_w)
-	AM_RANGE(0xfc03, 0xfc03) AM_WRITE(sn76496_3_w)
+	AM_RANGE(0xe005, 0xe005) AM_WRITENOP
+	AM_RANGE(0xe800, 0xe800) AM_READ_PORT("IN1")
+	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("DSW1") AM_WRITENOP //bankswitch ?
+	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("DSW2")
+	AM_RANGE(0xfc00, 0xfc00) AM_DEVWRITE("sn1", sn76496_w)
+	AM_RANGE(0xfc01, 0xfc01) AM_DEVWRITE("sn2", sn76496_w)
+	AM_RANGE(0xfc02, 0xfc02) AM_DEVWRITE("sn3", sn76496_w)
+	AM_RANGE(0xfc03, 0xfc03) AM_DEVWRITE("sn4", sn76496_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gigas_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READWRITE(spinner_r, spinner_select_w)
-	AM_RANGE(0x01, 0x01) AM_READ(SMH_NOP) //unused dip 3
+	AM_RANGE(0x01, 0x01) AM_READNOP //unused dip 3
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( oigas_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READWRITE(spinner_r, spinner_select_w)
-	AM_RANGE(0x01, 0x01) AM_READ(SMH_NOP) //unused dip 3
+	AM_RANGE(0x01, 0x01) AM_READNOP //unused dip 3
 	AM_RANGE(0x02, 0x02) AM_READ(oigas_2_r)
 	AM_RANGE(0x03, 0x03) AM_READ(oigas_3_r)
 	AM_RANGE(0x05, 0x05) AM_WRITE(oigas_5_w)
@@ -287,6 +266,7 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( pbillrd )
 
+
 	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 )
@@ -569,20 +549,20 @@ static READ8_DEVICE_HANDLER( snd_rom_r )
 static const ppi8255_interface ppi8255_intf[2] =
 {
 	{
-		NULL,							/* Port A read */
-		NULL,							/* Port B read */
-		snd_rom_r,						/* Port C read */
-		snd_rom_addr_l_w,				/* Port A write */
-		snd_rom_addr_h_w,				/* Port B write */
-		NULL							/* Port C write */
+		DEVCB_NULL,							/* Port A read */
+		DEVCB_NULL,							/* Port B read */
+		DEVCB_HANDLER(snd_rom_r),			/* Port C read */
+		DEVCB_HANDLER(snd_rom_addr_l_w),	/* Port A write */
+		DEVCB_HANDLER(snd_rom_addr_h_w),	/* Port B write */
+		DEVCB_NULL							/* Port C write */
 	},
 	{
-		DEVICE8_PORT("DSW1"),			/* Port A read */
-		DEVICE8_PORT("DSW2"),			/* Port B read */
-		DEVICE8_PORT("DSW3"),			/* Port C read */
-		NULL,							/* Port A write */
-		NULL,							/* Port B write */
-		NULL							/* Port C write */
+		DEVCB_INPUT_PORT("DSW1"),			/* Port A read */
+		DEVCB_INPUT_PORT("DSW2"),			/* Port B read */
+		DEVCB_INPUT_PORT("DSW3"),			/* Port C read */
+		DEVCB_NULL,							/* Port A write */
+		DEVCB_NULL,							/* Port B write */
+		DEVCB_NULL							/* Port C write */
 	}
 };
 
@@ -632,15 +612,15 @@ GFXDECODE_END
  *************************************/
 
 static MACHINE_DRIVER_START( base )
-	MDRV_CPU_ADD("main",Z80, 18432000/6)	//confirmed
-	MDRV_CPU_PROGRAM_MAP(pbillrd_readmem,pbillrd_writemem)
+	MDRV_CPU_ADD("maincpu",Z80, 18432000/6)	//confirmed
+	MDRV_CPU_PROGRAM_MAP(pbillrd_map)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold, 50*3) //??
-	MDRV_CPU_VBLANK_INT("main", freekick_irqgen)
+	MDRV_CPU_VBLANK_INT("screen", freekick_irqgen)
 
 	MDRV_GFXDECODE(freekick)
 
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -678,9 +658,9 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( freekckb )
 	MDRV_IMPORT_FROM(base)
 
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(freekckb_readmem,freekckb_writemem)
-	MDRV_CPU_IO_MAP(freekckb_io_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(freekckb_map)
+	MDRV_CPU_IO_MAP(freekckb_io_map)
 
 	MDRV_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
 	MDRV_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
@@ -691,17 +671,17 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( gigas )
 	MDRV_IMPORT_FROM(base)
 
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(gigas_readmem,gigas_writemem)
-	MDRV_CPU_IO_MAP(gigas_io_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(gigas_map)
+	MDRV_CPU_IO_MAP(gigas_io_map)
 
 	MDRV_VIDEO_UPDATE(gigas)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( oigas )
 	MDRV_IMPORT_FROM(gigas)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(oigas_io_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_IO_MAP(oigas_io_map)
 MACHINE_DRIVER_END
 
 
@@ -713,7 +693,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( pbillrd )
-	ROM_REGION( 0x18000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x18000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "pb.18", 0x00000, 0x4000, CRC(9e6275ac) SHA1(482e845e7fb4190da483155bd908ad470373cd5c) )
 	ROM_LOAD( "pb.7",  0x04000, 0x4000, CRC(dd438431) SHA1(07a950e38b3f627ecf95e5831e5480abb337a010) )
 	ROM_CONTINUE(      0x10000, 0x4000 )
@@ -738,8 +718,8 @@ ROM_START( pbillrd )
 	ROM_LOAD( "82s129.3c", 0x0500, 0x0100, CRC(cc1657e5) SHA1(358f20dce376c2389009f9673ce38b297af863f6) )
 ROM_END
 
-ROM_START( pbillrds ) /* Encrytped with a Sega MC-8123 (317-0030) CPU modual */
-	ROM_REGION( 0x18000, "main", 0 ) /* Z80 Code */
+ROM_START( pbillrds ) /* Encrytped with a Sega MC-8123 (317-0030) CPU module */
+	ROM_REGION( 0x18000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "10626.8n",  0x00000, 0x4000, CRC(51d725e6) SHA1(d7007c983530780e7fa3686cb7a6d7c382c802fa) ) /* encrypted */
 	ROM_LOAD( "10625.8r",  0x04000, 0x4000, CRC(8977c724) SHA1(f00835a04dc6fa7d8c1e382dace515f2aa7d6f44) ) /* encrypted */
 	ROM_CONTINUE(          0x10000, 0x4000 )
@@ -776,7 +756,7 @@ from an original counter run board before they all die :-(
 */
 
 ROM_START( freekick )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	// Custom CPU (pack) No. NS6201-A 1987.9 FREE KICK (also found NS6201-A 1987.10 FREE KICK)
 	ROM_LOAD( "freekick.cpu", 0x00000, 0x10000, NO_DUMP ) // missing, might be the same as the bootleg but not confirmed
 
@@ -803,7 +783,7 @@ ROM_START( freekick )
 ROM_END
 
 ROM_START( freekckb )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "freekbl8.q7", 0x00000, 0x10000, CRC(4208cfe5) SHA1(21628cbe8a217fbae30a6c24c9cc4c790fe45d65) ) // this was on the bootleg, would normally be battery backed inside cpu?
 
 	ROM_REGION( 0x08000, "user1", 0 ) /* sound data */
@@ -829,7 +809,7 @@ ROM_START( freekckb )
 ROM_END
 
 ROM_START( freekcb2 )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "15.bin", 0x00000, 0x10000, CRC(6569f2b0) SHA1(9306e316e6ae659bae3759a12a4e445b555a8893) ) // this was on the bootleg, would normally be battery backed inside cpu?
 
 	ROM_REGION( 0x08000, "user1", 0 ) /* sound data */
@@ -865,7 +845,7 @@ ROM_END
 
 
 ROM_START( countrun )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	//  Custom CPU (pack) No. NS6201-A 1988.3 COUNTER RUN
 	ROM_LOAD( "countrun.cpu", 0x00000, 0x10000, NO_DUMP ) // missing
 
@@ -892,7 +872,7 @@ ROM_START( countrun )
 ROM_END
 
 ROM_START( countrb2 )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "crunbl.8", 0x00000, 0x10000, CRC(318f95d9) SHA1(f2386b9d26d1bc98728aad9e257363b381043dc9) ) // encrypted? bad? its strange anyway
 
 	ROM_REGION( 0x01000, "cpu1", 0 )
@@ -921,7 +901,7 @@ ROM_START( countrb2 )
 ROM_END
 
 ROM_START( countrnb )
-	ROM_REGION( 0x10000, "main", 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* Z80 Code */
 	ROM_LOAD( "rom_cpu.bin", 0x00000, 0x10000, CRC(f65639ae) SHA1(faa81607858d49559098c887ac847722df955a76) )
 
 	ROM_REGION( 0x08000, "user1", 0 ) /* sound data */
@@ -947,7 +927,7 @@ ROM_START( countrnb )
 ROM_END
 
 ROM_START( gigasm2b )
-	ROM_REGION( 2*0x10000, "main", 0 )
+	ROM_REGION( 2*0x10000, "maincpu", 0 )
 	ROM_LOAD( "8.rom", 0x10000, 0x4000, CRC(c00a4a6c) SHA1(0d1bb849c9bfe4e92ad70e4ef19da494c0bd7ba8) )
 	ROM_CONTINUE(      0x00000, 0x4000 )
 	ROM_LOAD( "7.rom", 0x14000, 0x4000, CRC(92bd9045) SHA1(e4d8a94deeb795bb284ca0bd211ed40ed498b172) )
@@ -975,6 +955,42 @@ ROM_START( gigasm2b )
 ROM_END
 
 
+
+ROM_START( gigas ) /* From an actual Sega board 834-6167 with mc-8123: 317-5002 */
+/* The MC-8123 is located on a small daughterboard which plugs into the z80 socket;
+ * the daughterboard also has an input for the spinner control the game uses,
+ * It is also possible that the 7 and 8 labels were switched on the files submitted;
+ * the load order as it is now is definitely correct, and opposite of the bootlegs.
+ * 7 is at location 8p, 8 at location 8n according to pcb pics.
+ * An empty socket marked 27256 is at location 10n */
+	ROM_REGION( 0x10000, "maincpu", 0 )
+	ROM_LOAD( "8.8n",   0x00000, 0x4000, NO_DUMP ) /* 27128, dumped as all 0x00s, bad eprom */
+	ROM_LOAD( "7.8p",   0x04000, 0x8000, CRC(43653909) SHA1(30f6666ba5c0f016299f462c4c07c81ee4832808) ) /* 27256 */
+
+	ROM_REGION( 0x2000, "user1", 0 ) /* MC8123 key */
+	ROM_LOAD( "317-5002.key", 0x0000, 0x2000, CRC(86a7e5f6) SHA1(3ff3a17c02eb5610182b6febfada4e8eca0c5eea) )
+
+	ROM_REGION( 0xc000, "gfx1", ROMREGION_DISPOSE ) /* GFX */
+	ROM_LOAD( "4.3k", 0x00000, 0x04000, CRC(8ed78981) SHA1(1f2c0584fcc6d04b042638c7b9a7e21fc560ca3d) )
+	ROM_LOAD( "5.3h", 0x04000, 0x04000, CRC(0645ec2d) SHA1(ecf8b1ce98f845b5b32e7fc959cea7679a149d74) )
+	ROM_LOAD( "6.3g", 0x08000, 0x04000, CRC(99e9cb27) SHA1(d141d6caa077e3cd182eb64cf803613ac17e7d09) )
+
+	ROM_REGION( 0xc000, "gfx2", ROMREGION_DISPOSE ) /* GFX */
+	ROM_LOAD( "1.3p", 0x00000, 0x04000, CRC(d78fae6e) SHA1(a7bf3b213f2a3a51b964959bd45003351670575a) )
+	ROM_LOAD( "3.3l", 0x04000, 0x04000, CRC(37df4a4c) SHA1(ab996db636d89845474529ba2573307046fb96ee) )
+	ROM_LOAD( "2.3n", 0x08000, 0x04000, CRC(3a46e354) SHA1(ebd6a5db4c9cdfc6fabe6b412a704aaf03c32d7c) )
+
+	ROM_REGION( 0x0600, "proms", 0 ) /* not dumped yet; assumed to be the same */
+	/* fill in which locations for each prom when redumping; the chips have
+     * no labels, but are clearly located at 3a 3b 3c 3d 4a and 4d */
+	ROM_LOAD( "1.pr", 0x0000, 0x0100, CRC(a784e71f) SHA1(1741ce98d719bad6cc5ea42337ef897f2435bbab) )
+	ROM_LOAD( "6.pr", 0x0100, 0x0100, CRC(376df30c) SHA1(cc95920cd1c133da1becc7d92f4b187b56a90ec7) )
+	ROM_LOAD( "5.pr", 0x0200, 0x0100, CRC(4edff5bd) SHA1(305efc7ad7f86635489a655e214e216ac02b904d) )
+	ROM_LOAD( "4.pr", 0x0300, 0x0100, CRC(fe201a4e) SHA1(15f8ecfcf6c63ffbf9777bec9b203c319ba1b96c) )
+	ROM_LOAD( "2.pr", 0x0400, 0x0100, CRC(5796cc4a) SHA1(39576c4e48fd7ac52fc652a1ae0573db3d878878) )
+	ROM_LOAD( "3.pr", 0x0500, 0x0100, CRC(28b5ee4c) SHA1(e21b9c38f433dca1e8894619b1d9f0389a81b48a) )
+ROM_END
+
 /*
 Gigas (bootleg)
 
@@ -989,7 +1005,7 @@ Note: MCU dump has fixed bits, but read is good. If not correct, it's protected.
 */
 
 ROM_START( gigasb )
-	ROM_REGION( 2*0x10000, "main", 0 )
+	ROM_REGION( 2*0x10000, "maincpu", 0 )
 	ROM_LOAD( "g-7",   0x10000, 0x4000, CRC(daf4e88d) SHA1(391dff914ce8e9b7975fc8827c066d7db16c4171) )
 	ROM_CONTINUE(      0x00000, 0x4000 )
 	ROM_LOAD( "g-8",   0x14000, 0x8000, CRC(4ab4c1f1) SHA1(63d8f489c7a8271e99a66d97e6eb0eb252cb2b67) )
@@ -1015,7 +1031,7 @@ ROM_START( gigasb )
 ROM_END
 
 ROM_START( oigas )
-	ROM_REGION( 2*0x10000, "main", 0 )
+	ROM_REGION( 2*0x10000, "maincpu", 0 )
 	ROM_LOAD( "rom.7",   0x10000, 0x4000, CRC(e5bc04cc) SHA1(ffbd416313a9e49d2f9a7268d5ef48a8b641e480) )
 	ROM_CONTINUE(        0x00000, 0x4000)
 	ROM_LOAD( "rom.8",   0x04000, 0x8000, CRC(c199060d) SHA1(de8f1e0f941533abbbed25b595b1d51fadbb428d) )
@@ -1050,18 +1066,24 @@ ROM_END
  *
  *************************************/
 
-static DRIVER_INIT(gigas)
+static DRIVER_INIT(gigasb)
 {
-	const address_space *space = cputag_get_address_space(machine, "main", ADDRESS_SPACE_PROGRAM);
-	memory_set_decrypted_region(space, 0x0000, 0x7fff, memory_region(machine, "main") + 0x10000);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	memory_set_decrypted_region(space, 0x0000, 0xbfff, memory_region(machine, "maincpu") + 0x10000);
 }
 
 
 static DRIVER_INIT( pbillrds )
 {
-	mc8123_decrypt_rom(machine, "main", "user1", 1, 2);
+	mc8123_decrypt_rom(machine, "maincpu", "user1", 1, 2);
 }
 
+static DRIVER_INIT( gigas )
+{
+	mc8123_decrypt_rom(machine, "maincpu", "user1", 0, 1);
+}
+
+
 
 
 /*************************************
@@ -1069,10 +1091,11 @@ static DRIVER_INIT( pbillrds )
  *  Game driver(s)
  *
  *************************************/
-
-GAME( 1986, gigasb,   0,        gigas,    gigas,    gigas,    ROT270, "bootleg", "Gigas (bootleg)", GAME_NO_COCKTAIL )
-GAME( 1986, oigas,    gigasb,   oigas,    gigas,    gigas,    ROT270, "bootleg", "Oigas (bootleg)", GAME_NO_COCKTAIL )
-GAME( 1986, gigasm2b, 0,        gigas,    gigasm2,  gigas,    ROT270, "bootleg", "Gigas Mark II (bootleg)", GAME_NO_COCKTAIL )
+/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      ROT     COMPANY   FULLNAME        FLAGS  */
+GAME( 1986, gigas,    0,        gigas,    gigas,    gigas,    ROT270, "Sega", "Gigas (MC-8123, 317-5002)", GAME_NOT_WORKING )
+GAME( 1986, gigasb,   gigas,    gigas,    gigas,    gigasb,   ROT270, "bootleg", "Gigas (bootleg)", GAME_NO_COCKTAIL )
+GAME( 1986, oigas,    gigas ,   oigas,    gigas,    gigasb,   ROT270, "bootleg", "Oigas (bootleg)", GAME_NO_COCKTAIL )
+GAME( 1986, gigasm2b, 0,        gigas,    gigasm2,  gigasb,   ROT270, "bootleg", "Gigas Mark II (bootleg)", GAME_NO_COCKTAIL )
 GAME( 1987, pbillrd,  0,        pbillrd,  pbillrd,  0,        ROT0,   "Nihon System", "Perfect Billiard", 0 )
 GAME( 1987, pbillrds, pbillrd,  pbillrd,  pbillrd,  pbillrds, ROT0,   "Nihon System", "Perfect Billiard (MC-8123, 317-0030)", 0 )
 GAME( 1987, freekick, 0,        freekckb, freekck,  0,        ROT270, "Nihon System (Sega license)", "Free Kick", GAME_NOT_WORKING )
