@@ -111,32 +111,21 @@ VIDEO_START( bigkarnk );
 VIDEO_UPDATE( bigkarnk );
 
 
-static ADDRESS_MAP_START( bigkarnk_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)			/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_READ(SMH_RAM)			/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_READ(SMH_RAM)			/* Screen RAM */
-	AM_RANGE(0x200000, 0x2007ff) AM_READ(SMH_RAM)			/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SMH_RAM)			/* Sprite RAM */
-	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW1")
-	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW2")
-	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
-	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
-	AM_RANGE(0x700008, 0x700009) AM_READ_PORT("SERVICE")
-	AM_RANGE(0xff8000, 0xffffff) AM_READ(SMH_RAM)			/* Work RAM */
-ADDRESS_MAP_END
-
 static WRITE16_HANDLER( bigkarnk_sound_command_w )
 {
-	if (ACCESSING_BITS_0_7){
-		soundlatch_w(space,0,data & 0xff);
-		cpu_set_input_line(space->machine->cpu[1],M6809_FIRQ_LINE,HOLD_LINE);
+	if (ACCESSING_BITS_0_7)
+	{
+		soundlatch_w(space, 0, data & 0xff);
+		cputag_set_input_line(space->machine, "audiocpu", M6809_FIRQ_LINE, HOLD_LINE);
 	}
 }
 
 static WRITE16_HANDLER( bigkarnk_coin_w )
 {
-	if (ACCESSING_BITS_0_7){
-		switch ((offset >> 3)){
+	if (ACCESSING_BITS_0_7)
+	{
+		switch ((offset >> 3))
+		{
 			case 0x00:	/* Coin Lockouts */
 			case 0x01:
 				coin_lockout_w( (offset >> 3) & 0x01, ~data & 0x01);
@@ -149,35 +138,32 @@ static WRITE16_HANDLER( bigkarnk_coin_w )
 	}
 }
 
-static ADDRESS_MAP_START( bigkarnk_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)								/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_WRITE(SMH_RAM)								/* Screen RAM */
-	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                     /* INT 6 ACK/Watchdog timer */
-	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(bigkarnk_sound_command_w)				/* Triggers a FIRQ on the sound CPU */
-	AM_RANGE(0x70000a, 0x70003b) AM_WRITE(bigkarnk_coin_w)						/* Coin Counters + Coin Lockout */
-	AM_RANGE(0xff8000, 0xffffff) AM_WRITE(SMH_RAM)								/* Work RAM */
+
+static ADDRESS_MAP_START( bigkarnk_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_ROM																		/* ROM */
+	AM_RANGE(0x100000, 0x101fff) AM_RAM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)						/* Video RAM */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM																		/* Screen RAM */
+	AM_RANGE(0x108000, 0x108007) AM_WRITEONLY AM_BASE(&gaelco_vregs)										/* Video Registers */
+//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                                                 /* INT 6 ACK/Watchdog timer */
+	AM_RANGE(0x200000, 0x2007ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)	/* Palette */
+	AM_RANGE(0x440000, 0x440fff) AM_RAM AM_BASE(&gaelco_spriteram)											/* Sprite RAM */
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW1")
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW2")
+	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
+	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
+	AM_RANGE(0x700008, 0x700009) AM_READ_PORT("SERVICE")
+	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(bigkarnk_sound_command_w)											/* Triggers a FIRQ on the sound CPU */
+	AM_RANGE(0x70000a, 0x70003b) AM_WRITE(bigkarnk_coin_w)													/* Coin Counters + Coin Lockout */
+	AM_RANGE(0xff8000, 0xffffff) AM_RAM																		/* Work RAM */
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( bigkarnk_readmem_snd, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(SMH_RAM)				/* RAM */
-	AM_RANGE(0x0800, 0x0801) AM_READ(okim6295_status_0_r)	/* OKI6295 */
-	AM_RANGE(0x0a00, 0x0a00) AM_READ(ym3812_status_port_0_r)	/* YM3812 */
-	AM_RANGE(0x0b00, 0x0b00) AM_READ(soundlatch_r)			/* Sound latch */
-	AM_RANGE(0x0c00, 0xffff) AM_READ(SMH_ROM)				/* ROM */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( bigkarnk_writemem_snd, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(SMH_RAM)				/* RAM */
-	AM_RANGE(0x0800, 0x0800) AM_WRITE(okim6295_data_0_w)		/* OKI6295 */
-//  AM_RANGE(0x0900, 0x0900) AM_WRITE(SMH_NOP)             /* enable sound output? */
-	AM_RANGE(0x0a00, 0x0a00) AM_WRITE(ym3812_control_port_0_w)/* YM3812 */
-	AM_RANGE(0x0a01, 0x0a01) AM_WRITE(ym3812_write_port_0_w)	/* YM3812 */
-	AM_RANGE(0x0c00, 0xffff) AM_WRITE(SMH_ROM)				/* ROM */
+static ADDRESS_MAP_START( bigkarnk_snd_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_RAM											/* RAM */
+	AM_RANGE(0x0800, 0x0801) AM_DEVREADWRITE("oki", okim6295_r, okim6295_w)	/* OKI6295 */
+//  AM_RANGE(0x0900, 0x0900) AM_WRITENOP                                    /* enable sound output? */
+	AM_RANGE(0x0a00, 0x0a01) AM_DEVREADWRITE("ym", ym3812_r, ym3812_w)		/* YM3812 */
+	AM_RANGE(0x0b00, 0x0b00) AM_READ(soundlatch_r)							/* Sound latch */
+	AM_RANGE(0x0c00, 0xffff) AM_ROM											/* ROM */
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( bigkarnk )
@@ -224,17 +210,17 @@ GFXDECODEINFO(0x100000,64)
 static MACHINE_DRIVER_START( bigkarnk )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 10000000)	/* MC68000P10, 10 MHz */
-	MDRV_CPU_PROGRAM_MAP(bigkarnk_readmem,bigkarnk_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq6_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 10000000)	/* MC68000P10, 10 MHz */
+	MDRV_CPU_PROGRAM_MAP(bigkarnk_map)
+	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
 
-	MDRV_CPU_ADD("audio", M6809, 8867000/4)	/* 68B09, 2.21675 MHz? */
-	MDRV_CPU_PROGRAM_MAP(bigkarnk_readmem_snd,bigkarnk_writemem_snd)
+	MDRV_CPU_ADD("audiocpu", M6809, 8867000/4)	/* 68B09, 2.21675 MHz? */
+	MDRV_CPU_PROGRAM_MAP(bigkarnk_snd_map)
 
 	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -260,11 +246,11 @@ MACHINE_DRIVER_END
 
 
 ROM_START( bigkarnk )
-	ROM_REGION( 0x080000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x080000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE(	"d16",	0x000000, 0x040000, CRC(44fb9c73) SHA1(c33852b37afea15482f4a43cb045434660e7a056) )
 	ROM_LOAD16_BYTE(	"d19",	0x000001, 0x040000, CRC(ff79dfdd) SHA1(2bfa440299317967ba2018d3a148291ae0c144ae) )
 
-	ROM_REGION( 0x01e000, "audio", 0 )	/* 6809 code */
+	ROM_REGION( 0x01e000, "audiocpu", 0 )	/* 6809 code */
 	ROM_LOAD(	"d5",	0x000000, 0x010000, CRC(3b73b9c5) SHA1(1b1c5545609a695dab87d611bd53e0c3dd91e6b7) )
 
 	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
@@ -290,40 +276,31 @@ VIDEO_START( maniacsq );
 VIDEO_UPDATE( maniacsq );
 
 
-static ADDRESS_MAP_START( maniacsq_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)			/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_READ(SMH_RAM)			/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_READ(SMH_RAM)			/* Screen RAM */
-	AM_RANGE(0x200000, 0x2007ff) AM_READ(SMH_RAM)			/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SMH_RAM)			/* Sprite RAM */
-	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
-	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
-	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
-	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
-	AM_RANGE(0x70000e, 0x70000f) AM_READ(okim6295_status_0_lsb_r)/* OKI6295 status register */
-	AM_RANGE(0xff0000, 0xffffff) AM_READ(SMH_RAM)			/* Work RAM */
-ADDRESS_MAP_END
-
 static WRITE16_HANDLER( OKIM6295_bankswitch_w )
 {
 	UINT8 *RAM = memory_region(space->machine, "oki");
 
-	if (ACCESSING_BITS_0_7){
+	if (ACCESSING_BITS_0_7)
+	{
 		memcpy(&RAM[0x30000], &RAM[0x40000 + (data & 0x0f)*0x10000], 0x10000);
 	}
 }
 
-static ADDRESS_MAP_START( maniacsq_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)								/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_WRITE(SMH_RAM)								/* Screen RAM */
-	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                     /* INT 6 ACK/Watchdog timer */
-	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)					/* OKI6295 bankswitch */
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(okim6295_data_0_lsb_w)					/* OKI6295 data register */
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM)								/* Work RAM */
+static ADDRESS_MAP_START( maniacsq_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM																		/* ROM */
+	AM_RANGE(0x100000, 0x101fff) AM_RAM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)						/* Video RAM */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM																		/* Screen RAM */
+	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)									/* Video Registers */
+//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                                                 /* INT 6 ACK/Watchdog timer */
+	AM_RANGE(0x200000, 0x2007ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)	/* Palette */
+	AM_RANGE(0x440000, 0x440fff) AM_RAM AM_BASE(&gaelco_spriteram)											/* Sprite RAM */
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
+	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
+	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)											/* OKI6295 bankswitch */
+	AM_RANGE(0x70000e, 0x70000f) AM_DEVREADWRITE8("oki", okim6295_r, okim6295_w, 0x00ff)					/* OKI6295 status register */
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM																		/* Work RAM */
 ADDRESS_MAP_END
 
 
@@ -385,12 +362,12 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( maniacsq )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000,24000000/2)			/* 12 MHz */
-	MDRV_CPU_PROGRAM_MAP(maniacsq_readmem,maniacsq_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq6_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000,24000000/2)			/* 12 MHz */
+	MDRV_CPU_PROGRAM_MAP(maniacsq_map)
+	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -413,7 +390,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( maniacsp )
-	ROM_REGION( 0x100000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE(	"d18",	0x000000, 0x020000, CRC(740ecab2) SHA1(8d8583364cc6aeea58ea2b9cb9a2aab2a43a44df) )
 	ROM_LOAD16_BYTE(	"d16",	0x000001, 0x020000, CRC(c6c42729) SHA1(1aac9f93d47a4eb57e06e206e9f50e349b1817da) )
 
@@ -440,7 +417,7 @@ ROM_END
 
 
 ROM_START( biomtoy )
-	ROM_REGION( 0x100000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE(	"d18",	0x000000, 0x080000, CRC(4569ce64) SHA1(96557aca55779c23f7c2c11fddc618823c04ead0) )
 	ROM_LOAD16_BYTE(	"d16",	0x000001, 0x080000, CRC(739449bd) SHA1(711a8ea5081f15dea6067577516c9296239c4145) )
 
@@ -590,44 +567,34 @@ static WRITE16_HANDLER(thoop_encrypted_w)
 }
 
 
-static ADDRESS_MAP_START( squash_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)			/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_READ(SMH_RAM)			/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_READ(SMH_RAM)			/* Screen RAM */
-	AM_RANGE(0x200000, 0x2007ff) AM_READ(SMH_RAM)			/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SMH_RAM)			/* Sprite RAM */
+static ADDRESS_MAP_START( squash_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM																		/* ROM */
+	AM_RANGE(0x100000, 0x101fff) AM_RAM_WRITE(gaelco_vram_encrypted_w) AM_BASE(&gaelco_videoram)			/* Video RAM */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(gaelco_encrypted_w) AM_BASE(&gaelco_screen)                                                                /* Screen RAM */
+	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)									/* Video Registers */
+//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                                                 /* INT 6 ACK/Watchdog timer */
+	AM_RANGE(0x200000, 0x2007ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)	/* Palette */
+	AM_RANGE(0x440000, 0x440fff) AM_RAM AM_BASE(&gaelco_spriteram)											/* Sprite RAM */
 	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
 	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
 	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
 	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
-	AM_RANGE(0x70000e, 0x70000f) AM_READ(okim6295_status_0_lsb_r)/* OKI6295 status register */
-	AM_RANGE(0xff0000, 0xffffff) AM_READ(SMH_RAM)			/* Work RAM */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( squash_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)								/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_WRITE(gaelco_vram_encrypted_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_WRITE(gaelco_encrypted_w) AM_BASE(&gaelco_screen)                                                                /* Screen RAM */
-	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                     /* INT 6 ACK/Watchdog timer */
-	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)					/* OKI6295 bankswitch */
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(okim6295_data_0_lsb_w)					/* OKI6295 data register */
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM)								/* Work RAM */
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)											/* OKI6295 bankswitch */
+	AM_RANGE(0x70000e, 0x70000f) AM_DEVREADWRITE8("oki", okim6295_r, okim6295_w, 0x00ff)					/* OKI6295 status register */
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM																		/* Work RAM */
 ADDRESS_MAP_END
 
 static MACHINE_DRIVER_START( squash )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 12000000)	/* MC68000P12, 12 MHz */
-	MDRV_CPU_PROGRAM_MAP(squash_readmem,squash_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq6_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 12000000)	/* MC68000P12, 12 MHz */
+	MDRV_CPU_PROGRAM_MAP(squash_map)
+	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
 
 	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -699,7 +666,7 @@ Notes:
 
 /* encrypted video ram */
 ROM_START( squash )
-	ROM_REGION( 0x100000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "squash.d18", 0x000000, 0x20000, CRC(ce7aae96) SHA1(4fe8666ae571bffc5a08fa68346c0623282989eb) )
 	ROM_LOAD16_BYTE( "squash.d16", 0x000001, 0x20000, CRC(8ffaedd7) SHA1(f4aada17ba67dd8b6c5a395e832bcbba2764c59d) )
 
@@ -755,30 +722,34 @@ INPUT_PORTS_END
 
 
 
-static ADDRESS_MAP_START( thoop_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)								/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_WRITE(thoop_vram_encrypted_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
-	AM_RANGE(0x102000, 0x103fff) AM_WRITE(thoop_encrypted_w) AM_BASE(&gaelco_screen)                                                                /* Screen RAM */
-	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                     /* INT 6 ACK/Watchdog timer */
-	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)					/* OKI6295 bankswitch */
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(okim6295_data_0_lsb_w)					/* OKI6295 data register */
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM)								/* Work RAM */
+static ADDRESS_MAP_START( thoop_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM																			/* ROM */
+	AM_RANGE(0x100000, 0x101fff) AM_RAM_WRITE(thoop_vram_encrypted_w) AM_BASE(&gaelco_videoram)					/* Video RAM */
+	AM_RANGE(0x102000, 0x103fff) AM_RAM_WRITE(thoop_encrypted_w) AM_BASE(&gaelco_screen)						/* Screen RAM */
+	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&gaelco_vregs)										/* Video Registers */
+//  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                                                     /* INT 6 ACK/Watchdog timer */
+	AM_RANGE(0x200000, 0x2007ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)		/* Palette */
+	AM_RANGE(0x440000, 0x440fff) AM_RAM AM_BASE(&gaelco_spriteram)												/* Sprite RAM */
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
+	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
+	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)												/* OKI6295 bankswitch */
+	AM_RANGE(0x70000e, 0x70000f) AM_DEVREADWRITE8("oki", okim6295_r, okim6295_w, 0x00ff)						/* OKI6295 status register */
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM																			/* Work RAM */
 ADDRESS_MAP_END
 
 static MACHINE_DRIVER_START( thoop )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 12000000)	/* MC68000P12, 12 MHz */
-	MDRV_CPU_PROGRAM_MAP(squash_readmem,thoop_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq6_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 12000000)	/* MC68000P12, 12 MHz */
+	MDRV_CPU_PROGRAM_MAP(thoop_map)
+	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
 
 	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -801,7 +772,7 @@ MACHINE_DRIVER_END
 
 /* encrypted video ram */
 ROM_START( thoop )
-	ROM_REGION( 0x100000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "th18dea1.040", 0x000000, 0x80000, CRC(59bad625) SHA1(28e058b2290bc5f7130b801014d026432f9e7fd5) )
 	ROM_LOAD16_BYTE( "th161eb4.020", 0x000001, 0x40000, CRC(6add61ed) SHA1(0e789d9a0ac19b6143044fbc04ab2227735b2a8f) )
 
