@@ -168,6 +168,7 @@ static UINT16 *adsp_control_regs;
 static UINT16 *adsp_fastram_base;
 static UINT8 adsp_ireg;
 static offs_t adsp_ireg_base, adsp_incs, adsp_size;
+static const device_config *dmadac[SOUND_CHANNELS];
 
 static void adsp_tx_callback(const device_config *device, int port, INT32 data);
 static TIMER_CALLBACK( adsp_autobuffer_irq );
@@ -201,7 +202,14 @@ static MACHINE_RESET( common )
 	memory_set_bank(machine, 1, 0);
 
 	/* keep the TMS32031 halted until the code is ready to go */
-	cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+	cputag_set_input_line(machine, "tms", INPUT_LINE_RESET, ASSERT_LINE);
+
+	for (i = 0; i < SOUND_CHANNELS; i++)
+	{
+		char buffer[10];
+		sprintf(buffer, "dac%d", i + 1);
+		dmadac[i] = devtag_get_device(machine, buffer);
+	}
 
 	/* Save state support */
 	state_save_register_global(machine, sound_data);
@@ -247,7 +255,7 @@ static INTERRUPT_GEN( vblank_gen )
 
 static WRITE16_HANDLER( irq_ack_w )
 {
-	cpu_set_input_line(space->machine->cpu[0], 2, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "maincpu", 2, CLEAR_LINE);
 }
 
 
@@ -300,7 +308,7 @@ static TIMER_CALLBACK( delayed_sound_w )
 {
 	logerror("delayed_sound_w(%02X)\n", param);
 	sound_data = param;
-	cpu_set_input_line(machine->cpu[2], ADSP2115_IRQ2, ASSERT_LINE);
+	cputag_set_input_line(machine, "adsp", ADSP2115_IRQ2, ASSERT_LINE);
 }
 
 
@@ -315,7 +323,7 @@ static WRITE16_HANDLER( sound_data_w )
 static READ16_HANDLER( sound_data_r )
 {
 	logerror("sound_data_r(%02X)\n", sound_data);
-	cpu_set_input_line(space->machine->cpu[2], ADSP2115_IRQ2, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "adsp", ADSP2115_IRQ2, CLEAR_LINE);
 	return sound_data;
 }
 
@@ -425,7 +433,7 @@ static WRITE16_HANDLER( tms_reset_w )
 	/* this is set to 0 while data is uploaded, then set to $ffff after it is done */
 	/* it does not ever appear to be touched after that */
 	logerror("%06X:tms_reset_w(%02X) = %08X & %08X\n", cpu_get_pc(space->cpu), offset, data, mem_mask);
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (data == 0xffff) ? CLEAR_LINE : ASSERT_LINE);
+		cputag_set_input_line(space->machine, "tms", INPUT_LINE_RESET, (data == 0xffff) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -435,7 +443,7 @@ static WRITE16_HANDLER( tms_irq_w )
 	/* done after uploading, and after modifying the comm area */
 	logerror("%06X:tms_irq_w(%02X) = %08X & %08X\n", cpu_get_pc(space->cpu), offset, data, mem_mask);
 	if (ACCESSING_BITS_0_7)
-		cpu_set_input_line(space->machine->cpu[1], 0, (data & 0x01) ? CLEAR_LINE : ASSERT_LINE);
+		cputag_set_input_line(space->machine, "tms", 0, (data & 0x01) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -501,7 +509,7 @@ static WRITE16_HANDLER( adsp_control_w )
 			/* see if SPORT1 got disabled */
 			if ((data & 0x0800) == 0)
 			{
-				dmadac_enable(0, SOUND_CHANNELS, 0);
+				dmadac_enable(&dmadac[0], SOUND_CHANNELS, 0);
 				timer_adjust_oneshot(adsp_autobuffer_timer, attotime_never, 0);
 			}
 			break;
@@ -510,7 +518,7 @@ static WRITE16_HANDLER( adsp_control_w )
 			/* autobuffer off: nuke the timer, and disable the DAC */
 			if ((data & 0x0002) == 0)
 			{
-				dmadac_enable(0, SOUND_CHANNELS, 0);
+				dmadac_enable(&dmadac[0], SOUND_CHANNELS, 0);
 				timer_adjust_oneshot(adsp_autobuffer_timer, attotime_never, 0);
 			}
 			break;
@@ -542,12 +550,12 @@ static WRITE16_HANDLER( adsp_rombank_w )
 static TIMER_CALLBACK( adsp_autobuffer_irq )
 {
 	/* get the index register */
-	int reg = cpu_get_reg(machine->cpu[2], ADSP2100_I0 + adsp_ireg);
+	int reg = cpu_get_reg(cputag_get_cpu(machine, "adsp"), ADSP2100_I0 + adsp_ireg);
 
 	/* copy the current data into the buffer */
 // logerror("ADSP buffer: I%d=%04X incs=%04X size=%04X\n", adsp_ireg, reg, adsp_incs, adsp_size);
 	if (adsp_incs)
-		dmadac_transfer(0, SOUND_CHANNELS, adsp_incs, SOUND_CHANNELS * adsp_incs, adsp_size / (SOUND_CHANNELS * adsp_incs), (INT16 *)&adsp_fastram_base[reg - 0x3800]);
+		dmadac_transfer(&dmadac[0], SOUND_CHANNELS, adsp_incs, SOUND_CHANNELS * adsp_incs, adsp_size / (SOUND_CHANNELS * adsp_incs), (INT16 *)&adsp_fastram_base[reg - 0x3800]);
 
 	/* increment it */
 	reg += adsp_size;
@@ -559,11 +567,11 @@ static TIMER_CALLBACK( adsp_autobuffer_irq )
 		reg = adsp_ireg_base;
 
 		/* generate the (internal, thats why the pulse) irq */
-		generic_pulse_irq_line(machine->cpu[2], ADSP2105_IRQ1);
+		generic_pulse_irq_line(cputag_get_cpu(machine, "adsp"), ADSP2105_IRQ1);
 	}
 
 	/* store it */
-	cpu_set_reg(machine->cpu[2], ADSP2100_I0 + adsp_ireg, reg);
+	cpu_set_reg(cputag_get_cpu(machine, "adsp"), ADSP2100_I0 + adsp_ireg, reg);
 }
 
 
@@ -612,8 +620,8 @@ static void adsp_tx_callback(const device_config *device, int port, INT32 data)
 			/* now put it down to samples, so we know what the channel frequency has to be */
 			sample_period = attotime_mul(sample_period, 16 * SOUND_CHANNELS);
 
- 			dmadac_set_frequency(0, SOUND_CHANNELS, ATTOSECONDS_TO_HZ(sample_period.attoseconds));
-			dmadac_enable(0, SOUND_CHANNELS, 1);
+ 			dmadac_set_frequency(&dmadac[0], SOUND_CHANNELS, ATTOSECONDS_TO_HZ(sample_period.attoseconds));
+			dmadac_enable(&dmadac[0], SOUND_CHANNELS, 1);
 
 			/* fire off a timer wich will hit every half-buffer */
 			sample_period = attotime_div(attotime_mul(sample_period, adsp_size), SOUND_CHANNELS * adsp_incs);
@@ -627,7 +635,7 @@ static void adsp_tx_callback(const device_config *device, int port, INT32 data)
 	}
 
 	/* if we get there, something went wrong. Disable playing */
-	dmadac_enable(0, SOUND_CHANNELS, 0);
+	dmadac_enable(&dmadac[0], SOUND_CHANNELS, 0);
 
 	/* remove timer */
 	timer_adjust_oneshot(adsp_autobuffer_timer, attotime_never, 0);
@@ -924,18 +932,18 @@ static const tms32031_config tms_config =
 static MACHINE_DRIVER_START( gaelco3d )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 15000000)
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT("main", vblank_gen)
+	MDRV_CPU_ADD("maincpu", M68000, 15000000)
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_VBLANK_INT("screen", vblank_gen)
 
 	MDRV_CPU_ADD("tms", TMS32031, 60000000)
 	MDRV_CPU_CONFIG(tms_config)
-	MDRV_CPU_PROGRAM_MAP(tms_map,0)
+	MDRV_CPU_PROGRAM_MAP(tms_map)
 
 	MDRV_CPU_ADD("adsp", ADSP2115, 16000000)
 	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(adsp_program_map,0)
-	MDRV_CPU_DATA_MAP(adsp_data_map, 0)
+	MDRV_CPU_PROGRAM_MAP(adsp_program_map)
+	MDRV_CPU_DATA_MAP(adsp_data_map)
 
 	MDRV_MACHINE_RESET(gaelco3d)
 	MDRV_NVRAM_HANDLER(93C66B)
@@ -943,7 +951,7 @@ static MACHINE_DRIVER_START( gaelco3d )
 	MDRV_QUANTUM_TIME(HZ(6000))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -977,8 +985,8 @@ static MACHINE_DRIVER_START( gaelco3d2 )
 	MDRV_IMPORT_FROM(gaelco3d)
 
 	/* basic machine hardware */
-	MDRV_CPU_REPLACE("main", M68EC020, 25000000)
-	MDRV_CPU_PROGRAM_MAP(main020_map,0)
+	MDRV_CPU_REPLACE("maincpu", M68EC020, 25000000)
+	MDRV_CPU_PROGRAM_MAP(main020_map)
 
 	MDRV_CPU_REPLACE("tms", TMS32031, 50000000)
 
@@ -994,7 +1002,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( speedup )
-	ROM_REGION( 0x200000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x200000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "sup10.bin", 0x000000, 0x80000, CRC(07e70bae) SHA1(17013d859ec075e12518b094040a056d850b3271) )
 	ROM_LOAD16_BYTE( "sup15.bin", 0x000001, 0x80000, CRC(7947c28d) SHA1(46efb56d0f7fe2e92d0d04dcd2f130aef3be436d) )
 
@@ -1021,7 +1029,7 @@ ROM_END
 
 
 ROM_START( surfplnt )
-	ROM_REGION( 0x200000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x200000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "surfplnt.u5",  0x000000, 0x80000, CRC(c96e0a18) SHA1(b313d02d1d1bff8717b3d798e6ae681baefc1061) )
 	ROM_LOAD16_BYTE( "surfplnt.u11", 0x000001, 0x80000, CRC(99211d2d) SHA1(dee5b157489ce9c6988c8eec92fa91fff60d521c) )
 	ROM_LOAD16_BYTE( "surfplnt.u8",  0x100000, 0x80000, CRC(aef9e1d0) SHA1(15258e62fbf61e21e7d77aa7a81fdbf842fd4560) )
@@ -1054,7 +1062,7 @@ ROM_END
 
 
 ROM_START( surfpl40 )
-	ROM_REGION( 0x200000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x200000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "surfpl40.u5",  0x000000, 0x80000, CRC(572e0343) SHA1(badb08a5a495611b5fd2d821d4299348b2c9f308) )
 	ROM_LOAD16_BYTE( "surfpl40.u11", 0x000001, 0x80000, CRC(6056edaa) SHA1(9bc2df54d1367b9d58272a8f506e523e74110361) )
 	ROM_LOAD16_BYTE( "surfplnt.u8",  0x100000, 0x80000, CRC(aef9e1d0) SHA1(15258e62fbf61e21e7d77aa7a81fdbf842fd4560) )
@@ -1087,7 +1095,7 @@ ROM_END
 
 
 ROM_START( radikalb )
-	ROM_REGION( 0x200000, "main", 0 )	/* 68020 code */
+	ROM_REGION( 0x200000, "maincpu", 0 )	/* 68020 code */
 	ROM_LOAD32_BYTE( "rab.6",  0x000000, 0x80000, CRC(ccac98c5) SHA1(43a30caf9880f48aba79676f9e746fdc6258139d) )
 	ROM_LOAD32_BYTE( "rab.12", 0x000001, 0x80000, CRC(26199506) SHA1(1b7b44895aa296eab8061ae85cbb5b0d30119dc7) )
 	ROM_LOAD32_BYTE( "rab.14", 0x000002, 0x80000, CRC(4a0ac8cb) SHA1(4883e5eddb833dcd39376be435aa8e8e2ec47ab5) )
@@ -1139,8 +1147,8 @@ static DRIVER_INIT( gaelco3d )
 	/* allocate memory */
 	gaelco3d_texture_size = memory_region_length(machine, "gfx1");
 	gaelco3d_texmask_size = memory_region_length(machine, "gfx2") * 8;
-	gaelco3d_texture = auto_malloc(gaelco3d_texture_size);
-	gaelco3d_texmask = auto_malloc(gaelco3d_texmask_size);
+	gaelco3d_texture = auto_alloc_array(machine, UINT8, gaelco3d_texture_size);
+	gaelco3d_texmask = auto_alloc_array(machine, UINT8, gaelco3d_texmask_size);
 
 	/* first expand the pixel data */
 	src = memory_region(machine, "gfx1");
