@@ -105,9 +105,9 @@ static VIDEO_START(gamecstl)
 static void draw_char(bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx, int ch, int att, int x, int y)
 {
 	int i,j;
-	UINT8 *dp;
+	const UINT8 *dp;
 	int index = 0;
-	dp = gfx->gfxdata + ch * gfx->char_modulo;
+	dp = gfx_element_get_data(gfx, ch);
 
 	for (j=y; j < y+8; j++)
 	{
@@ -379,7 +379,8 @@ static READ8_HANDLER(at_page8_r)
 {
 	UINT8 data = at_pages[offset % 0x10];
 
-	switch(offset % 8) {
+	switch(offset % 8)
+	{
 	case 1:
 		data = dma_offset[(offset / 8) & 1][2];
 		break;
@@ -401,7 +402,8 @@ static WRITE8_HANDLER(at_page8_w)
 {
 	at_pages[offset % 0x10] = data;
 
-	switch(offset % 8) {
+	switch(offset % 8)
+	{
 	case 1:
 		dma_offset[(offset / 8) & 1][2] = data;
 		break;
@@ -420,7 +422,7 @@ static WRITE8_HANDLER(at_page8_w)
 
 static DMA8237_MEM_READ( pc_dma_read_byte )
 {
-	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
 		& 0xFF0000;
 
@@ -430,7 +432,7 @@ static DMA8237_MEM_READ( pc_dma_read_byte )
 
 static DMA8237_MEM_WRITE( pc_dma_write_byte )
 {
-	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
 		& 0xFF0000;
 
@@ -440,7 +442,7 @@ static DMA8237_MEM_WRITE( pc_dma_write_byte )
 
 static const struct dma8237_interface dma8237_1_config =
 {
-	"main",
+	"maincpu",
 	1.0e-6, // 1us
 
 	pc_dma_read_byte,
@@ -454,7 +456,7 @@ static const struct dma8237_interface dma8237_1_config =
 
 static const struct dma8237_interface dma8237_2_config =
 {
-	"main",
+	"maincpu",
 	1.0e-6, // 1us
 
 	NULL,
@@ -491,22 +493,22 @@ static ADDRESS_MAP_START( gamecstl_map, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START(gamecstl_io, ADDRESS_SPACE_IO, 32)
-	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8(DMA8237, "dma8237_1", dma8237_r, dma8237_w, 0xffffffff)
-	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8(PIC8259, "pic8259_1", pic8259_r, pic8259_w, 0xffffffff)
-	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8(PIT8254, "pit8254", pit8253_r, pit8253_w, 0xffffffff)
+	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8("dma8237_1", dma8237_r, dma8237_w, 0xffffffff)
+	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8("pic8259_1", pic8259_r, pic8259_w, 0xffffffff)
+	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8("pit8254", pit8253_r, pit8253_w, 0xffffffff)
 	AM_RANGE(0x0060, 0x006f) AM_READWRITE(kbdc8042_32le_r,			kbdc8042_32le_w)
 	AM_RANGE(0x0070, 0x007f) AM_READWRITE(mc146818_port32le_r,		mc146818_port32le_w)
 	AM_RANGE(0x0080, 0x009f) AM_READWRITE(at_page32_r,				at_page32_w)
-	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8(PIC8259, "pic8259_2", pic8259_r, pic8259_w, 0xffffffff)
-	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE(DMA8237, "dma8237_2", at32_dma8237_2_r, at32_dma8237_2_w)
+	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8("pic8259_2", pic8259_r, pic8259_w, 0xffffffff)
+	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE("dma8237_2", at32_dma8237_2_r, at32_dma8237_2_w)
 	AM_RANGE(0x00e8, 0x00eb) AM_NOP
-	AM_RANGE(0x01f0, 0x01f7) AM_DEVREADWRITE(IDE_CONTROLLER, "ide", ide_r, ide_w)
+	AM_RANGE(0x01f0, 0x01f7) AM_DEVREADWRITE("ide", ide_r, ide_w)
 	AM_RANGE(0x0300, 0x03af) AM_NOP
 	AM_RANGE(0x03b0, 0x03df) AM_NOP
 	AM_RANGE(0x0278, 0x027b) AM_WRITE(pnp_config_w)
-	AM_RANGE(0x03f0, 0x03ff) AM_DEVREADWRITE(IDE_CONTROLLER, "ide", fdc_r, fdc_w)
+	AM_RANGE(0x03f0, 0x03ff) AM_DEVREADWRITE("ide", fdc_r, fdc_w)
 	AM_RANGE(0x0a78, 0x0a7b) AM_WRITE(pnp_data_w)
-	AM_RANGE(0x0cf8, 0x0cff) AM_DEVREADWRITE(PCI_BUS, "pcibus", pci_32le_r,	pci_32le_w)
+	AM_RANGE(0x0cf8, 0x0cff) AM_DEVREADWRITE("pcibus", pci_32le_r,	pci_32le_w)
 ADDRESS_MAP_END
 
 /*****************************************************************************/
@@ -580,18 +582,18 @@ static IRQ_CALLBACK(irq_callback)
 
 static MACHINE_START(gamecstl)
 {
-	gamecstl_devices.pit8254 = device_list_find_by_tag( machine->config->devicelist, PIT8254, "pit8254" );
-	gamecstl_devices.pic8259_1 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_1" );
-	gamecstl_devices.pic8259_2 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_2" );
-	gamecstl_devices.dma8237_1 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_1" );
-	gamecstl_devices.dma8237_2 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_2" );
+	gamecstl_devices.pit8254 = devtag_get_device( machine, "pit8254" );
+	gamecstl_devices.pic8259_1 = devtag_get_device( machine, "pic8259_1" );
+	gamecstl_devices.pic8259_2 = devtag_get_device( machine, "pic8259_2" );
+	gamecstl_devices.dma8237_1 = devtag_get_device( machine, "dma8237_1" );
+	gamecstl_devices.dma8237_2 = devtag_get_device( machine, "dma8237_2" );
 }
 
 static MACHINE_RESET(gamecstl)
 {
 	memory_set_bankptr(machine, 1, memory_region(machine, "user1") + 0x30000);
 
-	cpu_set_irq_callback(machine->cpu[0], irq_callback);
+	cpu_set_irq_callback(cputag_get_cpu(machine, "maincpu"), irq_callback);
 }
 
 
@@ -601,12 +603,14 @@ static MACHINE_RESET(gamecstl)
  *
  *************************************************************/
 
-static PIC8259_SET_INT_LINE( gamecstl_pic8259_1_set_int_line ) {
-	cpu_set_input_line(device->machine->cpu[0], 0, interrupt ? HOLD_LINE : CLEAR_LINE);
+static PIC8259_SET_INT_LINE( gamecstl_pic8259_1_set_int_line )
+{
+	cputag_set_input_line(device->machine, "maincpu", 0, interrupt ? HOLD_LINE : CLEAR_LINE);
 }
 
 
-static PIC8259_SET_INT_LINE( gamecstl_pic8259_2_set_int_line ) {
+static PIC8259_SET_INT_LINE( gamecstl_pic8259_2_set_int_line )
+{
 	pic8259_set_irq_line( gamecstl_devices.pic8259_1, 2, interrupt);
 }
 
@@ -651,16 +655,16 @@ static const struct pit8253_config gamecstl_pit8254_config =
 static MACHINE_DRIVER_START(gamecstl)
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", PENTIUM, 200000000)
-	MDRV_CPU_PROGRAM_MAP(gamecstl_map, 0)
-	MDRV_CPU_IO_MAP(gamecstl_io, 0)
+	MDRV_CPU_ADD("maincpu", PENTIUM, 200000000)
+	MDRV_CPU_PROGRAM_MAP(gamecstl_map)
+	MDRV_CPU_IO_MAP(gamecstl_io)
 
 	MDRV_MACHINE_START(gamecstl)
 	MDRV_MACHINE_RESET(gamecstl)
 
 	MDRV_PCI_BUS_ADD("pcibus", 0)
-	MDRV_PCI_BUS_DEVICE(0, NULL, NULL, intel82439tx_pci_r, intel82439tx_pci_w)
-	MDRV_PCI_BUS_DEVICE(7, NULL, NULL, intel82371ab_pci_r, intel82371ab_pci_w)
+	MDRV_PCI_BUS_DEVICE(0, NULL, intel82439tx_pci_r, intel82439tx_pci_w)
+	MDRV_PCI_BUS_DEVICE(7, NULL, intel82371ab_pci_r, intel82371ab_pci_w)
 
 	MDRV_PIT8254_ADD( "pit8254", gamecstl_pit8254_config )
 
@@ -677,7 +681,7 @@ static MACHINE_DRIVER_START(gamecstl)
 	MDRV_NVRAM_HANDLER( mc146818 )
 
  	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -694,7 +698,7 @@ MACHINE_DRIVER_END
 
 static void set_gate_a20(running_machine *machine, int a20)
 {
-	cpu_set_input_line(machine->cpu[0], INPUT_LINE_A20, a20);
+	cputag_set_input_line(machine, "maincpu", INPUT_LINE_A20, a20);
 }
 
 static void keyboard_interrupt(running_machine *machine, int state)
@@ -707,7 +711,8 @@ static void ide_interrupt(const device_config *device, int state)
 	pic8259_set_irq_line( gamecstl_devices.pic8259_2, 6, state);
 }
 
-static int gamecstl_get_out2(running_machine *machine) {
+static int gamecstl_get_out2(running_machine *machine)
+{
 	return pit8253_get_output( gamecstl_devices.pit8254, 2 );
 }
 
@@ -716,13 +721,14 @@ static const struct kbdc8042_interface at8042 =
 	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, gamecstl_get_out2
 };
 
-static void gamecstl_set_keyb_int(running_machine *machine, int state) {
+static void gamecstl_set_keyb_int(running_machine *machine, int state)
+{
 	pic8259_set_irq_line(gamecstl_devices.pic8259_1, 1, state);
 }
 
 static DRIVER_INIT( gamecstl )
 {
-	bios_ram = auto_malloc(0x10000);
+	bios_ram = auto_alloc_array(machine, UINT32, 0x10000/4);
 
 	init_pc_common(machine, PCCOMMON_KEYBOARD_AT, gamecstl_set_keyb_int);
 	mc146818_init(machine, MC146818_STANDARD);
@@ -743,7 +749,7 @@ ROM_START(gamecstl)
 	ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 
 	DISK_REGION( "ide" )
-	DISK_IMAGE( "gamecstl", 0, MD5(501ddbebb530b8fd67eb64a4a2de3e35) SHA1(2477468ef1c1d4529057064a319ebfe9fd8facd7) )
+	DISK_IMAGE( "gamecstl", 0, SHA1(b431af3c42c48ba07972d77a3d24e60ee1e4359e) )
 ROM_END
 
 ROM_START(gamecst2)
@@ -754,11 +760,10 @@ ROM_START(gamecst2)
 	ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 
 	DISK_REGION( "ide" )
-	DISK_IMAGE( "gamecst2", 0, MD5(ef880a411521e0c6e10f715ad9dd796e) SHA1(8243d7d2eacedf358334821c9401c1b945524a69) )
+	DISK_IMAGE( "gamecst2", 0, SHA1(14e1b311cb474801c7bdda3164a0c220fb102159) )
 ROM_END
 
 /*****************************************************************************/
 
 GAME(2002, gamecstl, 0,	gamecstl, gamecstl, gamecstl,	ROT0,   "Cristaltec",  "GameCristal", GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME(2002, gamecst2, gamecstl, gamecstl, gamecstl, gamecstl, ROT0, "Cristaltec", "GameCristal (version 2.613)", GAME_NOT_WORKING | GAME_NO_SOUND)
-
