@@ -37,6 +37,9 @@ Unfortunately it's read protected.
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
+#include "sound/2612intf.h"
+#include "sound/sn76496.h"
+
 #include "genesis.h"
 
 #define MASTER_CLOCK		53693100
@@ -94,52 +97,37 @@ static INPUT_PORTS_START( hshavoc )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static ADDRESS_MAP_START( topshoot_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)					/* Cartridge Program Rom */
-	AM_RANGE(0x202000, 0x2023ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_READ(genesis_68k_to_z80_r)
-	AM_RANGE(0xc00000, 0xc0001f) AM_READ(genesis_vdp_r)				/* VDP Access */
-	AM_RANGE(0xe00000, 0xe1ffff) AM_READ(SMH_BANK3)
-	AM_RANGE(0xfe0000, 0xfeffff) AM_READ(SMH_BANK4)
-	AM_RANGE(0xff0000, 0xffffff) AM_READ(SMH_RAM)					/* Main Ram */
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( topshoot_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)					/* Cartridge Program Rom */
-//  AM_RANGE(0x200000, 0x20007f) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x200000, 0x2023ff) AM_WRITE(SMH_RAM) // tested
-	AM_RANGE(0xa10000, 0xa1001f) AM_WRITE(genesis_io_w) AM_BASE(&genesis_io_ram)				/* Genesis Input */
+static ADDRESS_MAP_START( topshoot_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM														/* Cartridge Program Rom */
+	AM_RANGE(0x200000, 0x201fff) AM_WRITENOP // tested
+	AM_RANGE(0x202000, 0x2023ff) AM_RAM // tested
+	AM_RANGE(0xa00000, 0xa0ffff) AM_READWRITE(genesis_68k_to_z80_r, genesis_68k_to_z80_w)
+	AM_RANGE(0xa10000, 0xa1001f) AM_WRITE(genesis_io_w) AM_BASE(&genesis_io_ram)			/* Genesis Input */
 	AM_RANGE(0xa11000, 0xa11203) AM_WRITE(genesis_ctrl_w)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_WRITE(genesis_68k_to_z80_w)
-	AM_RANGE(0xc00000, 0xc0001f) AM_WRITE(genesis_vdp_w)				/* VDP Access */
-	AM_RANGE(0xfe0000, 0xfeffff) AM_WRITE(SMH_BANK4)
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM) AM_BASE(&genesis_68k_ram)/* Main Ram */
+	AM_RANGE(0xc00000, 0xc0001f) AM_READWRITE(genesis_vdp_r, genesis_vdp_w)					/* VDP Access */
+	AM_RANGE(0xe00000, 0xe1ffff) AM_ROMBANK(3)
+	AM_RANGE(0xfe0000, 0xfeffff) AM_RAMBANK(4)
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM AM_BASE(&genesis_68k_ram)							/* Main Ram */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( genesis_z80_readmem, ADDRESS_SPACE_PROGRAM, 8 )
- 	AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_BANK1)
- 	AM_RANGE(0x2000, 0x3fff) AM_READ(SMH_BANK2) /* mirror */
-	AM_RANGE(0x4000, 0x7fff) AM_READ(genesis_z80_r)
+
+static ADDRESS_MAP_START( genesis_z80_map, ADDRESS_SPACE_PROGRAM, 8 )
+ 	AM_RANGE(0x0000, 0x1fff) AM_RAMBANK(1) AM_BASE(&genesis_z80_ram)
+ 	AM_RANGE(0x2000, 0x3fff) AM_RAMBANK(2) /* mirror */
+	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(genesis_z80_r, genesis_z80_w)
 	AM_RANGE(0x8000, 0xffff) AM_READ(genesis_z80_bank_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( genesis_z80_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_BANK1) AM_BASE(&genesis_z80_ram)
- 	AM_RANGE(0x2000, 0x3fff) AM_WRITE(SMH_BANK2) /* mirror */
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(genesis_z80_w)
  // AM_RANGE(0x8000, 0xffff) AM_WRITE(genesis_z80_bank_w)
 ADDRESS_MAP_END
 
 
 static MACHINE_DRIVER_START( genesis_base )
 	/*basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, MASTER_CLOCK / 7)
-	MDRV_CPU_VBLANK_INT("main", genesis_vblank_interrupt)
+	MDRV_CPU_ADD("maincpu", M68000, MASTER_CLOCK / 7)
+	MDRV_CPU_VBLANK_INT("screen", genesis_vblank_interrupt)
 
-	MDRV_CPU_ADD("sound", Z80, MASTER_CLOCK / 15)
-	MDRV_CPU_PROGRAM_MAP(genesis_z80_readmem, genesis_z80_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold) /* from vdp at scanline 0xe0 */
+	MDRV_CPU_ADD("genesis_snd_z80", Z80, MASTER_CLOCK / 15)
+	MDRV_CPU_PROGRAM_MAP(genesis_z80_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold) /* from vdp at scanline 0xe0 */
 
 	MDRV_QUANTUM_TIME(HZ(6000))
 
@@ -149,7 +137,7 @@ static MACHINE_DRIVER_START( genesis_base )
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(342,262)
@@ -172,8 +160,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( hshavoc )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM( genesis_base )
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(topshoot_readmem,topshoot_writemem)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(topshoot_map)
 
 	/* sound hardware */
 	MDRV_SOUND_ADD("sn", SN76496, MASTER_CLOCK/15)
@@ -181,7 +169,7 @@ static MACHINE_DRIVER_START( hshavoc )
 MACHINE_DRIVER_END
 
 ROM_START( hshavoc )
-	ROM_REGION( 0x200000, "main", 0 )
+	ROM_REGION( 0x200000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "d-25.11a", 0x000000, 0x080000, CRC(6a155060) SHA1(ecb47bd428786e50e300a062b5038f943419a389) )
 	ROM_LOAD16_BYTE( "d-26.9a",  0x000001, 0x080000, CRC(1afa84fe) SHA1(041296e0360b7747aedc2d948c39e06ba03a7d08) )
 
@@ -195,7 +183,7 @@ ROM_END
 
 #ifdef UNUSED_DEFINITION
 ROM_START( hshavoc2 ) /* Genesis Version, for reference */
-	ROM_REGION( 0x200000, "main", 0 )
+	ROM_REGION( 0x200000, "maincpu", 0 )
 	ROM_LOAD( "hsh.rom", 0x000000, 0x100000, CRC(17be551c) SHA1(0dc1969098716ba332978b89356f62961417682b) )
 ROM_END
 #endif
@@ -208,9 +196,9 @@ static READ16_HANDLER( vdp_fake_r )
 static DRIVER_INIT(genesis)
 {
 	/* hack -- fix vdp emulation instead */
-	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xC00004, 0xC00005, 0, 0, vdp_fake_r);
+	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xC00004, 0xC00005, 0, 0, vdp_fake_r);
 
-	memory_set_bankptr(machine, 3, memory_region(machine, "main") );
+	memory_set_bankptr(machine, 3, memory_region(machine, "maincpu") );
 	memory_set_bankptr(machine, 4, genesis_68k_ram );
 }
 
@@ -218,7 +206,7 @@ static DRIVER_INIT(hshavoc)
 {
 
 	int x;
-	UINT16 *src = (UINT16 *)memory_region(machine, "main");
+	UINT16 *src = (UINT16 *)memory_region(machine, "maincpu");
 
 	static const UINT16 typedat[16] = {
 		1,1,1,1, 1,1,1,1,
