@@ -102,13 +102,13 @@ static WRITE8_HANDLER( irobot_nvram_w )
 
 static WRITE8_HANDLER( irobot_clearirq_w )
 {
-    cpu_set_input_line(space->machine->cpu[0], M6809_IRQ_LINE ,CLEAR_LINE);
+    cputag_set_input_line(space->machine, "maincpu", M6809_IRQ_LINE ,CLEAR_LINE);
 }
 
 
 static WRITE8_HANDLER( irobot_clearfirq_w )
 {
-    cpu_set_input_line(space->machine->cpu[0], M6809_FIRQ_LINE ,CLEAR_LINE);
+    cputag_set_input_line(space->machine, "maincpu", M6809_FIRQ_LINE ,CLEAR_LINE);
 }
 
 
@@ -119,39 +119,28 @@ static WRITE8_HANDLER( irobot_clearfirq_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x07ff) AM_READ(SMH_RAM)
-    AM_RANGE(0x0800, 0x0fff) AM_READ(SMH_BANK2)
+static ADDRESS_MAP_START( irobot_map, ADDRESS_SPACE_PROGRAM, 8 )
+    AM_RANGE(0x0000, 0x07ff) AM_RAM
+    AM_RANGE(0x0800, 0x0fff) AM_RAMBANK(2)
     AM_RANGE(0x1000, 0x103f) AM_READ_PORT("IN0")
     AM_RANGE(0x1040, 0x1040) AM_READ_PORT("IN1")
     AM_RANGE(0x1080, 0x1080) AM_READ(irobot_status_r)
     AM_RANGE(0x10c0, 0x10c0) AM_READ_PORT("DSW1")
-    AM_RANGE(0x1200, 0x12ff) AM_READ(SMH_RAM)
-    AM_RANGE(0x1300, 0x13ff) AM_READ(irobot_control_r)
-    AM_RANGE(0x1400, 0x143f) AM_READ(quad_pokey_r)
-    AM_RANGE(0x1c00, 0x1fff) AM_READ(SMH_RAM)
-    AM_RANGE(0x2000, 0x3fff) AM_READ(irobot_sharedmem_r)
-    AM_RANGE(0x4000, 0x5fff) AM_READ(SMH_BANK1)
-    AM_RANGE(0x6000, 0xffff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x07ff) AM_WRITE(SMH_RAM)
-    AM_RANGE(0x0800, 0x0fff) AM_WRITE(SMH_BANK2)
     AM_RANGE(0x1100, 0x1100) AM_WRITE(irobot_clearirq_w)
     AM_RANGE(0x1140, 0x1140) AM_WRITE(irobot_statwr_w)
     AM_RANGE(0x1180, 0x1180) AM_WRITE(irobot_out0_w)
     AM_RANGE(0x11c0, 0x11c0) AM_WRITE(irobot_rom_banksel_w)
-    AM_RANGE(0x1200, 0x12ff) AM_WRITE(irobot_nvram_w) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
-    AM_RANGE(0x1400, 0x143f) AM_WRITE(quad_pokey_w)
+    AM_RANGE(0x1200, 0x12ff) AM_RAM_WRITE(irobot_nvram_w) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+    AM_RANGE(0x1300, 0x13ff) AM_READ(irobot_control_r)
+    AM_RANGE(0x1400, 0x143f) AM_READWRITE(quad_pokey_r, quad_pokey_w)
     AM_RANGE(0x1800, 0x18ff) AM_WRITE(irobot_paletteram_w)
     AM_RANGE(0x1900, 0x19ff) AM_WRITE(SMH_RAM)            /* Watchdog reset */
     AM_RANGE(0x1a00, 0x1a00) AM_WRITE(irobot_clearfirq_w)
     AM_RANGE(0x1b00, 0x1bff) AM_WRITE(irobot_control_w)
-    AM_RANGE(0x1c00, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-    AM_RANGE(0x2000, 0x3fff) AM_WRITE(irobot_sharedmem_w)
-    AM_RANGE(0x4000, 0xffff) AM_WRITE(SMH_ROM)
+    AM_RANGE(0x1c00, 0x1fff) AM_RAM AM_BASE(&videoram) AM_SIZE(&videoram_size)
+    AM_RANGE(0x2000, 0x3fff) AM_READWRITE(irobot_sharedmem_r, irobot_sharedmem_w)
+    AM_RANGE(0x4000, 0x5fff) AM_ROMBANK(1)
+    AM_RANGE(0x6000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 
@@ -281,8 +270,8 @@ GFXDECODE_END
 
 static const pokey_interface pokey_config =
 {
-	{ 0 },
-	input_port_4_r
+	{ DEVCB_NULL },
+	DEVCB_INPUT_PORT("DSW2")
 };
 
 
@@ -296,14 +285,14 @@ static const pokey_interface pokey_config =
 static MACHINE_DRIVER_START( irobot )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6809,1500000)
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_ADD("maincpu", M6809,1500000)
+	MDRV_CPU_PROGRAM_MAP(irobot_map)
 
 	MDRV_MACHINE_RESET(irobot)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -343,7 +332,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( irobot )
-	ROM_REGION( 0x20000, "main", 0 ) /* 64k for code + 48K Banked ROM*/
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* 64k for code + 48K Banked ROM*/
 	ROM_LOAD( "136029-208.bin",     0x06000, 0x2000, CRC(b4d0be59) SHA1(5b476dbee8b171a96301b2204420161333d4ca97) )
 	ROM_LOAD( "136029-209.bin",     0x08000, 0x4000, CRC(f6be3cd0) SHA1(a88ae0cc9ee22aa5dd3db0173f24313189f894f8) )
 	ROM_LOAD( "136029-210.bin",     0x0c000, 0x4000, CRC(c0eb2133) SHA1(daa77293678b7e822d0672b90789c53098c5451e) )
