@@ -21,6 +21,60 @@ Board Parts:
     6301 @ 6f and 7f (PROM's)
     6331 @ 1f and 2f (PROM's)
 
+Jail Break
+Konami 1986
+
+PCB Layout
+----------
+
+GX507
+PWB 300394A
+|----------------------------------------|
+| KONAMI-1   507P03.11D    6264     4416 |
+|            507P02.9D    |-------| 4416 |
+|                         |KONAMI | 4416 |
+|       507L01.8C         |005849 | 4416 |
+|                         |-------|      |
+| VLM5030                       507J13.7F|
+|                    SN76489    507J12.6F|
+| 3.579545MHz        18.432MHz           |
+| DSW3                          507J09.5F|
+|                               507L08.4F|
+| DSW2                          507J07.3F|
+|           UPC324                       |
+| DSW1                          507J11.2F|
+|      LA4460                   507J10.1F|
+|             005273 005273              |
+|             005273 005273              |
+|     VOL           18-WAY        CN1    |
+|----------------------------------------|
+Notes:
+      KONAMI1   - Custom encrypted 6809 CPU, clock 1.536MHz [18.432/12] (DIP42)
+      VLM5030   - Sanyo VLM5030 speech chip, clock 3.579545MHz (DIP40)
+      SN76489   - Texas Instruments SN76489 noise generator IC, clock 1.536MHz [18.432/12] (DIP16)
+      UPC324    - NEC UPC324 op amp. Also compatible with LM324 and Mitsubishi M5224P (DIP14)
+      LA4460    - Power amp IC
+      DSW1/2    - 8-position dip switches
+      DSW3      - 4-position dip switch
+      CN1       - 4-pin connector for monitors that require separate syncs. Pin 1 is negative vertical sync output.
+                  Horizontal sync is taken from the regular composite sync on the PCB on pin B14.
+      18-WAY    - 18-way edge connector. Pinout matches standard Konami 18-way pinout (Scramble/Frogger/Yie-Ar Kung Fu etc)
+      6264      - 8kx8 SRAM (DIP28)
+      4416      - 16kx4 DRAM (DIP18)
+      005849    - Konami custom graphics generator (PGA179)
+      005273    - Konami custom resistor array (SIL10)
+      507J12/13 - MMI 63S141 256x4 Bipolar PROM (= 82S129 & 6301 etc)
+      507J10/11 - MMI 63S081 32x8 Bipolar PROM (= 82S123 & 6331 etc)
+      All ROMs type 27C128. Pin 26 of 8C is tied high, the lower half is empty.
+
+      Measurements
+      ------------
+      Xtal  - 3.57867MHz
+      OSC   - 18.43199MHz
+      HSync - 15.5185kHz
+      VSync - 60.6059Hz
+
+
 ***************************************************************************/
 
 /*
@@ -35,13 +89,12 @@ Board Parts:
 #define MASTER_CLOCK		XTAL_18_432MHz
 #define VOICE_CLOCK			XTAL_3_579545MHz
 
-
 #include "driver.h"
 #include "machine/konami1.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/sn76496.h"
 #include "sound/vlm5030.h"
-
+#include "konamipt.h"
 
 extern UINT8 *jailbrek_scroll_x;
 extern UINT8 *jailbrek_scroll_dir;
@@ -77,14 +130,14 @@ static INTERRUPT_GEN( jb_interrupt_nmi )
 }
 
 
-static READ8_HANDLER( jailbrek_speech_r ) {
-	return ( vlm5030_bsy() ? 1 : 0 );
+static READ8_DEVICE_HANDLER( jailbrek_speech_r ) {
+	return ( vlm5030_bsy(device) ? 1 : 0 );
 }
 
-static WRITE8_HANDLER( jailbrek_speech_w ) {
+static WRITE8_DEVICE_HANDLER( jailbrek_speech_w ) {
 	/* bit 0 could be latch direction like in yiear */
-	vlm5030_st( ( data >> 1 ) & 1 );
-	vlm5030_rst( ( data >> 2 ) & 1 );
+	vlm5030_st( device, ( data >> 1 ) & 1 );
+	vlm5030_rst( device, ( data >> 2 ) & 1 );
 }
 
 static ADDRESS_MAP_START( jailbrek_map, ADDRESS_SPACE_PROGRAM, 8 )
@@ -100,15 +153,15 @@ static ADDRESS_MAP_START( jailbrek_map, ADDRESS_SPACE_PROGRAM, 8 )
     AM_RANGE(0x2043, 0x2043) AM_WRITENOP /* ??? */
     AM_RANGE(0x2044, 0x2044) AM_WRITE(ctrl_w) /* irq, nmi enable, screen flip */
 	AM_RANGE(0x3000, 0x307f) AM_RAM /* related to sprites? */
-	AM_RANGE(0x3100, 0x3100) AM_READ_PORT("DSW2") AM_WRITE(sn76496_0_w)
+	AM_RANGE(0x3100, 0x3100) AM_READ_PORT("DSW2") AM_DEVWRITE("sn", sn76496_w)
 	AM_RANGE(0x3200, 0x3200) AM_READ_PORT("DSW3") AM_WRITENOP /* mirror of the previous? */
 	AM_RANGE(0x3300, 0x3300) AM_READ_PORT("SYSTEM") AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x3301, 0x3301) AM_READ_PORT("P1")
 	AM_RANGE(0x3302, 0x3302) AM_READ_PORT("P2")
 	AM_RANGE(0x3303, 0x3303) AM_READ_PORT("DSW1")
-	AM_RANGE(0x4000, 0x4000) AM_WRITE(jailbrek_speech_w) /* speech pins */
-	AM_RANGE(0x5000, 0x5000) AM_WRITE(vlm5030_data_w) /* speech data */
-	AM_RANGE(0x6000, 0x6000) AM_READ(jailbrek_speech_r)
+	AM_RANGE(0x4000, 0x4000) AM_DEVWRITE("vlm", jailbrek_speech_w) /* speech pins */
+	AM_RANGE(0x5000, 0x5000) AM_DEVWRITE("vlm", vlm5030_data_w) /* speech data */
+	AM_RANGE(0x6000, 0x6000) AM_DEVREAD("vlm", jailbrek_speech_r)
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -116,66 +169,18 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( jailbrek )
 	PORT_START("SYSTEM")	/* $3300 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
+	KONAMI8_SYSTEM_10
 	PORT_BIT( 0xe0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("P1")		/* $3301 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )	// shoot
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )	// select
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_B12_UNK(1)	// button1 = shoot, button2 = select
 
 	PORT_START("P2")		/* $3302 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	KONAMI8_B12_UNK(2)
 
 	PORT_START("DSW1")		/* $3303 */
-	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )      PORT_DIPLOCATION( "SW1:4,3,2,1" )
-	PORT_DIPSETTING(    0x02, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(    0x05, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x04, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(    0x0f, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(    0x07, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x06, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(    0x09, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )      PORT_DIPLOCATION( "SW1:8,7,6,5" )
-	PORT_DIPSETTING(    0x20, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(    0x50, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x30, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(    0x70, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x60, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(    0x00, "Invalid" )
+	KONAMI_COINAGE_LOC(DEF_STR( Free_Play ), "Invalid", SW1)
+	/* "Invalid" = both coin slots disabled */
 
 	PORT_START("DSW2")		/* $3100 */
 	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Lives ) )       PORT_DIPLOCATION( "SW2:1,2" )
@@ -192,8 +197,8 @@ static INPUT_PORTS_START( jailbrek )
 	PORT_DIPNAME( 0x30, 0x10, DEF_STR( Difficulty ) )  PORT_DIPLOCATION( "SW2:5,6" )
 	PORT_DIPSETTING(    0x30, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x10, "Difficult" )
-	PORT_DIPSETTING(    0x00, "Very Difficult" )
+	PORT_DIPSETTING(    0x10, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Very_Difficult ) )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )        PORT_DIPLOCATION( "SW2:7" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION( "SW2:8" )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
@@ -251,9 +256,9 @@ static MACHINE_START( jailbrek )
 static MACHINE_DRIVER_START( jailbrek )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6809, MASTER_CLOCK/12)
-	MDRV_CPU_PROGRAM_MAP(jailbrek_map, 0)
-	MDRV_CPU_VBLANK_INT("main", jb_interrupt)
+	MDRV_CPU_ADD("maincpu", M6809, MASTER_CLOCK/12)
+	MDRV_CPU_PROGRAM_MAP(jailbrek_map)
+	MDRV_CPU_VBLANK_INT("screen", jb_interrupt)
 	MDRV_CPU_PERIODIC_INT(jb_interrupt_nmi, 500) /* ? */
 
 	MDRV_MACHINE_START(jailbrek)
@@ -262,7 +267,7 @@ static MACHINE_DRIVER_START( jailbrek )
 	MDRV_GFXDECODE(jailbrek)
 	MDRV_PALETTE_LENGTH(512)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_RAW_PARAMS(MASTER_CLOCK/3, 396, 8, 248, 256, 16, 240)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 
@@ -288,7 +293,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( jailbrek )
-    ROM_REGION( 0x10000, "main", 0 )
+    ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "507p03.11d", 0x8000, 0x4000, CRC(a0b88dfd) SHA1(f999e382b9d3b812fca41f4d0da3ea692fef6b19) )
 	ROM_LOAD( "507p02.9d",  0xc000, 0x4000, CRC(444b7d8e) SHA1(c708b67c2d249448dae9a3d10c24d13ba6849597) )
 
@@ -313,7 +318,7 @@ ROM_START( jailbrek )
 ROM_END
 
 ROM_START( manhatan )
-    ROM_REGION( 0x10000, "main", 0 )
+    ROM_REGION( 0x10000, "maincpu", 0 )
     ROM_LOAD( "507n03.11d", 0x8000, 0x4000, CRC(e5039f7e) SHA1(0f12484ed40444d978e0405c27bdd027ae2e2a0b) )
     ROM_LOAD( "507n02.9d",  0xc000, 0x4000, CRC(143cc62c) SHA1(9520dbb1b6f1fa439e03d4caa9bed96ef8f805f2) )
 
@@ -374,7 +379,7 @@ ROM_END
 */
 
 ROM_START( jailbrkb )
-    ROM_REGION( 0x10000, "main", 0 )
+    ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "1.k6",    0x8000, 0x8000, CRC(df0e8fc7) SHA1(62e59dbb3941ed8af365e96906315318d9aee060) )
 
     ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE ) /* characters */
@@ -422,7 +427,7 @@ static DRIVER_INIT( jailbrek )
         }
     }
 
-    konami1_decode(machine, "main");
+    konami1_decode(machine, "maincpu");
 }
 
 GAME( 1986, jailbrek, 0,        jailbrek, jailbrek, jailbrek, ROT0, "Konami", "Jail Break", GAME_SUPPORTS_SAVE )
