@@ -82,128 +82,104 @@ extern VIDEO_UPDATE( kchampvs );
 static int nmi_enable = 0;
 static int sound_nmi_enable = 0;
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd000, 0xd3ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd400, 0xd7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd800, 0xd8ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd900, 0xdfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
+/********************
+* VS Version        *
+********************/
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(kchamp_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xd400, 0xd7ff) AM_WRITE(kchamp_colorram_w) AM_BASE(&colorram)
-	AM_RANGE(0xd800, 0xd8ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xd900, 0xdfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x6000, 0xffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x6000, 0xffff) AM_WRITE(SMH_RAM)
-ADDRESS_MAP_END
-
-static WRITE8_HANDLER( control_w ) {
+static WRITE8_HANDLER( control_w )
+{
 	nmi_enable = data & 1;
 }
 
-static WRITE8_HANDLER( sound_reset_w ) {
+static WRITE8_HANDLER( sound_reset_w )
+{
 	if ( !( data & 1 ) )
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, PULSE_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, PULSE_LINE);
 }
 
-static WRITE8_HANDLER( sound_control_w ) {
-	msm5205_reset_w( 0, !( data & 1 ) );
+static WRITE8_DEVICE_HANDLER( sound_control_w )
+{
+	msm5205_reset_w( device, !( data & 1 ) );
 	sound_nmi_enable = ( ( data >> 1 ) & 1 );
 }
 
-static WRITE8_HANDLER( sound_command_w ) {
+static WRITE8_HANDLER( sound_command_w )
+{
 	soundlatch_w( space, 0, data );
-	cpu_set_input_line_and_vector(space->machine->cpu[1], 0, HOLD_LINE, 0xff );
+	cputag_set_input_line_and_vector(space->machine, "audiocpu", 0, HOLD_LINE, 0xff );
 }
 
 static int msm_data = 0;
 static int msm_play_lo_nibble = 1;
 
-static WRITE8_HANDLER( sound_msm_w ) {
+static WRITE8_HANDLER( sound_msm_w )
+{
 	msm_data = data;
 	msm_play_lo_nibble = 1;
 }
 
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( kchampvs_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xcfff) AM_RAM
+	AM_RANGE(0xd000, 0xd3ff) AM_RAM_WRITE(kchamp_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xd400, 0xd7ff) AM_RAM_WRITE(kchamp_colorram_w) AM_BASE(&colorram)
+	AM_RANGE(0xd800, 0xd8ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xd900, 0xdfff) AM_RAM
+	AM_RANGE(0xe000, 0xffff) AM_ROM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( kchampvs_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ_PORT("P1") AM_WRITE(kchamp_flipscreen_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(control_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(sound_reset_w)
 	AM_RANGE(0x40, 0x40) AM_READ_PORT("P2") AM_WRITE(sound_command_w)
 	AM_RANGE(0x80, 0x80) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0xC0, 0xC0) AM_READ_PORT("DSW")
+	AM_RANGE(0xc0, 0xc0) AM_READ_PORT("DSW")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_READWRITE(soundlatch_r, ay8910_control_port_0_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0x04, 0x04) AM_WRITE(sound_msm_w)
-	AM_RANGE(0x05, 0x05) AM_WRITE(sound_control_w)
+static ADDRESS_MAP_START( kchampvs_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x5fff) AM_ROM
+	AM_RANGE(0x6000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( kchampvs_sound_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x01) AM_DEVWRITE("ay1", ay8910_data_address_w)
+	AM_RANGE(0x01, 0x01) AM_READ(soundlatch_r)
+	AM_RANGE(0x02, 0x03) AM_DEVWRITE("ay2", ay8910_data_address_w)
+	AM_RANGE(0x04, 0x04) AM_WRITE(sound_msm_w)
+	AM_RANGE(0x05, 0x05) AM_DEVWRITE("msm", sound_control_w)
+ADDRESS_MAP_END
+
+
 /********************
 * 1 Player Version  *
 ********************/
-
-static ADDRESS_MAP_START( kc_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe000, 0xe3ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe400, 0xe7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xea00, 0xeaff) AM_READ(SMH_RAM)
-	AM_RANGE(0xeb00, 0xffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( kc_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xe000, 0xe3ff) AM_WRITE(kchamp_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xe400, 0xe7ff) AM_WRITE(kchamp_colorram_w) AM_BASE(&colorram)
-	AM_RANGE(0xea00, 0xeaff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xeb00, 0xffff) AM_WRITE(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( kc_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xdfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xe000, 0xe2ff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( kc_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xdfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xe000, 0xe2ff) AM_WRITE(SMH_RAM)
-ADDRESS_MAP_END
-
-static READ8_HANDLER( sound_reset_r ) {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, PULSE_LINE);
+static READ8_HANDLER( sound_reset_r )
+{
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, PULSE_LINE);
 	return 0;
 }
 
-static WRITE8_HANDLER( kc_sound_control_w ) {
+static WRITE8_HANDLER( kc_sound_control_w )
+{
 	if ( offset == 0 )
 		sound_nmi_enable = ( ( data >> 7 ) & 1 );
 //  else
 //      DAC_set_volume(0,( data == 1 ) ? 255 : 0,0);
 }
 
-static ADDRESS_MAP_START( kc_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( kchamp_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xdfff) AM_RAM
+	AM_RANGE(0xe000, 0xe3ff) AM_RAM_WRITE(kchamp_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xe400, 0xe7ff) AM_RAM_WRITE(kchamp_colorram_w) AM_BASE(&colorram)
+	AM_RANGE(0xea00, 0xeaff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xeb00, 0xffff) AM_RAM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( kchamp_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x80, 0x80) AM_READ_PORT("DSW") AM_WRITE(kchamp_flipscreen_w)
 	AM_RANGE(0x81, 0x81) AM_WRITE(control_w)
@@ -213,13 +189,16 @@ static ADDRESS_MAP_START( kc_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xa8, 0xa8) AM_READWRITE(sound_reset_r, sound_command_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( kc_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( kchamp_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xdfff) AM_ROM
+	AM_RANGE(0xe000, 0xe2ff) AM_RAM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( kchamp_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0x04, 0x04) AM_WRITE(dac_0_data_w)
+	AM_RANGE(0x00, 0x01) AM_DEVWRITE("ay1", ay8910_data_address_w)
+	AM_RANGE(0x02, 0x03) AM_DEVWRITE("ay2", ay8910_data_address_w)
+	AM_RANGE(0x04, 0x04) AM_DEVWRITE("dac", dac_w)
 	AM_RANGE(0x05, 0x05) AM_WRITE(kc_sound_control_w)
 	AM_RANGE(0x06, 0x06) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
@@ -374,26 +353,30 @@ GFXDECODE_END
 
 
 
-static INTERRUPT_GEN( kc_interrupt ) {
+static INTERRUPT_GEN( kc_interrupt )
+{
 
 	if ( nmi_enable )
 		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static void msmint(const device_config *device) {
+static void msmint(const device_config *device)
+{
 
 	static int counter = 0;
 
 	if ( msm_play_lo_nibble )
-		msm5205_data_w( 0, msm_data & 0x0f );
+		msm5205_data_w( device, msm_data & 0x0f );
 	else
-		msm5205_data_w( 0, ( msm_data >> 4 ) & 0x0f );
+		msm5205_data_w( device, ( msm_data >> 4 ) & 0x0f );
 
 	msm_play_lo_nibble ^= 1;
 
-	if ( !( counter ^= 1 ) ) {
-		if ( sound_nmi_enable ) {
-			cpu_set_input_line(device->machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE );
+	if ( !( counter ^= 1 ) )
+	{
+		if ( sound_nmi_enable )
+		{
+			cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
 		}
 	}
 }
@@ -408,8 +391,8 @@ static const msm5205_interface msm_interface =
 * 1 Player Version  *
 ********************/
 
-static INTERRUPT_GEN( sound_int ) {
-
+static INTERRUPT_GEN( sound_int )
+{
 	if ( sound_nmi_enable )
 		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
@@ -418,18 +401,18 @@ static INTERRUPT_GEN( sound_int ) {
 static MACHINE_DRIVER_START( kchampvs )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(io_map,0)
-	MDRV_CPU_VBLANK_INT("main", kc_interrupt)
+	MDRV_CPU_ADD("maincpu", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kchampvs_map)
+	MDRV_CPU_IO_MAP(kchampvs_io_map)
+	MDRV_CPU_VBLANK_INT("screen", kc_interrupt)
 
-	MDRV_CPU_ADD("audio", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_IO_MAP(sound_io_map,0)		/* irq's triggered from main cpu */
+	MDRV_CPU_ADD("audiocpu", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kchampvs_sound_map)
+	MDRV_CPU_IO_MAP(kchampvs_sound_io_map)		/* irq's triggered from main cpu */
 										/* nmi's from msm5205 */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -464,20 +447,20 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( kchamp )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(kc_readmem,kc_writemem)
-	MDRV_CPU_IO_MAP(kc_io_map,0)
-	MDRV_CPU_VBLANK_INT("main", kc_interrupt)
+	MDRV_CPU_ADD("maincpu", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kchamp_map)
+	MDRV_CPU_IO_MAP(kchamp_io_map)
+	MDRV_CPU_VBLANK_INT("screen", kc_interrupt)
 
-	MDRV_CPU_ADD("audio", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(kc_sound_readmem,kc_sound_writemem)
-	MDRV_CPU_IO_MAP(kc_sound_io_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 3000000)	/* 12MHz / 4 = 3.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kchamp_sound_map)
+	MDRV_CPU_IO_MAP(kchamp_sound_io_map)
 	MDRV_CPU_PERIODIC_INT(sound_int, 125)	/* Hz */
 											/* irq's triggered from main cpu */
 											/* nmi's from 125 Hz clock */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -501,7 +484,7 @@ static MACHINE_DRIVER_START( kchamp )
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
 	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15) /* guess: using volume 0.50 makes the sound to clip a lot */
 MACHINE_DRIVER_END
 
 
@@ -512,7 +495,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( kchamp )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "b014.bin", 0x0000, 0x2000, CRC(0000d1a0) SHA1(0c584096825e1d3cc718e0bda1abb897a7f4d2df) )
 	ROM_LOAD( "b015.bin", 0x2000, 0x2000, CRC(03fae67e) SHA1(3b6a30f39f5ad512415e3b8ba6e07f3118e28d9e) )
 	ROM_LOAD( "b016.bin", 0x4000, 0x2000, CRC(3b6e1d08) SHA1(ecf7d2b0f31f04c0be7d5a1f450b9c95d9f54d80) )
@@ -520,7 +503,7 @@ ROM_START( kchamp )
 	ROM_LOAD( "b018.bin", 0x8000, 0x2000, CRC(b824abc7) SHA1(4a30fec025150e889600a78497700155e743c99e) )
 	ROM_LOAD( "b019.bin", 0xa000, 0x2000, CRC(3b487a46) SHA1(7837e480fd4648e0d3f792b79fa0019e063abdc6) )
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* Sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* Sound CPU */
 	ROM_LOAD( "b026.bin", 0x0000, 0x2000, CRC(999ed2c7) SHA1(f01e4ee81f8f7b0d1cf001d3ec01a9210f8109b4) )
 	ROM_LOAD( "b025.bin", 0x2000, 0x2000, CRC(33171e07) SHA1(55ee74c9f1d86ec13d92ea0d1b700bbe24b79def) ) /* adpcm */
 	ROM_LOAD( "b024.bin", 0x4000, 0x2000, CRC(910b48b9) SHA1(c6a2f8266ff1f14b462b92d47a4a86542df77cdd) ) /* adpcm */
@@ -554,7 +537,7 @@ ROM_START( kchamp )
 ROM_END
 
 ROM_START( karatedo )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "be14", 0x0000, 0x2000, CRC(44e60aa0) SHA1(6d007d7082c15182832f947444b00b7feb0e7738) )
 	ROM_LOAD( "be15", 0x2000, 0x2000, CRC(a65e3793) SHA1(bf1e8fbc6755e85414eb7629e6fab3bf154f6546) )
 	ROM_LOAD( "be16", 0x4000, 0x2000, CRC(151d8872) SHA1(1bb27142fdb33e3aeaf95c7a0ad7e8c258bbcb66) )
@@ -562,7 +545,7 @@ ROM_START( karatedo )
 	ROM_LOAD( "be18", 0x8000, 0x2000, CRC(a09046ad) SHA1(665973bffc38e36b8b0f6bc79e10db280be0613e) )
 	ROM_LOAD( "be19", 0xa000, 0x2000, CRC(0cdc4da9) SHA1(405454deda311abb8badd58a47529e42ddce5f6a) )
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* Sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* Sound CPU */
 	ROM_LOAD( "be26", 0x0000, 0x2000, CRC(999ab0a3) SHA1(6aa545cee7a261f3dc5774dea2066f1412f63f49) )
 	ROM_LOAD( "be25", 0x2000, 0x2000, CRC(253bf0da) SHA1(33bae6401003dc57deaa14bf7f6a7ebad5b7efe3) ) /* adpcm */
 	ROM_LOAD( "be24", 0x4000, 0x2000, CRC(e2c188af) SHA1(b7a0801a4c634694f1556873fd21f7e13441be17) ) /* adpcm */
@@ -596,7 +579,7 @@ ROM_START( karatedo )
 ROM_END
 
 ROM_START( kchampvs )
-	ROM_REGION( 0x10000, "main", 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, "maincpu", 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "bs24", 0x0000, 0x2000, CRC(829da69b) SHA1(3266e7686e537f34ee5ce4cccc349eb12fc65038) )
 	ROM_LOAD( "bs23", 0x2000, 0x2000, CRC(091f810e) SHA1(283edb08ce106835185a1c2d6b88f7544d75f3b4) )
 	ROM_LOAD( "bs22", 0x4000, 0x2000, CRC(d4df2a52) SHA1(60d6cb1cb51c6f80a0f88913d4152ab8bda752d6) )
@@ -605,7 +588,7 @@ ROM_START( kchampvs )
 	ROM_LOAD( "bs19", 0xa000, 0x2000, CRC(43e196c4) SHA1(8029798ea0a560603c3dcde56db5a1ccde58c514) )
 	ROM_CONTINUE(     0xe000, 0x2000 )
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* Sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* Sound CPU */
 	ROM_LOAD( "bs18", 0x0000, 0x2000, CRC(eaa646eb) SHA1(cbd48f4d5d225b71c2dd0b14f420838561e3f83e) )
 	ROM_LOAD( "bs17", 0x2000, 0x2000, CRC(d71031ad) SHA1(b168f4ef4feb4195305404df699acecb731eab02) ) /* adpcm */
 	ROM_LOAD( "bs16", 0x4000, 0x2000, CRC(6f811c43) SHA1(1d33ac8129562ab709bd7396b4c2457b6db99277) ) /* adpcm */
@@ -637,7 +620,7 @@ ROM_START( kchampvs )
 ROM_END
 
 ROM_START( karatevs )
-	ROM_REGION( 0x10000, "main", 0 )	/* 64k for code + 64k for decrypted opcodes */
+	ROM_REGION( 0x10000, "maincpu", 0 )	/* 64k for code + 64k for decrypted opcodes */
 	ROM_LOAD( "br24", 0x0000, 0x2000, CRC(ea9cda49) SHA1(7d753a8d391418d0fe5231eb88b3627f7d3fd99e) )
 	ROM_LOAD( "br23", 0x2000, 0x2000, CRC(46074489) SHA1(5593f819b6893820ef0c0fece13cf3ca83e1ab85) )
 	ROM_LOAD( "br22", 0x4000, 0x2000, CRC(294f67ba) SHA1(45f13a7deb75bb167176c5405128de3ca76e22f0) )
@@ -646,7 +629,7 @@ ROM_START( karatevs )
 	ROM_LOAD( "br19", 0xa000, 0x2000, CRC(dd2239d2) SHA1(0533d5abf8e25a4aeec2f7832b657eab56fd11f0) )
 	ROM_CONTINUE(     0xe000, 0x2000 )
 
-	ROM_REGION( 0x10000, "audio", 0 ) /* Sound CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 ) /* Sound CPU */
 	ROM_LOAD( "br18", 0x0000, 0x2000, CRC(00ccb8ea) SHA1(83d69684dc3ad37aca03c901fd23c7652134766f) )
 	ROM_LOAD( "bs17", 0x2000, 0x2000, CRC(d71031ad) SHA1(b168f4ef4feb4195305404df699acecb731eab02) ) /* adpcm */
 	ROM_LOAD( "br16", 0x4000, 0x2000, CRC(2512d961) SHA1(f0cd1be112b915d700e0587759606d48d115a83f) ) /* adpcm */
@@ -681,9 +664,9 @@ ROM_END
 
 static DRIVER_INIT( kchampvs )
 {
-	const address_space *space = cputag_get_address_space(machine, "main", ADDRESS_SPACE_PROGRAM);
-	UINT8 *decrypted = auto_malloc(0x10000);
-	UINT8 *rom = memory_region(machine, "main");
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x10000);
+	UINT8 *rom = memory_region(machine, "maincpu");
 	int A;
 
 	memory_set_decrypted_region(space, 0x0000, 0xffff, decrypted);
