@@ -3,7 +3,7 @@
 King of Boxer - (c) 1985 Woodplace Inc.
 Ring King     - (c) 1985 Data East USA Inc. / Woodplace Inc.
 
-Preliminary driver by:
+Driver by:
 Ernesto Corvi
 ernesto@imagina.com
 
@@ -40,196 +40,125 @@ extern PALETTE_INIT( ringking );
 extern VIDEO_START( ringking );
 extern VIDEO_UPDATE( ringking );
 
-static UINT8 *video_shared;
-static UINT8 *sprite_shared;
 int kingofb_nmi_enable = 0;
 
-static READ8_HANDLER( video_shared_r ) {
-	return video_shared[offset];
+static WRITE8_HANDLER( video_interrupt_w )
+{
+	cputag_set_input_line_and_vector(space->machine, "video", 0, HOLD_LINE, 0xff );
 }
 
-static WRITE8_HANDLER( video_shared_w ) {
-	video_shared[offset] = data;
+static WRITE8_HANDLER( sprite_interrupt_w )
+{
+	cputag_set_input_line_and_vector(space->machine, "sprite", 0, HOLD_LINE, 0xff );
 }
 
-static READ8_HANDLER( sprite_shared_r ) {
-	return sprite_shared[offset];
-}
-
-static WRITE8_HANDLER( sprite_shared_w ) {
-	sprite_shared[offset] = data;
-}
-
-static WRITE8_HANDLER( video_interrupt_w ) {
-	cpu_set_input_line_and_vector(space->machine->cpu[1], 0, HOLD_LINE, 0xff );
-}
-
-static WRITE8_HANDLER( sprite_interrupt_w ) {
-	cpu_set_input_line_and_vector(space->machine->cpu[2], 0, HOLD_LINE, 0xff );
-}
-
-static WRITE8_HANDLER( scroll_interrupt_w ) {
+static WRITE8_HANDLER( scroll_interrupt_w )
+{
 	sprite_interrupt_w( space, offset, data );
 	*kingofb_scroll_y = data;
 }
 
-static WRITE8_HANDLER( sound_command_w ) {
+static WRITE8_HANDLER( sound_command_w )
+{
 	soundlatch_w( space, 0, data );
-	cpu_set_input_line_and_vector(space->machine->cpu[3], 0, HOLD_LINE, 0xff );
+	cputag_set_input_line_and_vector(space->machine, "audiocpu", 0, HOLD_LINE, 0xff );
 }
 
 
-static ADDRESS_MAP_START( main_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xe000, 0xe7ff) AM_READ(sprite_shared_r)
-    AM_RANGE(0xe800, 0xefff) AM_READ(video_shared_r)
-    AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM) /* ???? */
-    AM_RANGE(0xfc00, 0xfc00) AM_READ_PORT("DSW1")
-    AM_RANGE(0xfc01, 0xfc01) AM_READ_PORT("DSW2")
-    AM_RANGE(0xfc02, 0xfc02) AM_READ_PORT("P1")
-    AM_RANGE(0xfc03, 0xfc03) AM_READ_PORT("P2")
-    AM_RANGE(0xfc04, 0xfc04) AM_READ_PORT("SYSTEM")
-    AM_RANGE(0xfc05, 0xfc05) AM_READ_PORT("EXTRA")
+static ADDRESS_MAP_START( kingobox_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc3ff) AM_RAM /* work ram */
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE(2) /* shared with sprite cpu */
+	AM_RANGE(0xe800, 0xefff) AM_RAM AM_SHARE(1) /* shared with video cpu */
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM /* ???? */
+	AM_RANGE(0xf800, 0xf800) AM_WRITE(kingofb_f800_w)	/* NMI enable, palette bank */
+	AM_RANGE(0xf801, 0xf801) AM_WRITENOP /* ???? */
+	AM_RANGE(0xf802, 0xf802) AM_WRITEONLY AM_BASE(&kingofb_scroll_y)
+	AM_RANGE(0xf803, 0xf803) AM_WRITE(scroll_interrupt_w)
+	AM_RANGE(0xf804, 0xf804) AM_WRITE(video_interrupt_w)
+	AM_RANGE(0xf807, 0xf807) AM_WRITE(sound_command_w) /* sound latch */
+	AM_RANGE(0xfc00, 0xfc00) AM_READ_PORT("DSW1")
+	AM_RANGE(0xfc01, 0xfc01) AM_READ_PORT("DSW2")
+	AM_RANGE(0xfc02, 0xfc02) AM_READ_PORT("P1")
+	AM_RANGE(0xfc03, 0xfc03) AM_READ_PORT("P2")
+	AM_RANGE(0xfc04, 0xfc04) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xfc05, 0xfc05) AM_READ_PORT("EXTRA")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xe000, 0xe7ff) AM_WRITE(sprite_shared_w) /* shared with sprite cpu */
-    AM_RANGE(0xe800, 0xefff) AM_WRITE(video_shared_w) /* shared with video cpu */
-    AM_RANGE(0xf000, 0xf7ff) AM_WRITE(SMH_RAM) /* ???? */
-    AM_RANGE(0xf800, 0xf800) AM_WRITE(kingofb_f800_w)	/* NMI enable, palette bank */
-    AM_RANGE(0xf801, 0xf801) AM_WRITE(SMH_NOP) /* ???? */
-    AM_RANGE(0xf802, 0xf802) AM_WRITE(SMH_RAM) AM_BASE(&kingofb_scroll_y)
-    AM_RANGE(0xf803, 0xf803) AM_WRITE(scroll_interrupt_w)
-    AM_RANGE(0xf804, 0xf804) AM_WRITE(video_interrupt_w)
-    AM_RANGE(0xf807, 0xf807) AM_WRITE(sound_command_w) /* sound latch */
+static ADDRESS_MAP_START( kingobox_video_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM /* work ram */
+	AM_RANGE(0xa000, 0xa7ff) AM_RAM AM_SHARE(1) /* shared with main */
+	AM_RANGE(0xc000, 0xc0ff) AM_RAM_WRITE(kingofb_videoram_w) AM_BASE(&videoram) /* background vram */
+	AM_RANGE(0xc400, 0xc4ff) AM_RAM_WRITE(kingofb_colorram_w) AM_BASE(&colorram) /* background colorram */
+	AM_RANGE(0xc800, 0xcbff) AM_RAM_WRITE(kingofb_videoram2_w) AM_BASE(&kingofb_videoram2) /* foreground vram */
+	AM_RANGE(0xcc00, 0xcfff) AM_RAM_WRITE(kingofb_colorram2_w) AM_BASE(&kingofb_colorram2) /* foreground colorram */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( video_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xa000, 0xa7ff) AM_READ(video_shared_r) /* shared with main */
-    AM_RANGE(0xc000, 0xc0ff) AM_READ(SMH_RAM) /* background vram */
-    AM_RANGE(0xc400, 0xc4ff) AM_READ(SMH_RAM) /* background colorram */
-    AM_RANGE(0xc800, 0xcbff) AM_READ(SMH_RAM) /* foreground vram */
-    AM_RANGE(0xcc00, 0xcfff) AM_READ(SMH_RAM) /* foreground colorram */
+static ADDRESS_MAP_START( kingobox_sprite_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM /* work ram */
+	AM_RANGE(0xa000, 0xa7ff) AM_RAM AM_SHARE(2) /* shared with main */
+	AM_RANGE(0xc000, 0xc3ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size) /* sprite ram */
+	AM_RANGE(0xc400, 0xc43f) AM_RAM  /* something related to scroll? */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( video_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x3fff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xa000, 0xa7ff) AM_WRITE(video_shared_w) AM_BASE(&video_shared) /* shared with main */
-    AM_RANGE(0xc000, 0xc0ff) AM_WRITE(kingofb_videoram_w) AM_BASE(&videoram) /* background vram */
-    AM_RANGE(0xc400, 0xc4ff) AM_WRITE(kingofb_colorram_w) AM_BASE(&colorram) /* background colorram */
-    AM_RANGE(0xc800, 0xcbff) AM_WRITE(kingofb_videoram2_w) AM_BASE(&kingofb_videoram2) /* foreground vram */
-    AM_RANGE(0xcc00, 0xcfff) AM_WRITE(kingofb_colorram2_w) AM_BASE(&kingofb_colorram2) /* foreground colorram */
+static ADDRESS_MAP_START( kingobox_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0x8000, 0x8000) AM_WRITENOP /* ??? */
+    AM_RANGE(0xc000, 0xc3ff) AM_RAM /* work ram */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sprite_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xa000, 0xa7ff) AM_READ(sprite_shared_r) /* shared with main */
-    AM_RANGE(0xc000, 0xc3ff) AM_READ(SMH_RAM) /* sprite ram */
-    AM_RANGE(0xc400, 0xc43f) AM_READ(SMH_RAM) /* something related to scroll? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sprite_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xa000, 0xa7ff) AM_WRITE(sprite_shared_w) AM_BASE(&sprite_shared) /* shared with main */
-    AM_RANGE(0xc000, 0xc3ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size) /* sprite ram */
-    AM_RANGE(0xc400, 0xc43f) AM_WRITE(SMH_RAM)  /* something related to scroll? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_READ(SMH_RAM) /* work ram */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x8000, 0x8000) AM_WRITE(SMH_NOP) /* ??? */
-    AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_WRITE(SMH_RAM) /* work ram */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( kingobox_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_WRITE(dac_0_data_w)
-	AM_RANGE(0x08, 0x08) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
-	AM_RANGE(0x0c, 0x0c) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x00, 0x00) AM_DEVWRITE("dac", dac_w)
+	AM_RANGE(0x08, 0x08) AM_DEVREADWRITE("ay", ay8910_r, ay8910_data_w)
+	AM_RANGE(0x0c, 0x0c) AM_DEVWRITE("ay", ay8910_address_w)
 ADDRESS_MAP_END
 
 /* Ring King */
-static ADDRESS_MAP_START( rk_main_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xc800, 0xcfff) AM_READ(sprite_shared_r)
-    AM_RANGE(0xd000, 0xd7ff) AM_READ(video_shared_r)
-    AM_RANGE(0xe000, 0xe000) AM_READ_PORT("DSW1")
-    AM_RANGE(0xe001, 0xe001) AM_READ_PORT("DSW2")
-    AM_RANGE(0xe002, 0xe002) AM_READ_PORT("P1")
-    AM_RANGE(0xe003, 0xe003) AM_READ_PORT("P2")
-    AM_RANGE(0xe004, 0xe004) AM_READ_PORT("SYSTEM")
-    AM_RANGE(0xe005, 0xe005) AM_READ_PORT("EXTRA")
-    AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM) /* ???? */
+static ADDRESS_MAP_START( ringking_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc3ff) AM_RAM /* work ram */
+	AM_RANGE(0xc800, 0xcfff) AM_RAM AM_SHARE(2) /* shared with sprite cpu */
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_SHARE(1) /* shared with video cpu */
+	AM_RANGE(0xd800, 0xd800) AM_WRITE(kingofb_f800_w)
+	AM_RANGE(0xd801, 0xd801) AM_WRITE(sprite_interrupt_w)
+	AM_RANGE(0xd802, 0xd802) AM_WRITE(video_interrupt_w)
+	AM_RANGE(0xd803, 0xd803) AM_WRITE(sound_command_w)
+	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("DSW1")
+	AM_RANGE(0xe001, 0xe001) AM_READ_PORT("DSW2")
+	AM_RANGE(0xe002, 0xe002) AM_READ_PORT("P1")
+	AM_RANGE(0xe003, 0xe003) AM_READ_PORT("P2")
+	AM_RANGE(0xe004, 0xe004) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xe005, 0xe005) AM_READ_PORT("EXTRA")
+	AM_RANGE(0xe800, 0xe800) AM_WRITEONLY AM_BASE(&kingofb_scroll_y)
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM /* ???? */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( rk_main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0xc000, 0xc3ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xc800, 0xcfff) AM_WRITE(sprite_shared_w)
-    AM_RANGE(0xd000, 0xd7ff) AM_WRITE(video_shared_w)
-    AM_RANGE(0xd800, 0xd800) AM_WRITE(kingofb_f800_w)
-    AM_RANGE(0xd801, 0xd801) AM_WRITE(sprite_interrupt_w)
-    AM_RANGE(0xd802, 0xd802) AM_WRITE(video_interrupt_w)
-    AM_RANGE(0xd803, 0xd803) AM_WRITE(sound_command_w)
-    AM_RANGE(0xe800, 0xe800) AM_WRITE(SMH_RAM) AM_BASE(&kingofb_scroll_y)
-    AM_RANGE(0xf000, 0xf7ff) AM_WRITE(SMH_RAM) /* ???? */
+static ADDRESS_MAP_START( ringking_video_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM /* work ram */
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_SHARE(1) /* shared with main */
+	AM_RANGE(0xa800, 0xa8ff) AM_RAM_WRITE(kingofb_videoram_w) AM_BASE(&videoram) /* background vram */
+	AM_RANGE(0xac00, 0xacff) AM_RAM_WRITE(kingofb_colorram_w) AM_BASE(&colorram) /* background colorram */
+	AM_RANGE(0xa000, 0xa3ff) AM_RAM_WRITE(kingofb_videoram2_w) AM_BASE(&kingofb_videoram2) /* foreground vram */
+	AM_RANGE(0xa400, 0xa7ff) AM_RAM_WRITE(kingofb_colorram2_w) AM_BASE(&kingofb_colorram2) /* foreground colorram */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( rk_video_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xc000, 0xc7ff) AM_READ(video_shared_r) /* shared with main */
-    AM_RANGE(0xa800, 0xa8ff) AM_READ(SMH_RAM) /* background vram */
-    AM_RANGE(0xac00, 0xacff) AM_READ(SMH_RAM) /* background colorram */
-    AM_RANGE(0xa000, 0xa3ff) AM_READ(SMH_RAM) /* foreground vram */
-    AM_RANGE(0xa400, 0xa7ff) AM_READ(SMH_RAM) /* foreground colorram */
+static ADDRESS_MAP_START( ringking_sprite_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM /* work ram */
+	AM_RANGE(0xc800, 0xcfff) AM_RAM AM_SHARE(2) /* shared with main */
+	AM_RANGE(0xa000, 0xa3ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size) /* sprite ram */
+	AM_RANGE(0xa400, 0xa43f) AM_RAM /* something related to scroll? */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( rk_video_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x3fff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xc000, 0xc7ff) AM_WRITE(video_shared_w) AM_BASE(&video_shared) /* shared with main */
-    AM_RANGE(0xa800, 0xa8ff) AM_WRITE(kingofb_videoram_w) AM_BASE(&videoram) /* background vram */
-    AM_RANGE(0xac00, 0xacff) AM_WRITE(kingofb_colorram_w) AM_BASE(&colorram) /* background colorram */
-    AM_RANGE(0xa000, 0xa3ff) AM_WRITE(kingofb_videoram2_w) AM_BASE(&kingofb_videoram2) /* foreground vram */
-    AM_RANGE(0xa400, 0xa7ff) AM_WRITE(kingofb_colorram2_w) AM_BASE(&kingofb_colorram2) /* foreground colorram */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( rk_sprite_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM) /* work ram */
-    AM_RANGE(0xc800, 0xcfff) AM_READ(sprite_shared_r) /* shared with main */
-    AM_RANGE(0xa000, 0xa3ff) AM_READ(SMH_RAM) /* sprite ram */
-    AM_RANGE(0xa400, 0xa43f) AM_READ(SMH_RAM) /* something related to scroll? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( rk_sprite_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-    AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_ROM)
-    AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM) /* work ram */
-    AM_RANGE(0xc800, 0xcfff) AM_WRITE(sprite_shared_w) AM_BASE(&sprite_shared) /* shared with main */
-    AM_RANGE(0xa000, 0xa3ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size) /* sprite ram */
-    AM_RANGE(0xa400, 0xa43f) AM_WRITE(SMH_RAM)  /* something related to scroll? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( rk_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( ringking_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_WRITE(dac_0_data_w)
-	AM_RANGE(0x02, 0x02) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x00, 0x00) AM_DEVWRITE("dac", dac_w)
+	AM_RANGE(0x02, 0x02) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x02, 0x03) AM_DEVWRITE("ay", ay8910_data_address_w)
 ADDRESS_MAP_END
 
 
@@ -531,10 +460,11 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	soundlatch_r
+	DEVCB_MEMORY_HANDLER("audiocpu", PROGRAM, soundlatch_r)
 };
 
-static INTERRUPT_GEN( kingofb_interrupt ) {
+static INTERRUPT_GEN( kingofb_interrupt )
+{
 
 	if ( kingofb_nmi_enable )
 		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
@@ -543,27 +473,27 @@ static INTERRUPT_GEN( kingofb_interrupt ) {
 static MACHINE_DRIVER_START( kingofb )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(main_readmem,main_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_ADD("maincpu", Z80, 4000000)        /* 4.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kingobox_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
 	MDRV_CPU_ADD("video", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(video_readmem,video_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_PROGRAM_MAP(kingobox_video_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
 	MDRV_CPU_ADD("sprite", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(sprite_readmem,sprite_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_PROGRAM_MAP(kingobox_sprite_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
-	MDRV_CPU_ADD("audio", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_IO_MAP(sound_io_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 4000000)        /* 4.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kingobox_sound_map)
+	MDRV_CPU_IO_MAP(ringking_sound_io_map)
 	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 6000)	/* Hz */
 
 	MDRV_QUANTUM_TIME(HZ(6000)) /* We really need heavy synching among the processors */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -593,27 +523,27 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( ringking )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(rk_main_readmem,rk_main_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_ADD("maincpu", Z80, 4000000)        /* 4.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(ringking_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
 	MDRV_CPU_ADD("video", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(rk_video_readmem,rk_video_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_PROGRAM_MAP(ringking_video_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
 	MDRV_CPU_ADD("sprite", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(rk_sprite_readmem,rk_sprite_writemem)
-	MDRV_CPU_VBLANK_INT("main", kingofb_interrupt)
+	MDRV_CPU_PROGRAM_MAP(ringking_sprite_map)
+	MDRV_CPU_VBLANK_INT("screen", kingofb_interrupt)
 
-	MDRV_CPU_ADD("audio", Z80, 4000000)        /* 4.0 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_IO_MAP(rk_sound_io_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 4000000)        /* 4.0 MHz */
+	MDRV_CPU_PROGRAM_MAP(kingobox_sound_map)
+	MDRV_CPU_IO_MAP(ringking_sound_io_map)
 	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 6000)	/* Hz */
 
 	MDRV_QUANTUM_TIME(HZ(6000)) /* We really need heavy synching among the processors */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -646,7 +576,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( kingofb )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "d09_22.bin",   0x00000, 0x4000, CRC(6220bfa2) SHA1(cb329406ed07b71f9d2c40fc6c2c196daaa56fc8) )
 	ROM_LOAD( "e09_23.bin",   0x04000, 0x4000, CRC(5782fdd8) SHA1(6c8c1114ce7863f9e8331796e2c5fb4928904b55) )
 
@@ -656,7 +586,7 @@ ROM_START( kingofb )
 	ROM_REGION( 0x10000, "sprite", 0 )     /* 64k for the sprite cpu */
 	ROM_LOAD( "j09_dcr.bin",  0x00000, 0x2000, CRC(379f4f84) SHA1(c8171e15fe243857b6ca8f32c1cc09f12fa4c07c) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "f05_18.bin",   0x00000, 0x4000, CRC(c057e28e) SHA1(714d8f14d55a070efcf205f8946269181bf2198b) )
 	ROM_LOAD( "h05_19.bin",   0x04000, 0x4000, CRC(060253dd) SHA1(9a24fc6aca64262e935971f96b3a103df9711f20) )
 	ROM_LOAD( "j05_20.bin",   0x08000, 0x4000, CRC(64c137a4) SHA1(e38adeb19e24357cc5581f0a3097c1d24914e25c) )
@@ -692,7 +622,7 @@ ROM_END
 
 /* Ring King */
 ROM_START( ringking )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "cx13.9f",      0x00000, 0x8000, CRC(93e38c02) SHA1(8f96f16f2904ef83101448fdf201b98b8e75e1d6) )
 	ROM_LOAD( "cx14.11f",     0x08000, 0x4000, CRC(a435acb0) SHA1(2c9d4e8471d87ce148f9c2180769350401914fc0) )
 
@@ -702,7 +632,7 @@ ROM_START( ringking )
 	ROM_REGION( 0x10000, "sprite", 0 )     /* 64k for the sprite cpu */
 	ROM_LOAD( "cx00.4c",      0x00000, 0x2000, CRC(880b8aa7) SHA1(e5ee80cac85a62ae5a677115a74c08e433cd4fc9) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "cx12.4ef",     0x00000, 0x8000, CRC(1d5d6c6b) SHA1(ea771f3e25850319f2fecfc91400fc1b9df606ef) )
 	ROM_LOAD( "j05_20.bin",   0x08000, 0x4000, CRC(64c137a4) SHA1(e38adeb19e24357cc5581f0a3097c1d24914e25c) )
 
@@ -729,7 +659,7 @@ ROM_START( ringking )
 ROM_END
 
 ROM_START( ringkin2 )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "rkngm1.bin",   0x00000, 0x8000, CRC(086921ea) SHA1(c5a594be0738a80c5f912dc819332ff61aa6fc4b) )
 	ROM_LOAD( "rkngm2.bin",   0x08000, 0x4000, CRC(c0b636a4) SHA1(c3640a5597242e735673e1dbf8bf866e9122a20f) )
 
@@ -739,7 +669,7 @@ ROM_START( ringkin2 )
 	ROM_REGION( 0x10000, "sprite", 0 )     /* 64k for the sprite cpu */
 	ROM_LOAD( "cx00.4c",      0x00000, 0x2000, CRC(880b8aa7) SHA1(e5ee80cac85a62ae5a677115a74c08e433cd4fc9) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "cx12.4ef",     0x00000, 0x8000, CRC(1d5d6c6b) SHA1(ea771f3e25850319f2fecfc91400fc1b9df606ef) )
 	ROM_LOAD( "j05_20.bin",   0x08000, 0x4000, CRC(64c137a4) SHA1(e38adeb19e24357cc5581f0a3097c1d24914e25c) )
 
@@ -766,7 +696,7 @@ ROM_START( ringkin2 )
 ROM_END
 
 ROM_START( ringkin3 )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "14.9d",        0x00000, 0x4000, CRC(63627b8b) SHA1(eea736c8eec59fa561b9d1b5aa43df5410d8dde7) )
 	ROM_LOAD( "15.9e",        0x04000, 0x4000, CRC(e7557489) SHA1(49dce8f6ce26283fbdca17d75699de4d636a900a) )
 	ROM_LOAD( "16.9f",        0x08000, 0x4000, CRC(a3b3bb16) SHA1(4b4cb95a6bf4608ada1669208d9cabc3f856585a) )
@@ -777,7 +707,7 @@ ROM_START( ringkin3 )
 	ROM_REGION( 0x10000, "sprite", 0 )     /* 64k for the sprite cpu */
 	ROM_LOAD( "j09_dcr.bin",  0x00000, 0x2000, CRC(379f4f84) SHA1(c8171e15fe243857b6ca8f32c1cc09f12fa4c07c) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "f05_18.bin",   0x00000, 0x4000, CRC(c057e28e) SHA1(714d8f14d55a070efcf205f8946269181bf2198b) )
 	ROM_LOAD( "h05_19.bin",   0x04000, 0x4000, CRC(060253dd) SHA1(9a24fc6aca64262e935971f96b3a103df9711f20) )
 	ROM_LOAD( "j05_20.bin",   0x08000, 0x4000, CRC(64c137a4) SHA1(e38adeb19e24357cc5581f0a3097c1d24914e25c) )
@@ -808,7 +738,7 @@ ROM_START( ringkin3 )
 ROM_END
 
 ROM_START( ringkinw )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "15.9d",        0x00000, 0x4000, CRC(8263f517) SHA1(942012bfcc98dd2cd0437e015a164933c99d0f36) )
 	ROM_LOAD( "16.9e",        0x04000, 0x4000, CRC(daadd700) SHA1(2405e954a28d18ae8c30955d0ad7c25c9abb2bd3) )
 
@@ -818,7 +748,7 @@ ROM_START( ringkinw )
 	ROM_REGION( 0x10000, "sprite", 0 )     /* 64k for the sprite cpu */
 	ROM_LOAD( "17.xx",        0x00000, 0x2000, CRC(379f4f84) SHA1(c8171e15fe243857b6ca8f32c1cc09f12fa4c07c) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "18.4f",        0x00000, 0x4000, CRC(c057e28e) SHA1(714d8f14d55a070efcf205f8946269181bf2198b) )
 	ROM_LOAD( "19.4h",        0x04000, 0x4000, CRC(060253dd) SHA1(9a24fc6aca64262e935971f96b3a103df9711f20) )
 	ROM_LOAD( "20.4j",        0x08000, 0x4000, CRC(64c137a4) SHA1(e38adeb19e24357cc5581f0a3097c1d24914e25c) )
@@ -889,4 +819,3 @@ GAME( 1985, ringking, kingofb, ringking, ringking, 0,        ROT90, "Data East U
 GAME( 1985, ringkin2, kingofb, ringking, ringking, 0,        ROT90, "Data East USA", "Ring King (US set 2)", 0 )
 GAME( 1985, ringkin3, kingofb, kingofb,  kingofb,  ringkin3, ROT90, "Data East USA", "Ring King (US set 3)", 0 )
 GAME( 1985, ringkinw, kingofb, kingofb,  kingofb,  ringkinw, ROT90, "Woodplace", "Ring King (US, Woodplace license)", 0 )
-
