@@ -67,7 +67,7 @@ static WRITE32_HANDLER( soundr3k_w )
 		sndto000[ ( offset << 1 ) + 1 ] = data >> 16;
 		if( offset == 3 )
 		{
-			cpu_set_input_line(space->machine->cpu[1], 1, HOLD_LINE );
+			cputag_set_input_line(space->machine, "soundcpu", 1, HOLD_LINE );
 		}
 	}
 	if( ACCESSING_BITS_0_15 )
@@ -141,7 +141,7 @@ static WRITE32_HANDLER( eeprom_w )
 	eeprom_write_bit( ( data & 0x01 ) ? 1 : 0 );
 	eeprom_set_clock_line( ( data & 0x04 ) ? ASSERT_LINE : CLEAR_LINE );
 	eeprom_set_cs_line( ( data & 0x02 ) ? CLEAR_LINE : ASSERT_LINE );
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ( data & 0x40 ) ? CLEAR_LINE : ASSERT_LINE );
+	cputag_set_input_line(space->machine, "soundcpu", INPUT_LINE_RESET, ( data & 0x40 ) ? CLEAR_LINE : ASSERT_LINE );
 }
 
 /* PCM RAM */
@@ -220,11 +220,11 @@ static READ16_HANDLER( dual539_r )
 	data = 0;
 	if( ACCESSING_BITS_0_7 )
 	{
-		data |= k054539_1_r( space, offset );
+		data |= k054539_r( devtag_get_device(space->machine, "konami2"), offset );
 	}
 	if( ACCESSING_BITS_8_15 )
 	{
-		data |= k054539_0_r( space, offset ) << 8;
+		data |= k054539_r( devtag_get_device(space->machine, "konami1"), offset ) << 8;
 	}
 	return data;
 }
@@ -233,11 +233,11 @@ static WRITE16_HANDLER( dual539_w )
 {
 	if( ACCESSING_BITS_0_7 )
 	{
-		k054539_1_w( space, offset, data );
+		k054539_w( devtag_get_device(space->machine, "konami2"), offset, data );
 	}
 	if( ACCESSING_BITS_8_15 )
 	{
-		k054539_0_w( space, offset, data >> 8 );
+		k054539_w( devtag_get_device(space->machine, "konami1"), offset, data >> 8 );
 	}
 }
 
@@ -251,24 +251,36 @@ static WRITE16_HANDLER( sndcomm68k_w )
 	sndtor3k[ offset ] = data;
 }
 
+static READ16_HANDLER(tms57002_data_word_r)
+{
+	return 0;
+}
+
+static WRITE16_HANDLER(tms57002_data_word_w)
+{
+}
+
+static READ16_HANDLER(tms57002_status_word_r)
+{
+	return 0;
+}
+
+static WRITE16_HANDLER(tms57002_control_word_w)
+{
+}
+
 /* 68000 memory handling */
-static ADDRESS_MAP_START( sndreadmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(SMH_RAM)
-	AM_RANGE(0x200000, 0x2004ff) AM_READ(dual539_r)
-	AM_RANGE(0x300000, 0x300001) AM_READ(tms57002_data_word_r)
+static ADDRESS_MAP_START( konamigq_sound_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_ROM
+	AM_RANGE(0x100000, 0x10ffff) AM_RAM
+	AM_RANGE(0x200000, 0x2004ff) AM_READWRITE(dual539_r,dual539_w)
+	AM_RANGE(0x300000, 0x300001) AM_READWRITE(tms57002_data_word_r,tms57002_data_word_w)
+	AM_RANGE(0x400000, 0x40000f) AM_WRITE(sndcomm68k_w)
 	AM_RANGE(0x400010, 0x40001f) AM_READ(sndcomm68k_r)
-	AM_RANGE(0x500000, 0x500001) AM_READ(tms57002_status_word_r)
+	AM_RANGE(0x500000, 0x500001) AM_READWRITE(tms57002_status_word_r,tms57002_control_word_w)
+	AM_RANGE(0x580000, 0x580001) AM_WRITENOP /* ?? */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sndwritemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x200000, 0x2004ff) AM_WRITE(dual539_w)
-	AM_RANGE(0x300000, 0x300001) AM_WRITE(tms57002_data_word_w)
-	AM_RANGE(0x400000, 0x40000f) AM_WRITE(sndcomm68k_w)
-	AM_RANGE(0x500000, 0x500001) AM_WRITE(tms57002_control_word_w)
-	AM_RANGE(0x580000, 0x580001) AM_WRITE(SMH_NOP) /* ?? */
-ADDRESS_MAP_END
 
 static const k054539_interface k054539_config =
 {
@@ -364,17 +376,16 @@ static MACHINE_START( konamigq )
 static MACHINE_RESET( konamigq )
 {
 	psx_machine_init(machine);
-	tms57002_init();
 }
 
 static MACHINE_DRIVER_START( konamigq )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main",  PSXCPU, XTAL_67_7376MHz )
-	MDRV_CPU_PROGRAM_MAP( konamigq_map, 0 )
-	MDRV_CPU_VBLANK_INT("main", psx_vblank)
+	MDRV_CPU_ADD("maincpu",  PSXCPU, XTAL_67_7376MHz )
+	MDRV_CPU_PROGRAM_MAP( konamigq_map)
+	MDRV_CPU_VBLANK_INT("screen", psx_vblank)
 
-	MDRV_CPU_ADD( "sound", M68000, 8000000 )
-	MDRV_CPU_PROGRAM_MAP( sndreadmem, sndwritemem )
+	MDRV_CPU_ADD( "soundcpu", M68000, 8000000 )
+	MDRV_CPU_PROGRAM_MAP( konamigq_sound_map)
 	MDRV_CPU_PERIODIC_INT( irq2_line_hold, 480 )
 
 	MDRV_MACHINE_START( konamigq )
@@ -382,7 +393,7 @@ static MACHINE_DRIVER_START( konamigq )
 	MDRV_NVRAM_HANDLER( konamigq_93C46 )
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE( 60 )
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC( 0 ))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -396,17 +407,17 @@ static MACHINE_DRIVER_START( konamigq )
 	MDRV_VIDEO_UPDATE( psx )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("konami1", K054539, 48000)
 	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
 
 	MDRV_SOUND_ADD("konami2", K054539, 48000)
 	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
 MACHINE_DRIVER_END
 
 static INPUT_PORTS_START( konamigq )
@@ -489,7 +500,7 @@ static INPUT_PORTS_START( konamigq )
 INPUT_PORTS_END
 
 ROM_START( cryptklr )
-	ROM_REGION( 0x80000, "sound", 0 ) /* 68000 sound program */
+	ROM_REGION( 0x80000, "soundcpu", 0 ) /* 68000 sound program */
 	ROM_LOAD16_WORD_SWAP( "420a01.2g", 0x000000, 0x080000, CRC(84fc2613) SHA1(e06f4284614d33c76529eb43b168d095200a9eac) )
 
 	ROM_REGION( 0x400000, "shared", 0 )
@@ -499,7 +510,7 @@ ROM_START( cryptklr )
 	ROM_LOAD( "420b03.27p",   0x0000000, 0x080000, CRC(aab391b1) SHA1(bf9dc7c0c8168c22a4be266fe6a66d3738df916b) )
 
 	DISK_REGION( "disk" )
-	DISK_IMAGE( "420uaa04", 0, MD5(179464886f58a2e14b284e3813227a86) SHA1(18fe867c44982bacf0d3ff8453487cd06425a6b7) )
+	DISK_IMAGE( "420uaa04", 0, SHA1(67cb1418fc0de2a89fc61847dc9efb9f1bebb347) )
 ROM_END
 
 GAME( 1995, cryptklr, 0, konamigq, konamigq, konamigq, ROT0, "Konami", "Crypt Killer (GQ420 UAA)", GAME_IMPERFECT_GRAPHICS )
