@@ -318,7 +318,7 @@ static WRITE64_HANDLER(unk4_w)
 		if (data & 0x800000)
 		{
 			mame_printf_debug("CPU '%s': CPU1 IRQ at %08X\n", space->cpu->tag, cpu_get_pc(space->cpu));
-			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ0, ASSERT_LINE);
+			cputag_set_input_line(space->machine, "sub", INPUT_LINE_IRQ0, ASSERT_LINE);
 		}
 
 		unk20004 = (UINT32)(data);
@@ -413,7 +413,7 @@ static WRITE64_HANDLER(reset_w)
 	{
 		if (data & U64(0x100000000))
 		{
-			cpu_set_input_line(space->machine->cpu[0], INPUT_LINE_RESET, PULSE_LINE);
+			cputag_set_input_line(space->machine, "maincpu", INPUT_LINE_RESET, PULSE_LINE);
 			unk3 = 0;
 		}
 	}
@@ -789,18 +789,18 @@ static void cde_handle_reports(void)
 static void cde_dma_transfer(const address_space *space, int channel, int next)
 {
 	UINT32 address;
-	int length;
+	//int length;
 	int i;
 
 	if (next)
 	{
 		address = cde_dma[channel].next_dst_addr;
-		length = cde_dma[channel].next_length;
+		//length = cde_dma[channel].next_length;
 	}
 	else
 	{
 		address = cde_dma[channel].dst_addr;
-		length = cde_dma[channel].length;
+		//length = cde_dma[channel].length;
 	}
 
 	for (i=0; i < cde_dma[channel].next_length; i++)
@@ -1075,7 +1075,7 @@ static READ64_HANDLER(cpu_r)
 
 	if (ACCESSING_BITS_32_63)
 	{
-		r = (UINT64)((space->cpu != space->machine->cpu[0]) ? 0x80000000 : 0);
+		r = (UINT64)((space->cpu != cputag_get_cpu(space->machine, "maincpu")) ? 0x80000000 : 0);
 		//r |= 0x40000000;  // sets Video-LowRes !?
 		return r << 32;
 	}
@@ -1103,7 +1103,7 @@ static ADDRESS_MAP_START( m2_main, ADDRESS_SPACE_PROGRAM, 64 )
 	AM_RANGE(0x10000008, 0x10001007) AM_NOP		// ???
 	AM_RANGE(0x20000000, 0x201fffff) AM_ROM AM_SHARE(2)
 	AM_RANGE(0x40000000, 0x407fffff) AM_RAM AM_SHARE(3) AM_BASE(&main_ram)
-	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION("user1", 0) AM_SHARE(2)
+	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION("boot", 0) AM_SHARE(2)
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( m2 )
@@ -1133,17 +1133,17 @@ static INTERRUPT_GEN(m2)
 static MACHINE_DRIVER_START( m2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", PPC602, 33000000)	/* actually PPC602, 66MHz */
+	MDRV_CPU_ADD("maincpu", PPC602, 33000000)	/* actually PPC602, 66MHz */
 	MDRV_CPU_CONFIG(ppc602_config)
-	MDRV_CPU_PROGRAM_MAP(m2_main, 0)
-	MDRV_CPU_VBLANK_INT("main", m2)
+	MDRV_CPU_PROGRAM_MAP(m2_main)
+	MDRV_CPU_VBLANK_INT("screen", m2)
 
 	MDRV_CPU_ADD("sub", PPC602, 33000000)	/* actually PPC602, 66MHz */
 	MDRV_CPU_CONFIG(ppc602_config)
-	MDRV_CPU_PROGRAM_MAP(m2_main, 0)
+	MDRV_CPU_PROGRAM_MAP(m2_main)
 
  	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -1159,64 +1159,72 @@ static MACHINE_DRIVER_START( m2 )
 MACHINE_DRIVER_END
 
 
-ROM_START(polystar)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("623b01.8q", 0x000000, 0x200000, CRC(bd879f93) SHA1(e2d63bfbd2b15260a2664082652442eadea3eab6))
+ROM_START( polystar )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "623b01.8q", 0x000000, 0x200000, CRC(bd879f93) SHA1(e2d63bfbd2b15260a2664082652442eadea3eab6) )
 
-	ROM_REGION( 0x80, "user2", 0 ) /* serial eeprom */
+	ROM_REGION( 0x80, "eeprom", 0 )
 	ROM_LOAD( "93c46.7k",  0x000000, 0x000080, CRC(66d02984) SHA1(d07c57d198c611b6ff67a783c20a3d038ba34cd1) )
 
-	DISK_REGION( "cdrom" )
-	DISK_IMAGE( "623jaa02", 0, MD5(6071c1b70c190fa7c50676eb5308e024) SHA1(a7dc6086d0244b5472f61b41992623c7a9dc2e9c))
+	DISK_REGION( "cdrom" ) // TODO: Add correct CHD
+	DISK_IMAGE( "623jaa02", 0, BAD_DUMP SHA1(cd542931cdac95d05344d34421e223dd6e371bb5) )
 ROM_END
 
-ROM_START(btltryst)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
+ROM_START( btltryst )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
 
 	DISK_REGION( "cdrom" )
-	DISK_IMAGE( "btltryst", 0, MD5(4286d25a896d1450705f742cccd26ef2) SHA1(becc606b8480f6a09365b611565d83cfdc82b0b3))
+	DISK_IMAGE( "btltryst", 0, SHA1(c76326b0a0fcfe696a2ca019170d3abde40e773e) )
 ROM_END
 
-ROM_START(heatof11)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
+ROM_START( heatof11 )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )	/* boot rom */
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
 
-	ROM_REGION( 0x2000, "user2", 0 ) /* timekeeper eeprom */
+	ROM_REGION( 0x2000, "timekeep", 0 ) /* timekeeper SRAM */
 	ROM_LOAD( "dallas.5e",  0x000000, 0x002000, CRC(8611ff09) SHA1(6410236947d99c552c4a1f7dd5fd8c7a5ae4cba1) )
 
 	DISK_REGION( "cdrom" )
-	DISK_IMAGE( "heatof11", 0, MD5(1eef9f191439f13d1a867629226b0230) SHA1(87599d03aecadf5d119d05173bdef2940bcce515))
+	DISK_IMAGE( "heatof11", 0, SHA1(5a0a2782cd8676d3f6dfad4e0f805b309e230d8b) )
 ROM_END
 
-ROM_START(evilngt)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
+ROM_START( evilngt )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
 
-	ROM_REGION( 0x1000, "user2", 0 ) /* timekeeper eeprom */
-	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
-ROM_END
-
-ROM_START(hellngt)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
-
-	ROM_REGION( 0x1000, "user2", 0 ) /* timekeeper eeprom */
+	ROM_REGION( 0x1000, "timekeep", 0 ) /* timekeeper SRAM */
 	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
 
-	DISK_REGION( "cdrom" )
-	DISK_IMAGE( "810eaa02", 0, MD5(250a1b9cc2a25aed6c27321dd8f4f8a2) SHA1(d2f48a389f8091e03ada81c255231c7957d1aee3))
+	ROM_REGION( 0x400000, "ymz", 0 ) /* YMZ280B sound rom on sub board */
+	ROM_LOAD( "810a03.16h",  0x000000, 0x400000, CRC(4cd79d98) SHA1(12fea41cfc5c1b883ffbeda7e428dd1d1bf54d7f) )
+
+	// TODO: Add CHD
 ROM_END
 
-ROM_START(totlvice)
-	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
-	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
+ROM_START( hellngt )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
 
-	ROM_REGION( 0x100000, "user2", 0 ) /* sound rom on sub board */
+	ROM_REGION( 0x1000, "timekeep", 0 ) /* timekeeper SRAM */
+	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
+
+	ROM_REGION( 0x400000, "ymz", 0 ) /* YMZ280B sound rom on sub board. NOTE: May not be the same as evilngt! */
+	ROM_LOAD( "810a03.16h",  0x000000, 0x400000, CRC(4cd79d98) SHA1(12fea41cfc5c1b883ffbeda7e428dd1d1bf54d7f) )
+
+	DISK_REGION( "cdrom" ) // TODO: Add correct CHD
+	DISK_IMAGE( "810eaa02", 0, BAD_DUMP SHA1(c407bad498cb87788ce332dbef5e8c6e19c1fd16) )
+ROM_END
+
+ROM_START( totlvice )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
+
+	ROM_REGION( 0x100000, "ymz", 0 ) /* YMZ280B sound rom on sub board */
 	ROM_LOAD( "639jaa02.bin",  0x000000, 0x100000, CRC(c6163818) SHA1(b6f8f2d808b98610becc0a5be5443ece3908df0b) )
 
-	DISK_REGION( "cdrom" )
-	DISK_IMAGE( "639jad01", 0, MD5(bc3156be374e7a99040763bf0cea7ad3) SHA1(c4503d9954c72dd8f70521f313f0338528116c26))
+	DISK_REGION( "cdrom" ) // TODO: Add correct CHD
+	DISK_IMAGE( "639jad01", 0, BAD_DUMP SHA1(39d41d5a9d1c40636d174c8bb8172b1121e313f8) )
 ROM_END
 
 static DRIVER_INIT( m2 )
