@@ -86,7 +86,7 @@ static WRITE8_HANDLER( bank_select_w )
         xxxxxxx  - unused ?
 
     */
-	memory_set_bankptr(space->machine,  1, memory_region(space->machine, "main") + ((data&1) * 0x4000) + 0x10000 );
+	memory_set_bankptr(space->machine,  1, memory_region(space->machine, "maincpu") + ((data&1) * 0x4000) + 0x10000 );
 }
 
 static WRITE8_HANDLER( latch_w )
@@ -107,17 +107,17 @@ static WRITE8_HANDLER(tomaincpu_w)
 
 static ADDRESS_MAP_START( maincpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(SMH_BANK1, SMH_NOP)
+	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(SMH_BANK(1), SMH_NOP)
 	AM_RANGE(0x8000, 0x9fff) AM_ROM
 	AM_RANGE(0xa000, 0xa7ff) AM_RAM
 	AM_RANGE(0xa800, 0xa800) AM_READ_PORT("P1")
 	AM_RANGE(0xa801, 0xa801) AM_READ_PORT("P2")
 	AM_RANGE(0xa802, 0xa802) AM_READ_PORT("DSW")
-	AM_RANGE(0xa803, 0xa803) AM_READ(SMH_NOP) /* watchdog ? */
+	AM_RANGE(0xa803, 0xa803) AM_READNOP /* watchdog ? */
 	AM_RANGE(0xa804, 0xa804) AM_WRITE(ksayakyu_videoctrl_w)
 	AM_RANGE(0xa805, 0xa805) AM_WRITE(latch_w)
 	AM_RANGE(0xa806, 0xa806) AM_READ(sound_status_r)
-	AM_RANGE(0xa807, 0xa807) AM_READ(SMH_NOP) /* watchdog ? */
+	AM_RANGE(0xa807, 0xa807) AM_READNOP /* watchdog ? */
 	AM_RANGE(0xa808, 0xa808) AM_WRITE(bank_select_w)
 	AM_RANGE(0xb000, 0xb7ff) AM_RAM_WRITE(ksayakyu_videoram_w) AM_BASE(&videoram)
 	AM_RANGE(0xb800, 0xbfff) AM_RAM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
@@ -126,14 +126,12 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( soundcpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x83ff) AM_RAM
-	AM_RANGE(0xa001, 0xa001) AM_READ(ay8910_read_port_0_r)
-	AM_RANGE(0xa002, 0xa002) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0xa003, 0xa003) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0xa006, 0xa006) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0xa007, 0xa007) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0xa008, 0xa008) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa001, 0xa001) AM_DEVREAD("ay1", ay8910_r)
+	AM_RANGE(0xa002, 0xa003) AM_DEVWRITE("ay1", ay8910_data_address_w)
+	AM_RANGE(0xa006, 0xa006) AM_DEVWRITE("ay2", ay8910_data_address_w)
+	AM_RANGE(0xa008, 0xa008) AM_WRITENOP
 	AM_RANGE(0xa00c, 0xa00c) AM_WRITE(tomaincpu_w)
-	AM_RANGE(0xa010, 0xa010) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa010, 0xa010) AM_WRITENOP
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( ksayakyu )
@@ -174,7 +172,7 @@ static INPUT_PORTS_START( ksayakyu )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 INPUT_PORTS_END
 
-static WRITE8_HANDLER(dummy_w)
+static WRITE8_DEVICE_HANDLER(dummy_w)
 {
 	//DAC ? communication with main cpu ?
 }
@@ -183,20 +181,20 @@ static const ay8910_interface ay8910_interface_1 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	soundlatch_r,
-	NULL,
-	NULL,
-	dummy_w
+	DEVCB_MEMORY_HANDLER("audiocpu", PROGRAM, soundlatch_r),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_HANDLER(dummy_w)
 };
 
 static const ay8910_interface ay8910_interface_2 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	NULL,
-	NULL,
-	dummy_w,
-	dummy_w
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_HANDLER(dummy_w),
+	DEVCB_HANDLER(dummy_w)
 };
 
 static const gfx_layout charlayout =
@@ -242,18 +240,18 @@ static GFXDECODE_START( ksayakyu )
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( ksayakyu )
-	MDRV_CPU_ADD("main", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(maincpu_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(maincpu_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80, 80000000/2)
-	MDRV_CPU_PROGRAM_MAP(soundcpu_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, 80000000/2)
+	MDRV_CPU_PROGRAM_MAP(soundcpu_map)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -283,7 +281,7 @@ static MACHINE_DRIVER_START( ksayakyu )
 MACHINE_DRIVER_END
 
 ROM_START( ksayakyu )
-	ROM_REGION( 0x20000, "main", 0 )
+	ROM_REGION( 0x20000, "maincpu", 0 )
 
 	ROM_LOAD( "1.3a", 0x00000, 0x4000, CRC(6607976d) SHA1(23b15cae04922e54faf35a5a499ba5064b18ed46) )
 	ROM_LOAD( "2.3b", 0x04000, 0x4000, CRC(a289de5c) SHA1(d3b14364ef77ca74ac79c5099cf0e8f3baa97612) )
@@ -291,7 +289,7 @@ ROM_START( ksayakyu )
 	ROM_LOAD( "4.3d", 0x08000, 0x2000, CRC(db0ca023) SHA1(1356fa0239209dea6a4ac0af177fe8be47f12cd0) )
 	ROM_LOAD( "3.3c", 0x14000, 0x4000, CRC(bb4104a5) SHA1(1f793c4431a3476eeb92556228bf855efb73fb83) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "8.5l",  0x0000, 0x2000, CRC(3fbae535) SHA1(87b66091e33eee66f4d63c213a5a19b70e7b1e5a) )
 	ROM_LOAD( "7.5j",  0x2000, 0x2000, CRC(ad242eda) SHA1(928c04e4a48077ec9db148cb71d52ebfe01efa53) )
 	ROM_LOAD( "6.5h",  0x4000, 0x2000, CRC(17986662) SHA1(81b65e381b923c5544f4708efef09f0894c716b2) )
