@@ -39,16 +39,16 @@ static UINT8 *shared_ram;
 
 MACHINE_RESET( kyugo )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	// must start with interrupts and sub CPU disabled
-	cpu_interrupt_enable(machine->cpu[0], 0);
+	cpu_interrupt_enable(cputag_get_cpu(machine, "maincpu"), 0);
 	kyugo_sub_cpu_control_w(space, 0, 0);
 }
 
 
 WRITE8_HANDLER( kyugo_sub_cpu_control_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, data ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, data ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -123,15 +123,13 @@ Sub_MemMap( flashgla, 0x7fff, 0xe000, 0xc040, 0xc080, 0xc0c0 )
  *
  *************************************/
 
-#define Sub_PortMap( name, ay0_base, ay1_base )								\
-static ADDRESS_MAP_START( name##_sub_portmap, ADDRESS_SPACE_IO, 8 )			\
-	ADDRESS_MAP_GLOBAL_MASK(0xff)										\
-	AM_RANGE(ay0_base+0, ay0_base+0) AM_WRITE(ay8910_control_port_0_w)		\
-	AM_RANGE(ay0_base+1, ay0_base+1) AM_WRITE(ay8910_write_port_0_w)		\
-	AM_RANGE(ay0_base+2, ay0_base+2) AM_READ(ay8910_read_port_0_r)			\
-	AM_RANGE(ay1_base+0, ay1_base+0) AM_WRITE(ay8910_control_port_1_w)		\
-	AM_RANGE(ay1_base+1, ay1_base+1) AM_WRITE(ay8910_write_port_1_w)		\
-ADDRESS_MAP_END																\
+#define Sub_PortMap( name, ay0_base, ay1_base )											\
+static ADDRESS_MAP_START( name##_sub_portmap, ADDRESS_SPACE_IO, 8 )						\
+	ADDRESS_MAP_GLOBAL_MASK(0xff)														\
+	AM_RANGE(ay0_base+0, ay0_base+1) AM_DEVWRITE("ay1", ay8910_address_data_w)	\
+	AM_RANGE(ay0_base+2, ay0_base+2) AM_DEVREAD("ay1", ay8910_r)					\
+	AM_RANGE(ay1_base+0, ay1_base+1) AM_DEVWRITE("ay2", ay8910_address_data_w)	\
+ADDRESS_MAP_END																			\
 
 Sub_PortMap( gyrodine, 0x00, 0xc0 )
 Sub_PortMap( sonofphx, 0x00, 0x40 )
@@ -447,10 +445,10 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	input_port_0_r,
-	input_port_1_r,
-	NULL,
-	NULL
+	DEVCB_INPUT_PORT("DSW1"),
+	DEVCB_INPUT_PORT("DSW2"),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 
@@ -463,14 +461,14 @@ static const ay8910_interface ay8910_config =
 static MACHINE_DRIVER_START( gyrodine )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, XTAL_18_432MHz/6)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_IO_MAP(gyrodine_portmap,0)
-	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
+	MDRV_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)	/* verified on pcb */
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_IO_MAP(gyrodine_portmap)
+	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
 	MDRV_CPU_ADD("sub", Z80, XTAL_18_432MHz/6)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(gyrodine_sub_map,0)
-	MDRV_CPU_IO_MAP(gyrodine_sub_portmap,0)
+	MDRV_CPU_PROGRAM_MAP(gyrodine_sub_map)
+	MDRV_CPU_IO_MAP(gyrodine_sub_portmap)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
 
 	MDRV_QUANTUM_TIME(HZ(6000))
@@ -478,7 +476,7 @@ static MACHINE_DRIVER_START( gyrodine )
 	MDRV_MACHINE_RESET(kyugo)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -508,40 +506,40 @@ static MACHINE_DRIVER_START( sonofphx )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(sonofphx_sub_map,0)
-	MDRV_CPU_IO_MAP(sonofphx_sub_portmap,0)
+	MDRV_CPU_PROGRAM_MAP(sonofphx_sub_map)
+	MDRV_CPU_IO_MAP(sonofphx_sub_portmap)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( srdmissn )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(srdmissn_portmap,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_IO_MAP(srdmissn_portmap)
 
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(srdmissn_sub_map,0)
-	MDRV_CPU_IO_MAP(srdmissn_sub_portmap,0)
+	MDRV_CPU_PROGRAM_MAP(srdmissn_sub_map)
+	MDRV_CPU_IO_MAP(srdmissn_sub_portmap)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( flashgal )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(sonofphx)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(flashgal_portmap,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_IO_MAP(flashgal_portmap)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( flashgla )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(flashgla_portmap,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_IO_MAP(flashgla_portmap)
 
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(flashgla_sub_map,0)
-	MDRV_CPU_IO_MAP(flashgla_sub_portmap,0)
+	MDRV_CPU_PROGRAM_MAP(flashgla_sub_map)
+	MDRV_CPU_IO_MAP(flashgla_sub_portmap)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( legend )
@@ -549,8 +547,8 @@ static MACHINE_DRIVER_START( legend )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(gyrodine)
 	MDRV_CPU_MODIFY("sub")
-	MDRV_CPU_PROGRAM_MAP(legend_sub_map,0)
-	MDRV_CPU_IO_MAP(srdmissn_sub_portmap,0)
+	MDRV_CPU_PROGRAM_MAP(legend_sub_map)
+	MDRV_CPU_IO_MAP(srdmissn_sub_portmap)
 MACHINE_DRIVER_END
 
 
@@ -561,7 +559,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( gyrodine )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "a21.02", 0x0000, 0x2000, CRC(c5ec4a50) SHA1(4d012aabdc248143a4d3bab190ecb6e335c93427) )
 	ROM_LOAD( "a21.03", 0x2000, 0x2000, CRC(4e9323bd) SHA1(86ae4c6a29898fdb0e559ec2aac99fc874910fea) )
 	ROM_LOAD( "a21.04", 0x4000, 0x2000, CRC(57e659d4) SHA1(4c0e73d0661360731691a32a6e94f41b69315f93) )
@@ -602,7 +600,7 @@ ROM_END
 
 
 ROM_START( gyrodinc )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "rom2",   0x0000, 0x2000, CRC(85ddea38) SHA1(fe7e8d7962850b17c39cac627994d78768b094f8) )
 	ROM_LOAD( "a21.03", 0x2000, 0x2000, CRC(4e9323bd) SHA1(86ae4c6a29898fdb0e559ec2aac99fc874910fea) )
 	ROM_LOAD( "a21.04", 0x4000, 0x2000, CRC(57e659d4) SHA1(4c0e73d0661360731691a32a6e94f41b69315f93) )
@@ -643,7 +641,7 @@ ROM_END
 
 
 ROM_START( buzzard )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "rom2",       0x0000, 0x2000, CRC(85ddea38) SHA1(fe7e8d7962850b17c39cac627994d78768b094f8) )
 	ROM_LOAD( "a21.03",     0x2000, 0x2000, CRC(4e9323bd) SHA1(86ae4c6a29898fdb0e559ec2aac99fc874910fea) )
 	ROM_LOAD( "a21.04",     0x4000, 0x2000, CRC(57e659d4) SHA1(4c0e73d0661360731691a32a6e94f41b69315f93) )
@@ -684,7 +682,7 @@ ROM_END
 
 
 ROM_START( sonofphx )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "5.f4",   0x0000, 0x2000, CRC(e0d2c6cf) SHA1(87befaefa3e4f07523e9c4db19f13ff9309a7dcc) )
 	ROM_LOAD( "6.h4",   0x2000, 0x2000, CRC(3a0d0336) SHA1(8e538d45d27ad881fb2ed71647353c6535646047) )
 	ROM_LOAD( "7.j4",   0x4000, 0x2000, CRC(57a8e900) SHA1(bc878e27130f0a9afb50c1926b47621e5e58d8b2) )
@@ -720,7 +718,7 @@ ROM_START( sonofphx )
 ROM_END
 
 ROM_START( repulse )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "repulse.b5",   0x0000, 0x2000, CRC(fb2b7c9d) SHA1(7a6867a9deda7eb399bf5b01c5422400d443faea) )
 	ROM_LOAD( "repulse.b6",   0x2000, 0x2000, CRC(99129918) SHA1(9beba6ef62102d6a28cf7a52ce5ce2a2113f8dfc) )
 	ROM_LOAD( "7.j4",         0x4000, 0x2000, CRC(57a8e900) SHA1(bc878e27130f0a9afb50c1926b47621e5e58d8b2) )
@@ -756,7 +754,7 @@ ROM_START( repulse )
 ROM_END
 
 ROM_START( 99lstwar )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "1999.4f",      0x0000, 0x2000, CRC(e3cfc09f) SHA1(e48905726c6308194c596117dd30444dcb748908) )
 	ROM_LOAD( "1999.4h",      0x2000, 0x2000, CRC(fd58c6e1) SHA1(005f3114425fd2bfb9452c790d40653661b3d1d9) )
 	ROM_LOAD( "7.j4",         0x4000, 0x2000, CRC(57a8e900) SHA1(bc878e27130f0a9afb50c1926b47621e5e58d8b2) )
@@ -792,7 +790,7 @@ ROM_START( 99lstwar )
 ROM_END
 
 ROM_START( 99lstwra )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "4f.bin",       0x0000, 0x2000, CRC(efe2908d) SHA1(4de8661f523f002c6a9368f81d865c7cc98926dd) )
 	ROM_LOAD( "4h.bin",       0x2000, 0x2000, CRC(5b79c342) SHA1(293990dab3360139727a5c90aad0826d4a3746b7) )
 	ROM_LOAD( "4j.bin",       0x4000, 0x2000, CRC(d2a62c1b) SHA1(eef9103945db8cfc4c1e3a58d8ad222f8dc58492) )
@@ -828,7 +826,7 @@ ROM_START( 99lstwra )
 ROM_END
 
 ROM_START( 99lstwrk )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "1999.4f",      0x0000, 0x2000, CRC(e3cfc09f) SHA1(e48905726c6308194c596117dd30444dcb748908) )
 	ROM_LOAD( "1999.4h",      0x2000, 0x2000, CRC(fd58c6e1) SHA1(005f3114425fd2bfb9452c790d40653661b3d1d9) )
 	ROM_LOAD( "7.j4",         0x4000, 0x2000, CRC(57a8e900) SHA1(bc878e27130f0a9afb50c1926b47621e5e58d8b2) )
@@ -867,7 +865,7 @@ ROM_START( 99lstwrk )
 ROM_END
 
 ROM_START( flashgal )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "epr-7167.4f",  0x0000, 0x2000, CRC(cf5ad733) SHA1(24561db9a3d72c7a69a7ce5a85aaa78254788675) )
 	ROM_LOAD( "epr-7168.4h",  0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
 	ROM_LOAD( "epr-7169.4j",  0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
@@ -904,7 +902,7 @@ ROM_START( flashgal )
 ROM_END
 
 ROM_START( flashgla )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "flashgal.5",   0x0000, 0x2000, CRC(aa889ace) SHA1(7CAAC8FAE723485ADB6990367BDB8A94BD273322) )
 	ROM_LOAD( "epr-7168.4h",  0x2000, 0x2000, CRC(00c4851f) SHA1(f29ef123702bb3506ac3740b2779ae2757d884c2) )
 	ROM_LOAD( "epr-7169.4j",  0x4000, 0x2000, CRC(1ef0b8f7) SHA1(9c3ded1f985f4fb6b38843e0ca90ec458633d145) )
@@ -941,7 +939,7 @@ ROM_START( flashgla )
 ROM_END
 
 ROM_START( srdmissn )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "5.t2",   0x0000, 0x4000, CRC(a682b48c) SHA1(c7348cbe42e45cd336e0d03052e839781d1481d1) )
 	ROM_LOAD( "7.t3",   0x4000, 0x4000, CRC(1719c58c) SHA1(32faae584d0ada0a39b96655b1a9d7c449af4996) )
 
@@ -974,7 +972,7 @@ ROM_START( srdmissn )
 ROM_END
 
 ROM_START( fx )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "fx.01", 0x0000, 0x4000, CRC(b651754b) SHA1(05024276aeac0c2a3d62f3a6f1027518fe206784) )
 	ROM_LOAD( "fx.02", 0x4000, 0x4000, CRC(f3d2dcc1) SHA1(466bed28ecf25f9e2653662d7cc382ceb916d8db) )
 
@@ -1008,7 +1006,7 @@ ROM_END
 
 
 ROM_START( airwolf )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "b.2s",        0x0000, 0x8000, CRC(8c993cce) SHA1(925a5a9a2ee382556e2c2e928fd483344eba72c3) )
 
 	ROM_REGION( 0x10000, "sub", 0 )
@@ -1050,7 +1048,7 @@ ROM_START( airwolf )
 ROM_END
 
 ROM_START( airwolfa )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "airwolf.2",        0x0000, 0x8000, CRC(bc1a8587) SHA1(5487096621c175759eb4a4a85b76ef32900ca522) )
 
 	ROM_REGION( 0x10000, "sub", 0 ) /* the rom with this set was bad with FIXED BITS (11xxxxxx), but the remaining bits matched */
@@ -1092,7 +1090,7 @@ ROM_START( airwolfa )
 ROM_END
 
 ROM_START( skywolf )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "02s_03.bin",  0x0000, 0x4000, CRC(a0891798) SHA1(c1b1e1fce529509fb1dd921a0022d5367c3c495c) )
 	ROM_LOAD( "03s_04.bin",  0x4000, 0x4000, CRC(5f515d46) SHA1(ec12bddf72e98aeef5cd17d00f0fa6f2df59cf00) )
 
@@ -1125,7 +1123,7 @@ ROM_START( skywolf )
 ROM_END
 
 ROM_START( skywolf2 )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "z80_2.bin",   0x0000, 0x8000, CRC(34db7bda) SHA1(1a98d5cf97063453a0351f7dbe339c32d59a3d20) )
 
 	ROM_REGION( 0x10000, "sub", 0 )
@@ -1157,7 +1155,7 @@ ROM_START( skywolf2 )
 ROM_END
 
 ROM_START( legend )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "a_r2.rom",    0x0000, 0x4000, CRC(0cc1c4f4) SHA1(33f6a1b31eed75a92e06cb29f912321fe75c31e6) )
 	ROM_LOAD( "a_r3.rom",    0x4000, 0x4000, CRC(4b270c6b) SHA1(95ad79a9de037b6aaca325da75c8aef9a72dbfed) )
 
@@ -1206,19 +1204,19 @@ ROM_END
 static DRIVER_INIT( gyrodine )
 {
 	/* add watchdog */
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xe000, 0xe000, 0, 0, watchdog_reset_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xe000, 0xe000, 0, 0, watchdog_reset_w);
 }
 
 
 static DRIVER_INIT( srdmissn )
 {
 	/* shared RAM is mapped at 0xe000 as well  */
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xe000, 0xe7ff, 0, 0, SMH_BANK1, SMH_BANK1);
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xe000, 0xe7ff, 0, 0, (read8_space_func)SMH_BANK(1), (write8_space_func)SMH_BANK(1));
 	memory_set_bankptr(machine, 1, shared_ram);
 
 	/* extra RAM on sub CPU  */
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8800, 0x8fff, 0, 0, SMH_BANK2, SMH_BANK2);
-	memory_set_bankptr(machine, 2, auto_malloc(0x800));
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "sub", ADDRESS_SPACE_PROGRAM), 0x8800, 0x8fff, 0, 0, (read8_space_func)SMH_BANK(2), (write8_space_func)SMH_BANK(2));
+	memory_set_bankptr(machine, 2, auto_alloc_array(machine, UINT8, 0x800));
 }
 
 
@@ -1241,7 +1239,7 @@ GAME( 1985, flashgal, 0,        flashgal, flashgal, 0,        ROT0,  "Sega", "Fl
 GAME( 1985, flashgla, flashgal, flashgla, flashgal, 0,        ROT0,  "Sega", "Flashgal (set 2)", 0 )
 GAME( 1986, srdmissn, 0,        srdmissn, srdmissn, srdmissn, ROT90, "Taito Corporation", "S.R.D. Mission", 0 )
 GAME( 1986, fx,       srdmissn, srdmissn, srdmissn, srdmissn, ROT90, "bootleg", "F-X", 0 )
-GAME( 1986?,legend,   0,        legend,   legend,   srdmissn, ROT0,  "Sega / Coreland ?", "Legend", 0 )
+GAME( 1986, legend,   0,        legend,   legend,   srdmissn, ROT0,  "Sega / Coreland", "Legend", 0 )
 GAME( 1987, airwolf,  0,        srdmissn, airwolf,  srdmissn, ROT0,  "Kyugo", "Airwolf", 0 )
 GAME( 1987, airwolfa, airwolf,  srdmissn, airwolf,  srdmissn, ROT0,  "Kyugo (UA Theatre license)", "Airwolf (US)", 0 )
 GAME( 1987, skywolf,  airwolf,  srdmissn, skywolf,  srdmissn, ROT0,  "bootleg", "Sky Wolf (set 1)", 0 )
