@@ -49,106 +49,64 @@ static WRITE16_HANDLER( lastduel_sound_w )
 
 /******************************************************************************/
 
-static ADDRESS_MAP_START( lastduel_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0xfc0800, 0xfc0fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfc4000, 0xfc4001) AM_READ_PORT("P1_P2")
-	AM_RANGE(0xfc4002, 0xfc4003) AM_READ_PORT("SYSTEM")
+static ADDRESS_MAP_START( lastduel_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x05ffff) AM_ROM
+	AM_RANGE(0xfc0000, 0xfc0003) AM_WRITENOP /* Written rarely */
+	AM_RANGE(0xfc0800, 0xfc0fff) AM_RAM AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xfc4000, 0xfc4001) AM_READ_PORT("P1_P2") AM_WRITE(lastduel_flip_w)
+	AM_RANGE(0xfc4002, 0xfc4003) AM_READ_PORT("SYSTEM") AM_WRITE(lastduel_sound_w)
 	AM_RANGE(0xfc4004, 0xfc4005) AM_READ_PORT("DSW1")
 	AM_RANGE(0xfc4006, 0xfc4007) AM_READ_PORT("DSW2")
-	AM_RANGE(0xfcc000, 0xfcdfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfd0000, 0xfd3fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfd4000, 0xfd7fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfd8000, 0xfd87ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfe0000, 0xffffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( lastduel_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xfc0000, 0xfc0003) AM_WRITE(SMH_NOP) /* Written rarely */
-	AM_RANGE(0xfc0800, 0xfc0fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xfc4000, 0xfc4001) AM_WRITE(lastduel_flip_w)
-	AM_RANGE(0xfc4002, 0xfc4003) AM_WRITE(lastduel_sound_w)
 	AM_RANGE(0xfc8000, 0xfc800f) AM_WRITE(lastduel_scroll_w)
-	AM_RANGE(0xfcc000, 0xfcdfff) AM_WRITE(lastduel_vram_w) AM_BASE(&lastduel_vram)
-	AM_RANGE(0xfd0000, 0xfd3fff) AM_WRITE(lastduel_scroll1_w) AM_BASE(&lastduel_scroll1)
-	AM_RANGE(0xfd4000, 0xfd7fff) AM_WRITE(lastduel_scroll2_w) AM_BASE(&lastduel_scroll2)
-	AM_RANGE(0xfd8000, 0xfd87ff) AM_WRITE(lastduel_palette_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0xfe0000, 0xffffff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xfcc000, 0xfcdfff) AM_RAM_WRITE(lastduel_vram_w) AM_BASE(&lastduel_vram)
+	AM_RANGE(0xfd0000, 0xfd3fff) AM_RAM_WRITE(lastduel_scroll1_w) AM_BASE(&lastduel_scroll1)
+	AM_RANGE(0xfd4000, 0xfd7fff) AM_RAM_WRITE(lastduel_scroll2_w) AM_BASE(&lastduel_scroll2)
+	AM_RANGE(0xfd8000, 0xfd87ff) AM_RAM_WRITE(lastduel_palette_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0xfe0000, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( madgear_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0xfc1800, 0xfc1fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfc4000, 0xfc4001) AM_READ_PORT("DSW1")
-	AM_RANGE(0xfc4002, 0xfc4003) AM_READ_PORT("DSW2")
+static ADDRESS_MAP_START( madgear_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_ROM
+	AM_RANGE(0xfc1800, 0xfc1fff) AM_RAM AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xfc4000, 0xfc4001) AM_READ_PORT("DSW1") AM_WRITE(lastduel_flip_w)
+	AM_RANGE(0xfc4002, 0xfc4003) AM_READ_PORT("DSW2") AM_WRITE(lastduel_sound_w)
 	AM_RANGE(0xfc4004, 0xfc4005) AM_READ_PORT("P1_P2")
 	AM_RANGE(0xfc4006, 0xfc4007) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0xfc8000, 0xfc9fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfcc000, 0xfcc7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfd4000, 0xfd7fff) AM_READ(SMH_RAM)
-	AM_RANGE(0xfd8000, 0xfdffff) AM_READ(SMH_RAM)
-	AM_RANGE(0xff0000, 0xffffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( madgear_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xfc1800, 0xfc1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xfc4000, 0xfc4001) AM_WRITE(lastduel_flip_w)
-	AM_RANGE(0xfc4002, 0xfc4003) AM_WRITE(lastduel_sound_w)
-	AM_RANGE(0xfc8000, 0xfc9fff) AM_WRITE(lastduel_vram_w) AM_BASE(&lastduel_vram)
-	AM_RANGE(0xfcc000, 0xfcc7ff) AM_WRITE(lastduel_palette_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0xfc8000, 0xfc9fff) AM_RAM_WRITE(lastduel_vram_w) AM_BASE(&lastduel_vram)
+	AM_RANGE(0xfcc000, 0xfcc7ff) AM_RAM_WRITE(lastduel_palette_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0xfd0000, 0xfd000f) AM_WRITE(lastduel_scroll_w)
-	AM_RANGE(0xfd4000, 0xfd7fff) AM_WRITE(madgear_scroll1_w) AM_BASE(&lastduel_scroll1)
-	AM_RANGE(0xfd8000, 0xfdffff) AM_WRITE(madgear_scroll2_w) AM_BASE(&lastduel_scroll2)
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xfd4000, 0xfd7fff) AM_RAM_WRITE(madgear_scroll1_w) AM_BASE(&lastduel_scroll1)
+	AM_RANGE(0xfd8000, 0xfdffff) AM_RAM_WRITE(madgear_scroll2_w) AM_BASE(&lastduel_scroll2)
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
 /******************************************************************************/
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xdfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xe000, 0xe7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xe800, 0xe800) AM_READ(ym2203_status_port_0_r)
-	AM_RANGE(0xf000, 0xf000) AM_READ(ym2203_status_port_1_r)
+static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xdfff) AM_ROM
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM
+	AM_RANGE(0xe800, 0xe801) AM_DEVREADWRITE("ym1", ym2203_r,ym2203_w)
+	AM_RANGE(0xf000, 0xf001) AM_DEVREADWRITE("ym2", ym2203_r,ym2203_w)
 	AM_RANGE(0xf800, 0xf800) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xdfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xe800, 0xe800) AM_WRITE(ym2203_control_port_0_w)
-	AM_RANGE(0xe801, 0xe801) AM_WRITE(ym2203_write_port_0_w)
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(ym2203_control_port_1_w)
-	AM_RANGE(0xf001, 0xf001) AM_WRITE(ym2203_write_port_1_w)
-ADDRESS_MAP_END
-
 static WRITE8_HANDLER( mg_bankswitch_w )
 {
 	int bankaddress;
-	UINT8 *RAM = memory_region(space->machine, "audio");
+	UINT8 *RAM = memory_region(space->machine, "audiocpu");
 
 	bankaddress = 0x10000 + (data & 0x01) * 0x4000;
-	memory_set_bankptr(space->machine, 3,&RAM[bankaddress]);
+	memory_set_bankptr(space->machine, 1,&RAM[bankaddress]);
 }
 
-static ADDRESS_MAP_START( mg_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xcfff) AM_READ(SMH_BANK3)
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xf000, 0xf000) AM_READ(ym2203_status_port_0_r)
-	AM_RANGE(0xf002, 0xf002) AM_READ(ym2203_status_port_1_r)
+static ADDRESS_MAP_START( madgear_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xcfff) AM_ROMBANK(1)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM
+	AM_RANGE(0xf000, 0xf001) AM_DEVREADWRITE("ym1", ym2203_r,ym2203_w)
+	AM_RANGE(0xf002, 0xf003) AM_DEVREADWRITE("ym2", ym2203_r,ym2203_w)
+	AM_RANGE(0xf004, 0xf004) AM_DEVWRITE("oki", okim6295_w)
 	AM_RANGE(0xf006, 0xf006) AM_READ(soundlatch_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( mg_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xcfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(ym2203_control_port_0_w)
-	AM_RANGE(0xf001, 0xf001) AM_WRITE(ym2203_write_port_0_w)
-	AM_RANGE(0xf002, 0xf002) AM_WRITE(ym2203_control_port_1_w)
-	AM_RANGE(0xf003, 0xf003) AM_WRITE(ym2203_write_port_1_w)
-	AM_RANGE(0xf004, 0xf004) AM_WRITE(okim6295_data_0_w)
 	AM_RANGE(0xf00a, 0xf00a) AM_WRITE(mg_bankswitch_w)
 ADDRESS_MAP_END
 
@@ -234,9 +192,9 @@ GFXDECODE_END
 /******************************************************************************/
 
 /* handler called by the 2203 emulator when the internal timers cause an IRQ */
-static void irqhandler(running_machine *machine, int irq)
+static void irqhandler(const device_config *device, int irq)
 {
-	cpu_set_input_line(machine->cpu[1],0,irq ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine, "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2203_interface ym2203_config =
@@ -244,7 +202,7 @@ static const ym2203_interface ym2203_config =
 	{
 			AY8910_LEGACY_OUTPUT,
 			AY8910_DEFAULT_LOADS,
-			NULL, NULL, NULL, NULL,
+			DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL,
 	},
 	irqhandler
 };
@@ -268,17 +226,17 @@ static INTERRUPT_GEN( madgear_interrupt )
 static MACHINE_DRIVER_START( lastduel )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 10000000) /* Could be 8 MHz */
-	MDRV_CPU_PROGRAM_MAP(lastduel_readmem,lastduel_writemem)
+	MDRV_CPU_ADD("maincpu", M68000, 10000000) /* Could be 8 MHz */
+	MDRV_CPU_PROGRAM_MAP(lastduel_map)
 	MDRV_CPU_VBLANK_INT_HACK(lastduel_interrupt,3)	/* 1 for vbl, 2 for control reads?? */
 
-	MDRV_CPU_ADD("audio", Z80, 3579545) /* Accurate */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80, 3579545) /* Accurate */
+	MDRV_CPU_PROGRAM_MAP(sound_map)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -307,17 +265,17 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( madgear )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 10000000) /* Accurate */
-	MDRV_CPU_PROGRAM_MAP(madgear_readmem,madgear_writemem)
+	MDRV_CPU_ADD("maincpu", M68000, 10000000) /* Accurate */
+	MDRV_CPU_PROGRAM_MAP(madgear_map)
 	MDRV_CPU_VBLANK_INT_HACK(madgear_interrupt,3)	/* 1 for vbl, 2 for control reads?? */
 
-	MDRV_CPU_ADD("audio", Z80, XTAL_3_579545MHz) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(mg_sound_readmem,mg_sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80, XTAL_3_579545MHz) /* verified on pcb */
+	MDRV_CPU_PROGRAM_MAP(madgear_sound_map)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -405,8 +363,8 @@ static INPUT_PORTS_START( lastduel )
 	PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0200, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x0300, DEF_STR( Normal ) )
-	PORT_DIPSETTING(      0x0100, "Difficult" )
-	PORT_DIPSETTING(      0x0000, "Very Difficult" )
+	PORT_DIPSETTING(      0x0100, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Difficult ) )
 	PORT_DIPNAME( 0x0400, 0x0400, DEF_STR( Unknown ) )	/* Could be cabinet type? */
 	PORT_DIPSETTING(      0x0400, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -462,8 +420,8 @@ static INPUT_PORTS_START( madgear )
 	PORT_DIPNAME( 0x000c, 0x000c, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0008, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x000c, DEF_STR( Normal ) )
-	PORT_DIPSETTING(      0x0004, "Difficult" )
-	PORT_DIPSETTING(      0x0000, "Very Difficult" )
+	PORT_DIPSETTING(      0x0004, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Difficult ) )
 	PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(      0x0030, "Upright One Player" )
 	PORT_DIPSETTING(      0x0000, "Upright Two Players" )
@@ -566,13 +524,13 @@ INPUT_PORTS_END
 /******************************************************************************/
 
 ROM_START( lastduel )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "ldu-06.rom",   0x00000, 0x20000, CRC(4228a00b) SHA1(8c23f74f682ba2074da9f3306600c881ce41e50f) )
 	ROM_LOAD16_BYTE( "ldu-05.rom",   0x00001, 0x20000, CRC(7260434f) SHA1(55eeb12977efb3c6afd86d68612782ba526c9055) )
 	ROM_LOAD16_BYTE( "ldu-04.rom",   0x40000, 0x10000, CRC(429fb964) SHA1(78769b05e62c190d846dd08214427d1abbbe2bba) )
 	ROM_LOAD16_BYTE( "ldu-03.rom",   0x40001, 0x10000, CRC(5aa4df72) SHA1(9e7315b793f09c8b422bad1ce776588e3a48d80c) )
 
-	ROM_REGION( 0x10000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION( 0x10000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "ld_02.bin",    0x0000, 0x10000, CRC(91834d0c) SHA1(aaa63b8470fc19b82c25028ab27675a7837ab9a1) )
 
 	ROM_REGION( 0x80000, "gfx1", ROMREGION_DISPOSE )
@@ -609,13 +567,13 @@ ROM_START( lastduel )
 ROM_END
 
 ROM_START( lstduela )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "06",   0x00000, 0x20000, CRC(0e71acaf) SHA1(e804c77bfd768ae2fc1917bcec1fd0ec7418b780) )
 	ROM_LOAD16_BYTE( "05",   0x00001, 0x20000, CRC(47a85bea) SHA1(9d6b2a4e27c84ffce8ed58aa1b314c67c7314932) )
 	ROM_LOAD16_BYTE( "04",   0x40000, 0x10000, CRC(aa4bf001) SHA1(3f14b174016c6fa4c82011d3d0f1c957096d6d93) )
 	ROM_LOAD16_BYTE( "03",   0x40001, 0x10000, CRC(bbaac8ab) SHA1(3c5773e39e7a96ef62da7b846ce4099222b3e66b) )
 
-	ROM_REGION( 0x10000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION( 0x10000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "ld_02.bin",    0x0000, 0x10000, CRC(91834d0c) SHA1(aaa63b8470fc19b82c25028ab27675a7837ab9a1) )
 
 	ROM_REGION( 0x80000, "gfx1", ROMREGION_DISPOSE )
@@ -652,7 +610,7 @@ ROM_START( lstduela )
 ROM_END
 
 ROM_START( lstduelb )
-	ROM_REGION( 0x60000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x60000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "ld_08.bin",    0x00000, 0x10000, CRC(43811a96) SHA1(79db50c941d8845f1642f2257c610768172923a3) )
 	ROM_LOAD16_BYTE( "ld_07.bin",    0x00001, 0x10000, CRC(63c30946) SHA1(cab7374839a68483b3f94821144546cc3eb1528e) )
 	ROM_LOAD16_BYTE( "ld_04.bin",    0x20000, 0x10000, CRC(46a4e0f8) SHA1(7d5fac209357090c5faeee3834c19f1d8125aac5) )
@@ -660,7 +618,7 @@ ROM_START( lstduelb )
 	ROM_LOAD16_BYTE( "ldu-04.rom",   0x40000, 0x10000, CRC(429fb964) SHA1(78769b05e62c190d846dd08214427d1abbbe2bba) )
 	ROM_LOAD16_BYTE( "ldu-03.rom",   0x40001, 0x10000, CRC(5aa4df72) SHA1(9e7315b793f09c8b422bad1ce776588e3a48d80c) )
 
-	ROM_REGION( 0x10000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION( 0x10000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "ld_02.bin",    0x0000, 0x10000, CRC(91834d0c) SHA1(aaa63b8470fc19b82c25028ab27675a7837ab9a1) )
 
 	ROM_REGION( 0x80000, "gfx1", ROMREGION_DISPOSE )
@@ -697,13 +655,13 @@ ROM_START( lstduelb )
 ROM_END
 
 ROM_START( madgear )
-	ROM_REGION( 0x80000, "main", 0 )	/* 256K for 68000 code */
+	ROM_REGION( 0x80000, "maincpu", 0 )	/* 256K for 68000 code */
 	ROM_LOAD16_BYTE( "mg_04.rom",    0x00000, 0x20000, CRC(b112257d) SHA1(4acfd8ba0fe8d68ca7c9b0fde2b13ce0c9104258) )
 	ROM_LOAD16_BYTE( "mg_03.rom",    0x00001, 0x20000, CRC(b2672465) SHA1(96d10046e67181160daebb2b07c867c08f8600dc) )
 	ROM_LOAD16_BYTE( "mg_02.rom",    0x40000, 0x20000, CRC(9f5ebe16) SHA1(2183cb807157d48204d8d4d4b7555c9a7772ddfd) )
 	ROM_LOAD16_BYTE( "mg_01.rom",    0x40001, 0x20000, CRC(1cea2af0) SHA1(9f4642ed2d21fa525e9fecaac6235a3653df3030) )
 
-	ROM_REGION( 0x18000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION( 0x18000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "mg_05.rom",    0x00000,  0x08000, CRC(2fbfc945) SHA1(8066516dcf9261abee1edd103bdbe0cc18913ed3) )
 	ROM_CONTINUE(             0x10000,  0x08000 )
 
@@ -735,13 +693,13 @@ ROM_START( madgear )
 ROM_END
 
 ROM_START( madgearj )
-	ROM_REGION( 0x80000, "main", 0 )	/* 256K for 68000 code */
+	ROM_REGION( 0x80000, "maincpu", 0 )	/* 256K for 68000 code */
 	ROM_LOAD16_BYTE( "mdj_04.rom",   0x00000, 0x20000, CRC(9ebbebb1) SHA1(84a2b146c10c1635b11c3af0242fd4680994eb5a) )
 	ROM_LOAD16_BYTE( "mdj_03.rom",   0x00001, 0x20000, CRC(a5579c2d) SHA1(789dcb1cdf5cae20ab497c75460ad98c33d1a046) )
 	ROM_LOAD16_BYTE( "mg_02.rom",    0x40000, 0x20000, CRC(9f5ebe16) SHA1(2183cb807157d48204d8d4d4b7555c9a7772ddfd) )
 	ROM_LOAD16_BYTE( "mg_01.rom",    0x40001, 0x20000, CRC(1cea2af0) SHA1(9f4642ed2d21fa525e9fecaac6235a3653df3030) )
 
-	ROM_REGION(  0x18000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION(  0x18000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "mg_05.rom",    0x00000,  0x08000, CRC(2fbfc945) SHA1(8066516dcf9261abee1edd103bdbe0cc18913ed3) )
 	ROM_CONTINUE(             0x10000,  0x08000 )
 
@@ -773,13 +731,13 @@ ROM_START( madgearj )
 ROM_END
 
 ROM_START( ledstorm )
-	ROM_REGION( 0x80000, "main", 0 )	/* 256K for 68000 code */
+	ROM_REGION( 0x80000, "maincpu", 0 )	/* 256K for 68000 code */
 	ROM_LOAD16_BYTE( "mdu.04",    0x00000, 0x20000, CRC(7f7f8329) SHA1(9b7ecb7f5cc3f2c80e05da3b9055e2fbd64bf0ce) )
 	ROM_LOAD16_BYTE( "mdu.03",    0x00001, 0x20000, CRC(11fa542f) SHA1(1cedfc471058e0d0502a1eeafcab479dca4fea41) )
 	ROM_LOAD16_BYTE( "mg_02.rom", 0x40000, 0x20000, CRC(9f5ebe16) SHA1(2183cb807157d48204d8d4d4b7555c9a7772ddfd) )
 	ROM_LOAD16_BYTE( "mg_01.rom", 0x40001, 0x20000, CRC(1cea2af0) SHA1(9f4642ed2d21fa525e9fecaac6235a3653df3030) )
 
-	ROM_REGION(  0x18000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION(  0x18000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "mg_05.rom",    0x00000,  0x08000, CRC(2fbfc945) SHA1(8066516dcf9261abee1edd103bdbe0cc18913ed3) )
 	ROM_CONTINUE(             0x10000,  0x08000 )
 
@@ -811,13 +769,13 @@ ROM_START( ledstorm )
 ROM_END
 
 ROM_START( ledstrm2 )
-	ROM_REGION( 0x80000, "main", 0 )	/* 256K for 68000 code */
+	ROM_REGION( 0x80000, "maincpu", 0 )	/* 256K for 68000 code */
 	ROM_LOAD16_BYTE( "lsu-04.bin", 0x00000, 0x20000, CRC(56a2f079) SHA1(da581c117d92ac5c1e8e44324f1aed2858a3cdc8) )
 	ROM_LOAD16_BYTE( "lsu-03.bin", 0x00001, 0x20000, CRC(9b6408c0) SHA1(8ef8349f58c62a2d626b1053eae2032d168d602c) )
 	ROM_LOAD16_BYTE( "ls-02.bin", 0x40000, 0x20000, CRC(05c0285e) SHA1(b155d2d0c41f614bd324813c5d3d87a6765ad812) )
 	ROM_LOAD16_BYTE( "ls-01.bin", 0x40001, 0x20000, CRC(8bf934dd) SHA1(f2287a4361af4986eb010dfbfb6de3a3d4124937) )
 
-	ROM_REGION(  0x18000 , "audio", 0 ) /* audio CPU */
+	ROM_REGION(  0x18000 , "audiocpu", 0 ) /* audio CPU */
 	ROM_LOAD( "ls-07.bin",    0x00000,  0x08000, CRC(98af7838) SHA1(a0b87b9ce3c1b0e5d7696ffaab9cea483b9ee928) )
 	ROM_CONTINUE(             0x10000,  0x08000 )
 
