@@ -323,24 +323,25 @@ static WRITE8_HANDLER( coin_w )
 
 static WRITE8_HANDLER( snd_irq_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], 0, ASSERT_LINE);
+	cputag_set_input_line(space->machine, "soundcpu", 0, ASSERT_LINE);
 	timer_call_after_resynch(space->machine, NULL, 0, NULL);
 }
 
 static WRITE8_HANDLER( snddata_w )
 {
-	int num_ays = (sndti_exists(SOUND_AY8910, 1)) ? 2 : 1;
+	const device_config *ay1 = devtag_get_device(space->machine, "ay1");
+	const device_config *ay2 = devtag_get_device(space->machine, "ay2");
 
 	if ((p2 & 0xf0) == 0xe0)
-		ay8910_control_port_0_w(space,0,offset);
+		ay8910_address_w(ay1, 0, offset);
 	else if ((p2 & 0xf0) == 0xa0)
-		ay8910_write_port_0_w(space,0,offset);
-	else if (num_ays == 2 && (p1 & 0xe0) == 0x60)
-		ay8910_control_port_1_w(space,0,offset);
-	else if (num_ays == 2 && (p1 & 0xe0) == 0x40)
-		 ay8910_write_port_1_w(space,0,offset);
+		ay8910_data_w(ay1, 0, offset);
+	else if (ay2 != NULL && (p1 & 0xe0) == 0x60)
+		ay8910_address_w(ay2, 0, offset);
+	else if (ay2 != NULL && (p1 & 0xe0) == 0x40)
+		 ay8910_data_w(ay2, 0, offset);
 	else if ((p2 & 0xf0) == 0x70 )
-		sound_status=offset;
+		sound_status = offset;
 }
 
 static WRITE8_HANDLER( p1_w )
@@ -351,9 +352,9 @@ static WRITE8_HANDLER( p1_w )
 static WRITE8_HANDLER( p2_w )
 {
 	p2 = data;
-	if((p2&0xf0)==0x50)
+	if((p2 & 0xf0) == 0x50)
 	{
-		cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "soundcpu", 0, CLEAR_LINE);
 	}
 }
 
@@ -374,10 +375,10 @@ static READ8_HANDLER( irq_r )
 
 static READ8_HANDLER( snddata_r )
 {
-	switch(p2&0xf0)
+	switch(p2 & 0xf0)
 	{
-		case 0x60:	return soundlatch_r(space,0); ;
-		case 0x70:	return memory_region(space->machine, "user1")[((p1&0x1f)<<8)|offset];
+		case 0x60:	return soundlatch_r(space, 0); ;
+		case 0x70:	return memory_region(space->machine, "user1")[((p1 & 0x1f) << 8) | offset];
 	}
 	return 0xff;
 }
@@ -639,17 +640,17 @@ static MACHINE_DRIVER_START( m63 )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD("maincpu",Z80,XTAL_12MHz/4)     /* 3 MHz */
-	MDRV_CPU_PROGRAM_MAP(m63_map,0)
-	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
+	MDRV_CPU_PROGRAM_MAP(m63_map)
+	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
 	MDRV_CPU_ADD("soundcpu",I8039,XTAL_12MHz/4)	/* ????? */
-	MDRV_CPU_PROGRAM_MAP(i8039_map,0)
-	MDRV_CPU_IO_MAP(i8039_port_map,0)
+	MDRV_CPU_PROGRAM_MAP(i8039_map)
+	MDRV_CPU_IO_MAP(i8039_port_map)
 	MDRV_CPU_PERIODIC_INT(snd_irq, 60)
 
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -682,17 +683,17 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( fghtbskt )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, XTAL_12MHz/4)     /* 3 MHz */
-	MDRV_CPU_PROGRAM_MAP(fghtbskt_map,0)
-	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
+	MDRV_CPU_ADD("maincpu", Z80, XTAL_12MHz/4)     /* 3 MHz */
+	MDRV_CPU_PROGRAM_MAP(fghtbskt_map)
+	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
-	MDRV_CPU_ADD("audio", I8039,XTAL_12MHz/4)	/* ????? */
-	MDRV_CPU_PROGRAM_MAP(i8039_map,0)
-	MDRV_CPU_IO_MAP(i8039_port_map,0)
+	MDRV_CPU_ADD("soundcpu", I8039,XTAL_12MHz/4)	/* ????? */
+	MDRV_CPU_PROGRAM_MAP(i8039_map)
+	MDRV_CPU_IO_MAP(i8039_port_map)
 	MDRV_CPU_PERIODIC_INT(snd_irq, 60/2)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -709,7 +710,7 @@ static MACHINE_DRIVER_START( fghtbskt )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay", AY8910, XTAL_12MHz/8)
+	MDRV_SOUND_ADD("ay1", AY8910, XTAL_12MHz/8)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
 	MDRV_SOUND_ADD("samples", SAMPLES, 0)
@@ -848,14 +849,14 @@ ROM_START( atomboya )
 ROM_END
 
 ROM_START( fghtbskt )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "fb14.0f",      0x0000, 0x2000, CRC(82032853) SHA1(e103ace4cac6df3a429b785f9789b302ae8cdade) )
 	ROM_LOAD( "fb13.2f",      0x2000, 0x2000, CRC(5306df0f) SHA1(11be226e7167703bb08e48510a113b2d43b211a4) )
 	ROM_LOAD( "fb12.3f",      0x4000, 0x2000, CRC(ee9210d4) SHA1(c63d036314d635f65a2b5bb192ceb312a587db6e) )
 	ROM_LOAD( "fb10.6f",      0x8000, 0x2000, CRC(6b47efba) SHA1(cb55c7a9d5afe748c1c88f87dd1909e106932798) )
 	ROM_LOAD( "fb09.7f",      0xa000, 0x2000, CRC(be69e087) SHA1(be95ecafa494cb0787ee18eb3ecea4ad545a6ae3) )
 
-	ROM_REGION( 0x1000, "audio", 0 )	/* 8039 */
+	ROM_REGION( 0x1000, "soundcpu", 0 )	/* 8039 */
 	ROM_LOAD( "fb07.0b",      0x0000, 0x1000, CRC(50432dbd) SHA1(35a2218ed243bde47dbe06b5a11a65502ba734ea) )
 
 	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
