@@ -354,9 +354,9 @@ static WRITE32_HANDLER( macrossp_soundcmd_w )
 	if (ACCESSING_BITS_16_31)
 	{
 		//logerror("%08x write soundcmd %08x (%08x)\n",cpu_get_pc(space->cpu),data,mem_mask);
-		soundlatch_word_w(space,0,data >> 16,0xffff);
+		soundlatch_word_w(space, 0, data >> 16, 0xffff);
 		sndpending = 1;
-		cpu_set_input_line(space->machine->cpu[1],2,HOLD_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", 2, HOLD_LINE);
 		/* spin for a while to let the sound CPU read the command */
 		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(50));
 	}
@@ -366,7 +366,7 @@ static READ16_HANDLER( macrossp_soundcmd_r )
 {
 //  logerror("%06x read soundcmd\n",cpu_get_pc(space->cpu));
 	sndpending = 0;
-	return soundlatch_word_r(space,offset,mem_mask);
+	return soundlatch_word_r(space, offset, mem_mask);
 }
 
 static INT32 fade_effect,old_fade;
@@ -404,77 +404,48 @@ static WRITE32_HANDLER( macrossp_palette_fade_w )
 
 /*** MEMORY MAPS *************************************************************/
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x3fffff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( macrossp_map, ADDRESS_SPACE_PROGRAM, 32 )
+	AM_RANGE(0x000000, 0x3fffff) AM_ROM
+	AM_RANGE(0x800000, 0x802fff) AM_RAM AM_BASE(&macrossp_spriteram) AM_SIZE(&spriteram_size)
+	/* SCR A Layer */
+	AM_RANGE(0x900000, 0x903fff) AM_RAM_WRITE(macrossp_scra_videoram_w) AM_BASE(&macrossp_scra_videoram)
+	AM_RANGE(0x904200, 0x9043ff) AM_WRITEONLY /* W/O? */
+	AM_RANGE(0x905000, 0x90500b) AM_WRITEONLY AM_BASE(&macrossp_scra_videoregs) /* W/O? */
+	/* SCR B Layer */
+	AM_RANGE(0x908000, 0x90bfff) AM_RAM_WRITE(macrossp_scrb_videoram_w) AM_BASE(&macrossp_scrb_videoram)
+	AM_RANGE(0x90c200, 0x90c3ff) AM_WRITEONLY /* W/O? */
+	AM_RANGE(0x90d000, 0x90d00b) AM_WRITEONLY AM_BASE(&macrossp_scrb_videoregs) /* W/O? */
+	/* SCR C Layer */
+	AM_RANGE(0x910000, 0x913fff) AM_RAM_WRITE(macrossp_scrc_videoram_w) AM_BASE(&macrossp_scrc_videoram)
+	AM_RANGE(0x914200, 0x9143ff) AM_WRITEONLY /* W/O? */
+	AM_RANGE(0x915000, 0x91500b) AM_WRITEONLY AM_BASE(&macrossp_scrc_videoregs) /* W/O? */
+	/* Text Layer */
+	AM_RANGE(0x918000, 0x91bfff) AM_RAM_WRITE(macrossp_text_videoram_w) AM_BASE(&macrossp_text_videoram)
+	AM_RANGE(0x91c200, 0x91c3ff) AM_WRITEONLY /* W/O? */
+	AM_RANGE(0x91d000, 0x91d00b) AM_WRITEONLY AM_BASE(&macrossp_text_videoregs) /* W/O? */
 
-	AM_RANGE(0x800000, 0x802fff) AM_READ(SMH_RAM)
-
-	AM_RANGE(0x900000, 0x903fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x908000, 0x90bfff) AM_READ(SMH_RAM)
-	AM_RANGE(0x910000, 0x913fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x918000, 0x91bfff) AM_READ(SMH_RAM)
-
-	AM_RANGE(0xa00000, 0xa03fff) AM_READ(SMH_RAM)
+	AM_RANGE(0xa00000, 0xa03fff) AM_RAM_WRITE(paletteram32_macrossp_w) AM_BASE(&paletteram32)
 
 	AM_RANGE(0xb00000, 0xb00003) AM_READ_PORT("INPUTS")
-	AM_RANGE(0xb00004, 0xb00007) AM_READ(macrossp_soundstatus_r)
-	AM_RANGE(0xb0000c, 0xb0000f) AM_READ_PORT("DSW")
-
-	AM_RANGE(0xf00000, 0xf1ffff) AM_READ(SMH_RAM)
-
-//  AM_RANGE(0xfe0000, 0xfe0003) AM_READ(SMH_NOP)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x3fffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x800000, 0x802fff) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_spriteram) AM_SIZE(&spriteram_size)
-
-	/* SCR A Layer */
-	AM_RANGE(0x900000, 0x903fff) AM_WRITE(macrossp_scra_videoram_w) AM_BASE(&macrossp_scra_videoram)
-	AM_RANGE(0x904200, 0x9043ff) AM_WRITE(SMH_RAM) /* W/O? */
-	AM_RANGE(0x905000, 0x90500b) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_scra_videoregs) /* W/O? */
-	/* SCR B Layer */
-	AM_RANGE(0x908000, 0x90bfff) AM_WRITE(macrossp_scrb_videoram_w) AM_BASE(&macrossp_scrb_videoram)
-	AM_RANGE(0x90c200, 0x90c3ff) AM_WRITE(SMH_RAM) /* W/O? */
-	AM_RANGE(0x90d000, 0x90d00b) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_scrb_videoregs) /* W/O? */
-	/* SCR C Layer */
-	AM_RANGE(0x910000, 0x913fff) AM_WRITE(macrossp_scrc_videoram_w) AM_BASE(&macrossp_scrc_videoram)
-	AM_RANGE(0x914200, 0x9143ff) AM_WRITE(SMH_RAM) /* W/O? */
-	AM_RANGE(0x915000, 0x91500b) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_scrc_videoregs) /* W/O? */
-	/* Text Layer */
-	AM_RANGE(0x918000, 0x91bfff) AM_WRITE(macrossp_text_videoram_w) AM_BASE(&macrossp_text_videoram)
-	AM_RANGE(0x91c200, 0x91c3ff) AM_WRITE(SMH_RAM) /* W/O? */
-	AM_RANGE(0x91d000, 0x91d00b) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_text_videoregs) /* W/O? */
-
-	AM_RANGE(0xa00000, 0xa03fff) AM_WRITE(paletteram32_macrossp_w) AM_BASE(&paletteram32)
-
-	AM_RANGE(0xb00004, 0xb00007) AM_WRITE(SMH_NOP)	// irq related?
-	AM_RANGE(0xb00008, 0xb0000b) AM_WRITE(SMH_NOP)	// irq related?
-	AM_RANGE(0xb0000c, 0xb0000f) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xb00004, 0xb00007) AM_READ(macrossp_soundstatus_r) AM_WRITENOP // irq related?
+	AM_RANGE(0xb00008, 0xb0000b) AM_WRITENOP	// irq related?
+	AM_RANGE(0xb0000c, 0xb0000f) AM_READ_PORT("DSW") AM_WRITENOP
 	AM_RANGE(0xb00010, 0xb00013) AM_WRITE(macrossp_palette_fade_w)	// macrossp palette fade
-  	AM_RANGE(0xb00020, 0xb00023) AM_WRITE(SMH_NOP)
+  	AM_RANGE(0xb00020, 0xb00023) AM_WRITENOP
 
 	AM_RANGE(0xc00000, 0xc00003) AM_WRITE(macrossp_soundcmd_w)
 
-	AM_RANGE(0xf00000, 0xf1ffff) AM_WRITE(SMH_RAM) AM_BASE(&macrossp_mainram) /* Main Ram */
-
-//  AM_RANGE(0xfe0000, 0xfe0003) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xf00000, 0xf1ffff) AM_RAM AM_BASE(&macrossp_mainram) /* Main Ram */
+//  AM_RANGE(0xfe0000, 0xfe0003) AM_NOP
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x200000, 0x207fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x400000, 0x40007f) AM_READ(es5506_data_0_word_r)
+static ADDRESS_MAP_START( macrossp_sound_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x200000, 0x207fff) AM_RAM
+	AM_RANGE(0x400000, 0x40007f) AM_DEVREADWRITE8("ensoniq", es5506_r, es5506_w, 0x00ff)
 	AM_RANGE(0x600000, 0x600001) AM_READ(macrossp_soundcmd_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x200000, 0x207fff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x400000, 0x40007f) AM_WRITE(es5506_data_0_word_w)
-ADDRESS_MAP_END
-
 /*** INPUT PORTS *************************************************************/
 
 static INPUT_PORTS_START( macrossp )
@@ -613,13 +584,13 @@ GFXDECODE_END
 
 /*** MACHINE DRIVER **********************************************************/
 
-static void irqhandler(running_machine *machine, int irq)
+static void irqhandler(const device_config *device, int irq)
 {
 	logerror("ES5506 irq %d\n",irq);
 
 	/* IRQ lines 1 & 4 on the sound 68000 are definitely triggered by the ES5506,
     but I haven't noticed the ES5506 ever assert the line - maybe only used when developing the game? */
-//  cpu_set_input_line(machine->cpu[1],1,irq ? ASSERT_LINE : CLEAR_LINE);
+//  cputag_set_input_line(device, "audiocpu", 1, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const es5506_interface es5506_config =
@@ -634,18 +605,18 @@ static const es5506_interface es5506_config =
 
 static MACHINE_DRIVER_START( macrossp )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68EC020, 50000000/2)	/* 25 MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT("main", irq3_line_hold) // there are others ...
+	MDRV_CPU_ADD("maincpu", M68EC020, 50000000/2)	/* 25 MHz */
+	MDRV_CPU_PROGRAM_MAP(macrossp_map)
+	MDRV_CPU_VBLANK_INT("screen", irq3_line_hold) // there are others ...
 
-	MDRV_CPU_ADD("audio", M68000, 32000000/2)	/* 16 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_ADD("audiocpu", M68000, 32000000/2)	/* 16 MHz */
+	MDRV_CPU_PROGRAM_MAP(macrossp_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(32*16, 16*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 0*16, 15*16-1)
 
@@ -657,18 +628,18 @@ static MACHINE_DRIVER_START( macrossp )
 	MDRV_VIDEO_UPDATE(macrossp)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("ensoniq", ES5506, 16000000)
 	MDRV_SOUND_CONFIG(es5506_config)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( quizmoon )
 	MDRV_IMPORT_FROM(macrossp)
 
-	MDRV_SCREEN_MODIFY("main")
+	MDRV_SCREEN_MODIFY("screen")
 	MDRV_SCREEN_VISIBLE_AREA(0, 24*16-1, 0*8, 14*16-1)
 MACHINE_DRIVER_END
 
@@ -677,13 +648,13 @@ MACHINE_DRIVER_END
 /*** ROM LOADING *************************************************************/
 
 ROM_START( macrossp )
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD32_BYTE( "bp964a-c.u1", 0x000003, 0x080000, CRC(39da35e7) SHA1(022c902b0adf21090c650ce68e4b8b42498e1be6) )
 	ROM_LOAD32_BYTE( "bp964a-c.u2", 0x000002, 0x080000, CRC(86d0ca6a) SHA1(8cc1b4a83cbba8b07e1343c5c20e2590d3ce471a) )
 	ROM_LOAD32_BYTE( "bp964a-c.u3", 0x000001, 0x080000, CRC(fb895a7b) SHA1(547e5d3d43e503a15573748ab49a44e5569db1d7) )
 	ROM_LOAD32_BYTE( "bp964a-c.u4", 0x000000, 0x080000, CRC(8c8b966c) SHA1(881fa2b7aefc3ea916924b715d2cd0ceaffe2d92) )
 
-	ROM_REGION( 0x100000, "audio", 0 )
+	ROM_REGION( 0x100000, "audiocpu", 0 )
 	ROM_LOAD16_BYTE( "bp964a.u20", 0x000001, 0x080000, CRC(12960cbb) SHA1(7182c4b36849a5d34ddf388bf5f4485ed360fe84) )
 	ROM_LOAD16_BYTE( "bp964a.u21", 0x000000, 0x080000, CRC(87bdd2fc) SHA1(c33f087ebca6e98db195404788ca8e0cc6663622) )
 
@@ -719,7 +690,7 @@ ROM_START( macrossp )
 ROM_END
 
 ROM_START( quizmoon )
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD32_BYTE( "u1.bin",  0x000003, 0x020000, CRC(ea404553) SHA1(123bb8e399a5b54c43f4eb41d3e5f52c6947900f) )
 	ROM_LOAD32_BYTE( "u2.bin",  0x000002, 0x020000, CRC(024eedff) SHA1(cbaa2b71980a2686e582331616dc36e34ecd9e67) )
 	ROM_LOAD32_BYTE( "u3.bin",  0x000001, 0x020000, CRC(545b1d17) SHA1(f1b15260942482857c48b574ada1e2a3b728f395) )
@@ -729,7 +700,7 @@ ROM_START( quizmoon )
 	ROM_LOAD32_BYTE( "u7.bin",  0x200001, 0x080000, CRC(656b2125) SHA1(ac3874e71ec0aa4e77ac0d556e4572606ce673c7) )
 	ROM_LOAD32_BYTE( "u8.bin",  0x200000, 0x080000, CRC(944df309) SHA1(ee85f6dbfe970b63943d01d9f8b491717a4d5a71) )
 
-	ROM_REGION( 0x100000, "audio", 0 )
+	ROM_REGION( 0x100000, "audiocpu", 0 )
 	ROM_LOAD16_BYTE( "u20.bin", 0x000001, 0x020000, CRC(d7ad1ffb) SHA1(9d375285628b32296c93456a00bc005a3f40ce38) )
 	ROM_LOAD16_BYTE( "u21.bin", 0x000000, 0x020000, CRC(6fc625c6) SHA1(542bc025cf0e37686eae5d6c80bc5e047d6389fd) )
 
@@ -792,13 +763,13 @@ static WRITE32_HANDLER( quizmoon_speedup_w )
 
 static DRIVER_INIT( macrossp )
 {
-	memory_install_write32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xf10158, 0xf1015b, 0, 0, macrossp_speedup_w );
+	memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xf10158, 0xf1015b, 0, 0, macrossp_speedup_w );
 }
 
 static DRIVER_INIT( quizmoon )
 {
 #ifdef UNUSED_FUNCTION
-	memory_install_write32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xf00020, 0xf00023, 0, 0, quizmoon_speedup_w );
+	memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xf00020, 0xf00023, 0, 0, quizmoon_speedup_w );
 #endif
 }
 
