@@ -29,13 +29,13 @@ static READ8_HANDLER( markham_e004_r )
 
 /****************************************************************************/
 
-static ADDRESS_MAP_START( readmem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( markham_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x5fff) AM_ROM
 
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd800, 0xdfff) AM_READ(SMH_RAM) AM_SHARE(1)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
+	AM_RANGE(0xc800, 0xcfff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(markham_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xd800, 0xdfff) AM_RAM AM_SHARE(1)
 
 	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("DSW2")
 	AM_RANGE(0xe001, 0xe001) AM_READ_PORT("DSW1")
@@ -46,38 +46,22 @@ static ADDRESS_MAP_START( readmem1, ADDRESS_SPACE_PROGRAM, 8 )
 
 	AM_RANGE(0xe005, 0xe005) AM_READ_PORT("SYSTEM")
 
-ADDRESS_MAP_END
+	AM_RANGE(0xe008, 0xe008) AM_WRITENOP /* coin counter? */
+	AM_RANGE(0xe009, 0xe009) AM_WRITENOP /* to CPU2 busreq */
 
-static ADDRESS_MAP_START( writemem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_WRITE(SMH_ROM)
-
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xc800, 0xcfff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(markham_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xd800, 0xdfff) AM_WRITE(SMH_RAM) AM_SHARE(1)
-
-	AM_RANGE(0xe008, 0xe008) AM_WRITE(SMH_NOP) /* coin counter? */
-
-	AM_RANGE(0xe009, 0xe009) AM_WRITE(SMH_NOP) /* to CPU2 busreq */
-
-	AM_RANGE(0xe00c, 0xe00d) AM_WRITE(SMH_RAM) AM_BASE(&markham_xscroll)
+	AM_RANGE(0xe00c, 0xe00d) AM_WRITEONLY AM_BASE(&markham_xscroll)
 	AM_RANGE(0xe00e, 0xe00e) AM_WRITE(markham_flipscreen_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( readmem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM) AM_SHARE(1)
-ADDRESS_MAP_END
+static ADDRESS_MAP_START( markham_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x5fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_SHARE(1)
 
-static ADDRESS_MAP_START( writemem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM) AM_SHARE(1)
+	AM_RANGE(0xc000, 0xc000) AM_DEVWRITE("sn1", sn76496_w)
+	AM_RANGE(0xc001, 0xc001) AM_DEVWRITE("sn2", sn76496_w)
 
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(sn76496_0_w)
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(sn76496_1_w)
-
-	AM_RANGE(0xc002, 0xc002) AM_WRITE(SMH_NOP) /* unknown */
-	AM_RANGE(0xc003, 0xc003) AM_WRITE(SMH_NOP) /* unknown */
+	AM_RANGE(0xc002, 0xc002) AM_WRITENOP /* unknown */
+	AM_RANGE(0xc003, 0xc003) AM_WRITENOP /* unknown */
 ADDRESS_MAP_END
 
 
@@ -199,18 +183,18 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( markham )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80,8000000/2) /* 4.000MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem1,writemem1)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,8000000/2) /* 4.000MHz */
+	MDRV_CPU_PROGRAM_MAP(markham_master_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_CPU_ADD("sub", Z80,8000000/2) /* 4.000MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem2,writemem2)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_PROGRAM_MAP(markham_slave_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_QUANTUM_TIME(HZ(6000))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -237,7 +221,7 @@ MACHINE_DRIVER_END
 /****************************************************************************/
 
 ROM_START( markham )
-	ROM_REGION( 0x10000, "main", 0 ) /* main CPU */
+	ROM_REGION( 0x10000, "maincpu", 0 ) /* main CPU */
 	ROM_LOAD( "tv3.9",   0x0000,  0x2000, CRC(59391637) SHA1(e0cfe49a5591d6a6e64c3277319a19235b0ee6ea) )
 	ROM_LOAD( "tvg4.10", 0x2000,  0x2000, CRC(1837bcce) SHA1(50e1ae0a4937f09a3dced48bb12f57cee846487a) )
 	ROM_LOAD( "tvg5.11", 0x4000,  0x2000, CRC(651da602) SHA1(9f33d6ea0526af9be8ac9210910ea768da825ee5) )
