@@ -10,6 +10,10 @@
       Other: 2 Z80APIO (I/O and interrupt controllers)
              1 8255 (I/O)
 
+  CRT 252: addon board for CRT 250, stores question roms
+
+  CRT 258: addon board for CRT 250, contains UART and Microtouch touch screen controller
+
   CRT 260 additional components:
   - Microtouch touch screen controller (SMT-3)
   - PC16550 UART (for communication with touch screen controller)
@@ -30,9 +34,9 @@
   Pit Boss Superstar (c)1990
   *Pit Boss Superstar 30 (c)1993
   Pit Boss Megastar (c)1994
+  *Pit Boss Supertouch 30 (c)1993/4
 
   CRT 260:
-  *Pit Boss Supertouch 30 (c)1994?
   *Megatouch Video (c)1994?
   *Megatouch II (c)1995
   Megatouch III (c)1995
@@ -40,6 +44,7 @@
   Megatouch IV (c)1996
   Megatouch IV Tournament Edition (c)1996
   Super Megatouch IV (c) 1996  (rom labels 9255-41-0x, see below)
+  Super Megatouch IV Tournament Edition (c) 1996
   *Megatouch 5 (c)1997
   *Megatouch 5 Tournament Edition (c)1997
   Megatouch 6 (c)1998
@@ -47,20 +52,41 @@
 
   * indicates that game needs to be dumped or redumped
 
-Custom Program Versions (from Super Megatouch IV manual):
+Custom Program Versions (from different Megatouch manuals):
 
 PROGRAM#    Program Version      Program Differences
 ---------------------------------------------------------------------------------------------
-9255-41-01  Standard Version     Includes all Options, no Restrictions
-9255-41-02  Minnesota Version    Excludes Casino Games
-9255-41-06  California Version   Excludes Poker Double-up feature & No Free Game in Solitaire
-9255-41-07  New Jersey Version   Includes 2-Coin Limit with Lockout Coil
-9255-41-50  Bi-Lingual ENG/GER   Same as Standard Version, Without Word/Casino Games
-9255-41-57  Internation Version  Same as Standard Version, Without Word Games
-9255-41-60  Bi-Lingual ENG/FRE   Same as Standard Version, Without Word/Casino Games
-9255-41-62  No Free Credit       Same as Standard Version, With No Free Credit
-9255-41-70  Australia Version    Same as Standard Version with Special Question Set
-9255-41-71  South Africa Ver.    Same as Standard Version with Special Question Set
+9255-xx-01  Standard Version     Includes all Options, no Restrictions
+9255-xx-02  Minnesota Version    Excludes Casino Games
+9255-xx-03  Louisiana Version    Excludes all Poker Games
+9255-xx-04  Wisconsin Version    Game Connot End if Player Busts; 1,000 Points are Added to End of Each Hand
+9255-xx-06  California Version   Excludes Poker Double-up feature & No Free Game in Solitaire
+9255-xx-07  New Jersey Version   Includes 2-Coin Limit with Lockout Coil
+9255-xx-50  Bi-Lingual ENG/GER   Same as Standard Version, Without Word/Casino Games
+9255-xx-54  Bi-Lingual ENG/SPA   Same as Standard Version, Without Word Games
+9255-xx-56  No Free Credits      Same as Standard Version, Without Word Games and No Free Credits
+9255-xx-57  Internation Version  Same as Standard Version, Without Word Games
+9255-xx-60  Bi-Lingual ENG/FRE   Same as Standard Version, Without Word/Casino Games
+9255-xx-62  No Free Credit       Same as Standard Version, With No Free Credit (see regional notes below)
+9255-xx-62  Croatia              Same as Standard Version, With No Free Credit (see regional notes below)
+9255-xx-70  Australia Version    Same as Standard Version with Special Question Set
+9255-xx-71  South Africa Ver.    Same as Standard Version with Special Question Set
+
+xx = game/version code:
+
+ 20 - Megatouch 3
+ 30 - Megatouch 3 Tournament
+ 40 - Megatouch 4
+ 41 - Megatouch Super 4
+ 50 - Megatouch 4 Tournament
+ 51 - Megatouch Super 4 Tournament
+ 60 - Megatouch 5
+ 70 - Megatouch 5 Tournament??
+ 80 - Megatouch 6
+
+Not all regional versions are available for each Megatouch series
+ For Megatouch 4,       set 9255-40-62 is Croatia
+ For Megatouch Super 4, set 9255-41-62 is No Free Credit
 
   Notes/ToDo:
   - offset for top V9938 layer is hardcoded, probably should be taken from V9938 setup
@@ -68,7 +94,8 @@ PROGRAM#    Program Version      Program Differences
   - clean up V9938 interrupt implementation
   - finish inputs, dsw, outputs (lamps)
   - problem with registering touches on the bottom of the screen (currently hacked to work)
-  - megat5: has jmp $0000 in the initialization code causing infinite loop, is rom bad?
+  - megat5: has jmp $0000 in the initialization code causing infinite loop, rom U38 is dumped at half size / bad dump
+  - for pbst30 only roms were found, it appears that two roms with graphics data were missing, using pitbossm roms for now
  */
 
 #include "driver.h"
@@ -446,7 +473,7 @@ static WRITE8_HANDLER(meritm_crt250_questions_bank_w)
 		return;
 	}
 
-	dst = memory_region(space->machine, "main") + 0x70000 + 2;
+	dst = memory_region(space->machine, "maincpu") + 0x70000 + 2;
 
 	if (data == 0)
 	{
@@ -559,11 +586,30 @@ static ADDRESS_MAP_START( meritm_crt250_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x21, 0x21) AM_READWRITE(v9938_1_status_r, v9938_1_command_w)
 	AM_RANGE(0x22, 0x22) AM_WRITE(v9938_1_palette_w)
 	AM_RANGE(0x23, 0x23) AM_WRITE(v9938_1_register_w)
-	AM_RANGE(0x30, 0x33) AM_DEVREADWRITE(PPI8255, "ppi8255", ppi8255_r, ppi8255_w)
-	AM_RANGE(0x40, 0x43) AM_DEVREADWRITE(Z80PIO, "z80pio_0", z80pio_r, z80pio_w)
-	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE(Z80PIO, "z80pio_1", z80pio_r, z80pio_w)
-	AM_RANGE(0x80, 0x80) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
-	AM_RANGE(0x81, 0x81) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x30, 0x33) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
+	AM_RANGE(0x40, 0x43) AM_DEVREADWRITE("z80pio_0", z80pio_r, z80pio_w)
+	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE("z80pio_1", z80pio_r, z80pio_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x80, 0x81) AM_DEVWRITE("ay", ay8910_address_data_w)
+	AM_RANGE(0xff, 0xff) AM_WRITE(meritm_crt250_bank_w)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( meritm_crt250_crt258_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x10, 0x10) AM_READWRITE(v9938_0_vram_r, v9938_0_vram_w)
+	AM_RANGE(0x11, 0x11) AM_READWRITE(v9938_0_status_r, v9938_0_command_w)
+	AM_RANGE(0x12, 0x12) AM_WRITE(v9938_0_palette_w)
+	AM_RANGE(0x13, 0x13) AM_WRITE(v9938_0_register_w)
+	AM_RANGE(0x20, 0x20) AM_READWRITE(v9938_1_vram_r, v9938_1_vram_w)
+	AM_RANGE(0x21, 0x21) AM_READWRITE(v9938_1_status_r, v9938_1_command_w)
+	AM_RANGE(0x22, 0x22) AM_WRITE(v9938_1_palette_w)
+	AM_RANGE(0x23, 0x23) AM_WRITE(v9938_1_register_w)
+	AM_RANGE(0x30, 0x33) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
+	AM_RANGE(0x40, 0x43) AM_DEVREADWRITE("z80pio_0", z80pio_r, z80pio_w)
+	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE("z80pio_1", z80pio_r, z80pio_w)
+	AM_RANGE(0x60, 0x67) AM_READWRITE(pc16552d_0_r,pc16552d_0_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x80, 0x81) AM_DEVWRITE("ay", ay8910_address_data_w)
 	AM_RANGE(0xff, 0xff) AM_WRITE(meritm_crt250_bank_w)
 ADDRESS_MAP_END
 
@@ -585,12 +631,12 @@ static ADDRESS_MAP_START( meritm_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x21, 0x21) AM_READWRITE(v9938_1_status_r, v9938_1_command_w)
 	AM_RANGE(0x22, 0x22) AM_WRITE(v9938_1_palette_w)
 	AM_RANGE(0x23, 0x23) AM_WRITE(v9938_1_register_w)
-	AM_RANGE(0x30, 0x33) AM_DEVREADWRITE(PPI8255, "ppi8255", ppi8255_r, ppi8255_w)
-	AM_RANGE(0x40, 0x43) AM_DEVREADWRITE(Z80PIO, "z80pio_0", z80pio_r, z80pio_w)
-	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE(Z80PIO, "z80pio_1", z80pio_r, z80pio_w)
+	AM_RANGE(0x30, 0x33) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
+	AM_RANGE(0x40, 0x43) AM_DEVREADWRITE("z80pio_0", z80pio_r, z80pio_w)
+	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE("z80pio_1", z80pio_r, z80pio_w)
 	AM_RANGE(0x60, 0x67) AM_READWRITE(pc16552d_0_r,pc16552d_0_w)
-	AM_RANGE(0x80, 0x80) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
-	AM_RANGE(0x81, 0x81) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x80, 0x81) AM_DEVWRITE("ay", ay8910_address_data_w)
 	AM_RANGE(0xff, 0xff) AM_WRITE(meritm_bank_w)
 ADDRESS_MAP_END
 
@@ -618,6 +664,9 @@ static INPUT_PORTS_START(meritm_crt260)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "Calibration" ) PORT_CODE(KEYCODE_C)
+
+	PORT_START("DSW")	/* need for AY-8910 accesses */
+	PORT_BIT( 0xff, 0x00, IPT_UNUSED)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START(meritm_crt250)
@@ -636,12 +685,15 @@ static INPUT_PORTS_START(meritm_crt250)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN)
+
+	PORT_START("DSW")	/* need for AY-8910 accesses */
+	PORT_BIT( 0xff, 0x00, IPT_UNUSED)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START(pitbossm)
 	PORT_INCLUDE(meritm_crt250)
 
-	PORT_START("DSW")
+	PORT_MODIFY("DSW")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
@@ -668,6 +720,36 @@ static INPUT_PORTS_START(pitbossm)
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 INPUT_PORTS_END
 
+static INPUT_PORTS_START(pbst30)
+	PORT_INCLUDE(meritm_crt260)
+
+	PORT_MODIFY("DSW")
+	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) ) // when on, touch screen coordinates are mirrored?
+	PORT_DIPNAME( 0x02, 0x02, "Enable casino games" )
+	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Yes ) )
+	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) ) // off 1 coin 0.5 credit, on 1 coin 1 credit
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
+INPUT_PORTS_END
+
 /*************************************
  *
  *  8255
@@ -694,22 +776,22 @@ static WRITE8_DEVICE_HANDLER(meritm_crt250_port_b_w)
 
 static const ppi8255_interface crt260_ppi8255_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	meritm_8255_port_c_r,		/* Port C read */
-	NULL,						/* Port A write (used) */
-	NULL,						/* Port B write (used LMP x DRIVE) */
-	NULL						/* Port C write */
+	DEVCB_NULL,								/* Port A read */
+	DEVCB_NULL,								/* Port B read */
+	DEVCB_HANDLER(meritm_8255_port_c_r),	/* Port C read */
+	DEVCB_NULL,								/* Port A write (used) */
+	DEVCB_NULL,								/* Port B write (used LMP x DRIVE) */
+	DEVCB_NULL								/* Port C write */
 };
 
 static const ppi8255_interface crt250_ppi8255_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	meritm_8255_port_c_r,		/* Port C read */
-	NULL,						/* Port A write (used) */
-	meritm_crt250_port_b_w,		/* Port B write (used LMP x DRIVE) */
-	NULL						/* Port C write */
+	DEVCB_NULL,								/* Port A read */
+	DEVCB_NULL,								/* Port B read */
+	DEVCB_HANDLER(meritm_8255_port_c_r),	/* Port C read */
+	DEVCB_NULL,								/* Port A write (used) */
+	DEVCB_HANDLER(meritm_crt250_port_b_w),	/* Port B write (used LMP x DRIVE) */
+	DEVCB_NULL								/* Port C write */
 };
 
 /*************************************
@@ -723,12 +805,7 @@ static const ppi8255_interface crt250_ppi8255_intf =
  Port B: Bits 0,1 used
 */
 
-static READ8_HANDLER(meritm_ay8930_port_a_r)
-{
-	return input_port_read_safe(space->machine, "DSW", 0);
-};
-
-static WRITE8_HANDLER(meritm_ay8930_port_b_w)
+static WRITE8_DEVICE_HANDLER(meritm_ay8930_port_b_w)
 {
 	// lamps
 };
@@ -737,10 +814,10 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	meritm_ay8930_port_a_r, /* Port A read */
-	NULL, /* Port B read */
-	NULL, /* Port A write */
-	meritm_ay8930_port_b_w  /* Port B write */
+	DEVCB_INPUT_PORT("DSW"), /* Port A read */
+	DEVCB_NULL, /* Port B read */
+	DEVCB_NULL, /* Port A write */
+	DEVCB_HANDLER(meritm_ay8930_port_b_w)  /* Port B write */
 };
 
 /*************************************
@@ -749,16 +826,16 @@ static const ay8910_interface ay8910_config =
  *
  *************************************/
 
-static void meritm_audio_pio_interrupt(const device_config *device, int state)
+static WRITE_LINE_DEVICE_HANDLER( meritm_audio_pio_interrupt )
 {
 	//logerror( "PIO(0) interrupt line: %d, V = %d, H = %d\n", state, video_screen_get_vpos(0), video_screen_get_hpos(0) );
-	cpu_set_input_line(device->machine->cpu[0], 0, state);
+	cputag_set_input_line(device->machine, "maincpu", 0, state);
 }
 
-static void meritm_io_pio_interrupt(const device_config *device, int state)
+static WRITE_LINE_DEVICE_HANDLER( meritm_io_pio_interrupt  )
 {
 	//logerror( "PIO(1) interrupt line: %d, V = %d, H = %d\n", state, video_screen_get_vpos(0), video_screen_get_hpos(0) );
-	cpu_set_input_line(device->machine->cpu[0], 0, state);
+	cputag_set_input_line(device->machine, "maincpu", 0, state);
 }
 
 
@@ -783,16 +860,6 @@ static WRITE8_DEVICE_HANDLER(meritm_audio_pio_port_b_w)
 	ds1204_w((data & 0x4) >> 2, (data & 0x2) >> 1, data & 0x01);
 };
 
-static READ8_DEVICE_HANDLER(meritm_io_pio_port_a_r)
-{
-	return input_port_read(device->machine, "PIO1_PORTA");
-};
-
-static READ8_DEVICE_HANDLER(meritm_io_pio_port_b_r)
-{
-	return input_port_read(device->machine, "PIO1_PORTB");
-};
-
 static WRITE8_DEVICE_HANDLER(meritm_io_pio_port_a_w)
 {
 };
@@ -803,43 +870,43 @@ static WRITE8_DEVICE_HANDLER(meritm_io_pio_port_b_w)
 
 static const z80pio_interface meritm_audio_pio_intf =
 {
-	meritm_audio_pio_interrupt,
-	meritm_audio_pio_port_a_r,
-	meritm_audio_pio_port_b_r,
-	meritm_audio_pio_port_a_w,
-	meritm_audio_pio_port_b_w,
-	0,
-	0
+	DEVCB_LINE(meritm_audio_pio_interrupt),
+	DEVCB_HANDLER(meritm_audio_pio_port_a_r),
+	DEVCB_HANDLER(meritm_audio_pio_port_b_r),
+	DEVCB_HANDLER(meritm_audio_pio_port_a_w),
+	DEVCB_HANDLER(meritm_audio_pio_port_b_w),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static const z80pio_interface meritm_io_pio_intf =
 {
-	meritm_io_pio_interrupt,
-	meritm_io_pio_port_a_r,
-	meritm_io_pio_port_b_r,
-	meritm_io_pio_port_a_w,
-	meritm_io_pio_port_b_w,
-	0,
-	0
+	DEVCB_LINE(meritm_io_pio_interrupt),
+	DEVCB_INPUT_PORT("PIO1_PORTA"),
+	DEVCB_INPUT_PORT("PIO1_PORTB"),
+	DEVCB_HANDLER(meritm_io_pio_port_a_w),
+	DEVCB_HANDLER(meritm_io_pio_port_b_w),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static const z80_daisy_chain meritm_daisy_chain[] =
 {
-	{ Z80PIO, "z80pio_1" },
-	{ Z80PIO, "z80pio_0" },
+	{ "z80pio_1" },
+	{ "z80pio_0" },
 	{ NULL }
 };
 
 static MACHINE_START(merit_common)
 {
-	meritm_z80pio[0] = devtag_get_device( machine, Z80PIO, "z80pio_0" );
-	meritm_z80pio[1] = devtag_get_device( machine, Z80PIO, "z80pio_1" );
+	meritm_z80pio[0] = devtag_get_device( machine, "z80pio_0" );
+	meritm_z80pio[1] = devtag_get_device( machine, "z80pio_1" );
 
 };
 
 static MACHINE_START(meritm_crt250)
 {
-	memory_configure_bank(machine, 1, 0, 8, memory_region(machine, "main"), 0x10000);
+	memory_configure_bank(machine, 1, 0, 8, memory_region(machine, "maincpu"), 0x10000);
 	meritm_bank = 0xff;
 	meritm_crt250_switch_banks(machine);
 	MACHINE_START_CALL(merit_common);
@@ -853,12 +920,19 @@ static MACHINE_START(meritm_crt250_questions)
 	state_save_register_global(machine, questions_loword_address);
 };
 
+static MACHINE_START(meritm_crt250_crt252_crt258)
+{
+	MACHINE_START_CALL(meritm_crt250_questions);
+	pc16552d_init(machine, 0, UART_CLK, NULL, pc16650d_tx_callback);
+	microtouch_init(machine, meritm_microtouch_tx_callback, meritm_touch_coord_transform);
+}
+
 static MACHINE_START(meritm_crt260)
 {
-	meritm_ram = auto_malloc( 0x8000 );
+	meritm_ram = auto_alloc_array(machine, UINT8,  0x8000 );
 	memset( meritm_ram, 0x8000, 0x00 );
-	memory_configure_bank(machine, 1, 0, 128, memory_region(machine, "main"), 0x8000);
-	memory_configure_bank(machine, 2, 0, 128, memory_region(machine, "main"), 0x8000);
+	memory_configure_bank(machine, 1, 0, 128, memory_region(machine, "maincpu"), 0x8000);
+	memory_configure_bank(machine, 2, 0, 128, memory_region(machine, "maincpu"), 0x8000);
 	memory_configure_bank(machine, 3, 0, 4, meritm_ram, 0x2000);
 	meritm_bank = 0xff;
 	meritm_psd_a15 = 0;
@@ -892,9 +966,9 @@ static NVRAM_HANDLER(meritm_crt260)
 #define MSX2_VISIBLE_YBORDER_PIXELS	14 * 2
 
 static MACHINE_DRIVER_START(meritm_crt250)
-	MDRV_CPU_ADD("main", Z80, SYSTEM_CLK/6)
-	MDRV_CPU_PROGRAM_MAP(meritm_crt250_map,0)
-	MDRV_CPU_IO_MAP(meritm_crt250_io_map,0)
+	MDRV_CPU_ADD("maincpu", Z80, SYSTEM_CLK/6)
+	MDRV_CPU_PROGRAM_MAP(meritm_crt250_map)
+	MDRV_CPU_IO_MAP(meritm_crt250_io_map)
 	MDRV_CPU_CONFIG(meritm_daisy_chain)
   	MDRV_CPU_VBLANK_INT_HACK(meritm_interrupt,262)
 
@@ -909,7 +983,7 @@ static MACHINE_DRIVER_START(meritm_crt250)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-  	MDRV_SCREEN_ADD("main",RASTER)
+  	MDRV_SCREEN_ADD("screen",RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 
@@ -932,16 +1006,23 @@ MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START(meritm_crt250_questions)
 	MDRV_IMPORT_FROM(meritm_crt250)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(meritm_crt250_questions_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(meritm_crt250_questions_map)
 	MDRV_MACHINE_START(meritm_crt250_questions)
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START(meritm_crt250_crt252_crt258)
+	MDRV_IMPORT_FROM(meritm_crt250_questions)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_IO_MAP(meritm_crt250_crt258_io_map)
+	MDRV_MACHINE_START(meritm_crt250_crt252_crt258)
+MACHINE_DRIVER_END
+
 static MACHINE_DRIVER_START(meritm_crt260)
 	MDRV_IMPORT_FROM(meritm_crt250)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(meritm_map,0)
-	MDRV_CPU_IO_MAP(meritm_io_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(meritm_map)
+	MDRV_CPU_IO_MAP(meritm_io_map)
 
 	MDRV_PPI8255_RECONFIG( "ppi8255", crt260_ppi8255_intf )
 
@@ -979,7 +1060,7 @@ MACHINE_DRIVER_END
 */
 
 ROM_START( pitboss2 )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD( "u9",  0x00000, 0x10000, CRC(a1b6ac15) SHA1(b7b395f3e7e14dbb84003e03bf7d054e795a7211) )
 	ROM_LOAD( "u10", 0x10000, 0x10000, CRC(207aa83c) SHA1(1955d75b9e561312e98831571c9853579ded3734) )
 	ROM_LOAD( "u11", 0x20000, 0x10000, CRC(2052e043) SHA1(36b6cbc5712fc736c748a68bd12675291eae669d) )
@@ -991,7 +1072,7 @@ ROM_START( pitboss2 )
 ROM_END
 
 ROM_START( pitbosss )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD( "9221-10-0b.u9",  0x00000, 0x10000, CRC(e1fbf7cb) SHA1(e04163219c357cd3da2a78ba2590d453df8e9477) )
 	ROM_LOAD( "9221-10-0.u10",  0x10000, 0x10000, CRC(853a1a99) SHA1(45e33442aa7e51c05c9ac8b8458937ee3ff4c21d) )
 	ROM_LOAD( "9221-10-0b.u11", 0x20000, 0x10000, CRC(6d6dfaf3) SHA1(de76c577eef1bb6637aacffedcc40266af92506e) )
@@ -1003,7 +1084,7 @@ ROM_START( pitbosss )
 ROM_END
 
 ROM_START( spitboss )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD( "u9-0a.rom",  0x00000, 0x10000, CRC(e0c45c9c) SHA1(534bff67c8fee08f1c348275de8977659efa9f69) )
 	ROM_LOAD( "u10.rom",    0x10000, 0x10000, CRC(ed010c58) SHA1(02750944a28c1c27ce2a9904d11b7e46272a940e) )
 	ROM_LOAD( "u11-0a.rom", 0x20000, 0x10000, CRC(0c65fa86) SHA1(7906a8d615116ca67bf370dfb2da8cb2389a313d) )
@@ -1047,7 +1128,7 @@ ROM_END
 */
 
 ROM_START( pitbossm )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD( "4",  0x00000, 0x10000, CRC(55e14fb1) SHA1(ec29764d1b63360f64b82452e0db8054b99fcca0) )
 	ROM_LOAD( "5",  0x10000, 0x10000, CRC(853a1a99) SHA1(45e33442aa7e51c05c9ac8b8458937ee3ff4c21d) )
 	ROM_LOAD( "6",  0x20000, 0x10000, CRC(47a9dfc7) SHA1(eca100003f5605bcf405f610a0458ccb67894d35) )
@@ -1064,6 +1145,40 @@ ROM_START( pitbossm )
 	ROM_LOAD( "1",  0x80000, 0x40000, CRC(590a1565) SHA1(b80ea967b6153847b2594e9c59bfe87559022b6c) )
 ROM_END
 
+
+ROM_START( pbst30 ) /* Dallas DS1204V security key at U1 labeled 9234-10 U1-RO1 C1994 MII */
+	ROM_REGION( 0x80000, "maincpu", 0 )
+	ROM_LOAD( "9234-10-01_u9-r0",  0x00000, 0x10000, CRC(96f39c9a) SHA1(df698e94a5204cf050ceadc5c257ca5f68171114) )
+	ROM_LOAD( "5",  0x10000, 0x10000, BAD_DUMP CRC(853a1a99) SHA1(45e33442aa7e51c05c9ac8b8458937ee3ff4c21d) ) // taken from pitbossm
+	ROM_LOAD( "9234-10-01_u11-r0",  0x20000, 0x10000, CRC(835fa041) SHA1(2ae754c5fcf50548eb214902409217d1643c6eaa) )
+	ROM_LOAD( "7",  0x30000, 0x10000, BAD_DUMP CRC(b9fb4203) SHA1(84b514d9739d9c2ab1081cfc7cdedb41155ee038) ) // taken from pitbossm
+	ROM_LOAD( "9234-10-01_u14-r0",  0x50000, 0x10000, CRC(9b0873a4) SHA1(7362c6220aa4bf1a9ab7c11cb8a51587a2a0a992) )
+	ROM_LOAD( "9234-10-01_u15-r0",  0x60000, 0x10000, CRC(9fbd8582) SHA1(c0f68c8a7cdca34c8736cefc71767c421bcaba8a) )
+
+
+	ROM_REGION( 0xc0000, "user1", 0 ) // extra data / extra banks?
+	ROM_LOAD( "qs9234-01_u7-r0",  0x00000, 0x40000, CRC(c0534aaa) SHA1(4b3cbf03f29fd5b4b8fd423e73c0c8147692fa75) )
+	ROM_LOAD( "qs9234-01_u6-r0",  0x40000, 0x40000, CRC(fe2cd934) SHA1(623011dc53ed6eefefa0725dba6fd1efee2077c1) )
+	ROM_LOAD( "qs9234-01_u5-r0",  0x80000, 0x40000, CRC(293fe305) SHA1(8a551ae8fb4fa4bf329128be1bfd6f1c3ff5a366) )
+ROM_END
+
+ROM_START( pbst30b ) /* Dallas DS1204V security key at U1 labeled 9234-01 U1-RO1 C1993 MII */
+	ROM_REGION( 0x80000, "maincpu", 0 )
+	ROM_LOAD( "9234-00-01_u9-r0a",  0x00000, 0x10000, CRC(5f058f95) SHA1(98382935340a076bdb1b20c7f16c25b6084599fe) )
+	ROM_LOAD( "5",  0x10000, 0x10000, BAD_DUMP CRC(853a1a99) SHA1(45e33442aa7e51c05c9ac8b8458937ee3ff4c21d) ) // taken from pitbossm
+	ROM_LOAD( "9234-00-01_u11-r0a",  0x20000, 0x10000, CRC(79125fb5) SHA1(6ca4f33c363cfb6f5c0f23b8fcc8cfcc076f68b1) )
+	ROM_LOAD( "7",  0x30000, 0x10000, BAD_DUMP CRC(b9fb4203) SHA1(84b514d9739d9c2ab1081cfc7cdedb41155ee038) ) // taken from pitbossm
+	ROM_LOAD( "9234-00-01_u14-r0a",  0x50000, 0x10000, CRC(e83f91d5) SHA1(1d64c943787b239763f44be412ee7f5ad13eb37d) )
+	ROM_LOAD( "9234-00-01_u15-r0a",  0x60000, 0x10000, CRC(f10f0d39) SHA1(2b5d5a93adb5251e09160b10c067b6e70289f608) )
+
+
+	ROM_REGION( 0xc0000, "user1", 0 ) // extra data / extra banks?
+	ROM_LOAD( "qs9234-01_u7-r0",  0x00000, 0x40000, CRC(c0534aaa) SHA1(4b3cbf03f29fd5b4b8fd423e73c0c8147692fa75) )
+	ROM_LOAD( "qs9234-01_u6-r0",  0x40000, 0x40000, CRC(fe2cd934) SHA1(623011dc53ed6eefefa0725dba6fd1efee2077c1) )
+	ROM_LOAD( "qs9234-01_u5-r0",  0x80000, 0x40000, CRC(293fe305) SHA1(8a551ae8fb4fa4bf329128be1bfd6f1c3ff5a366) )
+ROM_END
+
+
 /*
     Mega Touch
     by Merit Industries
@@ -1146,7 +1261,7 @@ SC3943.u20    = ATF16V8B25PC
 */
 
 ROM_START( megat3 ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-RO1 C1995 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-20-01_u32-r0d", 0x000000, 0x080000, CRC(ac969296) SHA1(7e09e9141637339b83c21f2488560cdf8a460069) ) /* Location U32 */
 	ROM_RELOAD(                     0x080000, 0x080000)
 	ROM_LOAD( "qs9255-01_u36-r0",   0x100000, 0x080000, CRC(96bb501e) SHA1(f48ef238e8543676c42e3b85464a25ac179dcdd1) ) /* Location U36 */
@@ -1163,7 +1278,7 @@ ROM_START( megat3 ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-R
 ROM_END
 
 ROM_START( megat3a ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-RO1 C1995 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-20-01_u32-r0d", 0x000000, 0x080000, CRC(ac969296) SHA1(7e09e9141637339b83c21f2488560cdf8a460069) ) /* Location U32 */
 	ROM_RELOAD(                     0x080000, 0x080000)
 	ROM_LOAD( "qs9255-01_u36-r0",   0x100000, 0x080000, CRC(96bb501e) SHA1(f48ef238e8543676c42e3b85464a25ac179dcdd1) ) /* Location U36 */
@@ -1180,7 +1295,7 @@ ROM_START( megat3a ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-
 ROM_END
 
 ROM_START( megat3ca ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-RO1 C1995 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-20-01_u32-r0a", 0x000000, 0x080000, CRC(69110f8f) SHA1(253487f0b4a82072efb7c70bebf953ea1c41d0d8) ) /* Location U32 */
 	ROM_RELOAD(                     0x080000, 0x080000)
 	ROM_LOAD( "qs9255-01_u36-r0",   0x100000, 0x080000, CRC(96bb501e) SHA1(f48ef238e8543676c42e3b85464a25ac179dcdd1) ) /* Location U36 */
@@ -1197,7 +1312,7 @@ ROM_START( megat3ca ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5
 ROM_END
 
 ROM_START( megat3nj ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5-RO1 C1995 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-20-01_u32-r0d", 0x000000, 0x080000, CRC(ac969296) SHA1(7e09e9141637339b83c21f2488560cdf8a460069) ) /* Location U32 */
 	ROM_RELOAD(                     0x080000, 0x080000)
 	ROM_LOAD( "qs9255-01_u36-r0",   0x100000, 0x080000, CRC(96bb501e) SHA1(f48ef238e8543676c42e3b85464a25ac179dcdd1) ) /* Location U36 */
@@ -1214,7 +1329,7 @@ ROM_START( megat3nj ) /* Dallas DS1204V security key at U5 labeled 9255-20-01 U5
 ROM_END
 
 ROM_START( megat3te ) /* Dallas DS1204V security key at U5 labeled 9255-30-01 U5-RO1 C1995 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-30-01_u32-r0",  0x000000, 0x100000, CRC(31ac0004) SHA1(4bec97a852a7dadb0ab4f193bc376ed149102082) ) /* Location U32 */
 	ROM_LOAD( "qs9255-01_u36-r0",   0x100000, 0x080000, CRC(96bb501e) SHA1(f48ef238e8543676c42e3b85464a25ac179dcdd1) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x080000)
@@ -1230,7 +1345,7 @@ ROM_START( megat3te ) /* Dallas DS1204V security key at U5 labeled 9255-30-01 U5
 ROM_END
 
 ROM_START( megat4 ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5-B-RO1 C1996 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-40-01_u32-r0",  0x000000, 0x100000, CRC(08b1b8fe) SHA1(c562f2e065d6d7f753f6fd1d0b8355b01cb089ec) ) /* Location U32 */
 	ROM_LOAD( "qs9255-02_u36-r0",   0x100000, 0x80000,  CRC(57322328) SHA1(12bc604c9d34cde431ef7cd2aa33c7b12ac01833) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1247,7 +1362,7 @@ ROM_START( megat4 ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5-B
 ROM_END
 
 ROM_START( megat4a ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5-B-RO1 C1996 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-40-01_u32-r0",  0x000000, 0x100000, CRC(08b1b8fe) SHA1(c562f2e065d6d7f753f6fd1d0b8355b01cb089ec) ) /* Location U32 */
 	ROM_LOAD( "qs9255-02_u36-r0",   0x100000, 0x80000,  CRC(57322328) SHA1(12bc604c9d34cde431ef7cd2aa33c7b12ac01833) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1264,7 +1379,7 @@ ROM_START( megat4a ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5-
 ROM_END
 
 ROM_START( megat4sn ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5-B-RO1 C1996 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-40-01_u32-r0a", 0x000000, 0x100000, CRC(9ace8f52) SHA1(7c755c77cbfb234e1d6f531c90e4a8661275d464) ) /* Location U32 */
 	ROM_LOAD( "qs9255-02_u36-r0",   0x100000, 0x80000,  CRC(57322328) SHA1(12bc604c9d34cde431ef7cd2aa33c7b12ac01833) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1273,8 +1388,8 @@ ROM_START( megat4sn ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5
 	ROM_LOAD( "9255-41-07_u38-r0g", 0x300000, 0x80000,  CRC(71eac4d4) SHA1(73b9ed876f0af94bbd88503921a2b4f26bcfd397) ) /* Location U38, 02/11/1997 11:59:41 - New Jersey version */
 	ROM_RELOAD(                     0x380000, 0x80000)
 
-	ROM_REGION( 0x8000, "user1", 0 ) // nvram
-	ROM_LOAD( "megat4sn.nv",  0x0000, 0x8000, CRC(1ac8de52) SHA1(d4e7e455f581d7c5192209995af1b98d7802e50f) )
+	ROM_REGION( 0x8000, "user1", 0 ) // DS1225Y nv ram
+	ROM_LOAD( "mt4sn_ds1225y.u31",  0x0000, 0x8000, CRC(8d2a97e7) SHA1(7cb01d9499fed1674da6a04a11ed1cef0a39b3c0) ) /* No actual label, so use a unique name for this set */
 
 	ROM_REGION( 0x1000, "user2", 0 ) // PALs
 	ROM_LOAD( "sc3943.u20",     0x000, 0x117, CRC(5a72fe78) SHA1(4b1a36904eb7048518507fe14bdade5c2589dbd7) )
@@ -1284,7 +1399,7 @@ ROM_START( megat4sn ) /* Dallas DS1204V security key at U5 labeled 9255-40-01 U5
 ROM_END
 
 ROM_START( megat4te ) /* Dallas DS1204V security key at U5 labeled 9255-50-01 U5-B-RO1 C1996 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-40-01_u32-r0",  0x000000, 0x100000, CRC(08b1b8fe) SHA1(c562f2e065d6d7f753f6fd1d0b8355b01cb089ec) ) /* Location U32 */
 	ROM_LOAD( "qs9255-02_u36-r0",   0x100000, 0x80000,  CRC(57322328) SHA1(12bc604c9d34cde431ef7cd2aa33c7b12ac01833) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1294,7 +1409,27 @@ ROM_START( megat4te ) /* Dallas DS1204V security key at U5 labeled 9255-50-01 U5
 	ROM_RELOAD(                     0x380000, 0x080000 )
 
 	ROM_REGION( 0x8000, "user1", 0 ) // DS1644 nv ram
-	ROM_LOAD( "ds1644.u31",  0x00000,  0x8000,   CRC(0908bc39) SHA1(e6ec6238d6bf5c802e046407c0f25a83b09f6135) )
+	ROM_LOAD( "mt4te_ds1644.u31",  0x00000,  0x8000,   CRC(d9485491) SHA1(c602bf954fe8b06f81b0f5002246e8fa89237705) ) /* No actual label, so use a unique name for this set */
+
+	ROM_REGION( 0x1000, "user2", 0 ) // PALs
+	ROM_LOAD( "sc3943.u20",     0x000, 0x117, CRC(5a72fe78) SHA1(4b1a36904eb7048518507fe14bdade5c2589dbd7) )
+	ROM_LOAD( "sc3944-0a.u19",  0x000, 0x2dd, CRC(4cc46c5e) SHA1(0bab970df1539ce905f43603ad13171b05449a01) )
+	ROM_LOAD( "sc3980.u40",     0x000, 0x117, CRC(ee0cdab5) SHA1(216fef50a8a0f6a33b704d3501a4c5c3cbac2bad) )
+	ROM_LOAD( "sc3981-0a.u51",  0x000, 0x117, CRC(4fc750d0) SHA1(d09ff7a8c66aeb5c49e9fec84bd1521e3f5d8d0a) )
+ROM_END
+
+ROM_START( megat4st ) /* Dallas DS1204V security key at U5 labeled 9255-51-01 U5-B-RO1 C1996 MII */
+	ROM_REGION( 0x400000, "maincpu", 0 )
+	ROM_LOAD( "9255-41-01_u32-r0",  0x000000, 0x100000, CRC(f51ae565) SHA1(99c58063bfa24b4383c8b37a1eab670fa6e4c62c) ) /* Location U32 */
+	ROM_LOAD( "qs9255-02_u36-r0",   0x100000, 0x80000,  CRC(57322328) SHA1(12bc604c9d34cde431ef7cd2aa33c7b12ac01833) ) /* Location U36 */
+	ROM_RELOAD(                     0x180000, 0x80000)
+	ROM_LOAD( "qs9255-02_u37-r0",   0x200000, 0x80000,  CRC(f2e8bb4e) SHA1(5c5475b3c176a6aca9b2c6aa4aee422675d20bd1) ) /* Location U37 */
+	ROM_RELOAD(                     0x280000, 0x80000)
+	ROM_LOAD( "9255-51-01_u38-r0b", 0x300000, 0x080000, CRC(181a83cb) SHA1(b8f92ae76ebba3849db76b084f0ab7d82256d81a) ) /* Location U38, 12/10/1996 16:59:23 - Standard Version */
+	ROM_RELOAD(                     0x380000, 0x080000 )
+
+	ROM_REGION( 0x8000, "user1", 0 ) // DS1644 nv ram
+	ROM_LOAD( "mt4st_ds1644.u31",  0x00000,  0x8000,   CRC(c6226d91) SHA1(20c9fa7ad135ac229c6bdf85b901629a0ecb8a81) ) /* No actual label, so use a unique name for this set */
 
 	ROM_REGION( 0x1000, "user2", 0 ) // PALs
 	ROM_LOAD( "sc3943.u20",     0x000, 0x117, CRC(5a72fe78) SHA1(4b1a36904eb7048518507fe14bdade5c2589dbd7) )
@@ -1304,7 +1439,7 @@ ROM_START( megat4te ) /* Dallas DS1204V security key at U5 labeled 9255-50-01 U5
 ROM_END
 
 ROM_START( megat5 ) /* Dallas DS1204V security key at U5 labeled 9255-60-01 U5-B-RO1 C1998 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-60-01_u32-r0",  0x000000, 0x100000, CRC(f8f7f48e) SHA1(1bebe1f8898c60b795a0f794ca9b79e03d2744e4) )
 	ROM_LOAD( "qs9255-05_u36-r0",   0x100000, 0x80000,  CRC(0bed9e27) SHA1(1414385ce562b127e1ddeccc20ea4ff2a7098b7e) )
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1321,7 +1456,7 @@ ROM_START( megat5 ) /* Dallas DS1204V security key at U5 labeled 9255-60-01 U5-B
 ROM_END
 
 ROM_START( megat5nj ) /* Dallas DS1204V security key at U5 labeled 9255-60-01 U5-B-RO1 C1998 MII */
-	ROM_REGION( 0x400000, "main", 0 )
+	ROM_REGION( 0x400000, "maincpu", 0 )
 	ROM_LOAD( "9255-60-01_u32-r0",  0x000000, 0x100000, CRC(f8f7f48e) SHA1(1bebe1f8898c60b795a0f794ca9b79e03d2744e4) )
 	ROM_LOAD( "qs9255-05_u36-r0",   0x100000, 0x80000,  CRC(0bed9e27) SHA1(1414385ce562b127e1ddeccc20ea4ff2a7098b7e) )
 	ROM_RELOAD(                     0x180000, 0x80000)
@@ -1337,8 +1472,8 @@ ROM_START( megat5nj ) /* Dallas DS1204V security key at U5 labeled 9255-60-01 U5
 ROM_END
 
 ROM_START( megat6 ) /* Dallas DS1204V security key at U5 labeled 9255-80 U5-B-RO1 C1998 MII */
-	ROM_REGION( 0x400000, "main", 0 )
-	ROM_LOAD( "9255-60-01_u32-r0",  0x000000, 0x100000, CRC(f8f7f48e) SHA1(1bebe1f8898c60b795a0f794ca9b79e03d2744e4) ) /* Location U32 */
+	ROM_REGION( 0x400000, "maincpu", 0 )
+	ROM_LOAD( "9255-80-01_u32-r0",  0x000000, 0x100000, CRC(f8f7f48e) SHA1(1bebe1f8898c60b795a0f794ca9b79e03d2744e4) ) /* Location U32 */
 	ROM_LOAD( "qs9255-08_u36-r0",   0x100000, 0x080000, CRC(800f5a1f) SHA1(4d3ee6fb896d6452aab1f279a3ee878284bd1acc) ) /* Location U36 */
 	ROM_RELOAD(                     0x180000, 0x080000 )
 	ROM_LOAD( "qs9255-08_u37-r0",   0x200000, 0x100000, CRC(5ba01949) SHA1(1598949ea18d07bbc78af0ddd279a687173c1229) ) /* Location U37 */
@@ -1354,6 +1489,30 @@ ROM_START( megat6 ) /* Dallas DS1204V security key at U5 labeled 9255-80 U5-B-RO
 	ROM_LOAD( "sc3981-0a.u51",  0x000, 0x117, CRC(4fc750d0) SHA1(d09ff7a8c66aeb5c49e9fec84bd1521e3f5d8d0a) )
 ROM_END
 
+static DRIVER_INIT(pbst30)
+{
+	static const UINT8 pbst30b_ds1204_key[8] =
+		{ 0xf0, 0xaa, 0x0f, 0x0f, 0x55, 0x55, 0xff, 0xab };
+
+	static const UINT8 pbst30b_ds1204_nvram[16] =
+		{ 0x3e, 0x9a, 0x3c, 0x3f, 0x1d, 0x51, 0x72, 0xc9, 0x28, 0x2c, 0x1d, 0x2d, 0x0e, 0x56, 0x41, 0x00 };
+
+	ds1204_init(machine, pbst30b_ds1204_key, pbst30b_ds1204_nvram);
+
+};
+
+static DRIVER_INIT(pbst30b)
+{
+	static const UINT8 megat3_ds1204_key[8] =
+		{ 0xf0, 0xaa, 0x0f, 0x0f, 0x55, 0x55, 0xff, 0xab };
+
+	static const UINT8 megat3_ds1204_nvram[16] =
+		{ 0xa9, 0xdb, 0x41, 0xf8, 0xe4, 0x42, 0x20, 0x6e, 0xde, 0xaf, 0x4f, 0x046, 0x3d, 0x55, 0x44, 0x00 };
+
+	ds1204_init(machine, megat3_ds1204_key, megat3_ds1204_nvram);
+
+};
+
 static DRIVER_INIT(megat3)
 {
 	static const UINT8 megat3_ds1204_key[8] =
@@ -1376,7 +1535,7 @@ static DRIVER_INIT(megat3te)
 
 	ds1204_init(machine, megat3_ds1204_key, megat3_ds1204_nvram);
 
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xfff8, 0xffff, 0, 0, meritm_ds1644_r, meritm_ds1644_w );
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xfff8, 0xffff, 0, 0, meritm_ds1644_r, meritm_ds1644_w );
 
 };
 
@@ -1395,7 +1554,18 @@ static DRIVER_INIT(megat4te)
 
 	ds1204_init(machine, 0, megat4te_ds1204_nvram);
 
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xfff8, 0xffff, 0, 0, meritm_ds1644_r, meritm_ds1644_w );
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xfff8, 0xffff, 0, 0, meritm_ds1644_r, meritm_ds1644_w );
+
+};
+
+static DRIVER_INIT(megat4st)
+{
+	static const UINT8 megat4te_ds1204_nvram[16] =
+		{ 0x11, 0x04, 0x96, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x00, 0x00 };
+
+	ds1204_init(machine, 0, megat4te_ds1204_nvram);
+
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xfff8, 0xffff, 0, 0, meritm_ds1644_r, meritm_ds1644_w );
 
 };
 
@@ -1425,6 +1595,10 @@ GAME( 1990, pitbosss,  0,      meritm_crt250, meritm_crt250, 0, ROT0, "Merit", "
 /* CRT 250 + question roms */
 GAME( 1994, pitbossm,  0,      meritm_crt250_questions, pitbossm, 0, ROT0, "Merit", "Pit Boss Megastar", GAME_IMPERFECT_GRAPHICS )
 
+/* CRT 250 + CRT 252 + CRT 258 */
+GAME( 1994, pbst30,    0,      meritm_crt250_crt252_crt258, pbst30, pbst30,  ROT0, "Merit", "Pit Boss Supertouch 30", GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, pbst30b,   0,      meritm_crt250_crt252_crt258, pbst30, pbst30b, ROT0, "Merit", "Pit Boss Supertouch 30 (set 2)", GAME_IMPERFECT_GRAPHICS )
+
 /* CRT 260 */
 GAME( 1996, megat3,    0,      meritm_crt260, meritm_crt260, megat3,   ROT0, "Merit", "Megatouch III (9255-20-01 RON, Standard version)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1995, megat3a,   megat3, meritm_crt260, meritm_crt260, megat3,   ROT0, "Merit", "Megatouch III (9255-20-01 ROF, Standard version)", GAME_IMPERFECT_GRAPHICS )
@@ -1435,6 +1609,7 @@ GAME( 1996, megat4,    0,      meritm_crt260, meritm_crt260, megat4,   ROT0, "Me
 GAME( 1996, megat4a,   megat4, meritm_crt260, meritm_crt260, megat4,   ROT0, "Merit", "Megatouch IV (9255-40-01 ROD, Standard version)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1996, megat4sn,  megat4, meritm_crt260, meritm_crt260, megat4,   ROT0, "Merit", "Super Megatouch IV (9255-41-07 ROG, New Jersey version)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1996, megat4te,  megat4, meritm_crt260, meritm_crt260, megat4te, ROT0, "Merit", "Megatouch IV Tournament Edition (9255-50-01 ROD, Standard version)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1996, megat4st,  megat4, meritm_crt260, meritm_crt260, megat4st, ROT0, "Merit", "Super Megatouch IV Tournament Edition (9255-51-01 ROB, Standard version)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1997, megat5,    0,      meritm_crt260, meritm_crt260, megat5,   ROT0, "Merit", "Megatouch 5 (9255-60-01 ROC, Standard version)", GAME_IMPERFECT_GRAPHICS|GAME_NOT_WORKING )
 GAME( 1998, megat5nj,  megat5, meritm_crt260, meritm_crt260, megat5,   ROT0, "Merit", "Megatouch 5 (9255-60-07 RON, New Jersey version)", GAME_IMPERFECT_GRAPHICS )
 GAME( 1998, megat6,    0,      meritm_crt260, meritm_crt260, megat6,   ROT0, "Merit", "Megatouch 6 (9255-80-01 ROA, Standard version)", GAME_IMPERFECT_GRAPHICS )
