@@ -82,7 +82,7 @@ static void update_plunger(running_machine *machine)
 			time_released = timer_get_time(machine);
 
 			if (!mask)
-				cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
+				cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 		}
 		else
 			time_pushed = timer_get_time(machine);
@@ -98,7 +98,7 @@ static TIMER_CALLBACK( interrupt_callback )
 
 	update_plunger(machine);
 
-	generic_pulse_irq_line(machine->cpu[0], 0);
+	generic_pulse_irq_line(cputag_get_cpu(machine, "maincpu"), 0);
 
 	scanline = scanline + 32;
 
@@ -190,17 +190,17 @@ static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0180, 0x01ff) AM_READ(mgolf_wram_r)
 	AM_RANGE(0x0800, 0x0bff) AM_READ(SMH_RAM)
 
-	AM_RANGE(0x0000, 0x0009) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0024, 0x0024) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0028, 0x0028) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0042, 0x0042) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0044, 0x0044) AM_WRITE(SMH_NOP) /* watchdog? */
-	AM_RANGE(0x0046, 0x0046) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0060, 0x0060) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x0061, 0x0061) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x006a, 0x006a) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x006c, 0x006c) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x006d, 0x006d) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x0000, 0x0009) AM_WRITENOP
+	AM_RANGE(0x0024, 0x0024) AM_WRITENOP
+	AM_RANGE(0x0028, 0x0028) AM_WRITENOP
+	AM_RANGE(0x0042, 0x0042) AM_WRITENOP
+	AM_RANGE(0x0044, 0x0044) AM_WRITENOP /* watchdog? */
+	AM_RANGE(0x0046, 0x0046) AM_WRITENOP
+	AM_RANGE(0x0060, 0x0060) AM_WRITENOP
+	AM_RANGE(0x0061, 0x0061) AM_WRITENOP
+	AM_RANGE(0x006a, 0x006a) AM_WRITENOP
+	AM_RANGE(0x006c, 0x006c) AM_WRITENOP
+	AM_RANGE(0x006d, 0x006d) AM_WRITENOP
 	AM_RANGE(0x0080, 0x00ff) AM_WRITE(mgolf_wram_w)
 	AM_RANGE(0x0180, 0x01ff) AM_WRITE(mgolf_wram_w)
 	AM_RANGE(0x0800, 0x0bff) AM_WRITE(mgolf_vram_w) AM_BASE(&mgolf_video_ram)
@@ -292,13 +292,13 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( mgolf )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6502, 12096000 / 16) /* ? */
-	MDRV_CPU_PROGRAM_MAP(cpu_map, 0)
+	MDRV_CPU_ADD("maincpu", M6502, 12096000 / 16) /* ? */
+	MDRV_CPU_PROGRAM_MAP(cpu_map)
 
 	MDRV_MACHINE_RESET(mgolf)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 262)
@@ -316,7 +316,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( mgolf )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD_NIB_LOW ( "33496-01.e1", 0x2000, 0x0800, CRC(9ea98f39) SHA1(f5685554c2088032d3e8b9e8066bb3e8274c2425) )
 	ROM_LOAD_NIB_HIGH( "33497-01.j1", 0x2000, 0x0800, CRC(0f34962b) SHA1(f71c4a008905bc87cb2ce4971fea357ed7d5d28a) )
 	ROM_LOAD_NIB_LOW ( "33498-01.c2", 0x2800, 0x0800, CRC(413b616e) SHA1(dec9d9a86159a378ae79986d7fbc6f326b48c969) )
