@@ -192,8 +192,6 @@
 #include "sound/pokey.h"
 #include "mhavoc.h"
 
-static UINT8 speech_write_buffer;
-
 /*************************************
  *
  *  Alpha One: dual POKEY?
@@ -207,9 +205,9 @@ static READ8_HANDLER( dual_pokey_r )
 	int pokey_reg = (offset % 8) | control;
 
 	if (pokey_num == 0)
-		return pokey1_r(space, pokey_reg);
+		return pokey_r(devtag_get_device(space->machine, "pokey1"), pokey_reg);
 	else
-		return pokey2_r(space, pokey_reg);
+		return pokey_r(devtag_get_device(space->machine, "pokey2"), pokey_reg);
 }
 
 
@@ -220,29 +218,12 @@ static WRITE8_HANDLER( dual_pokey_w )
 	int pokey_reg = (offset % 8) | control;
 
 	if (pokey_num == 0)
-		pokey1_w(space, pokey_reg, data);
+		pokey_w(devtag_get_device(space->machine, "pokey1"), pokey_reg, data);
 	else
-		pokey2_w(space, pokey_reg, data);
+		pokey_w(devtag_get_device(space->machine, "pokey2"), pokey_reg, data);
 }
 
 
-/*************************************
- *
- *  Speech access
- *
- *************************************/
-
-static WRITE8_HANDLER( speech_data_w )
-{
-	speech_write_buffer = data;
-}
-
-
-static WRITE8_HANDLER( speech_strobe_w )
-{
-	tms5220_data_w(space, 0, speech_write_buffer);
-}
-
 /*************************************
  *
  *  Alpha CPU memory handlers
@@ -338,7 +319,7 @@ ADDRESS_MAP_END
 static CUSTOM_INPUT( clock_r )
 {
 	/* 2.4kHz (divide 2.5MHz by 1024) */
-	return (cpu_get_total_cycles(field->port->machine->cpu[0]) & 0x400) ? 0 : 1;
+	return (cputag_get_total_cycles(field->port->machine, "alpha") & 0x400) ? 0 : 1;
 }
 
 
@@ -479,8 +460,8 @@ INPUT_PORTS_END
 
 static const pokey_interface pokey_config =
 {
-	{ 0 },
-	input_port_3_r
+	{ DEVCB_NULL },
+	DEVCB_INPUT_PORT("DSW1")
 };
 
 
@@ -494,16 +475,16 @@ static MACHINE_DRIVER_START( mhavoc )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD("alpha", M6502, MHAVOC_CLOCK_2_5M)		/* 2.5 MHz */
-	MDRV_CPU_PROGRAM_MAP(alpha_map, 0)
+	MDRV_CPU_PROGRAM_MAP(alpha_map)
 
 	MDRV_CPU_ADD("gamma", M6502, MHAVOC_CLOCK_1_25M)	/* 1.25 MHz */
-	MDRV_CPU_PROGRAM_MAP(gamma_map, 0)
+	MDRV_CPU_PROGRAM_MAP(gamma_map)
 
 	MDRV_MACHINE_RESET(mhavoc)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", VECTOR)
+	MDRV_SCREEN_ADD("screen", VECTOR)
 	MDRV_SCREEN_REFRESH_RATE(50)
 	MDRV_SCREEN_SIZE(400, 300)
 	MDRV_SCREEN_VISIBLE_AREA(0, 300, 0, 260)
@@ -514,17 +495,17 @@ static MACHINE_DRIVER_START( mhavoc )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("pokey.1", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_ADD("pokey1", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_CONFIG(pokey_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("pokey.2", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_ADD("pokey2", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("pokey.3", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_ADD("pokey3", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("pokey.4", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_ADD("pokey4", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
@@ -542,21 +523,21 @@ static MACHINE_DRIVER_START( alphaone )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(mhavoc)
 	MDRV_CPU_MODIFY("alpha")
-	MDRV_CPU_PROGRAM_MAP(alphaone_map, 0)
-	MDRV_CPU_REMOVE("gamma")
+	MDRV_CPU_PROGRAM_MAP(alphaone_map)
+	MDRV_DEVICE_REMOVE("gamma")
 
-	MDRV_SCREEN_MODIFY("main")
+	MDRV_SCREEN_MODIFY("screen")
 	MDRV_SCREEN_VISIBLE_AREA(0, 580, 0, 500)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("pokey.1", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_REPLACE("pokey1", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_REPLACE("pokey.2", POKEY, MHAVOC_CLOCK_1_25M)
+	MDRV_SOUND_REPLACE("pokey2", POKEY, MHAVOC_CLOCK_1_25M)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_REMOVE("pokey.3")
-	MDRV_SOUND_REMOVE("pokey.4")
+	MDRV_DEVICE_REMOVE("pokey3")
+	MDRV_DEVICE_REMOVE("pokey4")
 MACHINE_DRIVER_END
 
 
@@ -752,22 +733,6 @@ ROM_END
 
 
 
-/*************************************
- *
- *  Driver-specific init
- *
- *************************************/
-
-static DRIVER_INIT( mhavocrv )
-{
-	/* install the speech support that was only optionally stuffed for use */
-	/* in the Return to Vax hack */
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x5800, 0x5800, 0, 0, speech_data_w);
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x5900, 0x5900, 0, 0, speech_strobe_w);
-}
-
-
-
 /*************************************
  *
  *  Game drivers
