@@ -38,7 +38,7 @@ static TIMER_CALLBACK( dac_callback )
 {
 	UINT8 *DACROM = memory_region(machine, "samples");
 
-	dac_data_w(0,DACROM[(dac_bank * 0x10000 + dac_adr++) & 0x1ffff]);
+	dac_data_w(devtag_get_device(machine, "dac"),DACROM[(dac_bank * 0x10000 + dac_adr++) & 0x1ffff]);
 
 	if (((dac_adr & 0xff00 ) >> 8) !=  dac_adr_e )
 		timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(MCLK), 1024), NULL, 0, dac_callback);
@@ -69,7 +69,7 @@ static MACHINE_RESET( mjsister )
 
 static WRITE8_HANDLER( mjsister_banksel1_w )
 {
-	UINT8 *BANKROM = memory_region(space->machine, "main");
+	UINT8 *BANKROM = memory_region(space->machine, "maincpu");
 	int tmp = mjsister_colorbank;
 
 	switch (data)
@@ -105,7 +105,7 @@ static WRITE8_HANDLER( mjsister_banksel1_w )
 
 static WRITE8_HANDLER( mjsister_banksel2_w )
 {
-	UINT8 *BANKROM = memory_region(space->machine, "main");
+	UINT8 *BANKROM = memory_region(space->machine, "maincpu");
 
 	switch (data)
 	{
@@ -151,24 +151,18 @@ static READ8_HANDLER( mjsister_keys_r )
 
 /****************************************************************************/
 
-static ADDRESS_MAP_START( mjsister_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x77ff) AM_READ(SMH_ROM)
-	AM_RANGE(0x7800, 0x7fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_BANK1)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( mjsister_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x77ff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x7800, 0x7fff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(mjsister_videoram_w)
+static ADDRESS_MAP_START( mjsister_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x77ff) AM_ROM
+	AM_RANGE(0x7800, 0x7fff) AM_RAM
+	AM_RANGE(0x8000, 0xffff) AM_ROMBANK(1) AM_WRITE(mjsister_videoram_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mjsister_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x01) AM_WRITE(SMH_NOP) /* HD46505? */
-	AM_RANGE(0x10, 0x10) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0x11, 0x11) AM_READ(ay8910_read_port_0_r)
-	AM_RANGE(0x12, 0x12) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x00, 0x01) AM_WRITENOP /* HD46505? */
+	AM_RANGE(0x10, 0x10) AM_DEVWRITE("ay", ay8910_address_w)
+	AM_RANGE(0x11, 0x11) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x12, 0x12) AM_DEVWRITE("ay", ay8910_data_w)
 	AM_RANGE(0x20, 0x20) AM_READ(mjsister_keys_r)
 	AM_RANGE(0x21, 0x21) AM_READ_PORT("IN0")
 	AM_RANGE(0x30, 0x30) AM_WRITE(mjsister_banksel1_w)
@@ -179,6 +173,7 @@ static ADDRESS_MAP_START( mjsister_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x35, 0x35) AM_WRITE(mjsister_dac_adr_e_w)
 ADDRESS_MAP_END
 
+
 /****************************************************************************/
 
 static INPUT_PORTS_START( mjsister )
@@ -299,24 +294,24 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	input_port_0_r,
-	input_port_1_r,
-	NULL,
-	NULL
+	DEVCB_INPUT_PORT("DSW1"),
+	DEVCB_INPUT_PORT("DSW2"),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 static MACHINE_DRIVER_START( mjsister )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, MCLK/2) /* 6.000 MHz */
-	MDRV_CPU_PROGRAM_MAP(mjsister_readmem,mjsister_writemem)
-	MDRV_CPU_IO_MAP(mjsister_io_map,0)
+	MDRV_CPU_ADD("maincpu", Z80, MCLK/2) /* 6.000 MHz */
+	MDRV_CPU_PROGRAM_MAP(mjsister_map)
+	MDRV_CPU_IO_MAP(mjsister_io_map)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
 
 	MDRV_MACHINE_RESET(mjsister)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -347,7 +342,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( mjsister )
-	ROM_REGION( 0x30000, "main", 0 )   /* CPU */
+	ROM_REGION( 0x30000, "maincpu", 0 )   /* CPU */
 	ROM_LOAD( "ms00.bin",  0x00000, 0x08000, CRC(9468c33b) SHA1(63aecdcaa8493d58549dfd1d217743210cf953bc) )
 	ROM_LOAD( "ms01t.bin", 0x10000, 0x10000, CRC(a7b6e530) SHA1(fda9bea214968a8814d2c43226b3b32316581050) ) /* banked */
 	ROM_LOAD( "ms02t.bin", 0x20000, 0x10000, CRC(7752b5ba) SHA1(84dcf27a62eb290ba07c85af155897ec72f320a8) ) /* banked */
