@@ -39,13 +39,13 @@
 
 void mystston_on_scanline_interrupt(running_machine *machine)
 {
-	cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
+	cputag_set_input_line(machine, "maincpu", 0, ASSERT_LINE);
 }
 
 
 static WRITE8_HANDLER( irq_clear_w )
 {
-	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
 }
 
 
@@ -59,7 +59,7 @@ static WRITE8_HANDLER( irq_clear_w )
 static INPUT_CHANGED( coin_inserted )
 {
 	/* coin insertion causes an NMI */
-	cpu_set_input_line(field->port->machine->cpu[0], INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(field->port->machine, "maincpu", INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -72,26 +72,20 @@ static INPUT_CHANGED( coin_inserted )
 
 static WRITE8_HANDLER( mystston_ay8910_select_w )
 {
-	mystston_state *state = space->machine->driver_data;
+	mystston_state *state = (mystston_state *)space->machine->driver_data;
 
 	/* bit 5 goes to 8910 #0 BDIR pin */
 	if (((*state->ay8910_select & 0x20) == 0x20) && ((data & 0x20) == 0x00))
 	{
 		/* bit 4 goes to the 8910 #0 BC1 pin */
-		if (*state->ay8910_select & 0x10)
-			ay8910_control_port_0_w(space, 0, *state->ay8910_data);
-		else
-			ay8910_write_port_0_w(space, 0, *state->ay8910_data);
+		ay8910_data_address_w(devtag_get_device(space->machine, "ay1"), *state->ay8910_select >> 4, *state->ay8910_data);
 	}
 
 	/* bit 7 goes to 8910 #1 BDIR pin */
 	if (((*state->ay8910_select & 0x80) == 0x80) && ((data & 0x80) == 0x00))
 	{
 		/* bit 6 goes to the 8910 #1 BC1 pin */
-		if (*state->ay8910_select & 0x40)
-			ay8910_control_port_1_w(space, 0, *state->ay8910_data);
-		else
-			ay8910_write_port_1_w(space, 0, *state->ay8910_data);
+		ay8910_data_address_w(devtag_get_device(space->machine, "ay2"), *state->ay8910_select >> 6, *state->ay8910_data);
 	}
 
 	*state->ay8910_select = data;
@@ -212,8 +206,8 @@ static MACHINE_DRIVER_START( mystston )
 	MDRV_DRIVER_DATA(mystston_state)
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6502, CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
+	MDRV_CPU_ADD("maincpu", M6502, CPU_CLOCK)
+	MDRV_CPU_PROGRAM_MAP(main_map)
 
 	/* video hardware */
 	MDRV_IMPORT_FROM(mystston_video)
@@ -237,7 +231,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( mystston )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "rom6.bin",     0x4000, 0x2000, CRC(7bd9c6cd) SHA1(4d14edc783ba1a6c01d2fb9ea29ec85b8fec3c3b) )
 	ROM_LOAD( "rom5.bin",     0x6000, 0x2000, CRC(a83f04a6) SHA1(d8cdf310511c1fef4fbde80ef2161fda00f965d7) )
 	ROM_LOAD( "rom4.bin",     0x8000, 0x2000, CRC(46c73714) SHA1(5b9ac3a35aeeea6a0cd2d838c144925d83b36a7f) )
@@ -267,7 +261,7 @@ ROM_END
 
 
 ROM_START( myststno )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "ms0",          0x4000, 0x2000, CRC(6dacc05f) SHA1(43054199901639516205c7ea145462d0abea8fb1) )
 	ROM_LOAD( "ms1",          0x6000, 0x2000, CRC(a3546df7) SHA1(89c0349885a9369406a1121cd3db28963b25f2e6) )
 	ROM_LOAD( "ms2",          0x8000, 0x2000, CRC(43bc6182) SHA1(dc36c10eee20009922e89d9bfdf6c2f6ffb881ce) )
@@ -303,5 +297,5 @@ ROM_END
  *
  *************************************/
 
-GAME( 1984, mystston, 0,        mystston, mystston, 0, ROT270, "Technos", "Mysterious Stones - Dr. John's Adventure", GAME_SUPPORTS_SAVE )
-GAME( 1984, myststno, mystston, mystston, mystston, 0, ROT270, "Technos", "Mysterious Stones - Dr. Kick in Adventure", GAME_SUPPORTS_SAVE )
+GAME( 1984, mystston, 0,        mystston, mystston, 0, ROT270, "Technos Japan", "Mysterious Stones - Dr. John's Adventure", GAME_SUPPORTS_SAVE )
+GAME( 1984, myststno, mystston, mystston, mystston, 0, ROT270, "Technos Japan", "Mysterious Stones - Dr. Kick in Adventure", GAME_SUPPORTS_SAVE )
