@@ -298,7 +298,7 @@ static TIMER_CALLBACK( namconb1_TriggerPOSIRQ )
 
 	video_screen_update_partial(machine->primary_screen, param);
 	pos_irq_active = 1;
-	cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x02] & 0xf, ASSERT_LINE);
+	cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x02] & 0xf, ASSERT_LINE);
 }
 
 static INTERRUPT_GEN( namconb1_interrupt )
@@ -374,7 +374,7 @@ static TIMER_CALLBACK( namconb2_TriggerPOSIRQ )
 {
 	video_screen_update_partial(machine->primary_screen, param);
 	pos_irq_active = 1;
-	cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x02], ASSERT_LINE);
+	cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x02], ASSERT_LINE);
 }
 
 static INTERRUPT_GEN( namconb2_interrupt )
@@ -429,9 +429,9 @@ static void namconb1_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 	switch(reg) {
 	case 0x02: // POS IRQ level/enable
 		if(pos_irq_active && (((prev & 0xf) != (data & 0xf)) || !(data & 0xf0))) {
-			cpu_set_input_line(machine->cpu[0], prev & 0xf, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", prev & 0xf, CLEAR_LINE);
 			if(data & 0xf0)
-				cpu_set_input_line(machine->cpu[0], data & 0xf, ASSERT_LINE);
+				cputag_set_input_line(machine, "maincpu", data & 0xf, ASSERT_LINE);
 			else
 				pos_irq_active = 0;
 		}
@@ -439,9 +439,9 @@ static void namconb1_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x04: // VBLANK IRQ level/enable
 		if(vblank_irq_active && (((prev & 0xf) != (data & 0xf)) || !(data & 0xf0))) {
-			cpu_set_input_line(machine->cpu[0], prev & 0xf, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", prev & 0xf, CLEAR_LINE);
 			if(data & 0xf0)
-				cpu_set_input_line(machine->cpu[0], data & 0xf, ASSERT_LINE);
+				cputag_set_input_line(machine, "maincpu", data & 0xf, ASSERT_LINE);
 			else
 				vblank_irq_active = 0;
 		}
@@ -449,14 +449,14 @@ static void namconb1_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x07: // POS ack
 		if(pos_irq_active) {
-			cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x02] & 0xf, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x02] & 0xf, CLEAR_LINE);
 			pos_irq_active = 0;
 		}
 		break;
 
 	case 0x09: // VBLANK ack
 		if(vblank_irq_active) {
-			cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x04] & 0xf, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x04] & 0xf, CLEAR_LINE);
 			vblank_irq_active = 0;
 		}
 		break;
@@ -466,11 +466,11 @@ static void namconb1_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x18: // C75 Control
 		if(data & 1) {
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_HALT, CLEAR_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_RESET, ASSERT_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_RESET, CLEAR_LINE);
 		} else
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_HALT, ASSERT_LINE);
 		break;
 	}
 }
@@ -495,9 +495,9 @@ static void namconb2_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 	switch(reg) {
 	case 0x00: // VBLANK IRQ level
 		if(vblank_irq_active && (prev != data)) {
-			cpu_set_input_line(machine->cpu[0], prev, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", prev, CLEAR_LINE);
 			if(data)
-				cpu_set_input_line(machine->cpu[0], data, ASSERT_LINE);
+				cputag_set_input_line(machine, "maincpu", data, ASSERT_LINE);
 			else
 				vblank_irq_active = 0;
 		}
@@ -505,9 +505,9 @@ static void namconb2_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x02: // POS IRQ level
 		if(pos_irq_active && (prev != data)) {
-			cpu_set_input_line(machine->cpu[0], prev, CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", prev, CLEAR_LINE);
 			if(data)
-				cpu_set_input_line(machine->cpu[0], data, ASSERT_LINE);
+				cputag_set_input_line(machine, "maincpu", data, ASSERT_LINE);
 			else
 				pos_irq_active = 0;
 		}
@@ -515,14 +515,14 @@ static void namconb2_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x04: // VBLANK ack
 		if(vblank_irq_active) {
-			cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x00], CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x00], CLEAR_LINE);
 			vblank_irq_active = 0;
 		}
 		break;
 
 	case 0x06: // POS ack
 		if(pos_irq_active) {
-			cpu_set_input_line(machine->cpu[0], namconb_cpureg[0x02], CLEAR_LINE);
+			cputag_set_input_line(machine, "maincpu", namconb_cpureg[0x02], CLEAR_LINE);
 			pos_irq_active = 0;
 		}
 		break;
@@ -532,11 +532,11 @@ static void namconb2_cpureg8_w(running_machine *machine, int reg, UINT8 data)
 
 	case 0x16: // C75 Control
 		if(data & 1) {
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_HALT, CLEAR_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_RESET, ASSERT_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_RESET, CLEAR_LINE);
 		} else {
-			cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+			cputag_set_input_line(machine, "mcu", INPUT_LINE_HALT, ASSERT_LINE);
 		}
 		break;
 	}
@@ -621,6 +621,11 @@ static DRIVER_INIT( gslgr94u )
 	namcos2_gametype = NAMCONB1_GSLGR94U;
 } /* gslgr94u */
 
+static DRIVER_INIT( gslgr94j )
+{
+	namcos2_gametype = NAMCONB1_GSLGR94J;
+} /* gslgr94j */
+
 static DRIVER_INIT( sws95 )
 {
 	namcos2_gametype = NAMCONB1_SWS95;
@@ -703,6 +708,14 @@ static READ32_HANDLER( custom_key_r )
 		}
 		break;
 
+	case NAMCONB1_GSLGR94J:
+		switch( offset )
+		{
+		case 1: return 0;
+		case 3: return (0x0171<<16) | count;
+		}
+		break;
+
 	case NAMCONB1_NEBULRAY:
 		switch( offset )
 		{
@@ -839,45 +852,45 @@ static WRITE32_HANDLER(namconb_share_w)
 }
 
 static ADDRESS_MAP_START( namconb1_am, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x10001f) AM_READ(gunbulet_gun_r)
-	AM_RANGE(0x1c0000, 0x1cffff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x1c0000, 0x1cffff) AM_RAM
 	AM_RANGE(0x1e4000, 0x1e4003) AM_READWRITE(randgen_r,srand_w)
 	AM_RANGE(0x200000, 0x207fff) AM_READWRITE(namconb_share_r, namconb_share_w)
 	AM_RANGE(0x208000, 0x2fffff) AM_RAM
 	AM_RANGE(0x400000, 0x40001f) AM_READWRITE(namconb_cpureg_r, namconb1_cpureg_w)
-	AM_RANGE(0x580000, 0x5807ff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&nvmem32)
+	AM_RANGE(0x580000, 0x5807ff) AM_RAM AM_BASE(&nvmem32)
 	AM_RANGE(0x600000, 0x61ffff) AM_READWRITE(namco_obj32_r,namco_obj32_w)
 	AM_RANGE(0x620000, 0x620007) AM_READWRITE(namco_spritepos32_r,namco_spritepos32_w)
 	AM_RANGE(0x640000, 0x64ffff) AM_READWRITE(namco_tilemapvideoram32_r,namco_tilemapvideoram32_w )
 	AM_RANGE(0x660000, 0x66003f) AM_READWRITE(namco_tilemapcontrol32_r,namco_tilemapcontrol32_w)
-	AM_RANGE(0x680000, 0x68000f) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&namconb1_spritebank32)
-	AM_RANGE(0x6e0000, 0x6e001f) AM_READ(custom_key_r) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x700000, 0x707fff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&paletteram32)
+	AM_RANGE(0x680000, 0x68000f) AM_RAM AM_BASE(&namconb1_spritebank32)
+	AM_RANGE(0x6e0000, 0x6e001f) AM_READ(custom_key_r) AM_WRITENOP
+	AM_RANGE(0x700000, 0x707fff) AM_RAM AM_BASE(&paletteram32)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( namconb2_am, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x1c0000, 0x1cffff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x1c0000, 0x1cffff) AM_RAM
 	AM_RANGE(0x1e4000, 0x1e4003) AM_READWRITE(randgen_r,srand_w)
 	AM_RANGE(0x200000, 0x207fff) AM_READWRITE(namconb_share_r, namconb_share_w)
 	AM_RANGE(0x208000, 0x2fffff) AM_RAM
 	AM_RANGE(0x400000, 0x4fffff) AM_ROM AM_REGION("data", 0)
 	AM_RANGE(0x600000, 0x61ffff) AM_READWRITE(namco_obj32_r,namco_obj32_w)
 	AM_RANGE(0x620000, 0x620007) AM_READWRITE(namco_spritepos32_r,namco_spritepos32_w)
-	AM_RANGE(0x640000, 0x64000f) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) /* unknown xy offset */
+	AM_RANGE(0x640000, 0x64000f) AM_RAM /* unknown xy offset */
 	AM_RANGE(0x680000, 0x68ffff) AM_READWRITE(namco_tilemapvideoram32_r, namco_tilemapvideoram32_w )
 	AM_RANGE(0x6c0000, 0x6c003f) AM_READWRITE(namco_tilemapcontrol32_r, namco_tilemapcontrol32_w )
 	AM_RANGE(0x700000, 0x71ffff) AM_READWRITE(namco_rozvideoram32_r,namco_rozvideoram32_w)
 	AM_RANGE(0x740000, 0x74001f) AM_READWRITE(namco_rozcontrol32_r,namco_rozcontrol32_w)
-	AM_RANGE(0x800000, 0x807fff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&paletteram32)
-	AM_RANGE(0x900008, 0x90000f) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&namconb1_spritebank32)
-	AM_RANGE(0x940000, 0x94000f) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&namconb1_tilebank32)
+	AM_RANGE(0x800000, 0x807fff) AM_RAM AM_BASE(&paletteram32)
+	AM_RANGE(0x900008, 0x90000f) AM_RAM AM_BASE(&namconb1_spritebank32)
+	AM_RANGE(0x940000, 0x94000f) AM_RAM AM_BASE(&namconb1_tilebank32)
 	AM_RANGE(0x980000, 0x98000f) AM_READ(namco_rozbank32_r) AM_WRITE(namco_rozbank32_w)
-	AM_RANGE(0xa00000, 0xa007ff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&nvmem32)
-	AM_RANGE(0xc00000, 0xc0001f) AM_READ(custom_key_r) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa00000, 0xa007ff) AM_RAM AM_BASE(&nvmem32)
+	AM_RANGE(0xc00000, 0xc0001f) AM_READ(custom_key_r) AM_WRITENOP
 	AM_RANGE(0xf00000, 0xf0001f) AM_READWRITE(namconb_cpureg_r, namconb2_cpureg_w)
-ADDRESS_MAP_END /* namconb2_readmem */
+ADDRESS_MAP_END
 
 static WRITE16_HANDLER( nbmcu_shared_w )
 {
@@ -899,7 +912,7 @@ static WRITE16_HANDLER( nbmcu_shared_w )
 }
 
 static ADDRESS_MAP_START( namcoc75_am, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x002000, 0x002fff) AM_READWRITE( c352_0_r, c352_0_w )
+	AM_RANGE(0x002000, 0x002fff) AM_DEVREADWRITE("c352", c352_r, c352_w)
 	AM_RANGE(0x004000, 0x00bfff) AM_RAM_WRITE(nbmcu_shared_w) AM_BASE(&namconb_shareram)
 	AM_RANGE(0x00c000, 0x00ffff) AM_ROM AM_REGION("c75", 0)
 	AM_RANGE(0x200000, 0x27ffff) AM_ROM AM_REGION("c75data", 0)
@@ -923,19 +936,15 @@ static READ8_HANDLER( port7_r )
 	{
 		case 0x00:
 			return input_port_read_safe(space->machine, "P4", 0xff);
-			break;
 
 		case 0x20:
 			return input_port_read(space->machine, "MISC");
-			break;
 
 		case 0x40:
 			return input_port_read(space->machine, "P1");
-			break;
 
 		case 0x60:
 			return input_port_read(space->machine, "P2");
-			break;
 
 		default:
 			break;
@@ -1003,20 +1012,20 @@ ADDRESS_MAP_END
 #define MASTER_CLOCK_HZ 48384000
 
 static MACHINE_DRIVER_START( namconb1 )
-	MDRV_CPU_ADD("main", M68EC020,MASTER_CLOCK_HZ/2)
-	MDRV_CPU_PROGRAM_MAP(namconb1_am,0)
-	MDRV_CPU_VBLANK_INT("main", namconb1_interrupt)
+	MDRV_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
+	MDRV_CPU_PROGRAM_MAP(namconb1_am)
+	MDRV_CPU_VBLANK_INT("screen", namconb1_interrupt)
 
 	MDRV_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
-	MDRV_CPU_PROGRAM_MAP(namcoc75_am, 0)
-	MDRV_CPU_IO_MAP(namcoc75_io, 0)
+	MDRV_CPU_PROGRAM_MAP(namcoc75_am)
+	MDRV_CPU_IO_MAP(namcoc75_io)
 	MDRV_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
 
 	MDRV_NVRAM_HANDLER(namconb1)
 	MDRV_MACHINE_START(namconb)
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(59.7)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
@@ -1027,29 +1036,29 @@ static MACHINE_DRIVER_START( namconb1 )
 	MDRV_VIDEO_START(namconb1)
 	MDRV_VIDEO_UPDATE(namconb1)
 
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 	MDRV_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
-	MDRV_SOUND_ROUTE(1, "left", 1.00)
-	MDRV_SOUND_ROUTE(2, "right", 1.00)
-	MDRV_SOUND_ROUTE(3, "left", 1.00)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( namconb2 )
-	MDRV_CPU_ADD("main", M68EC020,MASTER_CLOCK_HZ/2)
-	MDRV_CPU_PROGRAM_MAP(namconb2_am,0)
-	MDRV_CPU_VBLANK_INT("main", namconb2_interrupt)
+	MDRV_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
+	MDRV_CPU_PROGRAM_MAP(namconb2_am)
+	MDRV_CPU_VBLANK_INT("screen", namconb2_interrupt)
 
 	MDRV_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
-	MDRV_CPU_PROGRAM_MAP(namcoc75_am, 0)
-	MDRV_CPU_IO_MAP(namcoc75_io, 0)
+	MDRV_CPU_PROGRAM_MAP(namcoc75_am)
+	MDRV_CPU_IO_MAP(namcoc75_io)
 	MDRV_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
 
 	MDRV_NVRAM_HANDLER(namconb1)
 	MDRV_MACHINE_START(namconb)
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(59.7)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
@@ -1060,18 +1069,18 @@ static MACHINE_DRIVER_START( namconb2 )
 	MDRV_VIDEO_START(namconb2)
 	MDRV_VIDEO_UPDATE(namconb2)
 
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 	MDRV_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
-	MDRV_SOUND_ROUTE(1, "left", 1.00)
-	MDRV_SOUND_ROUTE(2, "right", 1.00)
-	MDRV_SOUND_ROUTE(3, "left", 1.00)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
 MACHINE_DRIVER_END
 
 /***************************************************************/
 
 ROM_START( ptblank )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "gn2mprlb.15b", 0x00002, 0x80000, CRC(fe2d9425) SHA1(51b166a629cbb522720d63720558816b496b6b76) )
 	ROM_LOAD32_WORD( "gn2mprub.13b", 0x00000, 0x80000, CRC(3bf4985a) SHA1(f559e0d5f55d23d886fe61bd7d5ca556acc7f87c) )
 
@@ -1101,7 +1110,7 @@ ROM_START( ptblank )
 ROM_END
 
 ROM_START( gunbulet )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "gn1-mprl.bin", 0x00002, 0x80000, CRC(f99e309e) SHA1(3fe0ddf756e6849f8effc7672456cbe32f65c98a) )
 	ROM_LOAD32_WORD( "gn1-mpru.bin", 0x00000, 0x80000, CRC(72a4db07) SHA1(8c5e1e51cd961b311d03f7b21f36a5bd5e8e9104) )
 
@@ -1131,7 +1140,7 @@ ROM_START( gunbulet )
 ROM_END
 
 ROM_START( nebulray )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "nr2-mpru.13b", 0x00000, 0x80000, CRC(049b97cb) SHA1(0e344b29a4d4bdc854fa9849589772df2eeb0a05) )
 	ROM_LOAD32_WORD( "nr2-mprl.15b", 0x00002, 0x80000, CRC(0431b6d4) SHA1(54c96e8ac9e753956c31bdef79d390f1c20e10ff) )
 
@@ -1168,7 +1177,7 @@ ROM_START( nebulray )
 ROM_END
 
 ROM_START( nebulryj )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "nr1-mpru", 0x00000, 0x80000, CRC(42ef71f9) SHA1(20e3cb63e1fde293c60c404b378d901d635c4b79) )
 	ROM_LOAD32_WORD( "nr1-mprl", 0x00002, 0x80000, CRC(fae5f62c) SHA1(143d716abbc834aac6270db3bbb89ec71ea3804d) )
 
@@ -1205,7 +1214,7 @@ ROM_START( nebulryj )
 ROM_END
 
 ROM_START( gslgr94u )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "gse2mprl.bin", 0x00002, 0x80000, CRC(a514349c) SHA1(1f7ec81cd6193410d2f01e6f0f84878561fc8035) )
 	ROM_LOAD32_WORD( "gse2mpru.bin", 0x00000, 0x80000, CRC(b6afd238) SHA1(438a3411ac8ce3d22d5da8c0800738cb8d2994a9) )
 
@@ -1232,6 +1241,35 @@ ROM_START( gslgr94u )
 	ROM_LOAD( "gse-sha0.bin", 0, 0x80000, CRC(6b2beabb) SHA1(815f7aef44735584edd4a9ca7e672471d07f225e) )
 ROM_END
 
+ROM_START( gslgr94j )
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
+	ROM_LOAD32_WORD( "gs41mprl.15b", 0x00002, 0x80000, CRC(5759bdb5) SHA1(a0fb332c484e168369a69cd9dd8ea72e5f4565df) )
+	ROM_LOAD32_WORD( "gs41mpru.13b", 0x00000, 0x80000, CRC(78bde1e7) SHA1(911d33897f03c59c6505f5f755d80471ff019812) )
+
+	ROM_REGION16_LE( 0x4000, "c75", 0 ) /* C75 program */
+	ROM_LOAD( "c75.bin", 0, 0x4000, CRC(42f539a5) SHA1(3103e5a0a2867620309fd4fe478a2be0effbeff8) )
+
+	ROM_REGION16_LE( 0x80000, "c75data", 0 ) /* sound data */
+	ROM_LOAD( "gs41spr0.5b", 0, 0x80000, CRC(3e2b6d55) SHA1(f6a1ecaee3a9a7a535850084e469aa7f873f301e) )
+
+	ROM_REGION( 0x200000, "c352", 0 )
+	ROM_LOAD( "gs4voi0.5j", 0, 0x200000, CRC(c3053a90) SHA1(e76799b33b2457421255b03786bc24266d59c7dd) )
+
+	ROM_REGION( 0x800000, NAMCONB1_SPRITEGFXREGION, ROMREGION_DISPOSE )
+	ROM_LOAD16_BYTE( "gs4obj0l.bin", 0x000001, 0x200000, CRC(3b499da0) SHA1(91ad5f68dbda64dd07e1133eb09ee69da3da3103) )
+	ROM_LOAD16_BYTE( "gs4obj0u.bin", 0x000000, 0x200000, CRC(80016b50) SHA1(9f7604c196835d31894ba4db1de43d7d2614da84) )
+	ROM_LOAD16_BYTE( "gs4obj1l.bin", 0x400001, 0x200000, CRC(1f4847a7) SHA1(908e419e42fa8bd786cc3bc96d5ccb3a47c8e2dc) )
+	ROM_LOAD16_BYTE( "gs4obj1u.bin", 0x400000, 0x200000, CRC(49bc48cd) SHA1(6bcc41546f3bd609e3aa962e5ce3bf5bc6b9229a) )
+
+	ROM_REGION( 0x400000, NAMCONB1_TILEGFXREGION, ROMREGION_DISPOSE )
+	ROM_LOAD( "gs4chr0.8j",  0x000000, 0x100000, CRC(8c6c682e) SHA1(ecf21035d5af28299c9cdb98d5d811b4d52857b8) )
+	ROM_LOAD( "gs4chr1.9j",  0x100000, 0x100000, CRC(523989f7) SHA1(fae0e2f58e9a8d0ddc7297b567579849e24e0a40) )
+	ROM_LOAD( "gs4chr2.10j", 0x200000, 0x100000, CRC(37569559) SHA1(ce31673f51c6302f4fb4e4c377e6693a40874f81) )
+	ROM_LOAD( "gs4chr3.11j", 0x300000, 0x100000, CRC(73ca58f6) SHA1(44bdc943fb10dc53279662cd528169a27d57e478) )
+
+	ROM_REGION( 0x80000, NAMCONB1_TILEMASKREGION, 0 )
+	ROM_LOAD( "gs4sha0.5m", 0, 0x80000, CRC(40e7e6a5) SHA1(70af76b6034e0d6e1b96bf54c973ab411e5907ab) )
+ROM_END
 
 /*
 Great Sluggers (Japan)
@@ -1359,7 +1397,7 @@ Note! All ROMs are different to the Great Sluggers '94 set.
 */
 
 ROM_START( gslugrsj )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "gs1mprl.15b", 0x00002, 0x80000, CRC(1e6c3626) SHA1(56abe21884fd87df10996db19c49ce14214d4b73) )
 	ROM_LOAD32_WORD( "gs1mpru.13b", 0x00000, 0x80000, CRC(ef355179) SHA1(0ab0ef4301a318681bb5827d35734a0732b35484) )
 
@@ -1387,7 +1425,7 @@ ROM_START( gslugrsj )
 ROM_END
 
 ROM_START( sws95 )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "ss51mprl.bin", 0x00002, 0x80000, CRC(c9e0107d) SHA1(0f10582416023a86ea1ef2679f3f06016c086e08) )
 	ROM_LOAD32_WORD( "ss51mpru.bin", 0x00000, 0x80000, CRC(0d93d261) SHA1(5edef26e2c86dbc09727d910af92747d022e4fed) )
 
@@ -1416,7 +1454,7 @@ ROM_START( sws95 )
 ROM_END
 
 ROM_START( sws96 )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "ss61mprl.bin", 0x00002, 0x80000, CRC(06f55e73) SHA1(6be26f8a2ef600bf07c580f210d7b265ac464002) )
 	ROM_LOAD32_WORD( "ss61mpru.bin", 0x00000, 0x80000, CRC(0abdbb83) SHA1(67e8b712291f9bcf2c3a52fbc451fad54679cab8) )
 
@@ -1444,7 +1482,7 @@ ROM_START( sws96 )
 ROM_END
 
 ROM_START( sws97 )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "ss71mprl.bin", 0x00002, 0x80000, CRC(bd60b50e) SHA1(9e00bacd506182ab2af2c0efdd5cc401b3e46485) )
 	ROM_LOAD32_WORD( "ss71mpru.bin", 0x00000, 0x80000, CRC(3444f5a8) SHA1(8d0f35b3ba8f65dbc67c3b2d273833227a8b8b2a) )
 
@@ -1472,7 +1510,7 @@ ROM_START( sws97 )
 ROM_END
 
 ROM_START( vshoot )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "vsj1mprl.15b", 0x00002, 0x80000, CRC(83a60d92) SHA1(c3db0c79f772a79418914353a3d6ecc4883ea54e) )
 	ROM_LOAD32_WORD( "vsj1mpru.13b", 0x00000, 0x80000, CRC(c63eb92d) SHA1(f93bd4b91daee645677955020dc8df14dc9bfd27) )
 
@@ -1660,7 +1698,7 @@ ou1obj4u.9b     OBJ4U     MB8316200B (16M SOP44)
 */
 
 ROM_START( outfxies )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "ou2mprl.11c", 0x00002, 0x80000, CRC(f414a32e) SHA1(9733ab087cfde1b8fb5b676d8a2eb5325ebdbb56) )
 	ROM_LOAD32_WORD( "ou2mpru.11d", 0x00000, 0x80000, CRC(ab5083fb) SHA1(cb2e7a4838c2b80057edb83ea63116bccb1394d3) )
 
@@ -1705,7 +1743,7 @@ ROM_START( outfxies )
 ROM_END
 
 ROM_START( outfxesj )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "ou1-mprl.11c", 0x00002, 0x80000, CRC(d3b9e530) SHA1(3f5fe5eea817a23dfe42e76f32912ce94d4c49c9) )
 	ROM_LOAD32_WORD( "ou1-mpru.11d", 0x00000, 0x80000, CRC(d98308fb) SHA1(fdefeebf56464a20e3aaefd88df4eee9f7b5c4f3) )
 
@@ -1751,7 +1789,7 @@ ROM_END
 
 
 ROM_START( machbrkr )
-	ROM_REGION( 0x100000, "main", 0 ) /* main program */
+	ROM_REGION( 0x100000, "maincpu", 0 ) /* main program */
 	ROM_LOAD32_WORD( "mb1_mprl.11c", 0x00002, 0x80000, CRC(86cf0644) SHA1(07eeadda1d94c9be2f882edb6f2eb0b98292e500) )
 	ROM_LOAD32_WORD( "mb1_mpru.11d", 0x00000, 0x80000, CRC(fb1ff916) SHA1(e0ba96c1f26a60f87d8050e582e164d91e132183) )
 
@@ -1962,12 +2000,13 @@ GAME( 1994, ptblank,  0,        namconb1, gunbulet, gunbulet, ROT0,  "Namco", "P
 GAME( 1994, gunbulet, ptblank,  namconb1, gunbulet, gunbulet, ROT0,  "Namco", "Gun Bullet (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1993, gslugrsj, 0,        namconb1, nbsports, gslgr94u, ROT0,  "Namco", "Great Sluggers (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1994, gslgr94u, 0,        namconb1, nbsports, gslgr94u, ROT0,  "Namco", "Great Sluggers '94", GAME_IMPERFECT_SOUND )
+GAME( 1994, gslgr94j, gslgr94u, namconb1, nbsports, gslgr94j, ROT0,  "Namco", "Great Sluggers '94 (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1995, sws95,    0,        namconb1, nbsports, sws95,    ROT0,  "Namco", "Super World Stadium '95 (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1996, sws96,    0,        namconb1, nbsports, sws96,    ROT0,  "Namco", "Super World Stadium '96 (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1997, sws97,    0,        namconb1, nbsports, sws97,    ROT0,  "Namco", "Super World Stadium '97 (Japan)", GAME_IMPERFECT_SOUND )
-GAME( 1994, vshoot,   0,        namconb1, namconb1, vshoot,   ROT0,  "Namco", "J-League Soccer V-Shoot", GAME_IMPERFECT_SOUND )
+GAME( 1994, vshoot,   0,        namconb1, namconb1, vshoot,   ROT0,  "Namco", "J-League Soccer V-Shoot (Japan)", GAME_IMPERFECT_SOUND )
 
 /*     YEAR, NAME,     PARENT,   MACHINE,  INPUT,    INIT,     MNTR,  COMPANY, FULLNAME,   FLAGS */
 GAME( 1994, outfxies, 0,		namconb2, outfxies, outfxies, ROT0, "Namco", "Outfoxies", GAME_IMPERFECT_SOUND )
-GAME( 1994, outfxesj, outfxies, namconb2, outfxies	, outfxies, ROT0, "Namco", "Outfoxies (Japan)", GAME_IMPERFECT_SOUND )
+GAME( 1994, outfxesj, outfxies, namconb2, outfxies, outfxies, ROT0, "Namco", "Outfoxies (Japan)", GAME_IMPERFECT_SOUND )
 GAME( 1995, machbrkr, 0,		namconb2, namconb1, machbrkr, ROT0, "Namco", "Mach Breakers - Numan Athletics 2 (Japan)", GAME_IMPERFECT_SOUND )
