@@ -23,7 +23,7 @@
     TODO:
     - Palette is not right.
 
-    - H8/3002 does not handshake.  Looks like it needs to speak serially with the I/O board.
+    - H8/3002 now communicates with the H8/3334 on the I/O board, but it's not reliable yet.
 
     - Hook up actual inputs (?) via the 2 serial latches at d00004 and d00006.
       Works like this: write to d00004, then read d00004 12 times.  Ditto at
@@ -38,6 +38,7 @@
 
     - Serial number data is at offset 0x201 in the BIOS.  Until the games are running
       and displaying it I'm not going to meddle with it though.
+
 */
 
 /*
@@ -52,7 +53,7 @@ This document covers all the known Namco System 23 / Super System 23 games, incl
 *Final Furlong    Namco, 1997    System 22.5/Gorgon
 Gunmen Wars       Namco, 1998    System 23 [not dumped, but have]
 Motocross Go!     Namco, 1997    System 23
-*Panic Park       Namco, 1998    System 23
+Panic Park        Namco, 1998    System 23
 Rapid River       Namco, 1997    System 22.5/Gorgon
 Time Crisis II    Namco, 1997    System 23
 *Underground King Namco, 1998    System 23
@@ -744,6 +745,7 @@ static int ss23_vstat = 0, hstat = 0, vstate = 0;
 static tilemap *bgtilemap;
 static UINT32 *namcos23_textram, *namcos23_shared_ram;
 static UINT32 *namcos23_charram;
+static UINT8 namcos23_jvssense;
 
 static UINT16 nthword( const UINT32 *pSource, int offs )
 {
@@ -775,6 +777,7 @@ static WRITE32_HANDLER( namcos23_textram_w )
 
 static VIDEO_START( ss23 )
 {
+	gfx_element_set_source(machine->gfx[0], (UINT8 *)namcos23_charram);
 	bgtilemap = tilemap_create(machine, TextTilemapGetInfo, tilemap_scan_rows, 16, 16, 64, 64);
 	tilemap_set_transparent_pen(bgtilemap, 0xf);
 }
@@ -936,11 +939,8 @@ static VIDEO_UPDATE( gorgon )
 
 static WRITE32_HANDLER( s23_txtchar_w )
 {
-	COMBINE_DATA(&namcos23_charram[offset]	);
-
-	decodechar( space->machine->gfx[0],offset/32,(UINT8 *)namcos23_charram );
-
-	tilemap_mark_all_tiles_dirty(bgtilemap);
+	COMBINE_DATA(&namcos23_charram[offset]);
+	gfx_element_mark_dirty(space->machine->gfx[0], offset/32);
 }
 
 static READ32_HANDLER( ss23_vstat_r )
@@ -995,9 +995,16 @@ static WRITE32_HANDLER( namcos23_paletteram_w )
 }
 
 // must return this magic number
+static UINT32 s23_vbl = 0;
+
+static INTERRUPT_GEN(s23_interrupt)
+{
+	s23_vbl ^= 0x80008000;
+}
+
 static READ32_HANDLER(s23_unk_r)
 {
-	return 0x008e008e;
+	return 0x008e008e | s23_vbl;
 }
 
 // this & 8 and this & 4 are checked
@@ -1018,12 +1025,12 @@ static WRITE32_HANDLER( s23_mcuen_w )
 		if (data)
 		{
 			logerror("S23: booting H8/3002\n");
-			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
+			cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, CLEAR_LINE);
 		}
 		else
 		{
 			logerror("S23: stopping H8/3002\n");
-			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+			cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, ASSERT_LINE);
 		}
 	}
 }
@@ -1069,6 +1076,12 @@ static WRITE16_HANDLER( sharedram_sub_w )
 {
 	UINT16 *shared16 = (UINT16 *)namcos23_shared_ram;
 
+	// fake that an I/O board is connected
+	if ((offset == 0x4052/2) && (data == 0x78))
+	{
+		data = 0;
+	}
+
 	COMBINE_DATA(&shared16[BYTE_XOR_BE(offset)]);
 }
 
@@ -1079,24 +1092,15 @@ static READ16_HANDLER( sharedram_sub_r )
 	return shared16[BYTE_XOR_BE(offset)];
 }
 
-#if 1
-static WRITE16_HANDLER(cause_sync_w)
-{
-	UINT16 *shared16 = (UINT16 *)namcos23_shared_ram;
-
-	shared16[BYTE_XOR_BE(0x4052/2)] = 0;
-}
-#endif
-
 /* H8/3002 MCU stuff */
 static ADDRESS_MAP_START( s23h8rwmap, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
 	AM_RANGE(0x080000, 0x08ffff) AM_READWRITE( sharedram_sub_r, sharedram_sub_w )
-	AM_RANGE(0x280000, 0x287fff) AM_READWRITE( c352_0_r, c352_0_w )
+	AM_RANGE(0x280000, 0x287fff) AM_DEVREADWRITE( "c352", c352_r, c352_w )
 	AM_RANGE(0x300000, 0x300001) AM_READNOP //AM_READ_PORT("IN1")
 	AM_RANGE(0x300002, 0x300003) AM_READNOP //AM_READ_PORT("IN2")
 	AM_RANGE(0x300010, 0x300011) AM_NOP
-	AM_RANGE(0x300030, 0x300031) AM_WRITE(cause_sync_w)	// cheats comms with I/O board and makes SUBCPU TEST pass
+	AM_RANGE(0x300030, 0x300031) AM_WRITENOP	// timecrs2 writes this when writing to the sync shared ram location, motoxgo doesn't
 ADDRESS_MAP_END
 
 static READ8_HANDLER( s23_mcu_p8_r )
@@ -1152,16 +1156,19 @@ static READ8_HANDLER( s23_mcu_rtc_r )
 			ret = make_bcd(systime.local_time.hour);	// hour (BCD, 0-23)
 			break;
 		case 3:
-			ret = make_bcd(weekday[systime.local_time.weekday]); // day of the week (1 = Monday, 7 = Sunday)
+			ret = make_bcd(weekday[systime.local_time.weekday]);	// low nibble = day of the week
+			ret |= (make_bcd(systime.local_time.mday) & 0x0f)<<4;	// high nibble = low digit of day
 			break;
 		case 4:
-			ret = make_bcd(systime.local_time.mday);	// day (BCD, 1-31)
+			ret = (make_bcd(systime.local_time.mday) >> 4);			// low nibble = high digit of day
+			ret |= (make_bcd(systime.local_time.month + 1) & 0x0f)<<4;	// high nibble = low digit of month
 			break;
 		case 5:
-			ret = make_bcd(systime.local_time.month + 1);	// month (BCD, 1-12)
+			ret = make_bcd(systime.local_time.month + 1) >> 4;	// low nibble = high digit of month
+			ret |= (make_bcd(systime.local_time.year % 10) << 4);	// high nibble = low digit of year
 			break;
 		case 6:
-			ret = make_bcd(systime.local_time.year % 100);	// year (BCD, 0-99)
+			ret = make_bcd(systime.local_time.year % 100) >> 4;	// low nibble = tens digit of year (BCD, 0-9)
 			break;
 	}
 
@@ -1213,12 +1220,74 @@ static WRITE8_HANDLER( s23_mcu_settings_w )
 	s23_setstate ^= 1;
 }
 
+static UINT8 maintoio[64], mi_rd, mi_wr;
+static UINT8 iotomain[64], im_rd, im_wr;
+
+static READ8_HANDLER( s23_mcu_iob_r )
+{
+	UINT8 ret = iotomain[im_rd];
+
+	im_rd++;
+	im_rd &= 0x3f;
+
+	if (im_rd == im_wr)
+	{
+		cputag_set_input_line(space->machine, "audiocpu", H8_SCI_0_RX, CLEAR_LINE);
+	}
+	else
+	{
+		cputag_set_input_line(space->machine, "audiocpu", H8_SCI_0_RX, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", H8_SCI_0_RX, ASSERT_LINE);
+	}
+
+	return ret;
+}
+
+static WRITE8_HANDLER( s23_mcu_iob_w )
+{
+	maintoio[mi_wr++] = data;
+	mi_wr &= 0x3f;
+
+	cputag_set_input_line(space->machine, "ioboard", H8_SCI_0_RX, ASSERT_LINE);
+}
+
+static INPUT_PORTS_START( ss23 )
+	PORT_START("H8PORT")
+INPUT_PORTS_END
+
+
+static READ8_HANDLER(s23_mcu_p6_r)
+{
+	// bit 1 = JVS cable present sense (1 = I/O board plugged in)
+		return (namcos23_jvssense << 1) | 0xfd;
+}
+
+static WRITE8_HANDLER(s23_mcu_p6_w)
+{
+//  printf("%02x to port 6\n", data);
+}
+
 static ADDRESS_MAP_START( s23h8iomap, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(H8_PORT_7, H8_PORT_7) AM_READ( input_port_0_r )
+	AM_RANGE(H8_PORT_6, H8_PORT_6) AM_READWRITE( s23_mcu_p6_r, s23_mcu_p6_w )
+	AM_RANGE(H8_PORT_7, H8_PORT_7) AM_READ_PORT( "H8PORT" )
 	AM_RANGE(H8_PORT_8, H8_PORT_8) AM_READ( s23_mcu_p8_r ) AM_WRITENOP
 	AM_RANGE(H8_PORT_A, H8_PORT_A) AM_READWRITE( s23_mcu_pa_r, s23_mcu_pa_w )
 	AM_RANGE(H8_PORT_B, H8_PORT_B) AM_READWRITE( s23_mcu_portB_r, s23_mcu_portB_w )
-	AM_RANGE(H8_SERIAL_1, H8_SERIAL_1) AM_READ( s23_mcu_rtc_r ) AM_WRITE( s23_mcu_settings_w )
+	AM_RANGE(H8_SERIAL_0, H8_SERIAL_0) AM_READWRITE( s23_mcu_iob_r, s23_mcu_iob_w )
+	AM_RANGE(H8_SERIAL_1, H8_SERIAL_1) AM_READWRITE( s23_mcu_rtc_r, s23_mcu_settings_w )
+	AM_RANGE(H8_ADC_0_H, H8_ADC_0_L) AM_NOP
+	AM_RANGE(H8_ADC_1_H, H8_ADC_1_L) AM_NOP
+	AM_RANGE(H8_ADC_2_H, H8_ADC_2_L) AM_NOP
+	AM_RANGE(H8_ADC_3_H, H8_ADC_3_L) AM_NOP
+ADDRESS_MAP_END
+
+// version without serial hookup to I/O board for games where the PIC isn't dumped
+static ADDRESS_MAP_START( s23h8ionoiobmap, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(H8_PORT_7, H8_PORT_7) AM_READ_PORT( "H8PORT" )
+	AM_RANGE(H8_PORT_8, H8_PORT_8) AM_READ( s23_mcu_p8_r ) AM_WRITENOP
+	AM_RANGE(H8_PORT_A, H8_PORT_A) AM_READWRITE( s23_mcu_pa_r, s23_mcu_pa_w )
+	AM_RANGE(H8_PORT_B, H8_PORT_B) AM_READWRITE( s23_mcu_portB_r, s23_mcu_portB_w )
+	AM_RANGE(H8_SERIAL_1, H8_SERIAL_1) AM_READWRITE( s23_mcu_rtc_r, s23_mcu_settings_w )
 	AM_RANGE(H8_ADC_0_H, H8_ADC_0_L) AM_NOP
 	AM_RANGE(H8_ADC_1_H, H8_ADC_1_L) AM_NOP
 	AM_RANGE(H8_ADC_2_H, H8_ADC_2_L) AM_NOP
@@ -1226,17 +1295,62 @@ static ADDRESS_MAP_START( s23h8iomap, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
+static READ8_HANDLER( s23_iob_mcu_r )
+{
+	UINT8 ret = maintoio[mi_rd];
+
+	mi_rd++;
+	mi_rd &= 0x3f;
+
+	if (mi_rd == mi_wr)
+	{
+		cputag_set_input_line(space->machine, "ioboard", H8_SCI_0_RX, CLEAR_LINE);
+	}
+
+	return ret;
+}
+
+static WRITE8_HANDLER( s23_iob_mcu_w )
+{
+	iotomain[im_wr++] = data;
+	im_wr &= 0x3f;
+
+	cputag_set_input_line(space->machine, "audiocpu", H8_SCI_0_RX, ASSERT_LINE);
+}
+
+static UINT8 s23_tssio_port_4 = 0;
+
+static READ8_HANDLER( s23_iob_p4_r )
+{
+	return s23_tssio_port_4;
+}
+
+static WRITE8_HANDLER( s23_iob_p4_w )
+{
+	s23_tssio_port_4 = data;
+
+	namcos23_jvssense = (data & 0x04) ? 0 : 1;
+ }
+
 /* H8/3334 (Namco C78) I/O board MCU */
 static ADDRESS_MAP_START( s23iobrdmap, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_READ(SMH_ROM)
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
 ADDRESS_MAP_END
 
+/*
+    port 5 bit 2 = LED to indicate transmitting packet to main
+    port 4 bit 2 = SENSE line back to main (0 = asserted, 1 = dropped)
+*/
 static ADDRESS_MAP_START( s23iobrdiomap, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(H8_PORT_4, H8_PORT_4) AM_READWRITE( s23_iob_p4_r, s23_iob_p4_w )
+	AM_RANGE(H8_SERIAL_0, H8_SERIAL_0) AM_READWRITE( s23_iob_mcu_r, s23_iob_mcu_w )
 ADDRESS_MAP_END
 
 static DRIVER_INIT(ss23)
 {
+	mi_rd = mi_wr = im_rd = im_wr = 0;
+	namcos23_jvssense = 1;
 }
 
 static const gfx_layout namcos23_cg_layout =
@@ -1292,18 +1406,18 @@ static INTERRUPT_GEN( namcos23_interrupt )
 static MACHINE_DRIVER_START( gorgon )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", R4650BE, 133000000)
+	MDRV_CPU_ADD("maincpu", R4650BE, 133000000)
 	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_PROGRAM_MAP(gorgon_map, 0)
+	MDRV_CPU_PROGRAM_MAP(gorgon_map)
 
-	MDRV_CPU_ADD("audio", H83002, 14745600 )
-	MDRV_CPU_PROGRAM_MAP( s23h8rwmap, 0 )
-	MDRV_CPU_IO_MAP( s23h8iomap, 0 )
-	MDRV_CPU_VBLANK_INT("main", irq1_line_pulse)
+	MDRV_CPU_ADD("audiocpu", H83002, 14745600 )
+	MDRV_CPU_PROGRAM_MAP( s23h8rwmap)
+	MDRV_CPU_IO_MAP( s23h8ionoiobmap)
+	MDRV_CPU_VBLANK_INT("screen", irq1_line_pulse)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -1318,36 +1432,35 @@ static MACHINE_DRIVER_START( gorgon )
 	MDRV_VIDEO_UPDATE(gorgon)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("c352", C352, 14745600)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
-	MDRV_SOUND_ROUTE(1, "left", 1.00)
-	MDRV_SOUND_ROUTE(2, "right", 1.00)
-	MDRV_SOUND_ROUTE(3, "left", 1.00)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( s23 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", R4650BE, 166000000)
+	MDRV_CPU_ADD("maincpu", R4650BE, 166000000)
 	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_PROGRAM_MAP(ss23_map, 0)
+	MDRV_CPU_PROGRAM_MAP(ss23_map)
+	MDRV_CPU_VBLANK_INT("screen", s23_interrupt)
 
-	MDRV_CPU_ADD("audio", H83002, 14745600 )
-	MDRV_CPU_PROGRAM_MAP( s23h8rwmap, 0 )
-	MDRV_CPU_IO_MAP( s23h8iomap, 0 )
-	MDRV_CPU_VBLANK_INT("main", irq1_line_pulse)
+	MDRV_CPU_ADD("audiocpu", H83002, 14745600 )
+	MDRV_CPU_PROGRAM_MAP( s23h8rwmap)
+	MDRV_CPU_IO_MAP( s23h8iomap)
+	MDRV_CPU_VBLANK_INT("screen", irq1_line_pulse)
 
 	MDRV_CPU_ADD("ioboard", H83334, 14745600 )
-	MDRV_CPU_PROGRAM_MAP( s23iobrdmap, 0 )
-	MDRV_CPU_IO_MAP( s23iobrdiomap, 0 )
-	MDRV_CPU_VBLANK_INT("main", irq1_line_pulse)
+	MDRV_CPU_PROGRAM_MAP( s23iobrdmap)
+	MDRV_CPU_IO_MAP( s23iobrdiomap)
 
+	MDRV_QUANTUM_TIME(HZ(60*4000))
 
-	MDRV_QUANTUM_TIME(HZ(60000))
-
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -1362,31 +1475,31 @@ static MACHINE_DRIVER_START( s23 )
 	MDRV_VIDEO_UPDATE(ss23)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("c352", C352, 14745600)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
-	MDRV_SOUND_ROUTE(1, "left", 1.00)
-	MDRV_SOUND_ROUTE(2, "right", 1.00)
-	MDRV_SOUND_ROUTE(3, "left", 1.00)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ss23 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", R4650BE, 166000000)
+	MDRV_CPU_ADD("maincpu", R4650BE, 166000000)
 	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_PROGRAM_MAP(ss23_map, 0)
-	MDRV_CPU_VBLANK_INT("main", namcos23_interrupt)
+	MDRV_CPU_PROGRAM_MAP(ss23_map)
+	MDRV_CPU_VBLANK_INT("screen", namcos23_interrupt)
 
-	MDRV_CPU_ADD("audio", H83002, 14745600 )
-	MDRV_CPU_PROGRAM_MAP( s23h8rwmap, 0 )
-	MDRV_CPU_IO_MAP( s23h8iomap, 0 )
-	MDRV_CPU_VBLANK_INT("main", irq1_line_pulse)
+	MDRV_CPU_ADD("audiocpu", H83002, 14745600 )
+	MDRV_CPU_PROGRAM_MAP( s23h8rwmap)
+	MDRV_CPU_IO_MAP( s23h8ionoiobmap)
+	MDRV_CPU_VBLANK_INT("screen", irq1_line_pulse)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -1401,13 +1514,13 @@ static MACHINE_DRIVER_START( ss23 )
 	MDRV_VIDEO_UPDATE(ss23)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("c352", C352, 14745600)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
-	MDRV_SOUND_ROUTE(1, "left", 1.00)
-	MDRV_SOUND_ROUTE(2, "right", 1.00)
-	MDRV_SOUND_ROUTE(3, "left", 1.00)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
 MACHINE_DRIVER_END
 
 ROM_START( rapidrvr )
@@ -1415,7 +1528,7 @@ ROM_START( rapidrvr )
         ROM_LOAD16_BYTE( "rd3verc.ic2",  0x000000, 0x200000, CRC(c15c0f30) SHA1(9f529232818f3e184f81f62408a5cad615b05613) )
         ROM_LOAD16_BYTE( "rd3verc.ic1",  0x000001, 0x200000, CRC(9d7f4411) SHA1(d049efaa539d36ed0f73ca3f50a8f7112e67f865) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
 	ROM_LOAD16_WORD_SWAP( "rd3verc.ic3",  0x000000, 0x080000, CRC(6e26fbaf) SHA1(4ab6637d22f0d26f7e1d10e9c80059c56f64303d) )
 
 	ROM_REGION( 0x800000, "sprite", 0 )	/* sprite? tilemap? tiles */
@@ -1474,7 +1587,7 @@ ROM_START( motoxgo )
         ROM_LOAD16_BYTE( "mg3vera.ic2",  0x000000, 0x200000, CRC(1bf06f00) SHA1(e9d04e9f19bff7a58cb280dd1d5db12801b68ba0) )
         ROM_LOAD16_BYTE( "mg3vera.ic1",  0x000001, 0x200000, CRC(f5e6e25b) SHA1(1de30e8e831be66987112645a9db3a3001b89fe6) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "mg3vera.ic3",  0x000000, 0x080000, CRC(9e3d46a8) SHA1(9ffa5b91ea51cc0fb97def25ce47efa3441f3c6f) )
 
 	ROM_REGION( 0x40000, "ioboard", 0 )	/* I/O board HD643334 H8/3334 MCU code */
@@ -1521,7 +1634,7 @@ ROM_START( timecrs2 )
         ROM_LOAD16_BYTE( "tss3verb.2",   0x000000, 0x200000, CRC(c7be691f) SHA1(5e2e7a0db3d8ce6dfeb6c0d99e9fe6a9f9cab467) )
         ROM_LOAD16_BYTE( "tss3verb.1",   0x000001, 0x200000, CRC(6e3f232b) SHA1(8007d8f31a605a5df89938d7c9f9d3d209c934be) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "tss3verb.3",   0x000000, 0x080000, CRC(41e41994) SHA1(eabc1a307c329070bfc6486cb68169c94ff8a162) )
 
 	ROM_REGION( 0x40000, "ioboard", 0 )	/* I/O board HD643334 H8/3334 MCU code */
@@ -1561,7 +1674,7 @@ ROM_START( timcrs2b )
         ROM_LOAD16_BYTE( "tss2verb.ic2", 0x000000, 0x200000, CRC(9f56a4df) SHA1(5ecb3cd93726ab6be02762853fd6a45266d6c0bc) )
         ROM_LOAD16_BYTE( "tss2verb.ic1", 0x000001, 0x200000, CRC(aa147f71) SHA1(e00267d1a8286942c83dc35289ad65bd3cb6d8db) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "tss3verb.3",   0x000000, 0x080000, CRC(41e41994) SHA1(eabc1a307c329070bfc6486cb68169c94ff8a162) )
 
 	ROM_REGION( 0x40000, "ioboard", 0 )	/* I/O board HD643334 H8/3334 MCU code */
@@ -1602,7 +1715,7 @@ ROM_START( 500gp )
         ROM_LOAD16_BYTE( "5gp3verc.2",   0x000000, 0x200000, CRC(e2d43468) SHA1(5e861dd223c7fa177febed9803ac353cba18e19d) )
         ROM_LOAD16_BYTE( "5gp3verc.1",   0x000001, 0x200000, CRC(f6efc94a) SHA1(785eee2bec5080d4e8ef836f28d446328c942b0e) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "5gp3verc.3",   0x000000, 0x080000, CRC(b323abdf) SHA1(8962e39b48a7074a2d492afb5db3f5f3e5ae2389) )
 
 	ROM_REGION( 0x2000000, "sprite", 0 )	/* sprite? tilemap? tiles */
@@ -1645,7 +1758,7 @@ ROM_START( finfurl2 )
         ROM_LOAD16_BYTE( "29f016.ic2",   0x000000, 0x200000, CRC(13cbc545) SHA1(3e67a7bfbb1c1374e8e3996a0c09e4861b0dca14) )
         ROM_LOAD16_BYTE( "29f016.ic1",   0x000001, 0x200000, CRC(5b04e4f2) SHA1(8099fc3deab9ed14a2484a774666fbd928330de8) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "m29f400.ic3",  0x000000, 0x080000, CRC(9fd69bbd) SHA1(53a9bf505de70495dcccc43fdc722b3381aad97c) )
 
 	ROM_REGION( 0x2000000, "sprite", 0 )	/* sprite? tilemap? tiles */
@@ -1684,7 +1797,7 @@ ROM_START( finfrl2j )
         ROM_LOAD16_BYTE( "29f016_jap1.ic2", 0x000000, 0x200000, CRC(0215125d) SHA1(a99f601441c152b0b00f4811e5752c71897b1ed4) )
         ROM_LOAD16_BYTE( "29f016_jap1.ic1", 0x000001, 0x200000, CRC(38c9ae96) SHA1(b50afc7276662267ff6460f82d0e5e8b00b341ea) )
 
-	ROM_REGION( 0x80000, "audio", 0 )	/* Hitachi H8/3002 MCU code */
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
         ROM_LOAD16_WORD_SWAP( "m29f400.ic3",  0x000000, 0x080000, CRC(9fd69bbd) SHA1(53a9bf505de70495dcccc43fdc722b3381aad97c) )
 
 	ROM_REGION( 0x2000000, "sprite", 0 )	/* sprite? tilemap? tiles */
@@ -1718,11 +1831,52 @@ ROM_START( finfrl2j )
         ROM_LOAD( "ffs1waveh.2a", 0x800000, 0x800000, CRC(178e8bd3) SHA1(8ab1a97003914f70b09e96c5924f3a839fe634c7) )
 ROM_END
 
+ROM_START( panicprk )
+	ROM_REGION32_BE( 0x400000, "user1", 0 ) /* 4 megs for main R4650 code */
+        ROM_LOAD16_BYTE( "pnp2ver-a.ic2", 0x000000, 0x200000, CRC(cd528597) SHA1(cf390e78228eb10d5f50ff7e7e37063a2d87f469) )
+        ROM_LOAD16_BYTE( "pnp2ver-a.ic1", 0x000001, 0x200000, CRC(80fea853) SHA1(b18003bde060ebb3c892a6d7fa4abf868cadc777) )
+
+	ROM_REGION( 0x80000, "audiocpu", 0 )	/* Hitachi H8/3002 MCU code */
+        ROM_LOAD16_WORD_SWAP( "pnp2ver-a.ic3", 0x000000, 0x080000, CRC(fe4bc6f4) SHA1(2114dc4bc63d589e6c3b26a73dbc60924f3b1765) )
+
+	ROM_REGION( 0x2000000, "sprite", 0 )	/* sprite? tilemap? tiles */
+        ROM_LOAD16_BYTE( "pnp1mtal.2h",  0x000000, 0x800000, CRC(6490faaa) SHA1(03443746009b434e5d4074ea6314910418907360) )
+        ROM_LOAD16_BYTE( "pnp1mtah.2j",  0x000001, 0x800000, CRC(37addddd) SHA1(3032989653304417df80606bc3fde6e9425d8cbb) )
+
+	ROM_REGION( 0x4000000, "textile", 0 )	/* texture tiles */
+        ROM_LOAD( "pnp1cguu.5f",  0x000000, 0x800000, CRC(cd64f57f) SHA1(8780270298e0823db1acbbf79396788df0c3c19c) )
+        ROM_LOAD( "pnp1cgum.4j",  0x800000, 0x800000, CRC(206217ca) SHA1(9c095bba7764f3405c3fab10513b9b78981ec44d) )
+        ROM_LOAD( "pnp1cgll.4m",  0x1000000, 0x800000, CRC(d03932cf) SHA1(49240e44923cc6e815e9457b6290fd18466658af) )
+        ROM_LOAD( "pnp1cglm.5k",  0x180000, 0x800000, CRC(abf4ccf2) SHA1(3848e26d0ba6c872bbc6d5e0eb23a9d4b34152d5) )
+        ROM_LOAD( "pnp1cguu.4f",  0x2000000, 0x800000, CRC(cd64f57f) SHA1(8780270298e0823db1acbbf79396788df0c3c19c) )
+        ROM_LOAD( "pnp1cgum.5j",  0x2800000, 0x800000, CRC(206217ca) SHA1(9c095bba7764f3405c3fab10513b9b78981ec44d) )
+        ROM_LOAD( "pnp1cgll.5m",  0x3000000, 0x800000, CRC(d03932cf) SHA1(49240e44923cc6e815e9457b6290fd18466658af) )
+        ROM_LOAD( "pnp1cglm.4k",  0x3800000, 0x800000, CRC(abf4ccf2) SHA1(3848e26d0ba6c872bbc6d5e0eb23a9d4b34152d5) )
+
+	ROM_REGION( 0x800000, "textilemap", 0 )	/* texture tilemap */
+        ROM_LOAD( "pnp1ccrl.7f",  0x000000, 0x200000, CRC(b7bc43c2) SHA1(f4b470540194486ca6822f438fc1d4700cfb2ab1) )
+        ROM_LOAD( "pnp1ccrh.7e",  0x200000, 0x200000, CRC(caaf1b73) SHA1(b436992817ab4e4dad05e7429eb102d4fb57fa6a) )
+        ROM_LOAD( "pnp1ccrl.7m",  0x400000, 0x200000, CRC(b7bc43c2) SHA1(f4b470540194486ca6822f438fc1d4700cfb2ab1) )
+        ROM_LOAD( "pnp1ccrh.7k",  0x600000, 0x200000, CRC(caaf1b73) SHA1(b436992817ab4e4dad05e7429eb102d4fb57fa6a) )
+
+	ROM_REGION32_LE( 0x2000000, "pointrom", 0 )	/* 3D model data */
+        ROM_LOAD32_WORD( "pnp1pt0l.7c",  0x000000, 0x400000, CRC(26af5fa1) SHA1(12fcf98c2a59643e0fdfdd7186f9f16baf54a9cf) )
+        ROM_LOAD32_WORD( "pnp1pt0h.7a",  0x000002, 0x400000, CRC(43fc2246) SHA1(301d321cd4a01ebd7ccfa6f295d6c3daf0a19efe) )
+        ROM_LOAD32_WORD( "pnp1pt1l.5c",  0x800000, 0x400000, CRC(15c6f236) SHA1(e8c393359a91cdce6e9110a48c0a80708f8fc132) )
+        ROM_LOAD32_WORD( "pnp1pt1h.5a",  0x800002, 0x400000, CRC(1ff470c0) SHA1(ca8fad90743589744939d681b0ce94f368337b3f) )
+
+	ROM_REGION( 0x1000000, "c352", 0 ) /* C352 PCM samples */
+        ROM_LOAD( "pnp1wavel.2c", 0x000000, 0x800000, CRC(35c6a9bd) SHA1(4b56fdc37525c15e57d93091e6609d6a6905fc5c) )
+        ROM_LOAD( "pnp1waveh.2a", 0x800000, 0x800000, CRC(6fa1826a) SHA1(20a5af49e65ae2bc57c016b5cd9bafa5a5220d35) )
+ROM_END
+
+
 /* Games */
-GAME( 1997, rapidrvr, 0,      gorgon, 0, ss23, ROT0, "Namco", "Rapid River (RD3 Ver. C)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1997, motoxgo,  0,         s23, 0, ss23, ROT0, "Namco", "Motocross Go! (MG3 Ver. A)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1997, timecrs2, 0,         s23, 0, ss23, ROT0, "Namco", "Time Crisis 2 (TSS3 Ver. B)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1997, timcrs2b, timecrs2,  s23, 0, ss23, ROT0, "Namco", "Time Crisis 2 (TSS2 Ver. B)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1999, 500gp,    0,        ss23, 0, ss23, ROT0, "Namco", "500GP", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1999, finfurl2, 0,        ss23, 0, ss23, ROT0, "Namco", "Final Furlong 2 (World)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
-GAME( 1999, finfrl2j, finfurl2, ss23, 0, ss23, ROT0, "Namco", "Final Furlong 2 (Japan)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1997, rapidrvr, 0,      gorgon, ss23, ss23, ROT0, "Namco", "Rapid River (RD3 Ver. C)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1997, motoxgo,  0,         s23, ss23, ss23, ROT0, "Namco", "Motocross Go! (MG3 Ver. A)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1997, timecrs2, 0,         s23, ss23, ss23, ROT0, "Namco", "Time Crisis 2 (TSS3 Ver. B)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1997, timcrs2b, timecrs2,  s23, ss23, ss23, ROT0, "Namco", "Time Crisis 2 (TSS2 Ver. B)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1998, panicprk, 0,        ss23, ss23, ss23, ROT0, "Namco", "Panic Park (PNP2 Ver. A)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1999, 500gp,    0,        ss23, ss23, ss23, ROT0, "Namco", "500GP", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1999, finfurl2, 0,        ss23, ss23, ss23, ROT0, "Namco", "Final Furlong 2 (World)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
+GAME( 1999, finfrl2j, finfurl2, ss23, ss23, ss23, ROT0, "Namco", "Final Furlong 2 (Japan)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND )
