@@ -21,7 +21,20 @@
           Zsolt Vasvari
 
 
-    Neogeo Motherboard (info - courtesy of Guru):
+    The arcade version of the Neo-Geo system is called Multi Video System (MVS).
+    It is a cartridge based system.
+    MVS hardware was produced in 1 / 2 / 4 and 6 Slot versions.
+
+    Known hardware (incomplete):
+    ============================
+
+    1 Slot: MV1 / MV1A / MV1B (MV1B CHX) / MV1C / MV1F (MV1FT / MV1FS) / MV1FZ
+    2 Slot: MV2F / MV2F-01
+    4 Slot: MV4F / MV4FS
+    6 Slot: MV6F
+
+
+    Neo-Geo Motherboard (info - courtesy of Guru):
 
           NEO-MVH MV1
           |---------------------------------------------------------------------|
@@ -55,7 +68,88 @@
           |---------------------------------------------------------------------|
 
 
-    Known issues/to-do's:
+    MVS cart pinout
+    ===============
+
+    kindly submitted by Apollo69 (apollo69@columbus.rr.com)
+    =================================================================
+                CTRG1                            CTRG2
+    =================================================================
+         GND = 01A | 01B = GND            GND = 01A | 01B = GND
+         GND = 02A | 02B = GND            GND = 02A | 02B = GND
+          P0 = 03A | 03B = P1             GND = 03A | 03B = GND
+          P2 = 04A | 04B = P3             GND = 04A | 04B = GND
+          P4 = 05A | 05B = P5              D0 = 05A | 05B = A1
+          P6 = 06A | 06B = P7              D1 = 06A | 06B = A2
+          P8 = 07A | 07B = P9              D2 = 07A | 07B = A3
+         P10 = 08A | 08B = P11             D3 = 08A | 08B = A4
+         P12 = 09A | 09B = P13             D4 = 09A | 09B = A5
+         P14 = 10A | 10B = P15             D5 = 10A | 10B = A6
+         P16 = 11A | 11B = P17             D6 = 11A | 11B = A7
+         P18 = 12A | 12B = P19             D7 = 12A | 12B = A8
+         P20 = 13A | 13B = P21             D8 = 13A | 13B = A9
+         P22 = 14A | 14B = P23             D9 = 14A | 14B = A10
+       PCK1B = 15A | 15B = 24M            D10 = 15A | 15B = A11
+       PCK2B = 16A | 16B = 12M            D11 = 16A | 16B = A12
+         2H1 = 17A | 17B = 8M             D12 = 17A | 17B = A13
+         CA4 = 18A | 18B = RESET          D13 = 18A | 18B = A14
+         CR0 = 19A | 19B = CR1            D14 = 19A | 19B = A15
+         CR2 = 20A | 20B = CR3            D15 = 20A | 20B = A16
+         CR4 = 21A | 21B = CR5            R/W = 21A | 21B = A17
+         CR6 = 22A | 22B = CR7             AS = 22A | 22B = A18
+         CR8 = 23A | 23B = CR9         ROMOEU = 23A | 23B = A19
+        CR10 = 24A | 24B = CR11        ROMOEL = 24A | 24B = 68KCLKB
+        CR12 = 25A | 25B = CR13       PORTOEU = 25A | 25B = ROMWAIT
+        CR14 = 26A | 26B = CR15       PORTOEL = 26A | 26B = PWAIT0
+        CR16 = 27A | 27B = CR17       PORTWEU = 27A | 27B = PWAIT1
+        CR18 = 28A | 28B = CR19       PORTWEL = 28A | 28B = PDTACT
+         VCC = 29A | 29B = VCC            VCC = 29A | 29B = VCC
+         VCC = 30A | 30B = VCC            VCC = 30A | 30B = VCC
+         VCC = 31A | 31B = VCC            VCC = 31A | 31B = VCC
+         VCC = 32A | 32B = VCC            VCC = 32A | 32B = VCC
+        CR20 = 33A | 33B = CR21      PORTADRS = 33A | 33B = 4MB
+        CR22 = 34A | 34B = CR23            NC = 34A | 34B = ROMOE
+        CR24 = 35A | 35B = CR25            NC = 35A | 35B = RESET
+        CR26 = 36A | 36B = CR27            NC = 36A | 36B = NC
+        CR28 = 37A | 37B = CR29            NC = 37A | 37B = NC
+        CR30 = 38A | 38B = CR31            NC = 38A | 38B = NC
+          NC = 39A | 39B = FIX00           NC = 39A | 39B = NC
+          NC = 40A | 40B = FIX01           NC = 40A | 40B = NC
+          NC = 41A | 41B = FIX02           NC = 41A | 41B = SDPAD0
+     SYSTEMB = 42A | 42B = FIX03      SYSTEMB = 42A | 42B = SDPAD1
+        SDA0 = 43A | 43B = FIX04        SDPA8 = 43A | 43B = SDPAD2
+        SDA1 = 44A | 44B = FIX05        SDPA9 = 44A | 44B = SDPAD3
+        SDA2 = 45A | 45B = FIX06       SDPA10 = 45A | 45B = SDPAD4
+        SDA3 = 46A | 46B = FIX07       SDPA11 = 46A | 46B = SDPAD5
+        SDA4 = 47A | 47B = SDRD0       SDPMPX = 47A | 47B = SDPAD6
+        SDA5 = 48A | 48B = SDRD1        SDPOE = 48A | 48B = SDPAD7
+        SDA6 = 49A | 49B = SDROM        SDRA8 = 49A | 49B = SDRA00
+        SDA7 = 50A | 50B = SDMRD        SDRA9 = 50A | 50B = SDRA01
+        SDA8 = 51A | 51B = SDDO        SDRA20 = 51A | 51B = SDRA02
+        SDA9 = 52A | 52B = SDD1        SDRA21 = 52A | 52B = SDRA03
+       SDA10 = 53A | 53B = SDD2        SDRA22 = 53A | 53B = SDRA04
+       SDA11 = 54A | 54B = SDD3        SDRA23 = 54A | 54B = SDRA05
+       SDA12 = 55A | 55B = SDD4        SDRMPX = 55A | 55B = SDRA06
+       SDA13 = 56A | 56B = SDD5         SDROE = 56A | 56B = SDRA07
+       SDA14 = 57A | 57B = SDD6           GND = 57A | 57B = GND
+       SDA15 = 58A | 58B = SDD7           GND = 58A | 58B = GND
+         GND = 59A | 59B = GND            GND = 59A | 59B = GND
+         GND = 60A | 60B = GND            GND = 60A | 60B = GND
+
+    CTRG1 (CHA)  = Contains gfx data ('C' - rom), text layer data ('S' - rom) and sound driver ('M' - rom)
+    CTRG2 (PROG) = Contains sample data ('V' - rom) and program code ('P' - rom)
+
+NOTE: On CTRG2-B, The "A" lines start at "A1". If you trace this on an
+    actual cart, you will see that this is actually "A0" (A0 - A18).
+
+    These are from a very hard to read copy of the schematics, so
+    I hope that I got the pin names correct.
+
+    Apollo69 10/19/99
+
+
+    Known driver issues/to-do's:
+    ============================
 
         * Fatal Fury 3 crashes during the ending - this doesn't occur if
           the language is set to Japanese, maybe the English endings
@@ -77,6 +171,24 @@
         * Distorted jumping sound in Nightmare in the Dark
         * Ninja Combat sometimes glitches
 
+
+    Mahjong Panel notes (2009-03 FP):
+    =================================
+
+    * In Service Mode menu with mahjong panel active, controls are as
+      follows:
+
+        A = select / up (for options)
+        B = down (for options)
+        C = go to previous menu
+        E = up (for menu entries)
+        F = down (for menu entries)
+        G = left (for options)
+        H = right (for options)
+
+    * These only work with Japanese BIOS, but I think it's not a bug: I
+      doubt other bios were programmed to be compatible with mahjong panels
+
 ****************************************************************************/
 
 #include "driver.h"
@@ -140,7 +252,6 @@ static UINT8 led2_value;
  *
  *************************************/
 
-static void calendar_clock(void);
 static void set_output_latch(running_machine *machine, UINT8 data);
 static void set_output_data(UINT8 data);
 
@@ -200,9 +311,9 @@ void neogeo_set_display_counter_lsb(const address_space *space, UINT16 data)
 
 static void update_interrupts(running_machine *machine)
 {
-	cpu_set_input_line(machine->cpu[0], 1, vblank_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
-	cpu_set_input_line(machine->cpu[0], 2, display_position_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
-	cpu_set_input_line(machine->cpu[0], 3, irq3_pending ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 1, vblank_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 2, display_position_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 3, irq3_pending ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -250,10 +361,12 @@ static TIMER_CALLBACK( display_position_vblank_callback )
 
 static TIMER_CALLBACK( vblank_interrupt_callback )
 {
+	const device_config *upd4990a = devtag_get_device(machine, "upd4990a");
+
 	if (LOG_VIDEO_SYSTEM) logerror("+++ VBLANK @ %d,%d\n", video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen));
 
 	/* add a timer tick to the pd4990a */
-	calendar_clock();
+	upd4990a_addretrace(upd4990a);
 
 	vblank_interrupt_pending = 1;
 
@@ -286,21 +399,21 @@ static void start_interrupt_timers(running_machine *machine)
  *
  *************************************/
 
-static void audio_cpu_irq(running_machine *machine, int assert)
+static void audio_cpu_irq(const device_config *device, int assert)
 {
-	cpu_set_input_line(machine->cpu[1], 0, assert ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine, "audiocpu", 0, assert ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void audio_cpu_assert_nmi(running_machine *machine)
 {
-	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, ASSERT_LINE);
+	cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 
 static WRITE8_HANDLER( audio_cpu_clear_nmi_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 
@@ -319,11 +432,14 @@ static void select_controller(UINT8 data)
 
 static CUSTOM_INPUT( multiplexed_controller_r )
 {
-	char tag[40];
+	int port = (FPTR)param;
 
-	sprintf(tag, "IN%s-%d", (const char *)param, controller_select & 0x01);
+	static const char *const cntrl[2][2] =
+		{
+			{ "IN0-0", "IN0-1" }, { "IN1-0", "IN1-1" }
+		};
 
-	return input_port_read(field->port->machine, tag);
+	return input_port_read_safe(field->port->machine, cntrl[port][controller_select & 0x01], 0x00);
 }
 
 
@@ -354,12 +470,14 @@ cpu #0 (PC=00C18C40): unmapped memory word write to 00380000 = 0000 & 00FF
 
 static WRITE16_HANDLER( io_control_w )
 {
+	const device_config *upd4990a = devtag_get_device(space->machine, "upd4990a");
+
 	switch (offset)
 	{
 	case 0x00: select_controller(data & 0x00ff); break;
 	case 0x18: set_output_latch(space->machine, data & 0x00ff); break;
 	case 0x20: set_output_data(data & 0x00ff); break;
-	case 0x28: pd4990a_control_16_w(space, 0, data, mem_mask); break;
+	case 0x28: upd4990a_control_16_w(upd4990a, 0, data, mem_mask); break;
 //  case 0x30: break; // coin counters
 //  case 0x31: break; // coin counters
 //  case 0x32: break; // coin lockout
@@ -408,35 +526,10 @@ READ16_HANDLER( neogeo_unmapped_r )
  *
  *************************************/
 
-static void calendar_init(running_machine *machine)
-{
-	/* set the celander IC to 'right now' */
-	mame_system_time systime;
-	mame_system_tm time;
-
-	mame_get_base_datetime(machine, &systime);
-	time = systime.local_time;
-
-	pd4990a.seconds = ((time.second / 10) << 4) + (time.second % 10);
-	pd4990a.minutes = ((time.minute / 10) << 4) + (time.minute % 10);
-	pd4990a.hours = ((time.hour / 10) <<4 ) + (time.hour % 10);
-	pd4990a.days = ((time.mday / 10) << 4) + (time.mday % 10);
-	pd4990a.month = time.month + 1;
-	pd4990a.year = ((((time.year - 1900) % 100) / 10) << 4) + ((time.year - 1900) % 10);
-	pd4990a.weekday = time.weekday;
-}
-
-
-static void calendar_clock(void)
-{
-	pd4990a_addretrace();
-}
-
-
 static CUSTOM_INPUT( get_calendar_status )
 {
-	const address_space *space = cpu_get_address_space(field->port->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
-	return (pd4990a_databit_r(space, 0) << 1) | pd4990a_testbit_r(space, 0);
+	const device_config *upd4990a = devtag_get_device(field->port->machine, "upd4990a");
+	return (upd4990a_databit_r(upd4990a, 0) << 1) | upd4990a_testbit_r(upd4990a, 0);
 }
 
 
@@ -486,13 +579,6 @@ static WRITE16_HANDLER( save_ram_w )
 #define MEMCARD_SIZE	0x0800
 
 
-static void memcard_init(void)
-{
-	memcard_data = auto_malloc(MEMCARD_SIZE);
-	memset(memcard_data, 0, MEMCARD_SIZE);
-}
-
-
 static CUSTOM_INPUT( get_memcard_status )
 {
 	/* D0 and D1 are memcard presence indicators, D2 indicates memcard
@@ -593,7 +679,7 @@ static CUSTOM_INPUT( get_audio_result )
 {
 	UINT32 ret = audio_result;
 
-//  if (LOG_CPU_COMM) logerror("MAIN CPU PC %06x: audio_result_r %02x\n", cpu_get_pc(field->port->machine->cpu[0]), ret);
+//  if (LOG_CPU_COMM) logerror("MAIN CPU PC %06x: audio_result_r %02x\n", cpu_get_pc(cputag_get_cpu(field->port->machine, "maincpu")), ret);
 
 	return ret;
 }
@@ -622,7 +708,7 @@ static void set_main_cpu_vector_table_source(running_machine *machine, UINT8 dat
 
 static void _set_main_cpu_bank_address(running_machine *machine)
 {
-	memory_set_bankptr(machine, NEOGEO_BANK_CARTRIDGE, &memory_region(machine, "main")[main_cpu_bank_address]);
+	memory_set_bankptr(machine, NEOGEO_BANK_CARTRIDGE, &memory_region(machine, "maincpu")[main_cpu_bank_address]);
 }
 
 
@@ -639,7 +725,7 @@ void neogeo_set_main_cpu_bank_address(const address_space *space, UINT32 bank_ad
 static WRITE16_HANDLER( main_cpu_bank_select_w )
 {
 	UINT32 bank_address;
-	UINT32 len = memory_region_length(space->machine, "main");
+	UINT32 len = memory_region_length(space->machine, "maincpu");
 
 	if ((len <= 0x100000) && (data & 0x07))
 		logerror("PC %06x: warning: bankswitch to %02x but no banks available\n", cpu_get_pc(space->cpu), data);
@@ -660,14 +746,14 @@ static WRITE16_HANDLER( main_cpu_bank_select_w )
 
 static void main_cpu_banking_init(running_machine *machine)
 {
-	const address_space *mainspace = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *mainspace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	/* create vector banks */
 	memory_configure_bank(machine, NEOGEO_BANK_VECTORS, 0, 1, memory_region(machine, "mainbios"), 0);
-	memory_configure_bank(machine, NEOGEO_BANK_VECTORS, 1, 1, memory_region(machine, "main"), 0);
+	memory_configure_bank(machine, NEOGEO_BANK_VECTORS, 1, 1, memory_region(machine, "maincpu"), 0);
 
 	/* set initial main CPU bank */
-	if (memory_region_length(machine, "main") > 0x100000)
+	if (memory_region_length(machine, "maincpu") > 0x100000)
 		neogeo_set_main_cpu_bank_address(mainspace, 0x100000);
 	else
 		neogeo_set_main_cpu_bank_address(mainspace, 0x000000);
@@ -744,7 +830,7 @@ static void _set_audio_cpu_rom_source(const address_space *space)
 	{
 		audio_cpu_rom_source_last = audio_cpu_rom_source;
 
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, PULSE_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, PULSE_LINE);
 
 		if (LOG_AUDIO_CPU_BANKING) logerror("Audio CPU PC %03x: selectign %s ROM\n", cpu_get_pc(space->cpu), audio_cpu_rom_source ? "CARTRIDGE" : "BIOS");
 	}
@@ -769,12 +855,12 @@ static void audio_cpu_banking_init(running_machine *machine)
 	/* audio bios/cartridge selection */
  	if (memory_region(machine, "audiobios"))
 		memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 0, 1, memory_region(machine, "audiobios"), 0);
-	memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 1, 1, memory_region(machine, "audio"), 0);
+	memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 1, 1, memory_region(machine, "audiocpu"), 0);
 
 	/* audio banking */
-	address_mask = memory_region_length(machine, "audio") - 0x10000 - 1;
+	address_mask = memory_region_length(machine, "audiocpu") - 0x10000 - 1;
 
-	rgn = memory_region(machine, "audio");
+	rgn = memory_region(machine, "audiocpu");
 	for (region = 0; region < 4; region++)
 	{
 		for (bank = 0; bank < 0x100; bank++)
@@ -794,7 +880,7 @@ static void audio_cpu_banking_init(running_machine *machine)
 	set_audio_cpu_banking(machine);
 
 	audio_cpu_rom_source_last = 0;
-	set_audio_cpu_rom_source(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0);
+	set_audio_cpu_rom_source(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0);
 }
 
 
@@ -946,7 +1032,7 @@ static STATE_POSTLOAD( neogeo_postload )
 	_set_main_cpu_bank_address(machine);
 	_set_main_cpu_vector_table_source(machine);
 	set_audio_cpu_banking(machine);
-	_set_audio_cpu_rom_source(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM));
+	_set_audio_cpu_rom_source(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM));
 	set_outputs();
 }
 
@@ -963,11 +1049,8 @@ static MACHINE_START( neogeo )
 
 	create_interrupt_timers(machine);
 
-	/* initialize the celander IC to 'right now' */
-	calendar_init(machine);
-
 	/* initialize the memcard data structure */
-	memcard_init();
+	memcard_data = auto_alloc_array_clear(machine, UINT8, MEMCARD_SIZE);
 
 	/* start with an IRQ3 - but NOT on a reset */
 	irq3_pending = 1;
@@ -1007,12 +1090,12 @@ static MACHINE_START( neogeo )
 static MACHINE_RESET( neogeo )
 {
 	offs_t offs;
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	/* reset system control registers */
 	for (offs = 0; offs < 8; offs++)
 		system_control_w(space, offs, 0, 0x00ff);
-	device_reset(machine->cpu[0]);
+	device_reset(cputag_get_cpu(machine, "maincpu"));
 
 	neogeo_reset_rng();
 
@@ -1084,10 +1167,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( auido_io_map, ADDRESS_SPACE_IO, 8 )
   /*AM_RANGE(0x00, 0x00) AM_MIRROR(0xff00) AM_READWRITE(audio_command_r, audio_cpu_clear_nmi_w);*/  /* may not and NMI clear */
 	AM_RANGE(0x00, 0x00) AM_MIRROR(0xff00) AM_READ(audio_command_r)
-	AM_RANGE(0x04, 0x04) AM_MIRROR(0xff00) AM_READWRITE(ym2610_status_port_0_a_r, ym2610_control_port_0_a_w)
-	AM_RANGE(0x05, 0x05) AM_MIRROR(0xff00) AM_READWRITE(ym2610_read_port_0_r, ym2610_data_port_0_a_w)
-	AM_RANGE(0x06, 0x06) AM_MIRROR(0xff00) AM_READWRITE(ym2610_status_port_0_b_r, ym2610_control_port_0_b_w)
-	AM_RANGE(0x07, 0x07) AM_MIRROR(0xff00) AM_WRITE(ym2610_data_port_0_b_w)
+	AM_RANGE(0x04, 0x07) AM_MIRROR(0xff00) AM_DEVREADWRITE("ym", ym2610_r, ym2610_w)
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) /* write - NMI enable / acknowledge? (the data written doesn't matter) */
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_f000_f7ff_r)
 	AM_RANGE(0x09, 0x09) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_e000_efff_r)
@@ -1105,7 +1185,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ym2610_interface ym2610_config =
+static const ym2610_interface ym2610_config =
 {
 	audio_cpu_irq
 };
@@ -1119,32 +1199,34 @@ static ym2610_interface ym2610_config =
  *
  *************************************/
 
-#define STANDARD_DIPS 																	\
-	PORT_DIPNAME( 0x0001, 0x0001, "Test Switch" ) PORT_DIPLOCATION("SW:1")				\
-	PORT_DIPSETTING(	  0x0001, DEF_STR( Off ) )										\
-	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )										\
-	PORT_DIPNAME( 0x0002, 0x0002, "Coin Chutes?" ) PORT_DIPLOCATION("SW:2")				\
-	PORT_DIPSETTING(	  0x0000, "1?" )												\
-	PORT_DIPSETTING(	  0x0002, "2?" )												\
-	PORT_DIPNAME( 0x0004, 0x0004, "Autofire (in some games)" ) PORT_DIPLOCATION("SW:3")	\
-	PORT_DIPSETTING(	  0x0004, DEF_STR( Off ) )										\
-	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )										\
-	PORT_DIPNAME( 0x0038, 0x0038, "COMM Setting" ) PORT_DIPLOCATION("SW:4,5,6")			\
-	PORT_DIPSETTING(	  0x0038, DEF_STR( Off ) )										\
-	PORT_DIPSETTING(	  0x0030, "1" )													\
-	PORT_DIPSETTING(	  0x0020, "2" )													\
-	PORT_DIPSETTING(	  0x0010, "3" )													\
-	PORT_DIPSETTING(	  0x0000, "4" )													\
-	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Free_Play ) ) PORT_DIPLOCATION("SW:7")		\
-	PORT_DIPSETTING(	  0x0040, DEF_STR( Off ) )										\
-	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )										\
-	PORT_DIPNAME( 0x0080, 0x0080, "Freeze" ) PORT_DIPLOCATION("SW:8")					\
-	PORT_DIPSETTING(	  0x0080, DEF_STR( Off ) )										\
+#define STANDARD_DIPS																		\
+	PORT_DIPNAME( 0x0001, 0x0001, "Test Switch" ) PORT_DIPLOCATION("SW:1")					\
+	PORT_DIPSETTING(	  0x0001, DEF_STR( Off ) )											\
+	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )											\
+	PORT_DIPNAME( 0x0002, 0x0002, "Coin Chutes?" ) PORT_DIPLOCATION("SW:2")					\
+	PORT_DIPSETTING(	  0x0000, "1?" )													\
+	PORT_DIPSETTING(	  0x0002, "2?" )													\
+	PORT_DIPNAME( 0x0004, 0x0004, "Autofire (in some games)" ) PORT_DIPLOCATION("SW:3")		\
+	PORT_DIPSETTING(	  0x0004, DEF_STR( Off ) )											\
+	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )											\
+	PORT_DIPNAME( 0x0018, 0x0018, "COMM Setting (Cabinet No.)" ) PORT_DIPLOCATION("SW:4,5")	\
+	PORT_DIPSETTING(	  0x0018, "1" )														\
+	PORT_DIPSETTING(	  0x0008, "2" )														\
+	PORT_DIPSETTING(	  0x0010, "3" )														\
+	PORT_DIPSETTING(	  0x0000, "4" )														\
+	PORT_DIPNAME( 0x0020, 0x0020, "COMM Setting (Link Enable)" ) PORT_DIPLOCATION("SW:6")	\
+	PORT_DIPSETTING(	  0x0020, DEF_STR( Off ) )											\
+	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )											\
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Free_Play ) ) PORT_DIPLOCATION("SW:7")			\
+	PORT_DIPSETTING(	  0x0040, DEF_STR( Off ) )											\
+	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )											\
+	PORT_DIPNAME( 0x0080, 0x0080, "Freeze" ) PORT_DIPLOCATION("SW:8")						\
+	PORT_DIPSETTING(	  0x0080, DEF_STR( Off ) )											\
 	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )
 
 
 #define STANDARD_IN0														\
-	PORT_START("IN0")													\
+	PORT_START("IN0")														\
 	STANDARD_DIPS															\
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)		\
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)		\
@@ -1228,12 +1310,12 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( neogeo )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, NEOGEO_MAIN_CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
+	MDRV_CPU_ADD("maincpu", M68000, NEOGEO_MAIN_CPU_CLOCK)
+	MDRV_CPU_PROGRAM_MAP(main_map)
 
-	MDRV_CPU_ADD("audio", Z80, NEOGEO_AUDIO_CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(audio_map,0)
-	MDRV_CPU_IO_MAP(auido_io_map,0)
+	MDRV_CPU_ADD("audiocpu", Z80, NEOGEO_AUDIO_CPU_CLOCK)
+	MDRV_CPU_PROGRAM_MAP(audio_map)
+	MDRV_CPU_IO_MAP(auido_io_map)
 
 	MDRV_WATCHDOG_TIME_INIT(USEC(128762))
 
@@ -1248,19 +1330,22 @@ static MACHINE_DRIVER_START( neogeo )
 	MDRV_VIDEO_UPDATE(neogeo)
 	MDRV_DEFAULT_LAYOUT(layout_neogeo)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(NEOGEO_PIXEL_CLOCK, NEOGEO_HTOTAL, NEOGEO_HBEND, NEOGEO_HBSTART, NEOGEO_VTOTAL, NEOGEO_VBEND, NEOGEO_VBSTART)
 
 	/* audio hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("ym", YM2610, NEOGEO_YM2610_CLOCK)
 	MDRV_SOUND_CONFIG(ym2610_config)
-	MDRV_SOUND_ROUTE(0, "left",  0.60)
-	MDRV_SOUND_ROUTE(0, "right", 0.60)
-	MDRV_SOUND_ROUTE(1, "left",  1.0)
-	MDRV_SOUND_ROUTE(2, "right", 1.0)
+	MDRV_SOUND_ROUTE(0, "lspeaker",  0.60)
+	MDRV_SOUND_ROUTE(0, "rspeaker", 0.60)
+	MDRV_SOUND_ROUTE(1, "lspeaker",  1.0)
+	MDRV_SOUND_ROUTE(2, "rspeaker", 1.0)
+
+	/* NEC uPD4990A RTC */
+	MDRV_UPD4990A_ADD("upd4990a")
 MACHINE_DRIVER_END
 
 /*************************************
