@@ -147,7 +147,6 @@ Stephh's additional notes (based on the game Z80 code and some tests) :
 
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m6805/m6805.h"
 #include "sound/ay8910.h"
@@ -161,7 +160,7 @@ int nyc_gametype=0;
 
 static WRITE8_HANDLER( sub_cpu_halt_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, (data )? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, (data) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static UINT8 snd_data;
@@ -190,26 +189,26 @@ static WRITE8_HANDLER(nycaptor_sharedram_w)
 
 static READ8_HANDLER( nycaptor_b_r )
 {
-		return 1;
+	return 1;
 }
 
 static READ8_HANDLER( nycaptor_by_r )
 {
 	int port=input_port_read(space->machine, "LIGHTY");
 	if(nyc_gametype == 1)
-			port = 255 - port;
-		return port - 8;
+		port = 255 - port;
+	return port - 8;
 }
 
 static READ8_HANDLER( nycaptor_bx_r )
 {
-		return (input_port_read(space->machine, "LIGHTX") + 0x27) | 1;
+	return (input_port_read(space->machine, "LIGHTX") + 0x27) | 1;
 }
 
 
 static WRITE8_HANDLER( sound_cpu_reset_w )
 {
-	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (data&1 )? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, (data&1 )? ASSERT_LINE : CLEAR_LINE);
 }
 
 static int vol_ctrl[16];
@@ -233,7 +232,7 @@ static MACHINE_RESET( ta7630 )
 
 static TIMER_CALLBACK( nmi_callback )
 {
-	if (sound_nmi_enable) cpu_set_input_line(machine->cpu[2],INPUT_LINE_NMI,PULSE_LINE);
+	if (sound_nmi_enable) cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 	else pending_nmi = 1;
 }
 
@@ -253,12 +252,12 @@ static WRITE8_HANDLER( nmi_enable_w )
 	sound_nmi_enable = 1;
 	if (pending_nmi)
 	{
-		cpu_set_input_line(space->machine->cpu[2],INPUT_LINE_NMI,PULSE_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 		pending_nmi = 0;
 	}
 }
 
-static WRITE8_HANDLER(unk_w)
+static WRITE8_DEVICE_HANDLER(unk_w)
 {
 
 }
@@ -267,10 +266,10 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	NULL,
-	NULL,
-	unk_w,
-	unk_w
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_HANDLER(unk_w),
+	DEVCB_HANDLER(unk_w)
 };
 
 static const msm5232_interface msm5232_config =
@@ -287,121 +286,80 @@ static READ8_HANDLER ( nycaptor_generic_control_r )
 static WRITE8_HANDLER( nycaptor_generic_control_w )
 {
 	generic_control_reg = data;
-	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "main") + 0x10000 + ((data&0x08)>>3)*0x4000 );
+	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "maincpu") + 0x10000 + ((data&0x08)>>3)*0x4000 );
 }
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(nycaptor_videoram_r)
-	AM_RANGE(0xd000, 0xd000) AM_READ(nycaptor_mcu_r)
-	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r)
-	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r)
-	AM_RANGE(0xd401, 0xd401) AM_READ(SMH_NOP)
+static ADDRESS_MAP_START( nycaptor_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xc7ff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xd000, 0xd000) AM_READ(nycaptor_mcu_r) AM_WRITE(nycaptor_mcu_w)
+	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
+	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r) AM_WRITE(nycaptor_generic_control_w)	/* bit 3 - memory bank at 0x8000-0xbfff */
+	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r) AM_WRITE(sound_command_w)
+	AM_RANGE(0xd401, 0xd401) AM_READNOP
+	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
 	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("IN0")
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
 	AM_RANGE(0xd805, 0xd805) AM_READ(nycaptor_mcu_status_r1)
-	AM_RANGE(0xd806, 0xd806) AM_READ(SMH_NOP) /* unknown ?sound? */
+	AM_RANGE(0xd806, 0xd806) AM_READNOP /* unknown ?sound? */
 	AM_RANGE(0xd807, 0xd807) AM_READ(nycaptor_mcu_status_r2)
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
-	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+	AM_RANGE(0xdce1, 0xdce1) AM_WRITENOP
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
+	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r) AM_WRITE(nycaptor_gfxctrl_w)
+	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)  AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(nycaptor_mcu_w)
-	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
-	AM_RANGE(0xd002, 0xd002) AM_WRITE(nycaptor_generic_control_w)	/* bit 3 - memory bank at 0x8000-0xbfff */
-	AM_RANGE(0xd400, 0xd400) AM_WRITE(sound_command_w)
-	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdce1, 0xdce1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(nycaptor_gfxctrl_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( readmem_sub, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( nycaptor_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0xc000, 0xc7ff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
 	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("IN0")
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
 	AM_RANGE(0xdf00, 0xdf00) AM_READ(nycaptor_bx_r)
 	AM_RANGE(0xdf01, 0xdf01) AM_READ(nycaptor_by_r)
 	AM_RANGE(0xdf02, 0xdf02) AM_READ(nycaptor_b_r)
-	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
+	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r) AM_WRITENOP/* ? gfx control ? */
+	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r) AM_WRITE(nycaptor_sharedram_w)
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( writemem_sub, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(SMH_NOP)/* ? gfx control ? */
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xd000, 0xd000) AM_READ(soundlatch_r)
-	AM_RANGE(0xd200, 0xd200) AM_READ(SMH_NOP)
-	AM_RANGE(0xe000, 0xefff) AM_READ(SMH_NOP)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xc800, 0xc800) AM_WRITE(ay8910_control_port_0_w)
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0xc802, 0xc802) AM_WRITE(ay8910_control_port_1_w)
-	AM_RANGE(0xc803, 0xc803) AM_WRITE(ay8910_write_port_1_w)
-	AM_RANGE(0xc900, 0xc90d) AM_WRITE(msm5232_0_w)
-	AM_RANGE(0xca00, 0xca00) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xcb00, 0xcb00) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xcc00, 0xcc00) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(to_main_w)
-	AM_RANGE(0xd200, 0xd200) AM_WRITE(nmi_enable_w)
+static ADDRESS_MAP_START( nycaptor_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
+	AM_RANGE(0xc800, 0xc801) AM_DEVWRITE("ay1", ay8910_address_data_w)
+	AM_RANGE(0xc802, 0xc803) AM_DEVWRITE("ay2", ay8910_address_data_w)
+	AM_RANGE(0xc900, 0xc90d) AM_DEVWRITE("msm", msm5232_w)
+	AM_RANGE(0xca00, 0xca00) AM_WRITENOP
+	AM_RANGE(0xcb00, 0xcb00) AM_WRITENOP
+	AM_RANGE(0xcc00, 0xcc00) AM_WRITENOP
+	AM_RANGE(0xd000, 0xd000) AM_READ(soundlatch_r) AM_WRITE(to_main_w)
+	AM_RANGE(0xd200, 0xd200) AM_READNOP AM_WRITE(nmi_enable_w)
 	AM_RANGE(0xd400, 0xd400) AM_WRITE(nmi_disable_w)
-	AM_RANGE(0xd600, 0xd600) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xd600, 0xd600) AM_WRITENOP
+	AM_RANGE(0xe000, 0xefff) AM_NOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( m68705_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( nycaptor_m68705_map, ADDRESS_SPACE_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x7ff)
-	AM_RANGE(0x0000, 0x0000) AM_READ(nycaptor_68705_portA_r)
-	AM_RANGE(0x0001, 0x0001) AM_READ(nycaptor_68705_portB_r)
-	AM_RANGE(0x0002, 0x0002) AM_READ(nycaptor_68705_portC_r)
-	AM_RANGE(0x0010, 0x007f) AM_READ(SMH_RAM)
-	AM_RANGE(0x0080, 0x07ff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( m68705_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_GLOBAL_MASK(0x7ff)
-	AM_RANGE(0x0000, 0x0000) AM_WRITE(nycaptor_68705_portA_w)
-	AM_RANGE(0x0001, 0x0001) AM_WRITE(nycaptor_68705_portB_w)
-	AM_RANGE(0x0002, 0x0002) AM_WRITE(nycaptor_68705_portC_w)
+	AM_RANGE(0x0000, 0x0000) AM_READWRITE(nycaptor_68705_portA_r,nycaptor_68705_portA_w)
+	AM_RANGE(0x0001, 0x0001) AM_READWRITE(nycaptor_68705_portB_r,nycaptor_68705_portB_w)
+	AM_RANGE(0x0002, 0x0002) AM_READWRITE(nycaptor_68705_portC_r,nycaptor_68705_portC_w)
 	AM_RANGE(0x0004, 0x0004) AM_WRITE(nycaptor_68705_ddrA_w)
 	AM_RANGE(0x0005, 0x0005) AM_WRITE(nycaptor_68705_ddrB_w)
 	AM_RANGE(0x0006, 0x0006) AM_WRITE(nycaptor_68705_ddrC_w)
-	AM_RANGE(0x0010, 0x007f) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x0080, 0x07ff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x0010, 0x007f) AM_RAM
+	AM_RANGE(0x0080, 0x07ff) AM_ROM
 ADDRESS_MAP_END
 
 
@@ -432,73 +390,52 @@ static WRITE8_HANDLER( cyclshtg_generic_control_w )
 {
 	int bank=(data>>2)&3;
 	generic_control_reg = data;
-	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "main") + 0x10000 + bank*0x4000 );
+	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "maincpu") + 0x10000 + bank*0x4000 );
 }
 
 
-static ADDRESS_MAP_START( cyclshtg_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r)
-	AM_RANGE(0xd000, 0xd000) AM_READ(cyclshtg_mcu_r)
-	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r)
-	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r)
+static ADDRESS_MAP_START( cyclshtg_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xd000, 0xd000) AM_READ(cyclshtg_mcu_r) AM_WRITE(cyclshtg_mcu_w)
+	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
+	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r) AM_WRITE(cyclshtg_generic_control_w)
+	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r) AM_WRITE(sound_command_w)
+	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
 	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("IN0")
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
 	AM_RANGE(0xd805, 0xd805) AM_READ(cyclshtg_mcu_status_r)
-	AM_RANGE(0xd806, 0xd806) AM_READ(SMH_NOP)
+	AM_RANGE(0xd806, 0xd806) AM_READNOP
 	AM_RANGE(0xd807, 0xd807) AM_READ(cyclshtg_mcu_status_r)
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
-	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+	AM_RANGE(0xdce1, 0xdce1) AM_WRITENOP
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
+	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r) AM_WRITE(nycaptor_gfxctrl_w)
+	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r) AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cyclshtg_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(cyclshtg_mcu_w)
-	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
-	AM_RANGE(0xd002, 0xd002) AM_WRITE(cyclshtg_generic_control_w)
-	AM_RANGE(0xd400, 0xd400) AM_WRITE(sound_command_w)
-	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdce1, 0xdce1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(nycaptor_gfxctrl_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( cyclshtg_readmem_sub, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( cyclshtg_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
 	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("IN0")
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
 	AM_RANGE(0xdf00, 0xdf00) AM_READ(nycaptor_bx_r)
 	AM_RANGE(0xdf01, 0xdf01) AM_READ(nycaptor_by_r)
 	AM_RANGE(0xdf02, 0xdf02) AM_READ(nycaptor_b_r)
 	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( cyclshtg_writemem_sub, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w)
+	AM_RANGE(0xdf03, 0xdf03) AM_WRITENOP
+	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r) AM_WRITE(nycaptor_sharedram_w)
 ADDRESS_MAP_END
 
 static READ8_HANDLER(unk_r)
@@ -506,50 +443,34 @@ static READ8_HANDLER(unk_r)
   return mame_rand(space->machine);
 }
 
-static ADDRESS_MAP_START( bronx_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r)
-	AM_RANGE(0xd000, 0xd000) AM_READ(cyclshtg_mcu_r)
-	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r)
-	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r)
+static ADDRESS_MAP_START( bronx_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
+	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xd000, 0xd000) AM_READ(cyclshtg_mcu_r) AM_WRITENOP
+	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
+	AM_RANGE(0xd002, 0xd002) AM_READ(nycaptor_generic_control_r) AM_WRITE(cyclshtg_generic_control_w)
+	AM_RANGE(0xd400, 0xd400) AM_READ(from_snd_r) AM_WRITE(sound_command_w)
 	AM_RANGE(0xd401, 0xd401) AM_READ(unk_r)
+	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
 	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("IN0")
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
 	AM_RANGE(0xd805, 0xd805) AM_READ(cyclshtg_mcu_status_r)
-	AM_RANGE(0xd806, 0xd806) AM_READ(SMH_NOP)
+	AM_RANGE(0xd806, 0xd806) AM_READNOP
 	AM_RANGE(0xd807, 0xd807) AM_READ(cyclshtg_mcu_status_r)
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
-	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_READ(nycaptor_scrlram_r) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
+	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r) AM_WRITE(nycaptor_gfxctrl_w)
+	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r) AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( bronx_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xd000, 0xd000) AM_WRITENOP
-	AM_RANGE(0xd001, 0xd001) AM_WRITE(sub_cpu_halt_w)
-	AM_RANGE(0xd002, 0xd002) AM_WRITE(cyclshtg_generic_control_w)
-	AM_RANGE(0xd400, 0xd400) AM_WRITE(sound_command_w)
-	AM_RANGE(0xd403, 0xd403) AM_WRITE(sound_cpu_reset_w)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(nycaptor_gfxctrl_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w) AM_BASE(&nycaptor_sharedram)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( bronx_io, ADDRESS_SPACE_IO, 8 )
- 	AM_RANGE(0x0000, 0x7fff) AM_ROM AM_REGION("user1", 0)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( bronx_readmem_sub, ADDRESS_SPACE_PROGRAM, 8 )
- 	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( bronx_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+ 	AM_RANGE(0x0000, 0x7fff) AM_ROM
+ 	AM_RANGE(0xc000, 0xcfff) AM_READ(nycaptor_videoram_r) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
 	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
 	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
@@ -557,28 +478,23 @@ static ADDRESS_MAP_START( bronx_readmem_sub, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("IN1")
 	AM_RANGE(0xd805, 0xd805) AM_READ(cyclshtg_mcu_status_r1)
 	AM_RANGE(0xd807, 0xd807) AM_READ(cyclshtg_mcu_status_r)
-	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r)
-	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r)
+	AM_RANGE(0xdc00, 0xdc9f) AM_READ(nycaptor_spriteram_r) AM_WRITE(nycaptor_spriteram_w)
+	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
+	AM_RANGE(0xdd00, 0xdeff) AM_READ(nycaptor_palette_r) AM_WRITE(nycaptor_palette_w)
 	AM_RANGE(0xdf00, 0xdf00) AM_READ(nycaptor_bx_r)
 	AM_RANGE(0xdf01, 0xdf01) AM_READ(nycaptor_by_r)
 	AM_RANGE(0xdf02, 0xdf02) AM_READ(nycaptor_b_r)
-	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r)
- 	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r)
+	AM_RANGE(0xdf03, 0xdf03) AM_READ(nycaptor_gfxctrl_r) AM_WRITE(nycaptor_gfxctrl_w)
+ 	AM_RANGE(0xe000, 0xffff) AM_READ(nycaptor_sharedram_r) AM_WRITE(nycaptor_sharedram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( bronx_writemem_sub, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(nycaptor_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xdc00, 0xdc9f) AM_WRITE(nycaptor_spriteram_w)
-	AM_RANGE(0xdca0, 0xdcbf) AM_WRITE(nycaptor_scrlram_w) AM_BASE(&nycaptor_scrlram)
-	AM_RANGE(0xdd00, 0xdeff) AM_WRITE(nycaptor_palette_w)
-	AM_RANGE(0xdf03, 0xdf03) AM_WRITE(nycaptor_gfxctrl_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(nycaptor_sharedram_w)
+static ADDRESS_MAP_START( bronx_slave_io_map, ADDRESS_SPACE_IO, 8 )
+ 	AM_RANGE(0x0000, 0x7fff) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
+
 /* Cycle Shooting */
 
-
 static INPUT_PORTS_START( cyclshtg )
 	PORT_START("DSW0")
 	PORT_DIPNAME( 0x04, 0x04, "Test Mode" )
@@ -769,28 +685,27 @@ GFXDECODE_END
 
 static MACHINE_DRIVER_START( nycaptor )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80,8000000/2)		/* ??? */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,8000000/2)		/* ??? */
+	MDRV_CPU_PROGRAM_MAP(nycaptor_master_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_CPU_ADD("sub", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(readmem_sub,writemem_sub)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)	/* IRQ generated by ??? */
+	MDRV_CPU_PROGRAM_MAP(nycaptor_slave_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)	/* IRQ generated by ??? */
 
-	MDRV_CPU_ADD("audio", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
+	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(nycaptor_sound_map)
+	MDRV_CPU_PERIODIC_INT(irq0_line_hold,2*60)	/* IRQ generated by ??? */
 
 	MDRV_CPU_ADD("mcu", M68705,2000000)
-	MDRV_CPU_PROGRAM_MAP(m68705_readmem,m68705_writemem)
+	MDRV_CPU_PROGRAM_MAP(nycaptor_m68705_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
+	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper synchronization of the CPUs */
 
-	/* synchronization of the CPUs */
 	MDRV_MACHINE_RESET(ta7630)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -830,28 +745,27 @@ static MACHINE_DRIVER_START( nycaptor )
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( cyclshtg )
-	MDRV_CPU_ADD("main", Z80,8000000/2)
-
-	MDRV_CPU_PROGRAM_MAP(cyclshtg_readmem,cyclshtg_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(cyclshtg_master_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_CPU_ADD("sub", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(cyclshtg_readmem_sub,cyclshtg_writemem_sub)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_PROGRAM_MAP(cyclshtg_slave_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
+	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(nycaptor_sound_map)
+	MDRV_CPU_PERIODIC_INT(irq0_line_hold,2*60)
 
 #ifdef USE_MCU
 	MDRV_CPU_ADD("mcu", M68705,2000000)
-	MDRV_CPU_PROGRAM_MAP(m68705_readmem,m68705_writemem)
+	MDRV_CPU_PROGRAM_MAP(nycaptor_m68705_map)
 #endif
 
 	MDRV_QUANTUM_TIME(HZ(60))
 	MDRV_MACHINE_RESET(ta7630)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -891,25 +805,23 @@ MACHINE_DRIVER_END
 
 
 static MACHINE_DRIVER_START( bronx )
-	MDRV_CPU_ADD("main", Z80,8000000/2)
-
-	MDRV_CPU_PROGRAM_MAP(bronx_readmem, bronx_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(bronx_master_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	MDRV_CPU_ADD("sub", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(bronx_readmem_sub, bronx_writemem_sub)
-	MDRV_CPU_IO_MAP(bronx_io, 0)
+	MDRV_CPU_PROGRAM_MAP(bronx_slave_map)
+	MDRV_CPU_IO_MAP(bronx_slave_io_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
-
-	MDRV_CPU_ADD("audio", Z80,8000000/2)
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
+	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)
+	MDRV_CPU_PROGRAM_MAP(nycaptor_sound_map)
+	MDRV_CPU_PERIODIC_INT(irq0_line_hold,2*60)
 
 	MDRV_QUANTUM_TIME(HZ(120))
 	MDRV_MACHINE_RESET(ta7630)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -954,7 +866,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( nycaptor )
-	ROM_REGION( 0x18000, "main", 0 )
+	ROM_REGION( 0x18000, "maincpu", 0 )
 	ROM_LOAD( "a50_04",   0x00000, 0x4000, CRC(33d971a3) SHA1(8bf6cb8d799739dc6f115d352453af278d58de9a) )
 	ROM_LOAD( "a50_03",   0x04000, 0x4000, CRC(8557fa44) SHA1(5639ec2ac21ae94c416c01bd7c0dae722cc14598) )
 	ROM_LOAD( "a50_02",   0x10000, 0x4000, CRC(9697b898) SHA1(28b92963264b867ca4452dad7dcbbb8c8247d2f5) )
@@ -964,7 +876,7 @@ ROM_START( nycaptor )
 	ROM_LOAD( "a50_05-2", 0x0000, 0x4000, CRC(7796655a) SHA1(74cf84bf6f4dfee57ef6236280c0d64c1a156ffe) )
 	ROM_LOAD( "a50_06",   0x4000, 0x4000, CRC(450d6783) SHA1(e652bf83fb6bdd8152dbafb05bb695259c2619cc) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a50_15",   0x0000, 0x4000, CRC(f8a604e5) SHA1(8fae920fd09584b5e5ccd0db8b8934b393a23d50) )
 	ROM_LOAD( "a50_16",   0x4000, 0x4000, CRC(fc24e11d) SHA1(ce1a1d7b809fa0f5f5e7a462047374b1b3f621c6) )
 
@@ -983,7 +895,7 @@ ROM_START( nycaptor )
 ROM_END
 
 ROM_START( cyclshtg )
-	ROM_REGION( 0x18000, "main", 0 )
+	ROM_REGION( 0x18000, "maincpu", 0 )
 	ROM_LOAD( "a97_01.i17",   0x00000, 0x4000, CRC(686fac1a) SHA1(46d17cb98f064413bb76c5d869f8061d2771cda0) )
 	ROM_LOAD( "a97_02.i16",   0x04000, 0x4000, CRC(48a812f9) SHA1(8ab18cb8d6a8b7ce1ed1a4009f5435ce4b0937b4) )
 	ROM_LOAD( "a97_03.u15",   0x10000, 0x4000, CRC(67ad3067) SHA1(2e355653e91c093abe7db0a3d55d5a3f95c4a2e3) )
@@ -994,7 +906,7 @@ ROM_START( cyclshtg )
 	ROM_LOAD( "a80_06.u23",   0x4000, 0x4000, CRC(2769c5ab) SHA1(b8f5a4a8c70c8d37d5e92b37faa0e25b287b3fb2) )
 	ROM_LOAD( "a97_06.i24",   0x8000, 0x4000, CRC(c0473a54) SHA1(06fa7345a44a72995146e973c2cd7a14499f4310) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a80_16.i26",   0x0000, 0x4000, CRC(ce171a48) SHA1(e5ae9bb22f58c8857737bc6f5317866819a4e4d1) )
 	ROM_LOAD( "a80_17.i25",   0x4000, 0x4000, CRC(a90b7bbc) SHA1(bd5c96861a59a1f84bb5032775b1c70efdb7066f) )
 
@@ -1115,7 +1027,7 @@ Notes:
 */
 
 ROM_START( bronx )
-	ROM_REGION( 0x20000, "main", 0 )
+	ROM_REGION( 0x20000, "maincpu", 0 )
 	ROM_LOAD( "1.bin",   0x00000, 0x4000, CRC(399b5063) SHA1(286e0d1a0c1a41060e87f2dadf199f38c787d40f) )
 	ROM_LOAD( "2.bin",   0x04000, 0x4000, CRC(3b5f9756) SHA1(7df0e4808799ca6a7809bd9ac3a1689a18ae1cdb) )
 	ROM_LOAD( "3.bin",   0x10000, 0x8000, CRC(d2ffd3ce) SHA1(06d237a4aa46e37192bd94e2db361c62c35d469c) )
@@ -1128,7 +1040,7 @@ ROM_START( bronx )
 	ROM_REGION( 0x08000, "user1", 0 )
 	ROM_LOAD( "7.bin",   0x00000, 0x8000, CRC(463f9f62) SHA1(8e1fa8f78d230d32502422078599e9e9af889a92) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a80_16.i26",   0x0000, 0x4000, CRC(ce171a48) SHA1(e5ae9bb22f58c8857737bc6f5317866819a4e4d1) )
 	ROM_LOAD( "a80_17.i25",   0x4000, 0x4000, CRC(a90b7bbc) SHA1(bd5c96861a59a1f84bb5032775b1c70efdb7066f) )
 
@@ -1248,13 +1160,13 @@ Notes:
 
 */
 ROM_START( colt )
-	ROM_REGION( 0x20000, "main", 0 )
+	ROM_REGION( 0x20000, "maincpu", 0 )
 	ROM_LOAD( "04.bin",   0x00000, 0x4000, CRC(dc61fdb2) SHA1(94fdd95082936b2445008aee60381ebe35385b4a) )
 	ROM_LOAD( "03.bin",   0x04000, 0x4000, CRC(5835b8b1) SHA1(25a48660f8fb166f996133fb9113d1566dbae281) )
 	ROM_LOAD( "02.bin",   0x10000, 0x4000, CRC(89c99a28) SHA1(1a4fdb5c13569699dfbf2bde0aeeb5e7fcc22ef9) )
 	ROM_LOAD( "01.bin",   0x18000, 0x4000, CRC(9b0948f3) SHA1(a55e09243640ec56aa22e4b6d47165b02b880eb7) )
-	ROM_COPY( "main",   0x10000, 0x014000, 0x04000 )
-	ROM_COPY( "main",   0x18000, 0x01c000, 0x04000 )
+	ROM_COPY( "maincpu",   0x10000, 0x014000, 0x04000 )
+	ROM_COPY( "maincpu",   0x18000, 0x01c000, 0x04000 )
 
 	ROM_REGION( 0x10000, "sub", 0 )
 	ROM_LOAD( "05.bin",   0x0000, 0x4000, CRC(2b6e017a) SHA1(60715e1c6fbcdd2c0e114035c342ba587dfc1b4b) )
@@ -1262,7 +1174,7 @@ ROM_START( colt )
 
 	ROM_REGION( 0x08000, "user1", ROMREGION_ERASE00 ) //empty
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a50_15",   0x0000, 0x4000, CRC(f8a604e5) SHA1(8fae920fd09584b5e5ccd0db8b8934b393a23d50) )
 	ROM_LOAD( "a50_16",   0x4000, 0x4000, CRC(fc24e11d) SHA1(ce1a1d7b809fa0f5f5e7a462047374b1b3f621c6) )
 
@@ -1280,7 +1192,7 @@ ROM_END
 static DRIVER_INIT(bronx)
 {
 	int i;
-	UINT8 *rom = memory_region(machine, "main");
+	UINT8 *rom = memory_region(machine, "maincpu");
 	for(i=0;i<0x20000;i++)
 		rom[i]=BITSWAP8(rom[i],0,1,2,3,4,5,6,7);
 	nyc_gametype=1;
@@ -1289,7 +1201,7 @@ static DRIVER_INIT(bronx)
 static DRIVER_INIT(colt)
 {
 	int i;
-	UINT8 *rom = memory_region(machine, "main");
+	UINT8 *rom = memory_region(machine, "maincpu");
 	for(i=0;i<0x20000;i++)
 		rom[i]=BITSWAP8(rom[i],0,1,2,3,4,5,6,7);
 	nyc_gametype=2;
