@@ -28,7 +28,6 @@ VIDEO_UPDATE( ohmygod );
 
 static int adpcm_bank_shift;
 static int sndbank;
-static int nosound_kludge_step;
 
 static MACHINE_RESET( ohmygod )
 {
@@ -36,8 +35,6 @@ static MACHINE_RESET( ohmygod )
 
 	sndbank = 0;
 	memcpy(rom + 0x20000,rom + 0x40000 + 0x20000 * sndbank,0x20000);
-
-	nosound_kludge_step = 0;
 }
 
 static WRITE16_HANDLER( ohmygod_ctrl_w )
@@ -60,41 +57,28 @@ static WRITE16_HANDLER( ohmygod_ctrl_w )
 	}
 }
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x300000, 0x303fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x304000, 0x307fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x308000, 0x30ffff) AM_READ(SMH_RAM)
-	AM_RANGE(0x600000, 0x6007ff) AM_READ(SMH_RAM)
-	AM_RANGE(0x700000, 0x703fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x704000, 0x707fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x708000, 0x70ffff) AM_READ(SMH_RAM)
-	AM_RANGE(0x800000, 0x800001) AM_READ_PORT("P1")
-	AM_RANGE(0x800002, 0x800003) AM_READ_PORT("P2")
-	AM_RANGE(0xa00000, 0xa00001) AM_READ_PORT("DSW1")
-	AM_RANGE(0xa00002, 0xa00003) AM_READ_PORT("DSW2")
-	AM_RANGE(0xb00000, 0xb00001) AM_READ(okim6295_status_0_lsb_r)
-	AM_RANGE(0xc00000, 0xc00001) AM_READ(watchdog_reset16_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x300000, 0x303fff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x304000, 0x307fff) AM_WRITE(ohmygod_videoram_w) AM_BASE(&ohmygod_videoram)
-	AM_RANGE(0x308000, 0x30ffff) AM_WRITE(SMH_RAM)
+static ADDRESS_MAP_START( ohmygod_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_ROM
+	AM_RANGE(0x300000, 0x303fff) AM_RAM
+	AM_RANGE(0x304000, 0x307fff) AM_RAM_WRITE(ohmygod_videoram_w) AM_BASE(&ohmygod_videoram)
+	AM_RANGE(0x308000, 0x30ffff) AM_RAM
 	AM_RANGE(0x400000, 0x400001) AM_WRITE(ohmygod_scrollx_w)
 	AM_RANGE(0x400002, 0x400003) AM_WRITE(ohmygod_scrolly_w)
-	AM_RANGE(0x600000, 0x6007ff) AM_WRITE(paletteram16_xGGGGGRRRRRBBBBB_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x700000, 0x703fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x704000, 0x707fff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x708000, 0x70ffff) AM_WRITE(SMH_RAM)	/* work RAM */
+	AM_RANGE(0x600000, 0x6007ff) AM_RAM_WRITE(paletteram16_xGGGGGRRRRRBBBBB_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x700000, 0x703fff) AM_RAM AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x704000, 0x707fff) AM_RAM
+	AM_RANGE(0x708000, 0x70ffff) AM_RAM 	/* Work RAM */
+	AM_RANGE(0x800000, 0x800001) AM_READ_PORT("P1")
+	AM_RANGE(0x800002, 0x800003) AM_READ_PORT("P2")
 	AM_RANGE(0x900000, 0x900001) AM_WRITE(ohmygod_ctrl_w)
-	AM_RANGE(0xb00000, 0xb00001) AM_WRITE(okim6295_data_0_lsb_w)
+	AM_RANGE(0xa00000, 0xa00001) AM_READ_PORT("DSW1")
+	AM_RANGE(0xa00002, 0xa00003) AM_READ_PORT("DSW2")
+	AM_RANGE(0xb00000, 0xb00001) AM_DEVREADWRITE8("oki", okim6295_r,okim6295_w, 0x00ff)
+	AM_RANGE(0xc00000, 0xc00001) AM_READ(watchdog_reset16_r)
 	AM_RANGE(0xd00000, 0xd00001) AM_WRITE(ohmygod_spritebank_w)
 ADDRESS_MAP_END
 
 
-
 static INPUT_PORTS_START( ohmygod )
 	PORT_START("P1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
@@ -331,15 +315,15 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( ohmygod )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 12000000)
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 12000000)
+	MDRV_CPU_PROGRAM_MAP(ohmygod_map)
+	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
 
 	MDRV_MACHINE_RESET(ohmygod)
 	MDRV_WATCHDOG_TIME_INIT(SEC(3))	/* a guess, and certainly wrong */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -368,7 +352,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( ohmygod )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD16_WORD_SWAP( "omg-p.114", 0x00000, 0x80000, CRC(48fa40ca) SHA1(b1d91e1a4a888526febbe53a12b73e375f604f2b) )
 
 	ROM_REGION( 0x80000, "gfx1", ROMREGION_DISPOSE )
@@ -384,7 +368,7 @@ ROM_START( ohmygod )
 ROM_END
 
 ROM_START( naname )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD16_WORD_SWAP( "036-prg.114", 0x00000, 0x80000, CRC(3b7362f7) SHA1(ba16ec9df8569bacd387561ef2b3ea5b17cb650c) )
 
 	ROM_REGION( 0x80000, "gfx1", ROMREGION_DISPOSE )
