@@ -44,7 +44,7 @@ paradise: I'm not sure it's working correctly:
 static WRITE8_HANDLER( paradise_rombank_w )
 {
 	int bank = data;
-	int bank_n = memory_region_length(space->machine, "main")/0x4000 - 1;
+	int bank_n = memory_region_length(space->machine, "maincpu")/0x4000 - 1;
 	if (bank >= bank_n)
 	{
 		logerror("PC %04X - invalid rom bank %x\n",cpu_get_pc(space->cpu),bank);
@@ -52,15 +52,14 @@ static WRITE8_HANDLER( paradise_rombank_w )
 	}
 
 	if (bank >= 3)	bank+=1;
-	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "main") + bank * 0x4000);
+	memory_set_bankptr(space->machine, 1, memory_region(space->machine, "maincpu") + bank * 0x4000);
 }
 
-static WRITE8_HANDLER( paradise_okibank_w )
+static WRITE8_DEVICE_HANDLER( paradise_okibank_w )
 {
-	if (data & ~0x02)	logerror("CPU #0 - PC %04X: unknown oki bank bits %02X\n",cpu_get_pc(space->cpu),data);
+	if (data & ~0x02)	logerror("%s: unknown oki bank bits %02X\n",cpuexec_describe_context(device->machine),data);
 
-	if (sndti_exists(SOUND_OKIM6295, 1))
-		okim6295_set_bank_base(1, (data & 0x02) ? 0x40000 : 0);
+	okim6295_set_bank_base(device, (data & 0x02) ? 0x40000 : 0);
 }
 
 static WRITE8_HANDLER( torus_coin_counter_w )
@@ -102,14 +101,29 @@ static ADDRESS_MAP_START( paradise_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x2001, 0x2001) AM_WRITE(paradise_flipscreen_w	)	// Flip Screen
 	AM_RANGE(0x2004, 0x2004) AM_WRITE(paradise_palbank_w	)	// Layers palette bank
 	AM_RANGE(0x2006, 0x2006) AM_WRITE(paradise_rombank_w	)	// ROM bank
-	AM_RANGE(0x2007, 0x2007) AM_WRITE(paradise_okibank_w	)	// OKI 1 samples bank
-	AM_RANGE(0x2010, 0x2010) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)	// OKI 0
+	AM_RANGE(0x2007, 0x2007) AM_DEVWRITE("oki2", paradise_okibank_w	)	// OKI 1 samples bank
+	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)	// OKI 0
+	AM_RANGE(0x2020, 0x2020) AM_READ_PORT("DSW1"			)
+	AM_RANGE(0x2021, 0x2021) AM_READ_PORT("DSW2"			)
+	AM_RANGE(0x2022, 0x2022) AM_READ_PORT("P1"				)
+	AM_RANGE(0x2023, 0x2023) AM_READ_PORT("P2"				)
+	AM_RANGE(0x2024, 0x2024) AM_READ_PORT("SYSTEM"			)
+	AM_RANGE(0x2030, 0x2030) AM_DEVREADWRITE("oki2", okim6295_r, okim6295_w)	// OKI 1
+	AM_RANGE(0x8000, 0xffff) AM_RAM_WRITE(paradise_pixmap_w	) AM_BASE(&videoram) 	// Pixmap
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( torus_io_map, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x0000, 0x17ff) AM_RAM_WRITE(paradise_palette_w) AM_BASE(&paletteram)	// Palette
+	AM_RANGE(0x1800, 0x1800) AM_WRITE(paradise_priority_w	)	// Layers priority
+	AM_RANGE(0x2001, 0x2001) AM_WRITE(paradise_flipscreen_w	)	// Flip Screen
+	AM_RANGE(0x2004, 0x2004) AM_WRITE(paradise_palbank_w	)	// Layers palette bank
+	AM_RANGE(0x2006, 0x2006) AM_WRITE(paradise_rombank_w	)	// ROM bank
+	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)	// OKI 0
 	AM_RANGE(0x2020, 0x2020) AM_READ_PORT("DSW1"			)
 	AM_RANGE(0x2021, 0x2021) AM_READ_PORT("DSW2"			)
 	AM_RANGE(0x2022, 0x2022) AM_READ_PORT("P1"				)
 	AM_RANGE(0x2023, 0x2023) AM_READ_PORT("P2"				)
 	AM_RANGE(0x2024, 0x2024) AM_READ_PORT("SYSTEM"			)
-	AM_RANGE(0x2030, 0x2030) AM_READWRITE(okim6295_status_1_r, okim6295_data_1_w)	// OKI 1
 	AM_RANGE(0x8000, 0xffff) AM_RAM_WRITE(paradise_pixmap_w	) AM_BASE(&videoram) 	// Pixmap
 ADDRESS_MAP_END
 
@@ -529,13 +543,13 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( paradise )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, XTAL_12MHz/2)			/* Z8400B - 6mhz Verified */
-	MDRV_CPU_PROGRAM_MAP(paradise_map,0)
-	MDRV_CPU_IO_MAP(paradise_io_map,0)
+	MDRV_CPU_ADD("maincpu", Z80, XTAL_12MHz/2)			/* Z8400B - 6mhz Verified */
+	MDRV_CPU_PROGRAM_MAP(paradise_map)
+	MDRV_CPU_IO_MAP(paradise_io_map)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)	/* No nmi routine */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(54) /* 54 verified */
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */	/* we're using IPT_VBLANK */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -563,34 +577,36 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( tgtball )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(tgtball_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(tgtball_map)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( torus )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(torus_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(torus_map)
+	MDRV_CPU_IO_MAP(torus_io_map)
 
 	MDRV_GFXDECODE(torus)
 
 	MDRV_VIDEO_UPDATE(torus)
 
-	MDRV_SOUND_REMOVE("oki2")
+	MDRV_DEVICE_REMOVE("oki2")
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( madball )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(torus_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(torus_map)
+	MDRV_CPU_IO_MAP(torus_io_map)
 
 	MDRV_GFXDECODE(madball)
 
 	MDRV_VIDEO_UPDATE(madball)
 
-	MDRV_SOUND_REMOVE("oki2")
+	MDRV_DEVICE_REMOVE("oki2")
 MACHINE_DRIVER_END
 
 
@@ -646,7 +662,7 @@ The year is not shown but must be >= 1994, since the development system
 ***************************************************************************/
 
 ROM_START( paradise )
-	ROM_REGION( 0x44000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x44000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "u128", 0x00000, 0x0c000, CRC(8e5b5a24) SHA1(a4e559d9329f8a7a9d12cd90d98d0525958085d8) )
 	ROM_CONTINUE(     0x10000, 0x34000    )
 
@@ -673,7 +689,7 @@ ROM_START( paradise )
 ROM_END
 
 ROM_START( paradlx )
-	ROM_REGION( 0x44000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x44000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "8.u128", 0x00000, 0x0c000, CRC(3a45ac9e) SHA1(24e1b508ef582c8429e09929fea387f3a137f0e3) )
 	ROM_CONTINUE(     0x10000, 0x34000    )
 
@@ -702,7 +718,7 @@ ROM_END
 
 
 ROM_START( para2dx )
-	ROM_REGION( 0x44000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x44000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "pdx2_u128.bin", 0x00000, 0x0c000, CRC(4cbd22e1) SHA1(ad69663109d3127f6472797ec8763097da94b7d4) )
 	ROM_CONTINUE(     0x10000, 0x34000    )
 
@@ -773,7 +789,7 @@ Notes:
 ***************************************************************************/
 
 ROM_START( tgtball )
-	ROM_REGION( 0x44000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x44000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "rom7.u128", 0x00000, 0x0c000, CRC(8dbeab12) SHA1(7181c23459990aecbe2d13377aaf19f65108eac6) )
 	ROM_CONTINUE(          0x10000, 0x34000 )
 
@@ -800,7 +816,7 @@ ROM_START( tgtball )
 ROM_END
 
 ROM_START( tgtballa )
-	ROM_REGION( 0x44000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x44000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "yunsung.u128", 0x00000, 0x0c000, CRC(cb0f3d46) SHA1(b56c4abbd4248074c1559a0f1902d2ea11cb01a8) )
 	ROM_CONTINUE(             0x10000, 0x34000 )
 
@@ -874,7 +890,7 @@ All roms had a Yun Sung label with no other ID markings or numbers
 */
 
 ROM_START( torus )
-	ROM_REGION( 0x14000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x14000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "yunsung.u1", 0x00000, 0xc000, CRC(55d3ef3e) SHA1(195463271fdb3f9f5c19068efd1c99105f761fe9) )
 	ROM_CONTINUE(           0x10000, 0x4000 )
 
@@ -952,7 +968,7 @@ All roms read with manufacturer's IDs and routines
 */
 
 ROM_START( madball ) /* Models in swimsuits only, no nudity */
-	ROM_REGION( 0x24000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x24000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "p.u1", 0x00000, 0xc000, CRC(73008425) SHA1(6eded60fd5c637a63783247c858d999d5974d378) )
 	ROM_CONTINUE(     0x10000, 0x14000 )
 
@@ -976,7 +992,7 @@ ROM_START( madball ) /* Models in swimsuits only, no nudity */
 ROM_END
 
 ROM_START( madballn ) /* Even numbered stages show topless models.  Is nudity controlled by a dipswitch? */
-	ROM_REGION( 0x24000, "main", 0 )		/* Z80 Code */
+	ROM_REGION( 0x24000, "maincpu", 0 )		/* Z80 Code */
 	ROM_LOAD( "u1.bin", 0x00000, 0xc000, CRC(531fa919) SHA1(0eafc663b9ad50d0dfc5491fe96c9bcf30483991) )
 	ROM_CONTINUE(       0x10000, 0x14000 )
 
@@ -1008,13 +1024,13 @@ static DRIVER_INIT (paradise)
 static DRIVER_INIT (tgtball)
 {
 	paradise_sprite_inc = 4;
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_IO), 0x2001, 0x2001, 0, 0, tgtball_flipscreen_w );
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x2001, 0x2001, 0, 0, tgtball_flipscreen_w );
 }
 
 static DRIVER_INIT (torus)
 {
 	paradise_sprite_inc = 4;
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_IO), 0x2070, 0x2070, 0, 0, torus_coin_counter_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x2070, 0x2070, 0, 0, torus_coin_counter_w);
 }
 
 
@@ -1032,4 +1048,3 @@ GAME( 1995,  tgtballa, tgtball, tgtball,  tgtball,  tgtball,  ROT0,  "Yun Sung",
 GAME( 1996,  torus,    0,       torus,    torus,    torus,    ROT90, "Yun Sung", "Torus", 0 )
 GAME( 1998,  madball,  0,       madball,  madball,  tgtball,  ROT0,  "Yun Sung", "Mad Ball V2.0", 0 )
 GAME( 1997,  madballn, madball, madball,  madball,  tgtball,  ROT0,  "Yun Sung", "Mad Ball V2.0 (With Nudity)", 0 )
-
