@@ -45,20 +45,6 @@ static WRITE16_HANDLER( pkscramble_bgtilemap_w )
 	tilemap_mark_tile_dirty(bg_tilemap, offset >> 1);
 }
 
-static WRITE16_HANDLER( pkscramble_YM2203_w )
-{
-	switch (offset)
-	{
-		case 0: ym2203_control_port_0_w(space,0,data & 0xff);break;
-		case 1: ym2203_write_port_0_w(space,0,data & 0xff);break;
-	}
-}
-
-static READ16_HANDLER( pkscramble_YM2203_r )
-{
-	return ym2203_status_port_0_r(space,0);
-}
-
 // input bit 0x20 in port1 should stay low until bit 0x20 is written here, then
 // it should stay high for some time (currently we cheat keeping the input always active)
 static WRITE16_HANDLER( pkscramble_output_w )
@@ -87,7 +73,7 @@ static WRITE16_HANDLER( pkscramble_output_w )
 
 	if (!(out & 0x2000) && interrupt_line_active)
 	{
-	    cpu_set_input_line(space->machine->cpu[0], 1, CLEAR_LINE);
+	    cputag_set_input_line(space->machine, "maincpu", 1, CLEAR_LINE);
 		interrupt_line_active = 0;
 	}
 
@@ -112,8 +98,7 @@ static ADDRESS_MAP_START( pkscramble_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x049018, 0x049019) AM_WRITENOP
 	AM_RANGE(0x04901c, 0x04901d) AM_WRITENOP
 	AM_RANGE(0x049020, 0x049021) AM_WRITENOP
-	AM_RANGE(0x04900c, 0x04900d) AM_READ(pkscramble_YM2203_r)
-	AM_RANGE(0x04900c, 0x04900f) AM_WRITE(pkscramble_YM2203_w)
+	AM_RANGE(0x04900c, 0x04900f) AM_DEVREADWRITE8("ym", ym2203_r, ym2203_w, 0x00ff)
 	AM_RANGE(0x052086, 0x052087) AM_WRITENOP
 ADDRESS_MAP_END
 
@@ -208,17 +193,17 @@ static TILE_GET_INFO( get_fg_tile_info )
 
 static TIMER_CALLBACK( scanline_callback )
 {
-	if (param==interrupt_scanline)
+	if (param == interrupt_scanline)
 	{
-    	if (out&0x2000)
-    		cpu_set_input_line(machine->cpu[0], 1, ASSERT_LINE);
-		timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, param+1, 0), param+1);
+    	if (out & 0x2000)
+    		cputag_set_input_line(machine, "maincpu", 1, ASSERT_LINE);
+		timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, param + 1, 0), param+1);
 		interrupt_line_active = 1;
 	}
 	else
 	{
 		if (interrupt_line_active)
-	    	cpu_set_input_line(machine->cpu[0], 1, CLEAR_LINE);
+	    	cputag_set_input_line(machine, "maincpu", 1, CLEAR_LINE);
 		timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, interrupt_scanline, 0), interrupt_scanline);
 		interrupt_line_active = 0;
 	}
@@ -258,10 +243,10 @@ static GFXDECODE_START( pkscram )
 	GFXDECODE_ENTRY( "gfx1", 0, tiles8x8_layout, 0, 0x80 )
 GFXDECODE_END
 
-static void irqhandler(running_machine *machine, int irq)
+static void irqhandler(const device_config *device, int irq)
 {
 	if(out & 0x10)
-		cpu_set_input_line(machine->cpu[0],2,irq ? ASSERT_LINE : CLEAR_LINE);
+		cputag_set_input_line(device->machine, "maincpu", 2, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2203_interface ym2203_config =
@@ -269,7 +254,7 @@ static const ym2203_interface ym2203_config =
 	{
 		AY8910_LEGACY_OUTPUT,
 		AY8910_DEFAULT_LOADS,
-		NULL, NULL, NULL, NULL
+		DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL
 	},
 	irqhandler
 };
@@ -287,16 +272,16 @@ static MACHINE_RESET( pkscramble)
 
 static MACHINE_DRIVER_START( pkscramble )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 8000000 )
-	MDRV_CPU_PROGRAM_MAP(pkscramble_map,0)
-	//MDRV_CPU_VBLANK_INT("main", irq1_line_hold) /* only valid irq */
+	MDRV_CPU_ADD("maincpu", M68000, 8000000 )
+	MDRV_CPU_PROGRAM_MAP(pkscramble_map)
+	//MDRV_CPU_VBLANK_INT("screen", irq1_line_hold) /* only valid irq */
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	MDRV_MACHINE_RESET(pkscramble)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -319,7 +304,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( pkscram )
-	ROM_REGION( 0x20000, "main", 0 ) /* 68k */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* 68k */
 	ROM_LOAD16_BYTE( "pk1.6e", 0x00000, 0x10000, CRC(80e972e5) SHA1(cbbc6e1e3fbb65b40164e140f368d8fff85c1521) )
 	ROM_LOAD16_BYTE( "pk2.6j", 0x00001, 0x10000, CRC(752c86d1) SHA1(2e0c669307bed6f9eab957b0e1316416e653a72f) )
 
