@@ -333,7 +333,7 @@ static WRITE8_HANDLER( ram_8w_w )
 static WRITE8_HANDLER( sprite_dma_w )
 {
 	int source = ( data & 7 );
-	ppu2c0x_spriteram_dma( space, 0, source );
+	ppu2c0x_spriteram_dma( space, devtag_get_device(space->machine, "ppu"), source );
 }
 
 static NVRAM_HANDLER( playch10 )
@@ -361,19 +361,19 @@ static WRITE8_HANDLER( time_w )
 	popmessage("Time: %d%d%d%d",timedata[3],timedata[2],timedata[1],timedata[0]);
 }
 
-static READ8_HANDLER( psg_4015_r )
+static READ8_DEVICE_HANDLER( psg_4015_r )
 {
-	return nes_psg_0_r(space, 0x15);
+	return nes_psg_r(device, 0x15);
 }
 
-static WRITE8_HANDLER( psg_4015_w )
+static WRITE8_DEVICE_HANDLER( psg_4015_w )
 {
-	nes_psg_0_w(space, 0x15, data);
+	nes_psg_w(device, 0x15, data);
 }
 
-static WRITE8_HANDLER( psg_4017_w )
+static WRITE8_DEVICE_HANDLER( psg_4017_w )
 {
-	nes_psg_0_w(space, 0x17, data);
+	nes_psg_w(device, 0x17, data);
 }
 
 /******************************************************************************/
@@ -407,13 +407,13 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cart_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_MIRROR(0x1800) AM_BASE(&work_ram)
-	AM_RANGE(0x2000, 0x3fff) AM_READWRITE(ppu2c0x_0_r, ppu2c0x_0_w)
-	AM_RANGE(0x4011, 0x4011) AM_WRITE(dac_0_data_w)
-	AM_RANGE(0x4000, 0x4013) AM_READWRITE(nes_psg_0_r, nes_psg_0_w)
+	AM_RANGE(0x2000, 0x3fff) AM_DEVREADWRITE("ppu", ppu2c0x_r, ppu2c0x_w)
+	AM_RANGE(0x4011, 0x4011) AM_DEVWRITE("dac", dac_w)
+	AM_RANGE(0x4000, 0x4013) AM_DEVREADWRITE("nes", nes_psg_r, nes_psg_w)
 	AM_RANGE(0x4014, 0x4014) AM_WRITE(sprite_dma_w)
-	AM_RANGE(0x4015, 0x4015) AM_READWRITE(psg_4015_r, psg_4015_w)  /* PSG status / first control register */
+	AM_RANGE(0x4015, 0x4015) AM_DEVREADWRITE("nes", psg_4015_r, psg_4015_w)  /* PSG status / first control register */
 	AM_RANGE(0x4016, 0x4016) AM_READWRITE(pc10_in0_r, pc10_in0_w)
-	AM_RANGE(0x4017, 0x4017) AM_READWRITE(pc10_in1_r, psg_4017_w) /* IN1 - input port 2 / PSG second control register */
+	AM_RANGE(0x4017, 0x4017) AM_READ(pc10_in1_r) AM_DEVWRITE("nes", psg_4017_w) /* IN1 - input port 2 / PSG second control register */
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -684,15 +684,22 @@ static const nes_interface nes_config =
 };
 
 
+/* RP5H01 interface */
+static const rp5h01_interface rp5h01_intf =
+{
+	"user1",
+	0
+};
+
 static MACHINE_DRIVER_START( playch10 )
 	// basic machine hardware
-	MDRV_CPU_ADD("main", Z80, 8000000/2)	// 4 MHz
-	MDRV_CPU_PROGRAM_MAP(bios_map, 0)
-	MDRV_CPU_IO_MAP(bios_io_map, 0)
+	MDRV_CPU_ADD("maincpu", Z80, 8000000/2)	// 4 MHz
+	MDRV_CPU_PROGRAM_MAP(bios_map)
+	MDRV_CPU_IO_MAP(bios_io_map)
 	MDRV_CPU_VBLANK_INT("top", playch10_interrupt)
 
 	MDRV_CPU_ADD("cart", N2A03, N2A03_DEFAULTCLOCK)
-	MDRV_CPU_PROGRAM_MAP(cart_map, 0)
+	MDRV_CPU_PROGRAM_MAP(cart_map)
 
 	MDRV_MACHINE_RESET(pc10)
 
@@ -717,6 +724,8 @@ static MACHINE_DRIVER_START( playch10 )
 	MDRV_VIDEO_START(playch10)
 	MDRV_VIDEO_UPDATE(playch10)
 
+	MDRV_PPU2C03B_ADD("ppu", playch10_ppu_interface)
+
 	// sound hardware
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 	MDRV_SOUND_ADD("nes", NES, N2A03_DEFAULTCLOCK)
@@ -725,6 +734,8 @@ static MACHINE_DRIVER_START( playch10 )
 
 	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_RP5H01_ADD("rp5h01", rp5h01_intf)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( playchnv )
@@ -735,6 +746,9 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( playch10_hboard )
 	MDRV_IMPORT_FROM(playch10)
 	MDRV_VIDEO_START(playch10_hboard)
+
+	MDRV_DEVICE_REMOVE("ppu")
+	MDRV_PPU2C03B_ADD("ppu", playch10_ppu_interface)
 MACHINE_DRIVER_END
 
 /***************************************************************************
@@ -747,7 +761,7 @@ MACHINE_DRIVER_END
 	ROMX_LOAD(name, offset, length, hash, ROM_BIOS(bios+1)) /* Note '+1' */
 
 #define BIOS_CPU											\
-	ROM_REGION( 0x10000, "main", 0 )						\
+	ROM_REGION( 0x10000, "maincpu", 0 )						\
 	ROM_SYSTEM_BIOS( 0, "dual",   "Dual Monitor Version" ) \
 	ROM_LOAD_BIOS( 0, "pch1-c.8t", 0x00000, 0x4000, CRC(d52fa07a) SHA1(55cabf52ae10c050c2229081a80b9fe5454ab8c5) ) \
 	ROM_SYSTEM_BIOS( 1, "single", "Single Monitor Version" ) \
@@ -1659,7 +1673,7 @@ GAME( 1988, pc_cntra, playch10, playch10, playch10, pcbboard, ROT0, "Konami (Nin
 GAME( 1986, pc_goons, playch10, playch10, playch10, pccboard, ROT0, "Konami",									"The Goonies (PlayChoice-10)", 0 )
 
 /* D-Board Games */
-GAME( 1986, pc_mtoid, playch10, playch10, playch10, pcdboard_2, ROT0, "Nintendo",									"Metroid (PlayChoice-10)", 0 )
+GAME( 1986, pc_mtoid, playch10, playch10, playch10, pcdboard_2, ROT0, "Nintendo",								"Metroid (PlayChoice-10)", 0 )
 GAME( 1987, pc_radrc, playch10, playch10, playch10, pcdboard, ROT0, "Square",									"Rad Racer (PlayChoice-10)", 0 )
 
 /* E-Board Games */
@@ -1668,7 +1682,7 @@ GAME( 1987, pc_miket, playch10, playchnv, playch10, pceboard, ROT0, "Nintendo",
 /* F-Board Games */
 GAME( 1987, pc_rcpam, playch10, playch10, playch10, pcfboard, ROT0, "Rare",										"R.C. Pro-Am (PlayChoice-10)", 0 )
 GAME( 1987, pc_rrngr, playch10, playch10, playch10, pcfboard, ROT0, "Capcom USA (Nintendo of America license)", "Chip'n Dale: Rescue Rangers (PlayChoice-10)", 0 )
-GAME( 1988, pc_ddrgn, playch10, playch10, playch10, pcfboard, ROT0, "Technos",									"Double Dragon (PlayChoice-10)", 0 )
+GAME( 1988, pc_ddrgn, playch10, playch10, playch10, pcfboard, ROT0, "Technos Japan",							"Double Dragon (PlayChoice-10)", 0 )
 GAME( 1989, pc_ngaid, playch10, playch10, playch10, pcfboard, ROT0, "Tecmo (Nintendo of America license)",		"Ninja Gaiden (PlayChoice-10)", 0 )
 GAME( 1989, pc_tmnt,  playch10, playch10, playch10, pcfboard, ROT0, "Konami (Nintendo of America license)",		"Teenage Mutant Ninja Turtles (PlayChoice-10)", 0 )
 GAME( 1989, pc_ftqst, playch10, playch10, playch10, pcfboard, ROT0, "Sunsoft (Nintendo of America license)",	"Uncle Fester's Quest: The Addams Family (PlayChoice-10)", 0 )
@@ -1683,7 +1697,7 @@ GAME( 1988, pc_smb3,  playch10, playch10, playch10, pcgboard, ROT0, "Nintendo",
 GAME( 1990, pc_mman3, playch10, playch10, playch10, pcgboard, ROT0, "Capcom USA (Nintendo of America license)",	"Mega Man III (PlayChoice-10)", 0 )
 GAME( 1990, pc_suprc, playch10, playch10, playch10, pcgboard, ROT0, "Konami (Nintendo of America license)",		"Super C (PlayChoice-10)", 0 )
 GAME( 1990, pc_tmnt2, playch10, playch10, playch10, pcgboard, ROT0, "Konami (Nintendo of America license)",		"Teenage Mutant Ninja Turtles II: The Arcade Game (PlayChoice-10)", 0 )
-GAME( 1990, pc_wcup,  playch10, playch10, playch10, pcgboard, ROT0, "Technos (Nintendo license)",				"Nintendo World Cup (PlayChoice-10)", 0 )
+GAME( 1990, pc_wcup,  playch10, playch10, playch10, pcgboard, ROT0, "Technos Japan (Nintendo license)",			"Nintendo World Cup (PlayChoice-10)", 0 )
 GAME( 1990, pc_ngai2, playch10, playch10, playch10, pcgboard, ROT0, "Tecmo (Nintendo of America license)",		"Ninja Gaiden Episode II: The Dark Sword of Chaos (PlayChoice-10)", 0 )
 GAME( 1991, pc_ngai3, playch10, playch10, playch10, pcgboard, ROT0, "Tecmo (Nintendo of America license)",		"Ninja Gaiden Episode III: The Ancient Ship of Doom (PlayChoice-10)", 0 )
 GAME( 1991, pc_pwbld, playch10, playch10, playch10, pcgboard, ROT0, "Taito (Nintendo of America license)",		"Power Blade (PlayChoice-10)", 0 )
