@@ -218,7 +218,7 @@ static WRITE32_HANDLER( sound_w )
 
 static WRITE32_HANDLER( sound_irq_w )
 {
-	cputag_set_input_line(space->machine, "sound", 0, HOLD_LINE);
+	cputag_set_input_line(space->machine, "soundcpu", 0, HOLD_LINE);
 }
 
 /* DSP communications */
@@ -230,7 +230,7 @@ static READ32_HANDLER( dsp_host_interface_r )
 	if (mem_mask == 0x0000ff00)	{ hi_addr++; }	/* Low byte */
 	if (mem_mask == 0xff000000) {}				/* High byte */
 
-	value = dsp56k_host_interface_read((device_config*)cputag_get_cpu(space->machine, "dsp"), hi_addr);
+	value = dsp56k_host_interface_read(cputag_get_cpu(space->machine, "dsp"), hi_addr);
 
 	if (mem_mask == 0x0000ff00)	{ value <<= 8;  }
 	if (mem_mask == 0xff000000) { value <<= 24; }
@@ -299,7 +299,7 @@ static WRITE32_HANDLER( dsp_host_interface_w )
 	if (mem_mask == 0xff000000) { hi_data = (data & 0xff000000) >> 24; }
 
 	logerror("write (host-side) %08x %08x %08x (HI %04x)\n", offset, mem_mask, data, hi_addr);
-	dsp56k_host_interface_write((device_config*)cputag_get_cpu(space->machine, "dsp"), hi_addr, hi_data);
+	dsp56k_host_interface_write(cputag_get_cpu(space->machine, "dsp"), hi_addr, hi_data);
 }
 
 
@@ -309,7 +309,7 @@ static READ32_HANDLER( network_r )
 }
 
 
-WRITE32_HANDLER( plygonet_palette_w )
+static WRITE32_HANDLER( plygonet_palette_w )
 {
 	int r,g,b;
 
@@ -375,7 +375,7 @@ enum { BANK_GROUP_A, BANK_GROUP_B, INVALID_BANK_GROUP };
 
 static UINT8 dsp56k_bank_group(const device_config* cpu)
 {
-	UINT16 portC = dsp56k_get_peripheral_memory((device_config*)cpu, 0xffe3);
+	UINT16 portC = dsp56k_get_peripheral_memory(cpu, 0xffe3);
 
 	/* If bank group B is on, it overrides bank group A */
 	if (portC & 0x0002)
@@ -388,7 +388,7 @@ static UINT8 dsp56k_bank_group(const device_config* cpu)
 
 static UINT8 dsp56k_bank_num(const device_config* cpu, UINT8 bank_group)
 {
-	UINT16 portC = dsp56k_get_peripheral_memory((device_config*)cpu, 0xffe3);
+	UINT16 portC = dsp56k_get_peripheral_memory(cpu, 0xffe3);
 
 	if (bank_group == BANK_GROUP_A)
 	{
@@ -413,8 +413,8 @@ static UINT8 dsp56k_bank_num(const device_config* cpu, UINT8 bank_group)
 /* BANK HANDLERS */
 static READ16_HANDLER( dsp56k_ram_bank00_read )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank00_size * 8) + (bank_num * dsp56k_bank00_size);
 
 	return dsp56k_bank00_ram[driver_bank_offset + offset];
@@ -422,8 +422,8 @@ static READ16_HANDLER( dsp56k_ram_bank00_read )
 
 static WRITE16_HANDLER( dsp56k_ram_bank00_write )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank00_size * 8) + (bank_num * dsp56k_bank00_size);
 
 	COMBINE_DATA(&dsp56k_bank00_ram[driver_bank_offset + offset]);
@@ -432,8 +432,8 @@ static WRITE16_HANDLER( dsp56k_ram_bank00_write )
 
 static READ16_HANDLER( dsp56k_ram_bank01_read )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank01_size * 8) + (bank_num * dsp56k_bank01_size);
 
 	return dsp56k_bank01_ram[driver_bank_offset + offset];
@@ -441,8 +441,8 @@ static READ16_HANDLER( dsp56k_ram_bank01_read )
 
 static WRITE16_HANDLER( dsp56k_ram_bank01_write )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank01_size * 8) + (bank_num * dsp56k_bank01_size);
 
 	COMBINE_DATA(&dsp56k_bank01_ram[driver_bank_offset + offset]);
@@ -454,8 +454,8 @@ static WRITE16_HANDLER( dsp56k_ram_bank01_write )
 
 static READ16_HANDLER( dsp56k_ram_bank02_read )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank02_size * 8) + (bank_num * dsp56k_bank02_size);
 
 	return dsp56k_bank02_ram[driver_bank_offset + offset];
@@ -463,8 +463,8 @@ static READ16_HANDLER( dsp56k_ram_bank02_read )
 
 static WRITE16_HANDLER( dsp56k_ram_bank02_write )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank02_size * 8) + (bank_num * dsp56k_bank02_size);
 
 	COMBINE_DATA(&dsp56k_bank02_ram[driver_bank_offset + offset]);
@@ -473,8 +473,8 @@ static WRITE16_HANDLER( dsp56k_ram_bank02_write )
 
 static READ16_HANDLER( dsp56k_shared_ram_read )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_shared_ram_16_size * 8) + (bank_num * dsp56k_shared_ram_16_size);
 
 	return dsp56k_shared_ram_16[driver_bank_offset + offset];
@@ -482,8 +482,8 @@ static READ16_HANDLER( dsp56k_shared_ram_read )
 
 static WRITE16_HANDLER( dsp56k_shared_ram_write )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_shared_ram_16_size * 8) + (bank_num * dsp56k_shared_ram_16_size);
 
 	COMBINE_DATA(&dsp56k_shared_ram_16[driver_bank_offset + offset]);
@@ -501,8 +501,8 @@ static WRITE16_HANDLER( dsp56k_shared_ram_write )
 
 static READ16_HANDLER( dsp56k_ram_bank04_read )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank04_size * 8) + (bank_num * dsp56k_bank04_size);
 
 	return dsp56k_bank04_ram[driver_bank_offset + offset];
@@ -510,8 +510,8 @@ static READ16_HANDLER( dsp56k_ram_bank04_read )
 
 static WRITE16_HANDLER( dsp56k_ram_bank04_write )
 {
-	UINT8 en_group = dsp56k_bank_group((device_config*)space->cpu);
-	UINT8 bank_num = dsp56k_bank_num((device_config*)space->cpu, en_group);
+	UINT8 en_group = dsp56k_bank_group(space->cpu);
+	UINT8 bank_num = dsp56k_bank_num(space->cpu, en_group);
 	UINT32 driver_bank_offset = (en_group * dsp56k_bank04_size * 8) + (bank_num * dsp56k_bank04_size);
 
 	COMBINE_DATA(&dsp56k_bank04_ram[driver_bank_offset + offset]);
@@ -565,7 +565,7 @@ static int cur_sound_region;
 
 static void reset_sound_region(running_machine *machine)
 {
-	memory_set_bankptr(machine, 2, memory_region(machine, "sound") + 0x10000 + cur_sound_region*0x4000);
+	memory_set_bankptr(machine, 2, memory_region(machine, "soundcpu") + 0x10000 + cur_sound_region*0x4000);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
@@ -581,18 +581,18 @@ static INTERRUPT_GEN(audio_interrupt)
 
 static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK2)
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK(2))
+	AM_RANGE(0x0000, 0xbfff) AM_WRITENOP
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe22f) AM_READWRITE(k054539_0_r, k054539_0_w)
+	AM_RANGE(0xe000, 0xe22f) AM_DEVREADWRITE("konami1", k054539_r, k054539_w)
 	AM_RANGE(0xe230, 0xe3ff) AM_RAM
-	AM_RANGE(0xe400, 0xe62f) AM_READWRITE(k054539_1_r, k054539_1_w)
+	AM_RANGE(0xe400, 0xe62f) AM_DEVREADWRITE("konami2", k054539_r, k054539_w)
 	AM_RANGE(0xe630, 0xe7ff) AM_RAM
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(soundlatch3_w)
 	AM_RANGE(0xf002, 0xf002) AM_READ(soundlatch_r)
 	AM_RANGE(0xf003, 0xf003) AM_READ(soundlatch2_r)
 	AM_RANGE(0xf800, 0xf800) AM_WRITE(sound_bankswitch_w)
-	AM_RANGE(0xfff1, 0xfff3) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xfff1, 0xfff3) AM_WRITENOP
 ADDRESS_MAP_END
 
 static const k054539_interface k054539_config =
@@ -633,16 +633,16 @@ static MACHINE_START(polygonet)
 }
 
 static MACHINE_DRIVER_START( plygonet )
-	MDRV_CPU_ADD("main", M68EC020, 16000000)	/* 16 MHz (xtal is 32.0 MHz) */
-	MDRV_CPU_PROGRAM_MAP(main_map, 0)
-	MDRV_CPU_VBLANK_INT("main", polygonet_interrupt)
+	MDRV_CPU_ADD("maincpu", M68EC020, 16000000)	/* 16 MHz (xtal is 32.0 MHz) */
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_VBLANK_INT("screen", polygonet_interrupt)
 
 	MDRV_CPU_ADD("dsp", DSP56156, 40000000)		/* xtal is 40.0 MHz, DSP has an internal divide-by-2 */
-	MDRV_CPU_PROGRAM_MAP(dsp_program_map, 0)
-	MDRV_CPU_DATA_MAP(dsp_data_map, 0)
+	MDRV_CPU_PROGRAM_MAP(dsp_program_map)
+	MDRV_CPU_DATA_MAP(dsp_data_map)
 
-	MDRV_CPU_ADD("sound", Z80, 8000000)
-	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
+	MDRV_CPU_ADD("soundcpu", Z80, 8000000)
+	MDRV_CPU_PROGRAM_MAP(sound_map)
 	MDRV_CPU_PERIODIC_INT(audio_interrupt, 480)
 
 	MDRV_MACHINE_START(polygonet)
@@ -654,7 +654,7 @@ static MACHINE_DRIVER_START( plygonet )
 	MDRV_QUANTUM_TIME(HZ(1200000))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -667,17 +667,17 @@ static MACHINE_DRIVER_START( plygonet )
 	MDRV_VIDEO_UPDATE(polygonet)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("konami1", K054539, 48000)
 	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "left", 0.75)
-	MDRV_SOUND_ROUTE(1, "right", 0.75)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 0.75)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 0.75)
 
 	MDRV_SOUND_ADD("konami2", K054539, 48000)
 	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "left", 0.75)
-	MDRV_SOUND_ROUTE(1, "right", 0.75)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 0.75)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 0.75)
 MACHINE_DRIVER_END
 
 static INPUT_PORTS_START( polygonet )
@@ -709,33 +709,26 @@ static DRIVER_INIT(polygonet)
 	reset_sound_region(machine);
 
 	/* Allocate space for the dsp56k banking */
-	dsp56k_bank00_ram    = auto_malloc(2 * 8 * dsp56k_bank00_size 		 * sizeof(UINT16));		/* 2 bank sets, 8 potential banks each */
-	dsp56k_bank01_ram    = auto_malloc(2 * 8 * dsp56k_bank01_size 		 * sizeof(UINT16));
-	dsp56k_bank02_ram    = auto_malloc(2 * 8 * dsp56k_bank02_size 		 * sizeof(UINT16));
-	dsp56k_shared_ram_16 = auto_malloc(2 * 8 * dsp56k_shared_ram_16_size * sizeof(UINT16));
-	dsp56k_bank04_ram    = auto_malloc(2 * 8 * dsp56k_bank04_size 		 * sizeof(UINT16));
-
-	/* Clear the newly-allocated memory */
-	memset(dsp56k_bank00_ram,    0, 2 * 8 * dsp56k_bank00_size		  * sizeof(UINT16));
-	memset(dsp56k_bank01_ram,    0, 2 * 8 * dsp56k_bank01_size		  * sizeof(UINT16));
-	memset(dsp56k_bank02_ram,    0, 2 * 8 * dsp56k_bank02_size		  * sizeof(UINT16));
-	memset(dsp56k_shared_ram_16, 0, 2 * 8 * dsp56k_shared_ram_16_size * sizeof(UINT16));
-	memset(dsp56k_bank04_ram,    0, 2 * 8 * dsp56k_bank04_size		  * sizeof(UINT16));
+	dsp56k_bank00_ram    = auto_alloc_array_clear(machine, UINT16, 2 * 8 * dsp56k_bank00_size);		/* 2 bank sets, 8 potential banks each */
+	dsp56k_bank01_ram    = auto_alloc_array_clear(machine, UINT16, 2 * 8 * dsp56k_bank01_size);
+	dsp56k_bank02_ram    = auto_alloc_array_clear(machine, UINT16, 2 * 8 * dsp56k_bank02_size);
+	dsp56k_shared_ram_16 = auto_alloc_array_clear(machine, UINT16, 2 * 8 * dsp56k_shared_ram_16_size);
+	dsp56k_bank04_ram    = auto_alloc_array_clear(machine, UINT16, 2 * 8 * dsp56k_bank04_size);
 
 	/* The dsp56k occasionally executes out of mapped memory */
-	dsp56k_update_handler = memory_set_direct_update_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), plygonet_dsp56k_direct_handler);
+	dsp56k_update_handler = memory_set_direct_update_handler(cputag_get_address_space(machine, "dsp", ADDRESS_SPACE_PROGRAM), plygonet_dsp56k_direct_handler);
 }
 
 ROM_START( plygonet )
 	/* main program */
-	ROM_REGION( 0x200000, "main", 0)
+	ROM_REGION( 0x200000, "maincpu", 0)
 	ROM_LOAD32_BYTE( "305a01.4k", 0x000003, 512*1024, CRC(8bdb6c95) SHA1(e981833842f8fd89b9726901fbe2058444204792) )
 	ROM_LOAD32_BYTE( "305a02.2k", 0x000002, 512*1024, CRC(4d7e32b3) SHA1(25731526535036972577637d186f02ae467296bd) )
 	ROM_LOAD32_BYTE( "305a03.2h", 0x000001, 512*1024, CRC(36e4e3fe) SHA1(e8fcad4f196c9b225a0fbe70791493ff07c648a9) )
 	ROM_LOAD32_BYTE( "305a04.4h", 0x000000, 512*1024, CRC(d8394e72) SHA1(eb6bcf8aedb9ba5843204ab8aacb735cbaafb74d) )
 
 	/* Z80 sound program */
-	ROM_REGION( 0x30000, "sound", 0 )
+	ROM_REGION( 0x30000, "soundcpu", 0 )
 	ROM_LOAD("305b05.7b", 0x000000, 0x20000, CRC(2d3d9654) SHA1(784a409df47cee877e507b8bbd3610d161d63753) )
 	ROM_RELOAD( 0x10000, 0x20000)
 
