@@ -339,14 +339,10 @@ static VIDEO_START(rabbit)
 {
 	/* the tilemaps are bigger than the regions the cpu can see, need to allocate the ram here */
 	/* or maybe not for this game/hw .... */
-	rabbit_tilemap_ram[0] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[1] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[2] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[3] = auto_malloc(0x20000);
-	memset(rabbit_tilemap_ram[0], 0, 0x20000);
-	memset(rabbit_tilemap_ram[1], 0, 0x20000);
-	memset(rabbit_tilemap_ram[2], 0, 0x20000);
-	memset(rabbit_tilemap_ram[3], 0, 0x20000);
+	rabbit_tilemap_ram[0] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[1] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[2] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[3] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
 
 	rabbit_tilemap[0] = tilemap_create(machine, get_rabbit_tilemap0_tile_info,tilemap_scan_rows,16, 16, 128,32);
 	rabbit_tilemap[1] = tilemap_create(machine, get_rabbit_tilemap1_tile_info,tilemap_scan_rows,16, 16, 128,32);
@@ -356,7 +352,7 @@ static VIDEO_START(rabbit)
 	tilemap_set_transparent_pen(rabbit_tilemap[1],0x0);
 	tilemap_set_transparent_pen(rabbit_tilemap[2],0x0);
 	tilemap_set_transparent_pen(rabbit_tilemap[3],0x0);
-	rabbit_sprite_bitmap = auto_bitmap_alloc(0x1000,0x1000,video_screen_get_format(machine->primary_screen));
+	rabbit_sprite_bitmap = auto_bitmap_alloc(machine,0x1000,0x1000,video_screen_get_format(machine->primary_screen));
 	rabbit_sprite_clip.min_x = 0;
 	rabbit_sprite_clip.max_x = 0x1000-1;
 	rabbit_sprite_clip.min_y = 0;
@@ -483,30 +479,13 @@ static READ32_HANDLER( randomrabbits )
 	return mame_rand(space->machine);
 }
 
-static ADDRESS_MAP_START( rabbit_readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x200000, 0x200003) AM_READ_PORT("INPUTS")
-	AM_RANGE(0x400010, 0x400013) AM_READ(randomrabbits) // gfx chip status?
-	AM_RANGE(0x400980, 0x400983) AM_READ(randomrabbits) // sound chip status?
-	AM_RANGE(0x400984, 0x400987) AM_READ(randomrabbits) // sound chip status?
-	AM_RANGE(0x440000, 0x47ffff) AM_READ(SMH_BANK1) // roms read from here during testing
-	/* tilemaps */
-	AM_RANGE(0x480000, 0x483fff) AM_READ(rabbit_tilemap0_r)
-	AM_RANGE(0x484000, 0x487fff) AM_READ(rabbit_tilemap1_r)
-	AM_RANGE(0x488000, 0x48bfff) AM_READ(rabbit_tilemap2_r)
-	AM_RANGE(0x48c000, 0x48ffff) AM_READ(rabbit_tilemap3_r)
-	AM_RANGE(0x494000, 0x49ffff) AM_READ(SMH_RAM)
-	AM_RANGE(0x4a0000, 0x4affff) AM_READ(SMH_RAM) /* palette */
-	AM_RANGE(0xff0000, 0xffffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
 /* rom bank is used when testing roms, not currently hooked up */
 static WRITE32_HANDLER ( rabbit_rombank_w )
 {
 	UINT8 *dataroms = memory_region(space->machine, "gfx1");
-	int bank;
+//  int bank;
 //  mame_printf_debug("rabbit rombank %08x\n",data&0x3ff);
-	bank = data & 0x3ff;
+//  bank = data & 0x3ff;
 
 //  memory_set_bankptr(space->machine, 1,&dataroms[0x40000*(bank&0x3ff)]);
 	memory_set_bankptr(space->machine, 1,&dataroms[0]);
@@ -593,7 +572,7 @@ if (VERBOSE_AUDIO_LOG)
 
 static TIMER_CALLBACK( rabbit_blit_done )
 {
-	cpu_set_input_line(machine->cpu[0], rabbit_bltirqlevel, HOLD_LINE);
+	cputag_set_input_line(machine, "maincpu", rabbit_bltirqlevel, HOLD_LINE);
 }
 
 static void rabbit_do_blit(running_machine *machine)
@@ -718,54 +697,45 @@ static WRITE32_HANDLER( rabbit_eeprom_write )
 	}
 }
 
-static ADDRESS_MAP_START( rabbit_writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x000003) AM_WRITE(SMH_NOP) // bug in code / emulation?
-	AM_RANGE(0x000010, 0x000013) AM_WRITE(SMH_NOP) // bug in code / emulation?
-	AM_RANGE(0x000024, 0x000027) AM_WRITE(SMH_NOP) // bug in code / emulation?
-	AM_RANGE(0x00719C, 0x00719F) AM_WRITE(SMH_NOP) // bug in code / emulation?
-	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x200000, 0x200003) AM_WRITE(rabbit_eeprom_write)
+static ADDRESS_MAP_START( rabbit_map, ADDRESS_SPACE_PROGRAM, 32 )
+	AM_RANGE(0x000000, 0x1fffff) AM_ROM
+	AM_RANGE(0x000000, 0x000003) AM_WRITENOP // bug in code / emulation?
+	AM_RANGE(0x000010, 0x000013) AM_WRITENOP // bug in code / emulation?
+	AM_RANGE(0x000024, 0x000027) AM_WRITENOP // bug in code / emulation?
+	AM_RANGE(0x00719c, 0x00719f) AM_WRITENOP // bug in code / emulation?
+	AM_RANGE(0x200000, 0x200003) AM_READ_PORT("INPUTS") AM_WRITE(rabbit_eeprom_write)
+	AM_RANGE(0x400010, 0x400013) AM_READ(randomrabbits) // gfx chip status?
+	AM_RANGE(0x400980, 0x400983) AM_READ(randomrabbits) // sound chip status?
+	AM_RANGE(0x400984, 0x400987) AM_READ(randomrabbits) // sound chip status?
 	/* this lot are probably gfxchip/blitter etc. related */
-	AM_RANGE(0x400010, 0x400013) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs0 )
-	AM_RANGE(0x400100, 0x400117) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[0] ) // tilemap regs1
-	AM_RANGE(0x400120, 0x400137) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[1] ) // tilemap regs2
-	AM_RANGE(0x400140, 0x400157) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[2] ) // tilemap regs3
-	AM_RANGE(0x400160, 0x400177) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[3] ) // tilemap regs4
-	AM_RANGE(0x400200, 0x40021b) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_spriteregs ) // sprregs?
+	AM_RANGE(0x400010, 0x400013) AM_WRITEONLY AM_BASE( &rabbit_viewregs0 )
+	AM_RANGE(0x400100, 0x400117) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[0] ) // tilemap regs1
+	AM_RANGE(0x400120, 0x400137) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[1] ) // tilemap regs2
+	AM_RANGE(0x400140, 0x400157) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[2] ) // tilemap regs3
+	AM_RANGE(0x400160, 0x400177) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[3] ) // tilemap regs4
+	AM_RANGE(0x400200, 0x40021b) AM_WRITEONLY AM_BASE( &rabbit_spriteregs ) // sprregs?
 	AM_RANGE(0x400300, 0x400303) AM_WRITE(rabbit_rombank_w) // used during rom testing, rombank/area select + something else?
-	AM_RANGE(0x400400, 0x400413) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs6 ) // some global controls? (brightness etc.?)
-	AM_RANGE(0x400500, 0x400503) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs7 )
+	AM_RANGE(0x400400, 0x400413) AM_WRITEONLY AM_BASE( &rabbit_viewregs6 ) // some global controls? (brightness etc.?)
+	AM_RANGE(0x400500, 0x400503) AM_WRITEONLY AM_BASE( &rabbit_viewregs7 )
 	AM_RANGE(0x400700, 0x40070f) AM_WRITE(rabbit_blitter_w) AM_BASE( &rabbit_blitterregs )
-	AM_RANGE(0x400800, 0x40080f) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs9 ) // never changes?
+	AM_RANGE(0x400800, 0x40080f) AM_WRITEONLY AM_BASE( &rabbit_viewregs9 ) // never changes?
 	AM_RANGE(0x400900, 0x40098f) AM_WRITE(rabbit_audio_w)
 	/* hmm */
-	AM_RANGE(0x479700, 0x479713) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs10 )
+	AM_RANGE(0x479700, 0x479713) AM_WRITEONLY AM_BASE( &rabbit_viewregs10 )
+
+	AM_RANGE(0x440000, 0x47ffff) AM_ROMBANK(1) // roms read from here during testing
 	/* tilemaps */
-	AM_RANGE(0x480000, 0x483fff) AM_WRITE(rabbit_tilemap0_w)
-	AM_RANGE(0x484000, 0x487fff) AM_WRITE(rabbit_tilemap1_w)
-	AM_RANGE(0x488000, 0x48bfff) AM_WRITE(rabbit_tilemap2_w)
-	AM_RANGE(0x48c000, 0x48ffff) AM_WRITE(rabbit_tilemap3_w)
-	AM_RANGE(0x494000, 0x497fff) AM_WRITE(SMH_RAM) AM_BASE(&rabbit_spriteram) // sprites?
-	AM_RANGE(0x4a0000, 0x4affff) AM_WRITE(rabbit_paletteram_dword_w) AM_BASE(&paletteram32)
-	AM_RANGE(0xff0000, 0xffffff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x480000, 0x483fff) AM_READWRITE(rabbit_tilemap0_r,rabbit_tilemap0_w)
+	AM_RANGE(0x484000, 0x487fff) AM_READWRITE(rabbit_tilemap1_r,rabbit_tilemap1_w)
+	AM_RANGE(0x488000, 0x48bfff) AM_READWRITE(rabbit_tilemap2_r,rabbit_tilemap2_w)
+	AM_RANGE(0x48c000, 0x48ffff) AM_READWRITE(rabbit_tilemap3_r,rabbit_tilemap3_w)
+	AM_RANGE(0x494000, 0x497fff) AM_RAM AM_BASE(&rabbit_spriteram) // sprites?
+	AM_RANGE(0x4a0000, 0x4affff) AM_RAM_WRITE(rabbit_paletteram_dword_w) AM_BASE(&paletteram32)
+	AM_RANGE(0xff0000, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
 /* tmmjprd has a different memory map */
 
-static ADDRESS_MAP_START( tmmjprd_readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x200010, 0x200013) AM_READ(randomrabbits) // gfx chip status?
-	AM_RANGE(0x200980, 0x200983) AM_READ(randomrabbits) // sound chip status?
-	AM_RANGE(0x200984, 0x200987) AM_READ(randomrabbits) // sound chip status?
-	AM_RANGE(0x280000, 0x283fff) AM_READ(rabbit_tilemap0_r)
-	AM_RANGE(0x284000, 0x287fff) AM_READ(rabbit_tilemap1_r)
-	AM_RANGE(0x288000, 0x28bfff) AM_READ(rabbit_tilemap2_r)
-	AM_RANGE(0x28c000, 0x28ffff) AM_READ(rabbit_tilemap3_r)
-	AM_RANGE(0x290000, 0x29ffff) AM_READ(SMH_RAM)
-	AM_RANGE(0x400000, 0x400003) AM_READ_PORT("INPUTS")
-	AM_RANGE(0xf00000, 0xffffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
 static WRITE32_HANDLER( tmmjprd_paletteram_dword_w )
 {
 	int r,g,b;
@@ -778,36 +748,40 @@ static WRITE32_HANDLER( tmmjprd_paletteram_dword_w )
 	palette_set_color(space->machine,(offset^0xff)+0x2000,MAKE_RGB(r,g,b));
 }
 
-
-static ADDRESS_MAP_START( tmmjprd_writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(SMH_ROM)
-/* check these are used .. */
-//  AM_RANGE(0x200010, 0x200013) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs0 )
-	AM_RANGE(0x200100, 0x200117) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[0] ) // tilemap regs1
-	AM_RANGE(0x200120, 0x200137) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[1] ) // tilemap regs2
-	AM_RANGE(0x200140, 0x200157) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[2] ) // tilemap regs3
-	AM_RANGE(0x200160, 0x200177) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_tilemap_regs[3] ) // tilemap regs4
-	AM_RANGE(0x200200, 0x20021b) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_spriteregs ) // sprregs?
+static ADDRESS_MAP_START( tmmjprd_map, ADDRESS_SPACE_PROGRAM, 32 )
+	AM_RANGE(0x000000, 0x1fffff) AM_ROM
+	AM_RANGE(0x200010, 0x200013) AM_READ(randomrabbits) // gfx chip status?
+	AM_RANGE(0x200980, 0x200983) AM_READ(randomrabbits) // sound chip status?
+	AM_RANGE(0x200984, 0x200987) AM_READ(randomrabbits) // sound chip status?
+	/* check these are used .. */
+//  AM_RANGE(0x200010, 0x200013) AM_WRITEONLY AM_BASE( &rabbit_viewregs0 )
+	AM_RANGE(0x200100, 0x200117) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[0] ) // tilemap regs1
+	AM_RANGE(0x200120, 0x200137) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[1] ) // tilemap regs2
+	AM_RANGE(0x200140, 0x200157) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[2] ) // tilemap regs3
+	AM_RANGE(0x200160, 0x200177) AM_WRITEONLY AM_BASE( &rabbit_tilemap_regs[3] ) // tilemap regs4
+	AM_RANGE(0x200200, 0x20021b) AM_WRITEONLY AM_BASE( &rabbit_spriteregs ) // sprregs?
 //  AM_RANGE(0x200300, 0x200303) AM_WRITE(rabbit_rombank_w) // used during rom testing, rombank/area select + something else?
-//  AM_RANGE(0x200400, 0x200413) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs6 ) // some global controls? (brightness etc.?)
-//  AM_RANGE(0x200500, 0x200503) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs7 )
+//  AM_RANGE(0x200400, 0x200413) AM_WRITEONLY AM_BASE( &rabbit_viewregs6 ) // some global controls? (brightness etc.?)
+//  AM_RANGE(0x200500, 0x200503) AM_WRITEONLY AM_BASE( &rabbit_viewregs7 )
 //  AM_RANGE(0x200700, 0x20070f) AM_WRITE(rabbit_blitter_w) AM_BASE( &rabbit_blitterregs )
-//  AM_RANGE(0x200800, 0x20080f) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs9 ) // never changes?
+//  AM_RANGE(0x200800, 0x20080f) AM_WRITEONLY AM_BASE( &rabbit_viewregs9 ) // never changes?
 //  AM_RANGE(0x200900, 0x20098f) AM_WRITE(rabbit_audio_w)
 	/* hmm */
-//  AM_RANGE(0x279700, 0x279713) AM_WRITE(SMH_RAM) AM_BASE( &rabbit_viewregs10 )
+//  AM_RANGE(0x279700, 0x279713) AM_WRITEONLY AM_BASE( &rabbit_viewregs10 )
 	/* tilemaps */
-	AM_RANGE(0x280000, 0x283fff) AM_WRITE(rabbit_tilemap0_w)
-	AM_RANGE(0x284000, 0x287fff) AM_WRITE(rabbit_tilemap1_w)
-	AM_RANGE(0x288000, 0x28bfff) AM_WRITE(rabbit_tilemap2_w)
-	AM_RANGE(0x28c000, 0x28ffff) AM_WRITE(rabbit_tilemap3_w)
+	AM_RANGE(0x280000, 0x283fff) AM_READWRITE(rabbit_tilemap0_r,rabbit_tilemap0_w)
+	AM_RANGE(0x284000, 0x287fff) AM_READWRITE(rabbit_tilemap1_r,rabbit_tilemap1_w)
+	AM_RANGE(0x288000, 0x28bfff) AM_READWRITE(rabbit_tilemap2_r,rabbit_tilemap2_w)
+	AM_RANGE(0x28c000, 0x28ffff) AM_READWRITE(rabbit_tilemap3_r,rabbit_tilemap3_w)
 	/* ?? is palette ram shared with sprites in this case or just a different map */
-	AM_RANGE(0x290000, 0x29bfff) AM_WRITE(SMH_RAM) AM_BASE(&rabbit_spriteram)
-	AM_RANGE(0x29c000, 0x29ffff) AM_WRITE(tmmjprd_paletteram_dword_w) AM_BASE(&paletteram32)
-	AM_RANGE(0x400000, 0x400003) AM_WRITE(rabbit_eeprom_write)
-	AM_RANGE(0xf00000, 0xffffff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x290000, 0x29bfff) AM_RAM AM_BASE(&rabbit_spriteram)
+	AM_RANGE(0x29c000, 0x29ffff) AM_RAM_WRITE(tmmjprd_paletteram_dword_w) AM_BASE(&paletteram32)
+
+	AM_RANGE(0x400000, 0x400003) AM_READ_PORT("INPUTS") AM_WRITE(rabbit_eeprom_write)
+	AM_RANGE(0xf00000, 0xffffff) AM_RAM
 ADDRESS_MAP_END
 
+
 static INPUT_PORTS_START( rabbit )
 	PORT_START("INPUTS")
 	PORT_BIT( 0x00000001, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL)	// as per code at 4d932
@@ -1047,8 +1021,8 @@ static INTERRUPT_GEN( rabbit_interrupts )
 }
 
 static MACHINE_DRIVER_START( rabbit )
-	MDRV_CPU_ADD("main",M68EC020,24000000) /* 24 MHz */
-	MDRV_CPU_PROGRAM_MAP(rabbit_readmem,rabbit_writemem)
+	MDRV_CPU_ADD("maincpu",M68EC020,24000000) /* 24 MHz */
+	MDRV_CPU_PROGRAM_MAP(rabbit_map)
 	MDRV_CPU_VBLANK_INT_HACK(rabbit_interrupts,262)
 	/* (rabbit) */
 /*  lev 1 : 0x64 : 0000 027c -
@@ -1065,7 +1039,7 @@ static MACHINE_DRIVER_START( rabbit )
 
 
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -1108,14 +1082,10 @@ static VIDEO_START(tmmjprd)
 
 	/* the tilemaps are bigger than the regions the cpu can see, need to allocate the ram here */
 	/* or maybe not for this game/hw .... */
-	rabbit_tilemap_ram[0] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[1] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[2] = auto_malloc(0x20000);
-	rabbit_tilemap_ram[3] = auto_malloc(0x20000);
-	memset(rabbit_tilemap_ram[0], 0, 0x20000);
-	memset(rabbit_tilemap_ram[1], 0, 0x20000);
-	memset(rabbit_tilemap_ram[2], 0, 0x20000);
-	memset(rabbit_tilemap_ram[3], 0, 0x20000);
+	rabbit_tilemap_ram[0] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[1] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[2] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
+	rabbit_tilemap_ram[3] = auto_alloc_array_clear(machine, UINT32, 0x20000/4);
 
 	rabbit_tilemap[0] = tilemap_create(machine, get_tmmjprd_tilemap0_tile_info,tilemap_scan_rows, 8, 8, 64, 64);
 	rabbit_tilemap[1] = tilemap_create(machine, get_tmmjprd_tilemap1_tile_info,tilemap_scan_rows,16, 16, 64, 64);
@@ -1125,7 +1095,7 @@ static VIDEO_START(tmmjprd)
 	tilemap_set_transparent_pen(rabbit_tilemap[1],0x0);
 	tilemap_set_transparent_pen(rabbit_tilemap[2],0x0);
 	tilemap_set_transparent_pen(rabbit_tilemap[3],0x0);
-	rabbit_sprite_bitmap = auto_bitmap_alloc(0x1000,0x1000,video_screen_get_format(machine->primary_screen));
+	rabbit_sprite_bitmap = auto_bitmap_alloc(machine,0x1000,0x1000,video_screen_get_format(machine->primary_screen));
 	rabbit_sprite_clip.min_x = 0;
 	rabbit_sprite_clip.max_x = 0x1000-1;
 	rabbit_sprite_clip.min_y = 0;
@@ -1176,8 +1146,8 @@ static INTERRUPT_GEN( tmmjprd_interrupt )
 
 static MACHINE_DRIVER_START( tmmjprd )
 	MDRV_IMPORT_FROM(rabbit)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(tmmjprd_readmem,tmmjprd_writemem)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(tmmjprd_map)
 	MDRV_CPU_VBLANK_INT_HACK(tmmjprd_interrupt,2)
 
 	MDRV_VIDEO_START(tmmjprd)
@@ -1203,7 +1173,7 @@ static DRIVER_INIT(tmmjprd)
 
 
 ROM_START( rabbit )
-	ROM_REGION( 0x200000, "main", 0 ) /* 68020 Code */
+	ROM_REGION( 0x200000, "maincpu", 0 ) /* 68020 Code */
 	ROM_LOAD32_BYTE( "jpr0.0", 0x000000, 0x080000, CRC(52bb18c0) SHA1(625bc8a4daa6d08cacd92d9110cf67a95a91325a) )
 	ROM_LOAD32_BYTE( "jpr1.1", 0x000001, 0x080000, CRC(38299d0d) SHA1(72ccd51781b47636bb16ac18037cb3121d17199f) )
 	ROM_LOAD32_BYTE( "jpr2.2", 0x000002, 0x080000, CRC(fa3fd91a) SHA1(ac0e658af30b37b752ede833b44ff5423b93bdb1) )
@@ -1238,7 +1208,7 @@ ROM_START( rabbit )
 ROM_END
 
 ROM_START( tmmjprd )
-	ROM_REGION( 0x200000, "main", 0 ) /* 68020 Code - doesn't seem to dsam quite right, bitswap? */
+	ROM_REGION( 0x200000, "maincpu", 0 ) /* 68020 Code - doesn't seem to dsam quite right, bitswap? */
 	ROM_LOAD32_BYTE( "p00.bin", 0x000000, 0x080000, CRC(a1efd960) SHA1(7f41ab58de32777bccbfe28e6e5a1f2dca35bb90) )
 	ROM_LOAD32_BYTE( "p01.bin", 0x000001, 0x080000, CRC(9c325374) SHA1(1ddf1c292fc1bcf4dcefb5d4aa3abdeb1489c020) )
  	ROM_LOAD32_BYTE( "p02.bin", 0x000002, 0x080000, CRC(729a5f12) SHA1(615704d36afdceb4b1ff2e5dc34856e614181e16) )
@@ -1268,6 +1238,38 @@ ROM_START( tmmjprd )
 	ROM_LOAD16_BYTE( "21.bin", 0x0000001, 0x400000, CRC(bb5fa8da) SHA1(620e609b3e2524d06d58844625f186fd4682205f))
 ROM_END
 
+ROM_START( tmpdoki )
+	ROM_REGION( 0x200000, "maincpu", 0 ) /* 68020 Code - doesn't seem to dsam quite right, bitswap? */
+	ROM_LOAD32_BYTE( "u70_p0.bin", 0x000000, 0x080000, CRC(c0ee1942) SHA1(0cebc3e326d84e200c2399208d810c0ac767dbb4) )
+	ROM_LOAD32_BYTE( "u72_p1.bin", 0x000001, 0x080000, CRC(3c1bc6f6) SHA1(7b3719d4bb52e45db793564b0ccee067fd7af4e4) )
+ 	ROM_LOAD32_BYTE( "u71_p2.bin", 0x000002, 0x080000, CRC(f2091cce) SHA1(88c6822eb1546e914c2644264367e71fb2a82be3) )
+	ROM_LOAD32_BYTE( "u73_p3.bin", 0x000003, 0x080000, CRC(cca8ef13) SHA1(d5b077f3d8d38262e69d058a7d61e4563332abce) )
 
-GAME( 1997, rabbit,  0, rabbit,  rabbit,  rabbit,  ROT0, "Electronic Arts / Aorn", "Rabbit", GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND ) // somewhat playable
-GAME( 1997, tmmjprd, 0, tmmjprd, tmmjprd, tmmjprd, ROT0, "Media / Sonnet", "Tokimeki Mahjong Paradise - Dear My Love", GAME_NOT_WORKING | GAME_NO_SOUND )
+	ROM_REGION( 0x2000000, "gfx1", ROMREGION_INVERT ) /* Sprite Roms */
+	ROM_LOAD16_WORD_SWAP( "00.bin", 0x1000000, 0x400000, CRC(303e91a1) SHA1(c29a22061ab8af8b72e0e6bdb36915a0cb5b2a5c) )
+	ROM_LOAD16_WORD_SWAP( "01.bin", 0x1400000, 0x400000, CRC(3371b775) SHA1(131dd850bd01dac52fa82c41948d900c4833db3c) )
+	ROM_LOAD16_WORD_SWAP( "10.bin", 0x1800000, 0x400000, CRC(5ab6af41) SHA1(e29cee23c84e17dd8dabd2ec71e622c25418646e) )
+	ROM_LOAD16_WORD_SWAP( "11.bin", 0x1c00000, 0x400000, CRC(1d1fd633) SHA1(655be5b72bb70a90d23e49512ca84d9978d87b0b) )
+	ROM_LOAD16_WORD_SWAP( "02.bin", 0x0000000, 0x400000, CRC(4c1e13b9) SHA1(d244eb74f755350604824670db58ab2a56a856cb) )
+	ROM_LOAD16_WORD_SWAP( "03.bin", 0x0400000, 0x400000, CRC(9cf86152) SHA1(e27e0d9befb12ad5c2acf547afe80d1c7921a4d1) )
+	ROM_LOAD16_WORD_SWAP( "12.bin", 0x0800000, 0x400000, CRC(5b8bb9d6) SHA1(ee93774077d8a2ddcf70869a9c2f4961219a85b4) )
+	ROM_LOAD16_WORD_SWAP( "13.bin", 0x0c00000, 0x400000, CRC(d950df0a) SHA1(3b109341ab4ad87005113fb481b5d1ed9a82f50f) )
+
+	ROM_REGION( 0x2000000, "gfx2", ROMREGION_INVERT ) /* BG Roms */
+	ROM_LOAD32_WORD( "40.bin", 0x0000000, 0x400000, CRC(8bedc606) SHA1(7159c8b86e8d7d5ae202c239638483ccdc7dfc25) )
+	ROM_LOAD32_WORD( "41.bin", 0x0000002, 0x400000, CRC(e19713dd) SHA1(a8f1b716913f2e391abf277e5bf0e9986cc75898) )
+	ROM_LOAD32_WORD( "50.bin", 0x0800000, 0x400000, CRC(85ca9ce9) SHA1(c5a7270507522e11e9485196be325508846fda90) )
+	ROM_LOAD32_WORD( "51.bin", 0x0800002, 0x400000, CRC(6ba1d2ec) SHA1(bbe7309b33f213c8cb9ab7adb3221ea79f89e8b0) )
+	ROM_LOAD32_WORD( "60.bin", 0x1000000, 0x400000, CRC(7cb132e0) SHA1(f9c366befec46c7f6e307111a62eede029202b16) )
+	ROM_LOAD32_WORD( "61.bin", 0x1000002, 0x400000, CRC(caa7e854) SHA1(592867e001abd0781f83a5124bf9aa62ad1aa7f3) )
+	ROM_LOAD32_WORD( "70.bin", 0x1800000, 0x400000, CRC(9b737ae4) SHA1(0b62a90d42ace81ee32db073a57731a55a32f989) )
+	ROM_LOAD32_WORD( "71.bin", 0x1800002, 0x400000, CRC(189f694e) SHA1(ad0799d4aadade51be38d824910d299257a758a3) )
+
+	ROM_REGION( 0x800000, "unknown", 0 ) /* Sound Roms? */
+	ROM_LOAD16_BYTE( "21.bin", 0x0000001, 0x400000, CRC(bb5fa8da) SHA1(620e609b3e2524d06d58844625f186fd4682205f))
+ROM_END
+
+
+GAME( 1997, rabbit,        0, rabbit,  rabbit,  rabbit,  ROT0, "Electronic Arts / Aorn", "Rabbit", GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND ) // somewhat playable
+GAME( 1997, tmmjprd,       0, tmmjprd, tmmjprd, tmmjprd, ROT0, "Media / Sonnet", "Tokimeki Mahjong Paradise - Dear My Love", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, tmpdoki, tmmjprd, tmmjprd, tmmjprd, tmmjprd, ROT0, "Media / Sonnet", "Tokimeki Mahjong Paradise - Doki Doki Hen", GAME_NOT_WORKING | GAME_NO_SOUND )
