@@ -164,16 +164,15 @@ static ADDRESS_MAP_START( base_mem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x604000, 0x604fff) AM_READWRITE(SMH_RAM,realbrk_vram_2_w) AM_BASE(&realbrk_vram_2	)	// Text         (2)
 	AM_RANGE(0x606000, 0x60600f) AM_READWRITE(SMH_RAM,realbrk_vregs_w) AM_BASE(&realbrk_vregs 	)	// Scroll + Video Regs
 	AM_RANGE(0x605000, 0x61ffff) AM_RAM							               	//
-	AM_RANGE(0x800000, 0x800001) AM_WRITE(ymz280b_register_0_msb_w			)	// YMZ280
-	AM_RANGE(0x800002, 0x800003) AM_READWRITE(ymz280b_status_0_msb_r,ymz280b_data_0_msb_w)	//
+	AM_RANGE(0x800000, 0x800003) AM_DEVREADWRITE8("ymz", ymz280b_r, ymz280b_w, 0xff00)	// YMZ280
 	AM_RANGE(0xfe0000, 0xfeffff) AM_RAM						                 	// RAM
 	AM_RANGE(0xfffc00, 0xffffff) AM_READWRITE(SMH_RAM,tmp68301_regs_w) AM_BASE(&tmp68301_regs	)	// TMP68301 Registers
 ADDRESS_MAP_END
 
 /*realbrk specific memory map*/
 static ADDRESS_MAP_START( realbrk_mem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x800008, 0x800009) AM_WRITE(ym2413_register_port_0_lsb_w		)	// YM2413
-	AM_RANGE(0x80000a, 0x80000b) AM_WRITE(ym2413_data_port_0_lsb_w			)	//
+	AM_IMPORT_FROM(base_mem)
+	AM_RANGE(0x800008, 0x80000b) AM_DEVWRITE8("ym", ym2413_w, 0x00ff)	//
 	AM_RANGE(0xc00000, 0xc00001) AM_READ_PORT("IN0")							// P1 & P2 (Inputs)
 	AM_RANGE(0xc00002, 0xc00003) AM_READ_PORT("IN1")							// Coins
 	AM_RANGE(0xc00004, 0xc00005) AM_READWRITE(realbrk_dsw_r,SMH_RAM) AM_BASE(&realbrk_dsw_select)	// DSW select
@@ -183,32 +182,32 @@ ADDRESS_MAP_END
 
 /*pkgnsh specific memory map*/
 static ADDRESS_MAP_START( pkgnsh_mem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x800008, 0x800009) AM_WRITE(ym2413_register_port_0_msb_w		)	// YM2413
-	AM_RANGE(0x80000a, 0x80000b) AM_WRITE(ym2413_data_port_0_msb_w			)	//
+	AM_RANGE(0x800008, 0x80000b) AM_DEVWRITE8("ym", ym2413_w, 0xff00	)	// YM2413
 	AM_RANGE(0xc00000, 0xc00013) AM_READ(pkgnsh_input_r		        )	// P1 & P2 (Inputs)
 	AM_RANGE(0xff0000, 0xfffbff) AM_READWRITE(backup_ram_r,backup_ram_w) AM_BASE(&backup_ram)	// RAM
+	AM_IMPORT_FROM(base_mem)
 ADDRESS_MAP_END
 
 /*pkgnshdx specific memory map*/
 static ADDRESS_MAP_START( pkgnshdx_mem, ADDRESS_SPACE_PROGRAM, 16)
-	AM_RANGE(0x800008, 0x800009) AM_WRITE(ym2413_register_port_0_lsb_w		)	// YM2413
-	AM_RANGE(0x80000a, 0x80000b) AM_WRITE(ym2413_data_port_0_lsb_w			)	//
+	AM_RANGE(0x800008, 0x80000b) AM_DEVWRITE8("ym", ym2413_w, 0x00ff)	//
 	AM_RANGE(0xc00000, 0xc00013) AM_READ(pkgnshdx_input_r		        )	// P1 & P2 (Inputs)
 	AM_RANGE(0xc00004, 0xc00005) AM_WRITE(SMH_RAM) AM_BASE(&realbrk_dsw_select) // DSW select
 	AM_RANGE(0xff0000, 0xfffbff) AM_READWRITE(backup_ram_dx_r,backup_ram_w) AM_BASE(&backup_ram)	// RAM
+	AM_IMPORT_FROM(base_mem)
 ADDRESS_MAP_END
 
 /*dai2kaku specific memory map*/
 static ADDRESS_MAP_START( dai2kaku_mem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x605000, 0x6053ff) AM_READWRITE(SMH_RAM,SMH_RAM) AM_BASE(&realbrk_vram_0ras)	// rasterinfo   (0)
 	AM_RANGE(0x605400, 0x6057ff) AM_READWRITE(SMH_RAM,SMH_RAM) AM_BASE(&realbrk_vram_1ras)	// rasterinfo   (1)
-	AM_RANGE(0x800008, 0x800009) AM_WRITE(ym2413_register_port_0_lsb_w		)	// YM2413
-	AM_RANGE(0x80000a, 0x80000b) AM_WRITE(ym2413_data_port_0_lsb_w			)	//
+	AM_RANGE(0x800008, 0x80000b) AM_DEVWRITE8("ym", ym2413_w, 0x00ff)	//
 	AM_RANGE(0xc00000, 0xc00001) AM_READ_PORT("IN0")							// P1 & P2 (Inputs)
 	AM_RANGE(0xc00002, 0xc00003) AM_READ_PORT("IN1")							// Coins
 	AM_RANGE(0xc00004, 0xc00005) AM_READWRITE(realbrk_dsw_r,SMH_RAM) AM_BASE(&realbrk_dsw_select)	// DSW select
 	AM_RANGE(0xff0000, 0xfffbff) AM_RAM											// RAM
 	AM_RANGE(0xfffd0a, 0xfffd0b) AM_WRITE(dai2kaku_flipscreen_w				)	// Hack! Parallel port data register
+	AM_IMPORT_FROM(base_mem)
 ADDRESS_MAP_END
 
 /***************************************************************************
@@ -677,14 +676,14 @@ static INTERRUPT_GEN( realbrk_interrupt )
 static MACHINE_DRIVER_START( realbrk )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main",M68000, XTAL_32MHz / 2)			/* !! TMP68301 !! */
-	MDRV_CPU_PROGRAM_MAP(realbrk_mem,base_mem)
-	MDRV_CPU_VBLANK_INT("main", realbrk_interrupt)
+	MDRV_CPU_ADD("maincpu",M68000, XTAL_32MHz / 2)			/* !! TMP68301 !! */
+	MDRV_CPU_PROGRAM_MAP(realbrk_mem)
+	MDRV_CPU_VBLANK_INT("screen", realbrk_interrupt)
 
 	MDRV_MACHINE_RESET( tmp68301 )
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -698,33 +697,33 @@ static MACHINE_DRIVER_START( realbrk )
 	MDRV_VIDEO_UPDATE(realbrk)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
 	MDRV_SOUND_ADD("ymz", YMZ280B, XTAL_33_8688MHz / 2)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(1, "right", 0.50)
+	MDRV_SOUND_ROUTE(0, "lspeaker", 0.50)
+	MDRV_SOUND_ROUTE(1, "rspeaker", 0.50)
 
 	MDRV_SOUND_ADD("ym", YM2413, XTAL_3_579545MHz)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( pkgnsh )
 	MDRV_IMPORT_FROM( realbrk )
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(base_mem,pkgnsh_mem)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(pkgnsh_mem)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( pkgnshdx )
 	MDRV_IMPORT_FROM( realbrk )
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(base_mem,pkgnshdx_mem)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(pkgnshdx_mem)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( dai2kaku )
 	MDRV_IMPORT_FROM( realbrk )
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(base_mem,dai2kaku_mem)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(dai2kaku_mem)
 
 	MDRV_GFXDECODE(dai2kaku)
 	MDRV_VIDEO_UPDATE(dai2kaku)
@@ -823,7 +822,7 @@ Notes:
 ***************************************************************************/
 
 ROM_START( pkgnsh )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "50506.1h", 0x000001, 0x080000, CRC(06949a7d) SHA1(1276c28bc5cebeae749e0cded2da631353efbbb4) )
 	ROM_LOAD16_BYTE( "50505.1k", 0x000000, 0x080000, CRC(26df869f) SHA1(d716e561441da6ae8ca61e17335aab44770157a6) )
 
@@ -904,7 +903,7 @@ OKI M6242 clock: 32.768kHz
 ***************************************************************************/
 
 ROM_START( pkgnshdx )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "52202b.1r", 0x000000, 0x080000, CRC(3c1a10de) SHA1(44a13adec64645aa01e216dfd527b59e7298c732) )
 	ROM_LOAD16_BYTE( "52201b.2r", 0x000001, 0x080000, CRC(d63797ce) SHA1(d1b0b57b5426135e36772be296e94e04822e54ac) )
 
@@ -976,7 +975,7 @@ Vertical Sync: 60Hz
 ***************************************************************************/
 
 ROM_START( realbrk )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "600k02b.1r", 0x000000, 0x080000, CRC(6954ff7f) SHA1(dc17be7dadb2d6acff039d4d6484ee71070e466d) )
 	ROM_LOAD16_BYTE( "600k01b.2r", 0x000001, 0x080000, CRC(6eb865bf) SHA1(07bcdbec8fd8d280b1cdb4b5545607d3a87e2395) )
 
@@ -1002,7 +1001,7 @@ ROM_START( realbrk )
 ROM_END
 
 ROM_START( realbrkj )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "52302.1r", 0x000000, 0x080000, CRC(ab0379b0) SHA1(67af6670f2b37a7d4d6e03508f291f8ffe64d4cb) )
 	ROM_LOAD16_BYTE( "52301.2r", 0x000001, 0x080000, CRC(9cc1596e) SHA1(a598f18eaac1ed6943069e9500b07b77e263f0d0) )
 
@@ -1028,7 +1027,7 @@ ROM_START( realbrkj )
 ROM_END
 
 ROM_START( realbrkk )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "600k_02b", 0x000000, 0x080000, CRC(fdca08b1) SHA1(69b35c85b1842d0a8c98fc519b46c72954322ceb) )
 	ROM_LOAD16_BYTE( "600k_01b", 0x000001, 0x080000, CRC(b6fe8998) SHA1(86f7d6067e007de50a02478a0e583ab64408bc4f) )
 
@@ -1056,7 +1055,7 @@ ROM_END
 // Team Japump board:
 
 ROM_START( dai2kaku )
-	ROM_REGION( 0x100000, "main", 0 )		/* TMP68301 Code */
+	ROM_REGION( 0x100000, "maincpu", 0 )		/* TMP68301 Code */
 	ROM_LOAD16_BYTE( "52201b.2r", 0x000000, 0x080000, CRC(5672cbe6) SHA1(4379edd0725e1b8cd5b3f9201e484487eccd1714) )
 	ROM_LOAD16_BYTE( "52202b.1r", 0x000001, 0x080000, CRC(e45d6368) SHA1(5fb39b7c2e0fd474e7c366279f616b9244e6cf2e) )
 
@@ -1144,7 +1143,7 @@ This dump matches the already supported set, except for rom sizes:
 */
 #if 0
 ROM_START( dai2kaku_alt_rom_size )
-	ROM_REGION( 0x100000, "main", 0 )
+	ROM_REGION( 0x100000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "1r", 0x000000, 0x080000, CRC(5672cbe6) SHA1(4379edd0725e1b8cd5b3f9201e484487eccd1714) )
 	ROM_LOAD16_BYTE( "2r", 0x000001, 0x080000, CRC(e45d6368) SHA1(5fb39b7c2e0fd474e7c366279f616b9244e6cf2e) )
 
