@@ -134,11 +134,11 @@ static READ8_HANDLER( samples_r )
 	return memory_region(space->machine, "adpcm")[offset];
 }
 
-static WRITE8_HANDLER( adpcm_w )
+static WRITE8_DEVICE_HANDLER( adpcm_w )
 {
-	msm5205_data_w(0,data);         /* bit0..3  */
-	msm5205_reset_w(0,(data>>5)&1); /* bit 5    */
-	msm5205_vclk_w (0,(data>>4)&1); /* bit4     */
+	msm5205_data_w(device,data);         /* bit0..3  */
+	msm5205_reset_w(device,(data>>5)&1); /* bit 5    */
+	msm5205_vclk_w (device,(data>>4)&1); /* bit4     */
 }
 
 static WRITE8_HANDLER( ctrl_w )
@@ -157,7 +157,7 @@ static WRITE8_HANDLER( ctrl_w )
 
 static WRITE8_HANDLER( themj_rombank_w )
 {
-	UINT8 *rom = memory_region(space->machine, "main") + 0x10000;
+	UINT8 *rom = memory_region(space->machine, "maincpu") + 0x10000;
 	int bank = data & 0x03;
 logerror("banksw %d\n",bank);
 	memory_set_bankptr(space->machine, 1, rom + bank*0x4000);
@@ -166,66 +166,60 @@ logerror("banksw %d\n",bank);
 
 static MACHINE_RESET( themj )
 {
-	themj_rombank_w(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_IO),0,0);
+	themj_rombank_w(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0, 0);
 }
 
 
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_READ(SMH_ROM)
-	AM_RANGE(0xa000, 0xa7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xa800, 0xb7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)	/* rmhaisei only */
+static ADDRESS_MAP_START( rmhaihai_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x9fff) AM_ROM
+	AM_RANGE(0xa000, 0xa7ff) AM_RAM
+	AM_RANGE(0xa800, 0xafff) AM_RAM_WRITE(rmhaihai_colorram_w) AM_BASE(&colorram)
+	AM_RANGE(0xb000, 0xb7ff) AM_RAM_WRITE(rmhaihai_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xb83c, 0xb83c) AM_WRITENOP	// ??
+	AM_RANGE(0xbc00, 0xbc00) AM_WRITENOP	// ??
+	AM_RANGE(0xc000, 0xdfff) AM_ROM
+	AM_RANGE(0xe000, 0xffff) AM_ROM			/* rmhaisei only */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( themj_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-	AM_RANGE(0x8000, 0x9fff) AM_READ(SMH_BANK1)
-	AM_RANGE(0xa000, 0xa7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xa800, 0xb7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_BANK2)
-	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xa800, 0xafff) AM_WRITE(rmhaihai_colorram_w) AM_BASE(&colorram)
-	AM_RANGE(0xb000, 0xb7ff) AM_WRITE(rmhaihai_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xb83c, 0xb83c) AM_WRITE(SMH_NOP)	// ??
-	AM_RANGE(0xbc00, 0xbc00) AM_WRITE(SMH_NOP)	// ??
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_ROM)	/* rmhaisei only */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( rmhaihai_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(samples_r)
 	AM_RANGE(0x8000, 0x8000) AM_READWRITE(keyboard_r, SMH_NOP)	// ??
 	AM_RANGE(0x8001, 0x8001) AM_READWRITE(SMH_NOP, keyboard_w)	// ??
-	AM_RANGE(0x8020, 0x8020) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
-	AM_RANGE(0x8021, 0x8021) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x8040, 0x8040) AM_WRITE(adpcm_w)
+	AM_RANGE(0x8020, 0x8020) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x8020, 0x8021) AM_DEVWRITE("ay", ay8910_address_data_w)
+	AM_RANGE(0x8040, 0x8040) AM_DEVWRITE("msm", adpcm_w)
 	AM_RANGE(0x8060, 0x8060) AM_WRITE(ctrl_w)
-	AM_RANGE(0x8080, 0x8080) AM_WRITE(SMH_NOP)	// ??
-	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(SMH_NOP)	// ??
-	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0x8080, 0x8080) AM_WRITENOP	// ??
+	AM_RANGE(0xbc04, 0xbc04) AM_WRITENOP	// ??
+	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITENOP	// ??
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( themj_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0x9fff) AM_ROMBANK(1)
+	AM_RANGE(0xa000, 0xa7ff) AM_RAM
+	AM_RANGE(0xa800, 0xafff) AM_RAM_WRITE(rmhaihai_colorram_w) AM_BASE(&colorram)
+	AM_RANGE(0xb000, 0xb7ff) AM_RAM_WRITE(rmhaihai_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xc000, 0xdfff) AM_ROMBANK(2)
+	AM_RANGE(0xe000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( themj_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(samples_r)
 	AM_RANGE(0x8000, 0x8000) AM_READWRITE(keyboard_r, SMH_NOP)	// ??
 	AM_RANGE(0x8001, 0x8001) AM_READWRITE(SMH_NOP, keyboard_w)	// ??
-	AM_RANGE(0x8020, 0x8020) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
-	AM_RANGE(0x8021, 0x8021) AM_WRITE(ay8910_write_port_0_w)
-	AM_RANGE(0x8040, 0x8040) AM_WRITE(adpcm_w)
+	AM_RANGE(0x8020, 0x8020) AM_DEVREAD("ay", ay8910_r)
+	AM_RANGE(0x8020, 0x8021) AM_DEVWRITE("ay", ay8910_address_data_w)
+	AM_RANGE(0x8040, 0x8040) AM_DEVWRITE("msm", adpcm_w)
 	AM_RANGE(0x8060, 0x8060) AM_WRITE(ctrl_w)
-	AM_RANGE(0x8080, 0x8080) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0x8080, 0x8080) AM_WRITENOP	// ??
 	AM_RANGE(0x80a0, 0x80a0) AM_WRITE(themj_rombank_w)
-	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(SMH_NOP)	// ??
-	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xbc04, 0xbc04) AM_WRITENOP	// ??
+	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITENOP	// ??
 ADDRESS_MAP_END
 
+
 static INPUT_PORTS_START( mjctrl )
 	PORT_START("KEY0")		// fake, handled by keyboard_r()
 	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
@@ -415,11 +409,11 @@ static const gfx_layout charlayout =
 	16*8
 };
 
-static GFXDECODE_START( 1 )
+static GFXDECODE_START( rmhaihai )
 	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 32 )
 GFXDECODE_END
 
-static GFXDECODE_START( 2 )
+static GFXDECODE_START( themj )
 	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 64 )
 GFXDECODE_END
 
@@ -429,8 +423,8 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	input_port_0_r,
-	input_port_1_r
+	DEVCB_INPUT_PORT("DSW2"),
+	DEVCB_INPUT_PORT("DSW1")
 };
 
 static const msm5205_interface msm5205_config =
@@ -444,20 +438,20 @@ static const msm5205_interface msm5205_config =
 static MACHINE_DRIVER_START( rmhaihai )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main",Z80,20000000/4)	/* 5 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(io_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
+	MDRV_CPU_ADD("maincpu",Z80,20000000/4)	/* 5 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(rmhaihai_map)
+	MDRV_CPU_IO_MAP(rmhaihai_io_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(4*8, 60*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(1)
+	MDRV_GFXDECODE(rmhaihai)
 	MDRV_PALETTE_LENGTH(0x100)
 
 	MDRV_PALETTE_INIT(RRRR_GGGG_BBBB)
@@ -482,7 +476,7 @@ static MACHINE_DRIVER_START( rmhaisei )
 	MDRV_IMPORT_FROM(rmhaihai)
 
 	/* video hardware */
-	MDRV_GFXDECODE(2)
+	MDRV_GFXDECODE(themj)
 	MDRV_PALETTE_LENGTH(0x200)
 MACHINE_DRIVER_END
 
@@ -491,14 +485,14 @@ static MACHINE_DRIVER_START( themj )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(rmhaihai)
 
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(themj_readmem,writemem)
-	MDRV_CPU_IO_MAP(themj_io_map,0)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(themj_map)
+	MDRV_CPU_IO_MAP(themj_io_map)
 
 	MDRV_MACHINE_RESET(themj)
 
 	/* video hardware */
-	MDRV_GFXDECODE(2)
+	MDRV_GFXDECODE(themj)
 	MDRV_PALETTE_LENGTH(0x200)
 MACHINE_DRIVER_END
 
@@ -511,7 +505,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( rmhaihai )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "s3-6.11g",     0x00000, 0x2000, CRC(e7af7ba2) SHA1(1b0f87a16006a96e5b59e055966addac3e2ca926) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "s3-4.8g",      0x04000, 0x2000, CRC(f849e75c) SHA1(4636bcaa7cddb9bc012212098a25f3c57cfc6b51) )
@@ -538,7 +532,7 @@ ROM_START( rmhaihai )
 ROM_END
 
 ROM_START( rmhaihib )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "s-30-6.11g",   0x00000,  0x2000, CRC(f3e13cc8) SHA1(7eb9b17ea9efb5b2891ec40a9ff9744e84c0511c) )
 	ROM_CONTINUE(             0x06000,  0x2000 )
 	ROM_LOAD( "s-30-4.8g",    0x04000,  0x2000, CRC(f6642584) SHA1(5160baf267fd5dd8385ea5a9ff82e9c220fee342) )
@@ -565,7 +559,7 @@ ROM_START( rmhaihib )
 ROM_END
 
 ROM_START( rmhaijin )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "s-4-6.11g",    0x00000, 0x2000, CRC(474c9ace) SHA1(9161a5c64054f079d57676f3d7f61ca149018f61) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "s-4-4.8g",     0x04000, 0x2000, CRC(c76ab584) SHA1(7d76fa6166108d6a511d5311c0d34b55364afec1) )
@@ -592,7 +586,7 @@ ROM_START( rmhaijin )
 ROM_END
 
 ROM_START( rmhaisei )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "sei-11.h11",   0x00000, 0x2000, CRC(7c35692b) SHA1(8890ca90ae84c63bfd2b4857bbdd02bd9a2f29a9) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "sei-10.h8",    0x04000, 0x2000, CRC(cbd58124) SHA1(562eb13c2dc441294b1b7dafe37ac27a9b7bba2b) )
@@ -620,7 +614,7 @@ ROM_START( rmhaisei )
 ROM_END
 
 ROM_START( themj )
-	ROM_REGION( 0x20000, "main", 0 ) /* CPU */
+	ROM_REGION( 0x20000, "maincpu", 0 ) /* CPU */
 	ROM_LOAD( "t7.bin",       0x00000,  0x02000, CRC(a58563c3) SHA1(53faeb66606214eb97ef8ff9affe68705e18a0b3) )
 	ROM_CONTINUE(             0x06000,  0x02000 )
 	ROM_LOAD( "t8.bin",       0x04000,  0x02000, CRC(bdf29475) SHA1(6296561da9c3a299d69bba8a98362c40b677ea9a) )
