@@ -27,26 +27,31 @@ extern WRITE8_HANDLER( runaway_paletteram_w );
 extern WRITE8_HANDLER( runaway_video_ram_w );
 extern WRITE8_HANDLER( runaway_tile_bank_w );
 
+static emu_timer *interrupt_timer;
 
 static TIMER_CALLBACK( interrupt_callback )
 {
 	/* assume Centipede-style interrupt timing */
 	int scanline = param;
 
-	cpu_set_input_line(machine->cpu[0], 0, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 0, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
 
 	scanline += 32;
 
 	if (scanline >= 263)
 		scanline = 16;
 
-	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), NULL, scanline, interrupt_callback);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
+static MACHINE_START( runaway )
+{
+	interrupt_timer = timer_alloc(machine, interrupt_callback, NULL);
+}
 
 static MACHINE_RESET( runaway )
 {
-	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, 16, 0), NULL, 16, interrupt_callback);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, 16, 0), 16);
 }
 
 
@@ -67,9 +72,9 @@ static READ8_HANDLER( runaway_input_r )
 }
 
 
-static READ8_HANDLER( runaway_pot_r )
+static READ8_DEVICE_HANDLER( runaway_pot_r )
 {
-	return (input_port_read(space->machine, "7000") << (7 - offset)) & 0x80;
+	return (input_port_read(device->machine, "7000") << (7 - offset)) & 0x80;
 }
 
 
@@ -81,38 +86,30 @@ static WRITE8_HANDLER( runaway_led_w )
 
 static WRITE8_HANDLER( runaway_irq_ack_w )
 {
-	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
 }
 
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_READ(SMH_RAM)
-	AM_RANGE(0x0400, 0x07ff) AM_READ(SMH_RAM)
-	AM_RANGE(0x3000, 0x3007) AM_READ(runaway_input_r)
-	AM_RANGE(0x4000, 0x4000) AM_READ_PORT("4000")
-	AM_RANGE(0x5000, 0x5000) AM_READ(atari_vg_earom_r)
-	AM_RANGE(0x6000, 0x600f) AM_READ(pokey1_r)
-	AM_RANGE(0x7000, 0x700f) AM_READ(pokey2_r)
-	AM_RANGE(0x8000, 0xcfff) AM_READ(SMH_ROM)
-	AM_RANGE(0xf000, 0xffff) AM_READ(SMH_ROM)	/* for the interrupt vectors */
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x0400, 0x07bf) AM_WRITE(runaway_video_ram_w) AM_BASE(&runaway_video_ram)
-	AM_RANGE(0x07c0, 0x07ff) AM_WRITE(SMH_RAM) AM_BASE(&runaway_sprite_ram)
+static ADDRESS_MAP_START( runaway_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x03ff) AM_RAM
+	AM_RANGE(0x0400, 0x07bf) AM_RAM_WRITE(runaway_video_ram_w) AM_BASE(&runaway_video_ram)
+	AM_RANGE(0x07c0, 0x07ff) AM_RAM AM_BASE(&runaway_sprite_ram)
 	AM_RANGE(0x1000, 0x1000) AM_WRITE(runaway_irq_ack_w)
-	AM_RANGE(0x1400, 0x143F) AM_WRITE(atari_vg_earom_w)
-	AM_RANGE(0x1800, 0x1800) AM_WRITE(atari_vg_earom_ctrl_w)
+	AM_RANGE(0x1400, 0x143f) AM_DEVWRITE("earom", atari_vg_earom_w)
+	AM_RANGE(0x1800, 0x1800) AM_DEVWRITE("earom", atari_vg_earom_ctrl_w)
 	AM_RANGE(0x1c00, 0x1c0f) AM_WRITE(runaway_paletteram_w)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(SMH_NOP) /* coin counter? */
-	AM_RANGE(0x2001, 0x2001) AM_WRITE(SMH_NOP) /* coin counter? */
+	AM_RANGE(0x2000, 0x2000) AM_WRITENOP /* coin counter? */
+	AM_RANGE(0x2001, 0x2001) AM_WRITENOP /* coin counter? */
 	AM_RANGE(0x2003, 0x2004) AM_WRITE(runaway_led_w)
 	AM_RANGE(0x2005, 0x2005) AM_WRITE(runaway_tile_bank_w)
-	AM_RANGE(0x6000, 0x600f) AM_WRITE(pokey1_w)
-	AM_RANGE(0x7000, 0x700f) AM_WRITE(pokey2_w)
-	AM_RANGE(0x8000, 0xcfff) AM_WRITE(SMH_ROM)
+
+	AM_RANGE(0x3000, 0x3007) AM_READ(runaway_input_r)
+	AM_RANGE(0x4000, 0x4000) AM_READ_PORT("4000")
+	AM_RANGE(0x5000, 0x5000) AM_DEVREAD("earom", atari_vg_earom_r)
+	AM_RANGE(0x6000, 0x600f) AM_DEVREADWRITE("pokey1", pokey_r,pokey_w)
+	AM_RANGE(0x7000, 0x700f) AM_DEVREADWRITE("pokey2", pokey_r,pokey_w)
+	AM_RANGE(0x8000, 0xcfff) AM_ROM
+	AM_RANGE(0xf000, 0xffff) AM_ROM	/* for the interrupt vectors */
 ADDRESS_MAP_END
 
 
@@ -340,27 +337,38 @@ GFXDECODE_END
 
 static const pokey_interface pokey_interface_1 =
 {
-	{ 0 },
-	input_port_3_r
+	{ DEVCB_NULL },
+	DEVCB_INPUT_PORT("6008")
 };
 
 static const pokey_interface pokey_interface_2 =
 {
-	{ runaway_pot_r,runaway_pot_r,runaway_pot_r,runaway_pot_r,runaway_pot_r,runaway_pot_r,runaway_pot_r,runaway_pot_r }
+	{
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r),
+		DEVCB_HANDLER(runaway_pot_r)
+	}
 };
 
 
 static MACHINE_DRIVER_START( runaway )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6502, 12096000 / 8) /* ? */
-	MDRV_CPU_PROGRAM_MAP(readmem, writemem)
+	MDRV_CPU_ADD("maincpu", M6502, 12096000 / 8) /* ? */
+	MDRV_CPU_PROGRAM_MAP(runaway_map)
 
+	MDRV_MACHINE_START(runaway)
 	MDRV_MACHINE_RESET(runaway)
-	MDRV_NVRAM_HANDLER(atari_vg)
+
+	MDRV_ATARIVGEAROM_ADD("earom")
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 263)
@@ -400,7 +408,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( runaway )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "choo8000.d1", 0x8000, 0x1000, CRC(35794abe) SHA1(5ce872bda8bb2ed4888ba8b47ecd1afbe24b22eb) )
 	ROM_LOAD( "choo9000.d1", 0x9000, 0x1000, CRC(0d63756d) SHA1(2549a57ca106635f5c53ea1b03f5a0d6e901ab47) )
 	ROM_LOAD( "chooa000.e1", 0xa000, 0x1000, CRC(e6806b6b) SHA1(c260eaa35cbc46f0c0fd4006ec6d04315c3bb851) )
@@ -416,7 +424,7 @@ ROM_END
 
 
 ROM_START( qwak )
-	ROM_REGION( 0x10000, "main", 0 )
+	ROM_REGION( 0x10000, "maincpu", 0 )
 	ROM_LOAD( "qwak8000.bin", 0x8000, 0x1000, CRC(4d002d8a) SHA1(8621e7ec1ab3cb8d003858227e858354cd79dbf1) )
 	ROM_LOAD( "qwak9000.bin", 0x9000, 0x1000, CRC(e0c78fd7) SHA1(f5f397950971d12a7ae47fc64aa8f5751463b8a5) )
 	ROM_LOAD( "qwaka000.bin", 0xa000, 0x1000, CRC(e5770fc9) SHA1(c9556e9c2f7b6c37755ac9f10d95027118317b4a) )
@@ -431,5 +439,5 @@ ROM_START( qwak )
 ROM_END
 
 
-GAME( 1982, qwak,    0, qwak,    qwak,    0, ROT270, "Atari", "Qwak (prototype)", 0 )
-GAME( 1982, runaway, 0, runaway, runaway, 0, ROT0,   "Atari", "Runaway (prototype)", 0 )
+GAME( 1982, qwak,    0, qwak,    qwak,    0, ROT270, "Atari", "Qwak (prototype)", GAME_SUPPORTS_SAVE )
+GAME( 1982, runaway, 0, runaway, runaway, 0, ROT0,   "Atari", "Runaway (prototype)", GAME_SUPPORTS_SAVE )
