@@ -59,12 +59,12 @@ static WRITE8_HANDLER(sangho_ram_w)
 	sangho_ram[offset]=data;
 }
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( pzlestar_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_WRITE(sangho_ram_w)
-	AM_RANGE(0x0000, 0x3fff) AM_READ( SMH_BANK1 )
-	AM_RANGE(0x4000, 0x7fff) AM_READ( SMH_BANK2 )
-	AM_RANGE(0x8000, 0xbfff) AM_READ( SMH_BANK3 )
-	AM_RANGE(0xc000, 0xffff) AM_READ( SMH_BANK4 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROMBANK(1)
+	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK(2)
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(3)
+	AM_RANGE(0xc000, 0xffff) AM_ROMBANK(4)
 ADDRESS_MAP_END
 
 /* Wrong ! */
@@ -78,8 +78,7 @@ static WRITE8_HANDLER(pzlestar_bank_w)
 
 static ADDRESS_MAP_START( pzlestar_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE( 0x7c, 0x7c) AM_WRITE( ym2413_register_port_0_w )
-	AM_RANGE( 0x7d, 0x7d) AM_WRITE( ym2413_data_port_0_w )
+	AM_RANGE( 0x7c, 0x7d) AM_DEVWRITE( "ym", ym2413_w )
 	AM_RANGE( 0x91, 0x91) AM_WRITE( pzlestar_bank_w )
 	AM_RANGE( 0x98, 0x98) AM_READWRITE( v9938_0_vram_r, v9938_0_vram_w )
 	AM_RANGE( 0x99, 0x99) AM_READWRITE( v9938_0_status_r, v9938_0_command_w )
@@ -101,8 +100,7 @@ static ADDRESS_MAP_START( sexyboom_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE( 0xf1, 0xf1) AM_READ( v9938_0_status_r )
 
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE( 0x7c, 0x7c) AM_WRITE( ym2413_register_port_0_w )
-	AM_RANGE( 0x7d, 0x7d) AM_WRITE( ym2413_data_port_0_w )
+	AM_RANGE( 0x7c, 0x7d) AM_DEVWRITE( "ym", ym2413_w )
 	AM_RANGE( 0xf0, 0xf0) AM_WRITE( v9938_0_vram_w )
 	AM_RANGE( 0xf1, 0xf1) AM_WRITE( v9938_0_command_w )
 	AM_RANGE( 0xf2, 0xf2) AM_WRITE( v9938_0_palette_w )
@@ -205,7 +203,7 @@ static MACHINE_RESET(sexyboom)
 
 static void msx_vdp_interrupt(running_machine *machine, int i)
 {
-	cpu_set_input_line (machine->cpu[0], 0, (i ? HOLD_LINE : CLEAR_LINE));
+	cputag_set_input_line (machine, "maincpu", 0, (i ? HOLD_LINE : CLEAR_LINE));
 }
 
 static INTERRUPT_GEN( sangho_interrupt )
@@ -224,14 +222,14 @@ static VIDEO_START( sangho )
 
 static MACHINE_DRIVER_START(pzlestar)
 
-	MDRV_CPU_ADD("main", Z80,8000000) // ?
-	MDRV_CPU_PROGRAM_MAP(readmem, 0)
-	MDRV_CPU_IO_MAP(pzlestar_io_map,0)
+	MDRV_CPU_ADD("maincpu", Z80,8000000) // ?
+	MDRV_CPU_PROGRAM_MAP(pzlestar_map)
+	MDRV_CPU_IO_MAP(pzlestar_io_map)
 	MDRV_CPU_VBLANK_INT_HACK(sangho_interrupt,262)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -257,14 +255,14 @@ MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START(sexyboom )
 
-	MDRV_CPU_ADD("main", Z80,8000000) // ?
-	MDRV_CPU_PROGRAM_MAP(readmem, 0)
-	MDRV_CPU_IO_MAP(sexyboom_io_map,0)
+	MDRV_CPU_ADD("maincpu", Z80,8000000) // ?
+	MDRV_CPU_PROGRAM_MAP(pzlestar_map)
+	MDRV_CPU_IO_MAP(sexyboom_io_map)
 	MDRV_CPU_VBLANK_INT_HACK(sangho_interrupt,262)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -326,9 +324,8 @@ ROM_END
 
 static DRIVER_INIT(sangho)
 {
-	sangho_ram = auto_malloc(0x20000);
+	sangho_ram = auto_alloc_array(machine, UINT8, 0x20000);
 }
 
 GAME( 1991, pzlestar,  0,    pzlestar, sangho, sangho, ROT270, "Sang Ho Soft", "Puzzle Star (Sang Ho Soft)", GAME_NOT_WORKING )
 GAME( 1992, sexyboom,  0,    sexyboom, sangho, sangho, ROT270, "Sang Ho Soft", "Sexy Boom", GAME_NOT_WORKING | GAME_NO_SOUND )
-
