@@ -84,7 +84,7 @@ static READ8_DEVICE_HANDLER( ppi_port_b_r )
 	return 0xff;
 }
 
-void sfkick_remap_banks(running_machine *machine)
+static void sfkick_remap_banks(running_machine *machine)
 {
 	/* 0000-3ffff */
 	switch(sfkick_bank_cfg&3)
@@ -92,24 +92,24 @@ void sfkick_remap_banks(running_machine *machine)
 		case 0: /* bios */
 		{
 			UINT8 *mem = memory_region(machine, "bios");
-			memory_set_bankptr (machine, 1, mem);
-			memory_set_bankptr (machine,2, mem+0x2000);
+			memory_set_bankptr(machine,1, mem);
+			memory_set_bankptr(machine,2, mem+0x2000);
 		}
 		break;
 
 		case 1: /* ext rom */
 		{
 			UINT8 *mem = memory_region(machine, "extrom");
-			memory_set_bankptr (machine,1, mem+0x4000);
-			memory_set_bankptr (machine,2, mem+0x6000);
+			memory_set_bankptr(machine,1, mem+0x4000);
+			memory_set_bankptr(machine,2, mem+0x6000);
 		}
 		break;
 
 		case 2: /* banked */
 		{
 			UINT8 *mem = memory_region(machine, "banked");
-			memory_set_bankptr (machine,1, mem+0x2000*sfkick_bank[0]);
-			memory_set_bankptr (machine,2, mem+0x2000*sfkick_bank[1]);
+			memory_set_bankptr(machine,1, mem+0x2000*sfkick_bank[0]);
+			memory_set_bankptr(machine,2, mem+0x2000*sfkick_bank[1]);
 		}
 		break;
 
@@ -128,8 +128,8 @@ void sfkick_remap_banks(running_machine *machine)
 		case 0: /* bios - upper part */
 		{
 			UINT8 *mem = memory_region(machine, "bios");
-			memory_set_bankptr (machine,3, mem+0x4000);
-			memory_set_bankptr (machine,4, mem+0x6000);
+			memory_set_bankptr(machine,3, mem+0x4000);
+			memory_set_bankptr(machine,4, mem+0x6000);
 		}
 		break;
 
@@ -145,8 +145,8 @@ void sfkick_remap_banks(running_machine *machine)
 		case 2: /* banked */
 		{
 			UINT8 *mem = memory_region(machine, "banked");
-			memory_set_bankptr (machine,3, mem+0x2000*sfkick_bank[2]);
-			memory_set_bankptr (machine,4, mem+0x2000*sfkick_bank[3]);
+			memory_set_bankptr(machine,3, mem+0x2000*sfkick_bank[2]);
+			memory_set_bankptr(machine,4, mem+0x2000*sfkick_bank[3]);
 		}
 		break;
 	}
@@ -174,8 +174,8 @@ void sfkick_remap_banks(running_machine *machine)
 		case 2: /* banked */
 		{
 			UINT8 *mem = memory_region(machine, "banked");
-			memory_set_bankptr (machine,5, mem+0x2000*sfkick_bank[4]);
-			memory_set_bankptr (machine,6, mem+0x2000*sfkick_bank[5]);
+			memory_set_bankptr(machine,5, mem+0x2000*sfkick_bank[4]);
+			memory_set_bankptr(machine,6, mem+0x2000*sfkick_bank[5]);
 		}
 		break;
 	}
@@ -195,8 +195,8 @@ void sfkick_remap_banks(running_machine *machine)
 		case 2: /* banked */
 		{
 			UINT8 *mem = memory_region(machine, "banked");
-			memory_set_bankptr (machine,7, mem+0x2000*sfkick_bank[6]);
-			memory_set_bankptr (machine,8, mem+0x2000*sfkick_bank[7]);
+			memory_set_bankptr(machine,7, mem+0x2000*sfkick_bank[6]);
+			memory_set_bankptr(machine,8, mem+0x2000*sfkick_bank[7]);
 		}
 		break;
 
@@ -293,25 +293,22 @@ static WRITE8_HANDLER(page3_w)
 	}
 }
 
-static ADDRESS_MAP_START (readmem, ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x0000, 0x1fff) AM_READ( SMH_BANK1 )
-	AM_RANGE( 0x2000, 0x3fff) AM_READ( SMH_BANK2 )
-	AM_RANGE( 0x4000, 0x5fff) AM_READ( SMH_BANK3 )
-	AM_RANGE( 0x6000, 0x7fff) AM_READ( SMH_BANK4 )
-	AM_RANGE( 0x8000, 0x9fff) AM_READ( SMH_BANK5 )
-	AM_RANGE( 0xa000, 0xbfff) AM_READ( SMH_BANK6 )
-	AM_RANGE( 0xc000, 0xdfff) AM_READ( SMH_BANK7 )
-	AM_RANGE( 0xe000, 0xffff) AM_READ( SMH_BANK8 )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem , ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START( sfkick_map, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x1fff) AM_ROMBANK(1)
+	AM_RANGE( 0x2000, 0x3fff) AM_ROMBANK(2)
+	AM_RANGE( 0x4000, 0x5fff) AM_ROMBANK(3)
+	AM_RANGE( 0x6000, 0x7fff) AM_ROMBANK(4)
+	AM_RANGE( 0x8000, 0x9fff) AM_ROMBANK(5)
+	AM_RANGE( 0xa000, 0xbfff) AM_ROMBANK(6)
+	AM_RANGE( 0xc000, 0xdfff) AM_ROMBANK(7)
+	AM_RANGE( 0xe000, 0xffff) AM_ROMBANK(8)
 	AM_RANGE( 0x0000, 0x3fff) AM_WRITE( page0_w )
 	AM_RANGE( 0x4000, 0x7fff) AM_WRITE( page1_w )
 	AM_RANGE( 0x8000, 0xbfff) AM_WRITE( page2_w )
 	AM_RANGE( 0xc000, 0xffff) AM_WRITE( page3_w )
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START (main_io, ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START( sfkick_io_map, ADDRESS_SPACE_IO, 8)
 	ADDRESS_MAP_UNMAP_HIGH
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE( 0xa0, 0xa7) AM_WRITE( soundlatch_w )
@@ -319,19 +316,18 @@ static ADDRESS_MAP_START (main_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE( 0x99, 0x99) AM_READWRITE( v9938_0_status_r, v9938_0_command_w )
 	AM_RANGE( 0x9a, 0x9a) AM_WRITE( v9938_0_palette_w )
 	AM_RANGE( 0x9b, 0x9b) AM_WRITE( v9938_0_register_w )
-	AM_RANGE( 0xa8, 0xab) AM_DEVREADWRITE(PPI8255, "ppi8255", ppi8255_r, ppi8255_w)
+	AM_RANGE( 0xa8, 0xab) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_mem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sfkick_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START (sound_io, ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START( sfkick_sound_io_map, ADDRESS_SPACE_IO, 8)
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch_r)
-	AM_RANGE(0x04, 0x04) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
-	AM_RANGE(0x05, 0x05) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
+	AM_RANGE(0x04, 0x05) AM_DEVREADWRITE("ym1", ym2203_r, ym2203_w)
 ADDRESS_MAP_END
 
 static WRITE8_DEVICE_HANDLER ( ppi_port_c_w )
@@ -341,12 +337,12 @@ static WRITE8_DEVICE_HANDLER ( ppi_port_c_w )
 
 static const ppi8255_interface ppi8255_intf =
 {
-	NULL,
-	ppi_port_b_r,
-	NULL,
-	ppi_port_a_w,
-	NULL,
-	ppi_port_c_w
+	DEVCB_NULL,
+	DEVCB_HANDLER(ppi_port_b_r),
+	DEVCB_NULL,
+	DEVCB_HANDLER(ppi_port_a_w),
+	DEVCB_NULL,
+	DEVCB_HANDLER(ppi_port_c_w)
 
 };
 
@@ -414,10 +410,10 @@ INPUT_PORTS_END
 
 static void sfkick_vdp_interrupt(running_machine *machine, int i)
 {
-	cpu_set_input_line (machine->cpu[0], 0, (i ? HOLD_LINE : CLEAR_LINE));
+	cputag_set_input_line (machine, "maincpu", 0, (i ? HOLD_LINE : CLEAR_LINE));
 }
 
-VIDEO_START( sfkick )
+static VIDEO_START( sfkick )
 {
 	VIDEO_START_CALL(generic_bitmapped);
 	v9938_init (machine, 0, machine->primary_screen, tmpbitmap, MODEL_V9938, 0x80000, sfkick_vdp_interrupt);
@@ -443,9 +439,9 @@ static INTERRUPT_GEN( sfkick_interrupt )
 {
 	v9938_interrupt(device->machine, 0);
 }
-static void irqhandler(running_machine *machine, int irq)
+static void irqhandler(const device_config *device, int irq)
 {
-	cpu_set_input_line_and_vector(machine->cpu[1], 0, irq ? ASSERT_LINE : CLEAR_LINE, 0xff);
+	cputag_set_input_line_and_vector(device->machine, "soundcpu", 0, irq ? ASSERT_LINE : CLEAR_LINE, 0xff);
 }
 
 static const ym2203_interface ym2203_config =
@@ -453,25 +449,25 @@ static const ym2203_interface ym2203_config =
 	{
 		AY8910_LEGACY_OUTPUT,
 		AY8910_DEFAULT_LOADS,
-		0,0,0,0,
+		DEVCB_NULL,DEVCB_NULL,DEVCB_NULL,DEVCB_NULL,
 	},
 	irqhandler
 };
 
 static MACHINE_DRIVER_START( sfkick )
 
-	MDRV_CPU_ADD("main",Z80,MASTER_CLOCK/6)
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(main_io,0)
+	MDRV_CPU_ADD("maincpu",Z80,MASTER_CLOCK/6)
+	MDRV_CPU_PROGRAM_MAP(sfkick_map)
+	MDRV_CPU_IO_MAP(sfkick_io_map)
 	MDRV_CPU_VBLANK_INT_HACK(sfkick_interrupt,262)
 
 	MDRV_QUANTUM_TIME(HZ(60000))
 
-	MDRV_CPU_ADD("sound",Z80,MASTER_CLOCK/6)
-	MDRV_CPU_PROGRAM_MAP(sound_mem,0)
-	MDRV_CPU_IO_MAP(sound_io,0)
+	MDRV_CPU_ADD("soundcpu",Z80,MASTER_CLOCK/6)
+	MDRV_CPU_PROGRAM_MAP(sfkick_sound_map)
+	MDRV_CPU_IO_MAP(sfkick_sound_io_map)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -501,11 +497,11 @@ MACHINE_DRIVER_END
 
 static DRIVER_INIT(sfkick)
 {
-	main_mem=auto_malloc(0x4000);
+	main_mem=auto_alloc_array(machine, UINT8, 0x4000);
 }
 
 ROM_START( sfkick )
-	ROM_REGION( 0x10000, "main", ROMREGION_ERASEFF )
+	ROM_REGION( 0x10000, "maincpu", ROMREGION_ERASEFF )
 
 	ROM_REGION(0x20000,  "banked", ROMREGION_ERASEFF)
 	ROM_LOAD( "sfkick2.a7", 0x00000, 0x8000, CRC(1dcaec5e) SHA1(7e063d46fb6606df2d772866cc55f207035b98c4) )
@@ -522,13 +518,13 @@ ROM_START( sfkick )
 	ROM_REGION(0x8000,  "bios", 0)
 	ROM_LOAD( "sfkick7.l7", 0x00000, 0x8000, CRC(8cd94c63) SHA1(e6dba66c8716593b8ab88f79f7205211938d1598) )
 
-	ROM_REGION(0x10000,  "sound", 0)
+	ROM_REGION(0x10000,  "soundcpu", 0)
 	ROM_LOAD( "sfkick1.c5", 0x00000, 0x8000, CRC(2f5e3b7a) SHA1(d2ff566b415ab10c0681fa1eb221a56e3c137ecf) )
 ROM_END
 
 
 ROM_START( spinkick )
-	ROM_REGION( 0x10000, "main", ROMREGION_ERASEFF )
+	ROM_REGION( 0x10000, "maincpu", ROMREGION_ERASEFF )
 
 	ROM_REGION(0x20000,  "banked", ROMREGION_ERASEFF)
 	ROM_LOAD( "spinkick.r2", 0x00000, 0x8000, CRC(1dcaec5e) SHA1(7e063d46fb6606df2d772866cc55f207035b98c4) )
@@ -545,7 +541,7 @@ ROM_START( spinkick )
 	ROM_REGION(0x8000,  "bios", 0)
 	ROM_LOAD( "spinkick.r7", 0x00000, 0x8000, CRC(8cd94c63) SHA1(e6dba66c8716593b8ab88f79f7205211938d1598) )
 
-	ROM_REGION(0x10000,  "sound", 0)
+	ROM_REGION(0x10000,  "soundcpu", 0)
 	ROM_LOAD( "spinkick.r1", 0x00000, 0x8000, CRC(2f5e3b7a) SHA1(d2ff566b415ab10c0681fa1eb221a56e3c137ecf) )
 ROM_END
 
