@@ -56,13 +56,13 @@ static READ16_HANDLER( shangha3_prot_r )
 	static int count;
 	static const int result[] = { 0x0,0x1,0x3,0x7,0xf,0xe,0xc,0x8,0x0};
 
-logerror("PC %04x: read 20004e\n",cpu_get_pc(space->cpu));
+	logerror("PC %04x: read 20004e\n",cpu_get_pc(space->cpu));
 
 	return result[count++ % 9];
 }
 static WRITE16_HANDLER( shangha3_prot_w )
 {
-logerror("PC %04x: write %02x to 20004e\n",cpu_get_pc(space->cpu),data);
+	logerror("PC %04x: write %02x to 20004e\n",cpu_get_pc(space->cpu),data);
 }
 
 
@@ -91,7 +91,7 @@ static WRITE16_HANDLER( heberpop_coinctrl_w )
 	if (ACCESSING_BITS_0_7)
 	{
 		/* the sound ROM bank is selected by the main CPU! */
-		okim6295_set_bank_base(0,(data & 0x08) ? 0x40000 : 0x00000);
+		okim6295_set_bank_base(devtag_get_device(space->machine, "oki"),(data & 0x08) ? 0x40000 : 0x00000);
 
 		coin_lockout_w(0,~data & 0x04);
 		coin_lockout_w(1,~data & 0x04);
@@ -105,7 +105,7 @@ static WRITE16_HANDLER( blocken_coinctrl_w )
 	if (ACCESSING_BITS_0_7)
 	{
 		/* the sound ROM bank is selected by the main CPU! */
-		okim6295_set_bank_base(0, ((data >> 4) & 3) * 0x40000);
+		okim6295_set_bank_base(devtag_get_device(space->machine, "oki"), ((data >> 4) & 3) * 0x40000);
 
 		coin_lockout_w(0,~data & 0x04);
 		coin_lockout_w(1,~data & 0x04);
@@ -119,103 +119,73 @@ static WRITE16_HANDLER( heberpop_sound_command_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(space,0,data & 0xff);
-		cpu_set_input_line_and_vector(space->machine->cpu[1],0,HOLD_LINE,0xff);	/* RST 38h */
+		soundlatch_w(space, 0, data & 0xff);
+		cputag_set_input_line_and_vector(space->machine, "audiocpu", 0, HOLD_LINE, 0xff);	/* RST 38h */
 	}
 }
 
 
 
-static ADDRESS_MAP_START( shangha3_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( shangha3_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x07ffff) AM_ROM
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x200002, 0x200003) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0x20001e, 0x20001f) AM_READ(ay8910_read_port_0_lsb_r)
-	AM_RANGE(0x20004e, 0x20004f) AM_READ(shangha3_prot_r)
-	AM_RANGE(0x20006e, 0x20006f) AM_READ(okim6295_status_0_lsb_r)
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( shangha3_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200008, 0x200009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(SMH_NOP)	/* irq ack? */
+	AM_RANGE(0x20000a, 0x20000b) AM_WRITENOP	/* irq ack? */
 	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(shangha3_coinctrl_w)
-	AM_RANGE(0x20002e, 0x20002f) AM_WRITE(ay8910_write_port_0_lsb_w)
-	AM_RANGE(0x20003e, 0x20003f) AM_WRITE(ay8910_control_port_0_lsb_w)
-	AM_RANGE(0x20004e, 0x20004f) AM_WRITE(shangha3_prot_w)
-	AM_RANGE(0x20006e, 0x20006f) AM_WRITE(okim6295_data_0_lsb_w)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x20001e, 0x20001f) AM_DEVREAD8("ay", ay8910_r, 0x00ff)
+	AM_RANGE(0x20002e, 0x20002f) AM_DEVWRITE8("ay", ay8910_data_w, 0x00ff)
+	AM_RANGE(0x20003e, 0x20003f) AM_DEVWRITE8("ay", ay8910_address_w, 0x00ff)
+	AM_RANGE(0x20004e, 0x20004f) AM_READWRITE(shangha3_prot_r,shangha3_prot_w)
+	AM_RANGE(0x20006e, 0x20006f) AM_DEVREADWRITE8("oki", okim6295_r,okim6295_w, 0x00ff)
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( heberpop_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( heberpop_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x200002, 0x200003) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x200004, 0x200005) AM_READ_PORT("DSW")
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
+	AM_RANGE(0x200008, 0x200009) AM_WRITE(shangha3_blitter_go_w)
+	AM_RANGE(0x20000a, 0x20000b) AM_WRITENOP	/* irq ack? */
+	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(heberpop_coinctrl_w)
+	AM_RANGE(0x20000e, 0x20000f) AM_WRITE(heberpop_sound_command_w)
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
+	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( heberpop_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x200008, 0x200009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(SMH_NOP)	/* irq ack? */
-	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(heberpop_coinctrl_w)
-	AM_RANGE(0x20000e, 0x20000f) AM_WRITE(heberpop_sound_command_w)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
-	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
-	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( blocken_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+static ADDRESS_MAP_START( blocken_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x100004, 0x100005) AM_READ_PORT("DSW")
-	AM_RANGE(0x200000, 0x200fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
+	AM_RANGE(0x100008, 0x100009) AM_WRITE(shangha3_blitter_go_w)
+	AM_RANGE(0x10000a, 0x10000b) AM_WRITENOP	/* irq ack? */
+	AM_RANGE(0x10000c, 0x10000d) AM_WRITE(blocken_coinctrl_w)
+	AM_RANGE(0x10000e, 0x10000f) AM_WRITE(heberpop_sound_command_w)
+	AM_RANGE(0x200000, 0x200fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
+	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( blocken_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x100008, 0x100009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x10000a, 0x10000b) AM_WRITE(SMH_NOP)	/* irq ack? */
-	AM_RANGE(0x10000c, 0x10000d) AM_WRITE(blocken_coinctrl_w)
-	AM_RANGE(0x10000e, 0x10000f) AM_WRITE(heberpop_sound_command_w)
-	AM_RANGE(0x200000, 0x200fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
-	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
-	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
+
+static ADDRESS_MAP_START( heberpop_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xf7ff) AM_ROM
+	AM_RANGE(0xf800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( heberpop_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xf7ff) AM_READ(SMH_ROM)
-	AM_RANGE(0xf800, 0xffff) AM_READ(SMH_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( heberpop_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xf7ff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(SMH_RAM)
-ADDRESS_MAP_END
-
-
 static ADDRESS_MAP_START( heberpop_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_READWRITE(ym3438_status_port_0_a_r, ym3438_control_port_0_a_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(ym3438_data_port_0_a_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(ym3438_control_port_0_b_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(ym3438_data_port_0_b_w)
-	AM_RANGE(0x80, 0x80) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
+	AM_RANGE(0x00, 0x03) AM_DEVREADWRITE("ym", ym3438_r, ym3438_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE("oki", okim6295_r, okim6295_w)
 	AM_RANGE(0xc0, 0xc0) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
@@ -489,15 +459,15 @@ static const ay8910_interface ay8910_config =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
-	input_port_3_r,
-	input_port_2_r,
-	NULL,
-	NULL
+	DEVCB_INPUT_PORT("DSW2"),
+	DEVCB_INPUT_PORT("DSW1"),
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
-static void irqhandler(running_machine *machine, int linestate)
+static void irqhandler(const device_config *device, int linestate)
 {
-	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, linestate);
+	cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, linestate);
 }
 
 static const ym3438_interface ym3438_config =
@@ -509,14 +479,14 @@ static const ym3438_interface ym3438_config =
 static MACHINE_DRIVER_START( shangha3 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 8000000)
-	MDRV_CPU_PROGRAM_MAP(shangha3_readmem,shangha3_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 8000000)
+	MDRV_CPU_PROGRAM_MAP(shangha3_map)
+	MDRV_CPU_VBLANK_INT("screen", irq4_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS )
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -545,18 +515,18 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( heberpop )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 8000000)
-	MDRV_CPU_PROGRAM_MAP(heberpop_readmem,heberpop_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 8000000)
+	MDRV_CPU_PROGRAM_MAP(heberpop_map)
+	MDRV_CPU_VBLANK_INT("screen", irq4_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80, 6000000)	/* 6 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(heberpop_sound_readmem,heberpop_sound_writemem)
-	MDRV_CPU_IO_MAP(heberpop_sound_io_map,0)	/* NMI triggered by YM3438 */
+	MDRV_CPU_ADD("audiocpu", Z80, 6000000)	/* 6 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(heberpop_sound_map)
+	MDRV_CPU_IO_MAP(heberpop_sound_io_map)	/* NMI triggered by YM3438 */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -586,18 +556,18 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( blocken )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 8000000)
-	MDRV_CPU_PROGRAM_MAP(blocken_readmem,blocken_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 8000000)
+	MDRV_CPU_PROGRAM_MAP(blocken_map)
+	MDRV_CPU_VBLANK_INT("screen", irq4_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80, 6000000)	/* 6 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(heberpop_sound_readmem,heberpop_sound_writemem)
-	MDRV_CPU_IO_MAP(heberpop_sound_io_map,0)	/* NMI triggered by YM3438 */
+	MDRV_CPU_ADD("audiocpu", Z80, 6000000)	/* 6 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(heberpop_sound_map)
+	MDRV_CPU_IO_MAP(heberpop_sound_io_map)	/* NMI triggered by YM3438 */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -632,7 +602,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( shangha3 )
-	ROM_REGION( 0x80000, "main", 0 )
+	ROM_REGION( 0x80000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "s3j_ic3.v11",  0x0000, 0x40000, CRC(e98ce9c8) SHA1(359e117aebb644d7b235add7e71ed6891243d451) )
 	ROM_LOAD16_BYTE( "s3j_ic2.v11",  0x0001, 0x40000, CRC(09174620) SHA1(1d1639c07895f715facfe153fbdb6ae0f3cdd876) )
 
@@ -644,11 +614,11 @@ ROM_START( shangha3 )
 ROM_END
 
 ROM_START( heberpop )
-	ROM_REGION( 0x100000, "main", 0 )
+	ROM_REGION( 0x100000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "hbpic31.bin",  0x0000, 0x80000, CRC(c430d264) SHA1(4be12b1fa90da09047db3a31171ffda8ab8bd851) )
 	ROM_LOAD16_BYTE( "hbpic32.bin",  0x0001, 0x80000, CRC(bfa555a8) SHA1(754f581554022b98ba8e78ee96f846faa2cedc69) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "hbpic34.bin",  0x0000, 0x10000, CRC(0cf056c6) SHA1(9992cd3879d9a57fcb784fc1e11d6b6d87e5a366) )
 
 	ROM_REGION( 0x380000, "gfx1", 0 )	/* don't dispose, read during tests */
@@ -665,11 +635,11 @@ ROM_START( heberpop )
 ROM_END
 
 ROM_START( blocken )
-	ROM_REGION( 0x100000, "main", 0 )
+	ROM_REGION( 0x100000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "ic31j.bin",    0x0000, 0x20000, CRC(ec8de2a3) SHA1(09a6b8c1b656b17ab3d1fc057902487e4f94cf02) )
 	ROM_LOAD16_BYTE( "ic32j.bin",    0x0001, 0x20000, CRC(79b96240) SHA1(c1246bd4b91fa45c581a8fdf90cc6beb85adf8ec) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "ic34.bin",     0x0000, 0x10000, CRC(23e446ff) SHA1(82c03b45b337696b0f8293c446544d7ee080d415) )
 
 	ROM_REGION( 0x380000, "gfx1", 0 )	/* don't dispose, read during tests */
@@ -701,6 +671,7 @@ static DRIVER_INIT( shangha3 )
 {
 	shangha3_do_shadows = 1;
 }
+
 static DRIVER_INIT( heberpop )
 {
 	shangha3_do_shadows = 0;
