@@ -48,28 +48,19 @@ VIDEO_UPDATE( skyfox );
                                 Sky Fox
 ***************************************************************************/
 
-static ADDRESS_MAP_START( skyfox_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(SMH_ROM			)	// ROM
-	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM			)	// RAM
+static ADDRESS_MAP_START( skyfox_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM							// ROM
+	AM_RANGE(0xc000, 0xcfff) AM_RAM							// RAM
+	AM_RANGE(0xd000, 0xd3ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	// Sprites
+	AM_RANGE(0xd400, 0xdfff) AM_RAM							// RAM?
 	AM_RANGE(0xe000, 0xe000) AM_READ_PORT("INPUTS")			// Input Ports
 	AM_RANGE(0xe001, 0xe001) AM_READ_PORT("DSW0")			//
 	AM_RANGE(0xe002, 0xe002) AM_READ_PORT("DSW1")			//
+	AM_RANGE(0xe008, 0xe00f) AM_WRITE(skyfox_vregs_w)		// Video Regs
 	AM_RANGE(0xf001, 0xf001) AM_READ_PORT("DSW2")			//
-//  AM_RANGE(0xff00, 0xff07) AM_READ(skyfox_vregs_r     )   // fake to read the vregs
+//  AM_RANGE(0xff00, 0xff07) AM_READ(skyfox_vregs_r)        // fake to read the vregs
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( skyfox_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM								)	// ROM
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(SMH_RAM								)	// RAM
-	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size	)	// Sprites
-	AM_RANGE(0xd400, 0xdfff) AM_WRITE(SMH_RAM								)	// RAM?
-	AM_RANGE(0xe008, 0xe00f) AM_WRITE(skyfox_vregs_w						)	// Video Regs
-ADDRESS_MAP_END
-
-
-
-
-
 
 /***************************************************************************
 
@@ -85,27 +76,16 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 
-static ADDRESS_MAP_START( skyfox_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM				)	// ROM
-	AM_RANGE(0x8000, 0x87ff) AM_READ(SMH_RAM				)	// RAM
-	AM_RANGE(0xa001, 0xa001) AM_READ(ym2203_read_port_0_r 	)	// YM2203 #1
-//  AM_RANGE(0xc001, 0xc001) AM_READ(ym2203_read_port_1_r   )   // YM2203 #2
-	AM_RANGE(0xb000, 0xb000) AM_READ(soundlatch_r			)	// From Main CPU
+static ADDRESS_MAP_START( skyfox_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM								// ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM								// RAM
+//  AM_RANGE(0x9000, 0x9001) AM_WRITENOP                        // ??
+	AM_RANGE(0xa000, 0xa001) AM_DEVREADWRITE("ym1", ym2203_r,ym2203_w)	// YM2203 #1
+//  AM_RANGE(0xb000, 0xb001) AM_WRITENOP                        // ??
+	AM_RANGE(0xc000, 0xc001) AM_DEVREADWRITE("ym2", ym2203_r,ym2203_w)	// YM2203 #2
+	AM_RANGE(0xb000, 0xb000) AM_READ(soundlatch_r)				// From Main CPU
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( skyfox_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM					)	// ROM
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(SMH_RAM					)	// RAM
-//  AM_RANGE(0x9000, 0x9001) AM_WRITE(SMH_NOP                  )   // ??
-	AM_RANGE(0xa000, 0xa000) AM_WRITE(ym2203_control_port_0_w 	)	// YM2203 #1
-	AM_RANGE(0xa001, 0xa001) AM_WRITE(ym2203_write_port_0_w 	)	//
-//  AM_RANGE(0xb000, 0xb001) AM_WRITE(SMH_NOP                  )   // ??
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(ym2203_control_port_1_w 	)	// YM2203 #2
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(ym2203_write_port_1_w 	)	//
-ADDRESS_MAP_END
-
-
-
 
 /***************************************************************************
 
@@ -115,6 +95,11 @@ ADDRESS_MAP_END
 
 ***************************************************************************/
 
+static INPUT_CHANGED( coin_inserted )
+{
+	cputag_set_input_line(field->port->machine, "maincpu", INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
+}
+
 static INPUT_PORTS_START( skyfox )
 	PORT_START("INPUTS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
@@ -184,9 +169,9 @@ static INPUT_PORTS_START( skyfox )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START("COINS")	// Fake input port, polled every VBLANK to generate an NMI upon coin insertion
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_START("COINS")	// Fake input port, coins are directly connected on NMI line
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_CHANGED(coin_inserted, 0)
 INPUT_PORTS_END
 
 
@@ -224,10 +209,6 @@ static GFXDECODE_START( skyfox )
 GFXDECODE_END
 
 
-
-
-
-
 /***************************************************************************
 
 
@@ -241,30 +222,26 @@ GFXDECODE_END
                                 Sky Fox
 ***************************************************************************/
 
-/* Check for coin insertion once a frame (polling a fake input port).
-   Generate an NMI in case. Scroll the background too. */
+/* Scroll the background on every vblank (guess). */
 
 static INTERRUPT_GEN( skyfox_interrupt )
 {
 	/* Scroll the bg */
 	skyfox_bg_pos += (skyfox_bg_ctrl >> 1) & 0x7;	// maybe..
-
-	/* Check coin 1 & 2 */
-	if ((input_port_read(device->machine, "COINS") & 3) != 3) cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static MACHINE_DRIVER_START( skyfox )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(skyfox_readmem,skyfox_writemem)
-	MDRV_CPU_VBLANK_INT("main", skyfox_interrupt)		/* NMI caused by coin insertion */
+	MDRV_CPU_ADD("maincpu", Z80, 4000000)
+	MDRV_CPU_PROGRAM_MAP(skyfox_map)
+	MDRV_CPU_VBLANK_INT("screen", skyfox_interrupt)		/* NMI caused by coin insertion */
 
-	MDRV_CPU_ADD("audio", Z80, 1748000)
-	MDRV_CPU_PROGRAM_MAP(skyfox_sound_readmem,skyfox_sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80, 1748000)
+	MDRV_CPU_PROGRAM_MAP(skyfox_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -361,11 +338,11 @@ Sound processor - Z80  1.748MHz
 
 
 ROM_START( skyfox )
-	ROM_REGION( 0x10000, "main", 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 )		/* Main Z80 Code */
 	ROM_LOAD( "skyfox1.bin", 0x00000, 0x8000, CRC(b4d4bb6f) SHA1(ed1cf6d91ca7170cb7d1c80b586c11164430fd49) )
 	ROM_LOAD( "skyfox2.bin", 0x08000, 0x8000, CRC(e15e0263) SHA1(005934327834aed46b17161aef82117ee508e9c4) )	// identical halves
 
-	ROM_REGION( 0x10000, "audio", 0 )		/* Sound Z80 Code */
+	ROM_REGION( 0x10000, "audiocpu", 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "skyfox9.bin", 0x00000, 0x8000, CRC(0b283bf5) SHA1(5b14d0beea689ee7e9174017e5a127435df4fbe3) )
 
 	ROM_REGION( 0x60000, "gfx1", ROMREGION_DISPOSE )	/* Sprites */
@@ -386,11 +363,11 @@ ROM_START( skyfox )
 ROM_END
 
 ROM_START( exerizrb )
-	ROM_REGION( 0x10000, "main", 0 )		/* Main Z80 Code */
+	ROM_REGION( 0x10000, "maincpu", 0 )		/* Main Z80 Code */
 	ROM_LOAD( "1-a",         0x00000, 0x8000, CRC(5df72a5d) SHA1(ca35ac06f3702fd650a584da2f442fbc61c00fce) )
 	ROM_LOAD( "skyfox2.bin", 0x08000, 0x8000, CRC(e15e0263) SHA1(005934327834aed46b17161aef82117ee508e9c4) )	// 1-b
 
-	ROM_REGION( 0x10000, "audio", 0 )		/* Sound Z80 Code */
+	ROM_REGION( 0x10000, "audiocpu", 0 )		/* Sound Z80 Code */
 	ROM_LOAD( "skyfox9.bin", 0x00000, 0x8000, CRC(0b283bf5) SHA1(5b14d0beea689ee7e9174017e5a127435df4fbe3) )	// 1-i
 
 	ROM_REGION( 0x60000, "gfx1", ROMREGION_DISPOSE )	/* Sprites */
