@@ -140,82 +140,67 @@ static WRITE16_HANDLER( soundcommand_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(space,offset,data & 0xff);
-		cpu_set_input_line(space->machine->cpu[1],INPUT_LINE_NMI,PULSE_LINE);
+		soundlatch_w(space, offset, data & 0xff);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 	}
 }
 
-static ADDRESS_MAP_START( spbactn_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x3ffff) AM_READ(SMH_ROM)
-	AM_RANGE(0x40000, 0x43fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x50000, 0x50fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x60000, 0x67fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x70000, 0x77fff) AM_READ(SMH_RAM)
-	AM_RANGE(0x80000, 0x82fff) AM_READ(SMH_RAM)
+static ADDRESS_MAP_START( spbactn_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x00000, 0x3ffff) AM_ROM
+	AM_RANGE(0x40000, 0x43fff) AM_RAM	// main ram
+	AM_RANGE(0x50000, 0x50fff) AM_RAM AM_BASE(&spbactn_spvideoram)
+	AM_RANGE(0x60000, 0x67fff) AM_RAM AM_BASE(&spbactn_fgvideoram)
+	AM_RANGE(0x70000, 0x77fff) AM_RAM AM_BASE(&spbactn_bgvideoram)
+	AM_RANGE(0x80000, 0x827ff) AM_RAM_WRITE(paletteram16_xxxxBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x90000, 0x90001) AM_READ_PORT("IN0")
 	AM_RANGE(0x90010, 0x90011) AM_READ_PORT("IN1")
 	AM_RANGE(0x90020, 0x90021) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x90030, 0x90031) AM_READ_PORT("DSW1")
 	AM_RANGE(0x90040, 0x90041) AM_READ_PORT("DSW2")
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( spbactn_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x3ffff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0x40000, 0x43fff) AM_WRITE(SMH_RAM)	// main ram
-	AM_RANGE(0x50000, 0x50fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_spvideoram)
-	AM_RANGE(0x60000, 0x67fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_fgvideoram)
-	AM_RANGE(0x70000, 0x77fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_bgvideoram)
-	AM_RANGE(0x80000, 0x827ff) AM_WRITE(paletteram16_xxxxBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
 
 	/* this is an awful lot of unknowns */
-	AM_RANGE(0x90000, 0x90001) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x90000, 0x90001) AM_WRITENOP
 	AM_RANGE(0x90010, 0x90011) AM_WRITE(soundcommand_w)
 //  AM_RANGE(0x90020, 0x90021) AM_WRITE(soundcommand_w)
-	AM_RANGE(0x90030, 0x90031) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x90030, 0x90031) AM_WRITENOP
 
-	AM_RANGE(0x90080, 0x90081) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x90090, 0x90091) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900a0, 0x900a1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900b0, 0x900b1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900c0, 0x900c1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900d0, 0x900d1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900e0, 0x900e1) AM_WRITE(SMH_NOP)
-	AM_RANGE(0x900f0, 0x900f1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x90080, 0x90081) AM_WRITENOP
+	AM_RANGE(0x90090, 0x90091) AM_WRITENOP
+	AM_RANGE(0x900a0, 0x900a1) AM_WRITENOP
+	AM_RANGE(0x900b0, 0x900b1) AM_WRITENOP
+	AM_RANGE(0x900c0, 0x900c1) AM_WRITENOP
+	AM_RANGE(0x900d0, 0x900d1) AM_WRITENOP
+	AM_RANGE(0x900e0, 0x900e1) AM_WRITENOP
+	AM_RANGE(0x900f0, 0x900f1) AM_WRITENOP
 
-	AM_RANGE(0xa0000, 0xa0001) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0004, 0xa0005) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0008, 0xa0009) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa000c, 0xa000d) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0010, 0xa0011) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0000, 0xa0001) AM_WRITENOP
+	AM_RANGE(0xa0004, 0xa0005) AM_WRITENOP
+	AM_RANGE(0xa0008, 0xa0009) AM_WRITENOP
+	AM_RANGE(0xa000c, 0xa000d) AM_WRITENOP
+	AM_RANGE(0xa0010, 0xa0011) AM_WRITENOP
 
-	AM_RANGE(0xa0100, 0xa0101) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0104, 0xa0105) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0108, 0xa0109) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa010c, 0xa010d) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0110, 0xa0111) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0100, 0xa0101) AM_WRITENOP
+	AM_RANGE(0xa0104, 0xa0105) AM_WRITENOP
+	AM_RANGE(0xa0108, 0xa0109) AM_WRITENOP
+	AM_RANGE(0xa010c, 0xa010d) AM_WRITENOP
+	AM_RANGE(0xa0110, 0xa0111) AM_WRITENOP
 
-	AM_RANGE(0xa0200, 0xa0201) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0202, 0xa0203) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0204, 0xa0205) AM_WRITE(SMH_NOP)
-	AM_RANGE(0xa0206, 0xa0207) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0200, 0xa0201) AM_WRITENOP
+	AM_RANGE(0xa0202, 0xa0203) AM_WRITENOP
+	AM_RANGE(0xa0204, 0xa0205) AM_WRITENOP
+	AM_RANGE(0xa0206, 0xa0207) AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xefff) AM_READ(SMH_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0xf800, 0xf800) AM_READ(okim6295_status_0_r)
-	AM_RANGE(0xfc00, 0xfc00) AM_READ(SMH_NOP)	/* irq ack ?? */
+static ADDRESS_MAP_START( spbactn_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xefff) AM_ROM
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM
+	AM_RANGE(0xf800, 0xf800) AM_DEVREADWRITE("oki", okim6295_r,okim6295_w)
+	AM_RANGE(0xf810, 0xf811) AM_DEVWRITE("ym", ym3812_w)
+
+	AM_RANGE(0xfc00, 0xfc00) AM_READNOP	AM_WRITENOP /* irq ack ?? */
 	AM_RANGE(0xfc20, 0xfc20) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xefff) AM_WRITE(SMH_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0xf800, 0xf800) AM_WRITE(okim6295_data_0_w)
-	AM_RANGE(0xf810, 0xf810) AM_WRITE(ym3812_control_port_0_w)
-	AM_RANGE(0xf811, 0xf811) AM_WRITE(ym3812_write_port_0_w)
-	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(SMH_NOP)	/* irq ack ?? */
-ADDRESS_MAP_END
 
 static INPUT_PORTS_START( spbactn )
 	PORT_START("IN0")
@@ -286,7 +271,7 @@ static INPUT_PORTS_START( spbactn )
 	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPNAME( 0x10, 0x10, "Hit Difficulty" )		// From .xls file - WHAT does that mean ?
 	PORT_DIPSETTING(    0x10, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x00, "Difficult" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Difficult ) )
 	PORT_DIPNAME( 0x20, 0x20, "Display Instructions" )	// "Change Software" in .xls file
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( Yes ) )
@@ -343,9 +328,9 @@ static GFXDECODE_START( spbactn )
 	GFXDECODE_ENTRY( "gfx3", 0, spritelayout,   0x0000, 16 + 384 )
 GFXDECODE_END
 
-static void irqhandler(running_machine *machine, int linestate)
+static void irqhandler(const device_config *device, int linestate)
 {
-	cpu_set_input_line(machine->cpu[1],0,linestate);
+	cputag_set_input_line(device->machine, "audiocpu", 0, linestate);
 }
 
 static const ym3812_interface ym3812_config =
@@ -355,15 +340,15 @@ static const ym3812_interface ym3812_config =
 
 static MACHINE_DRIVER_START( spbactn )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 12000000)
-	MDRV_CPU_PROGRAM_MAP(spbactn_readmem,spbactn_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq3_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000, 12000000)
+	MDRV_CPU_PROGRAM_MAP(spbactn_map)
+	MDRV_CPU_VBLANK_INT("screen", irq3_line_hold)
 
-	MDRV_CPU_ADD("audio", Z80, 4000000)	/* 4 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80, 4000000)	/* 4 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(spbactn_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
@@ -390,11 +375,11 @@ MACHINE_DRIVER_END
 
 ROM_START( spbactn )
 	/* Board 9002-A (CPU Board) */
-	ROM_REGION( 0x40000, "main", 0 )
+	ROM_REGION( 0x40000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "rom1.bin", 0x00000, 0x20000, CRC(6741bd3f) SHA1(844eb6465a15d339043fd6d2b6ba20ba216de493) )
 	ROM_LOAD16_BYTE( "rom2.bin", 0x00001, 0x20000, CRC(488cc511) SHA1(41b4a01f35e0e93634b4843dbb894ab9840807bf) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a-u14.3", 0x00000, 0x10000, CRC(57f4c503) SHA1(e5ddc63a43ba824bcaa4340eeba25a0d3f26cad9) )
 
 	ROM_REGION( 0x20000, "oki", 0 )
@@ -416,11 +401,11 @@ ROM_END
 
 ROM_START( spbactnj )
 	/* Board 9002-A (CPU Board) */
-	ROM_REGION( 0x40000, "main", 0 )
+	ROM_REGION( 0x40000, "maincpu", 0 )
 	ROM_LOAD16_BYTE( "a-u68.1", 0x00000, 0x20000, CRC(b5b2d824) SHA1(be04ca370a381d7396f39e31fb2680973193daee) )
 	ROM_LOAD16_BYTE( "a-u67.2", 0x00001, 0x20000, CRC(9577b48b) SHA1(291d890a9d0e434455f183eb12ae6edf3156688d) )
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "a-u14.3", 0x00000, 0x10000, CRC(57f4c503) SHA1(e5ddc63a43ba824bcaa4340eeba25a0d3f26cad9) )
 
 	ROM_REGION( 0x20000, "oki", 0 )
