@@ -6,6 +6,8 @@
 
   M6809 for game, Z80 and YM-2203 for sound.
 
+2009/06 - DIP Location and Defaults verified against Speed Rumbler manual.
+
 ***************************************************************************/
 
 #include "driver.h"
@@ -53,7 +55,7 @@ static WRITE8_HANDLER( srumbler_bankswitch_w )
 
 static MACHINE_RESET( srumbler )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	/* initialize banked ROM pointers */
 	srumbler_bankswitch_w(space,0,0);
 }
@@ -66,28 +68,6 @@ static INTERRUPT_GEN( srumbler_interrupt )
 		cpu_set_input_line(device,M6809_FIRQ_LINE,HOLD_LINE);
 }
 
-
-
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_RAM)   /* RAM (of 1 sort or another) */
-	AM_RANGE(0x4008, 0x4008) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0x4009, 0x4009) AM_READ_PORT("P1")
-	AM_RANGE(0x400a, 0x400a) AM_READ_PORT("P2")
-	AM_RANGE(0x400b, 0x400b) AM_READ_PORT("DSW1")
-	AM_RANGE(0x400c, 0x400c) AM_READ_PORT("DSW2")
-	AM_RANGE(0x5000, 0x5fff) AM_READ(SMH_BANK6)	/* Banked ROM */
-	AM_RANGE(0x6000, 0x6fff) AM_READ(SMH_BANK7)	/* Banked ROM */
-	AM_RANGE(0x7000, 0x7fff) AM_READ(SMH_BANK8)	/* Banked ROM */
-	AM_RANGE(0x8000, 0x8fff) AM_READ(SMH_BANK9)	/* Banked ROM */
-	AM_RANGE(0x9000, 0x9fff) AM_READ(SMH_BANK10)	/* Banked ROM */
-	AM_RANGE(0xa000, 0xafff) AM_READ(SMH_BANK11)	/* Banked ROM */
-	AM_RANGE(0xb000, 0xbfff) AM_READ(SMH_BANK12)	/* Banked ROM */
-	AM_RANGE(0xc000, 0xcfff) AM_READ(SMH_BANK13)	/* Banked ROM */
-	AM_RANGE(0xd000, 0xdfff) AM_READ(SMH_BANK14)	/* Banked ROM */
-	AM_RANGE(0xe000, 0xefff) AM_READ(SMH_BANK15)	/* Banked ROM */
-	AM_RANGE(0xf000, 0xffff) AM_READ(SMH_BANK16)	/* Banked ROM */
-ADDRESS_MAP_END
-
 /*
 The "scroll test" routine on the test screen appears to overflow and write
 over the control registers (0x4000-0x4080) when it clears the screen.
@@ -98,33 +78,38 @@ to the page register.
 Ignore the warnings about writing to unmapped memory.
 */
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1dff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x1e00, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x2000, 0x3fff) AM_WRITE(srumbler_background_w) AM_BASE(&srumbler_backgroundram)
-	AM_RANGE(0x4008, 0x4008) AM_WRITE(srumbler_bankswitch_w)
-	AM_RANGE(0x4009, 0x4009) AM_WRITE(srumbler_4009_w)
+static ADDRESS_MAP_START( srumbler_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1dff) AM_RAM  /* RAM (of 1 sort or another) */
+	AM_RANGE(0x1e00, 0x1fff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x2000, 0x3fff) AM_RAM_WRITE(srumbler_background_w) AM_BASE(&srumbler_backgroundram)
+	AM_RANGE(0x4008, 0x4008) AM_READ_PORT("SYSTEM") AM_WRITE(srumbler_bankswitch_w)
+	AM_RANGE(0x4009, 0x4009) AM_READ_PORT("P1") AM_WRITE(srumbler_4009_w)
+	AM_RANGE(0x400a, 0x400a) AM_READ_PORT("P2")
+	AM_RANGE(0x400b, 0x400b) AM_READ_PORT("DSW1")
+	AM_RANGE(0x400c, 0x400c) AM_READ_PORT("DSW2")
 	AM_RANGE(0x400a, 0x400d) AM_WRITE(srumbler_scroll_w)
 	AM_RANGE(0x400e, 0x400e) AM_WRITE(soundlatch_w)
-	AM_RANGE(0x5000, 0x5fff) AM_WRITE(srumbler_foreground_w) AM_BASE(&srumbler_foregroundram)
-	AM_RANGE(0x6000, 0x6fff) AM_WRITE(SMH_RAM) /* Video RAM 2 ??? (not used) */
+	AM_RANGE(0x5000, 0x5fff) AM_ROMBANK(6)	AM_WRITE(srumbler_foreground_w) AM_BASE(&srumbler_foregroundram) /* Banked ROM */
+	AM_RANGE(0x6000, 0x6fff) AM_ROMBANK(7)	/* Banked ROM */
+	AM_RANGE(0x6000, 0x6fff) AM_WRITENOP 	/* Video RAM 2 ??? (not used) */
+	AM_RANGE(0x7000, 0x7fff) AM_ROMBANK(8)	/* Banked ROM */
 	AM_RANGE(0x7000, 0x73ff) AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_be_w) AM_BASE(&paletteram)
-	AM_RANGE(0x7400, 0xffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x8000, 0x8fff) AM_ROMBANK(9)	/* Banked ROM */
+	AM_RANGE(0x9000, 0x9fff) AM_ROMBANK(10)	/* Banked ROM */
+	AM_RANGE(0xa000, 0xafff) AM_ROMBANK(11)	/* Banked ROM */
+	AM_RANGE(0xb000, 0xbfff) AM_ROMBANK(12)	/* Banked ROM */
+	AM_RANGE(0xc000, 0xcfff) AM_ROMBANK(13)	/* Banked ROM */
+	AM_RANGE(0xd000, 0xdfff) AM_ROMBANK(14)	/* Banked ROM */
+	AM_RANGE(0xe000, 0xefff) AM_ROMBANK(15)	/* Banked ROM */
+	AM_RANGE(0xf000, 0xffff) AM_ROMBANK(16)	/* Banked ROM */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( srumbler_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0x8001) AM_DEVWRITE("ym1", ym2203_w)
+	AM_RANGE(0xa000, 0xa001) AM_DEVWRITE("ym2", ym2203_w)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 	AM_RANGE(0xe000, 0xe000) AM_READ(soundlatch_r)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
-	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM)
-	AM_RANGE(0x8000, 0x8000) AM_WRITE(ym2203_control_port_0_w)
-	AM_RANGE(0x8001, 0x8001) AM_WRITE(ym2203_write_port_0_w)
-	AM_RANGE(0xa000, 0xa000) AM_WRITE(ym2203_control_port_1_w)
-	AM_RANGE(0xa001, 0xa001) AM_WRITE(ym2203_write_port_1_w)
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
 
@@ -160,7 +145,7 @@ static INPUT_PORTS_START( srumbler )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START("DSW1")
-	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_B ) )
+	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_B ) )  PORT_DIPLOCATION("SW1:1,2,3")
 	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
@@ -169,7 +154,7 @@ static INPUT_PORTS_START( srumbler )
 	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_6C ) )
-	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_A ) )
+	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_A ) )  PORT_DIPLOCATION("SW1:4,5,6")
 	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
@@ -178,31 +163,31 @@ static INPUT_PORTS_START( srumbler )
 	PORT_DIPSETTING(    0x28, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x18, DEF_STR( 1C_6C ) )
-	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Flip_Screen ) )
+	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )  PORT_DIPLOCATION("SW1:7")
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Flip_Screen ) )  PORT_DIPLOCATION("SW1:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	PORT_START("DSW2")
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )  PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(    0x03, "3" )
 	PORT_DIPSETTING(    0x02, "4" )
 	PORT_DIPSETTING(    0x01, "5" )
 	PORT_DIPSETTING(    0x00, "7" )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Cabinet ) )  PORT_DIPLOCATION("SW2:3")
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( Cocktail ) )
-	PORT_DIPNAME( 0x18, 0x18, DEF_STR( Bonus_Life ) )
+	PORT_DIPNAME( 0x18, 0x10, DEF_STR( Bonus_Life ) )  PORT_DIPLOCATION("SW2:4,5")
 	PORT_DIPSETTING(    0x18, "20k 70k and every 70k" )
 	PORT_DIPSETTING(    0x10, "30k 80k and every 80k" )
 	PORT_DIPSETTING(    0x08, "20k 80k" )
 	PORT_DIPSETTING(    0x00, "30k 80k" )
-	PORT_DIPNAME( 0x60, 0x60, DEF_STR( Difficulty ) )
+	PORT_DIPNAME( 0x60, 0x60, DEF_STR( Difficulty ) )  PORT_DIPLOCATION("SW2:6,7")
 	PORT_DIPSETTING(    0x40, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x60, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Allow_Continue ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Difficult ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Very_Difficult ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Allow_Continue ) )  PORT_DIPLOCATION("SW2:8")
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Yes ) )
 INPUT_PORTS_END
@@ -258,12 +243,12 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( srumbler )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6809, 1500000)        /* 1.5 MHz (?) */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_ADD("maincpu", M6809, 1500000)        /* 1.5 MHz (?) */
+	MDRV_CPU_PROGRAM_MAP(srumbler_map)
 	MDRV_CPU_VBLANK_INT_HACK(srumbler_interrupt,2)
 
-	MDRV_CPU_ADD("audio", Z80, 3000000)        /* 3 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_ADD("audiocpu", Z80, 3000000)        /* 3 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(srumbler_sound_map)
 	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
 
 	MDRV_MACHINE_RESET(srumbler)
@@ -271,7 +256,7 @@ static MACHINE_DRIVER_START( srumbler )
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -320,7 +305,7 @@ ROM_START( srumbler )
 	ROM_LOAD( "12f_sr07.bin", 0x30000, 0x08000, CRC(de785076) SHA1(bdb104c6c875f5362c0d1ba9a8c5dd450c9c014b) )  /* RC7 */
 	ROM_LOAD( "11f_sr06.bin", 0x38000, 0x08000, CRC(a70f4fd4) SHA1(21be3865b9f7fa265f265a565bab896357d7464f) )  /* RC6 */
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "2f_sr05.bin",  0x0000, 0x8000, CRC(0177cebe) SHA1(0fa94d2057f509a6fe1de210bf513efc82f1ffe7) )
 
 	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
@@ -363,7 +348,7 @@ ROM_START( srumblr2 )
 	ROM_LOAD( "12f_sr07.bin", 0x30000, 0x08000, CRC(de785076) SHA1(bdb104c6c875f5362c0d1ba9a8c5dd450c9c014b) )  /* RC7 */
 	ROM_LOAD( "11f_sr06.bin", 0x38000, 0x08000, CRC(a70f4fd4) SHA1(21be3865b9f7fa265f265a565bab896357d7464f) )  /* RC6 */
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "rc05.2f",      0x0000, 0x8000, CRC(ea04fa07) SHA1(e29bfc3ed9e6606206ee41c90aaaeddffa26c1b4) )  /* AUDIO (different) */
 
 	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
@@ -406,7 +391,7 @@ ROM_START( rushcrsh )
 	ROM_LOAD( "12f_sr07.bin", 0x30000, 0x08000, CRC(de785076) SHA1(bdb104c6c875f5362c0d1ba9a8c5dd450c9c014b) )  /* RC7 */
 	ROM_LOAD( "11f_sr06.bin", 0x38000, 0x08000, CRC(a70f4fd4) SHA1(21be3865b9f7fa265f265a565bab896357d7464f) )  /* RC6 */
 
-	ROM_REGION( 0x10000, "audio", 0 )
+	ROM_REGION( 0x10000, "audiocpu", 0 )
 	ROM_LOAD( "rc05.2f",      0x0000, 0x8000, CRC(ea04fa07) SHA1(e29bfc3ed9e6606206ee41c90aaaeddffa26c1b4) )  /* AUDIO (different) */
 
 	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
