@@ -52,8 +52,8 @@ static WRITE16_HANDLER( stadhero_control_w )
 		case 4: /* Interrupt ack (VBL - IRQ 5) */
 			break;
 		case 6: /* 6502 sound cpu */
-			soundlatch_w(space,0,data & 0xff);
-			cpu_set_input_line(space->machine->cpu[1],INPUT_LINE_NMI,PULSE_LINE);
+			soundlatch_w(space, 0, data & 0xff);
+			cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 			break;
 		default:
 			logerror("CPU #0 PC %06x: warning - write %02x to unmapped memory address %06x\n",cpu_get_pc(space->cpu),data,0x30c010+offset);
@@ -78,36 +78,12 @@ ADDRESS_MAP_END
 
 /******************************************************************************/
 
-static WRITE8_HANDLER( YM3812_w )
-{
-	switch (offset) {
-	case 0:
-		ym3812_control_port_0_w(space,0,data);
-		break;
-	case 1:
-		ym3812_write_port_0_w(space,0,data);
-		break;
-	}
-}
-
-static WRITE8_HANDLER( YM2203_w )
-{
-	switch (offset) {
-	case 0:
-		ym2203_control_port_0_w(space,0,data);
-		break;
-	case 1:
-		ym2203_write_port_0_w(space,0,data);
-		break;
-	}
-}
-
 static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x05ff) AM_RAM
-	AM_RANGE(0x0800, 0x0801) AM_WRITE(YM2203_w)
-	AM_RANGE(0x1000, 0x1001) AM_WRITE(YM3812_w)
+	AM_RANGE(0x0800, 0x0801) AM_DEVWRITE("ym1", ym2203_w)
+	AM_RANGE(0x1000, 0x1001) AM_DEVWRITE("ym2", ym3812_w)
 	AM_RANGE(0x3000, 0x3000) AM_READ(soundlatch_r)
-	AM_RANGE(0x3800, 0x3800) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
+	AM_RANGE(0x3800, 0x3800) AM_DEVREADWRITE("oki", okim6295_r, okim6295_w)
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -231,9 +207,9 @@ GFXDECODE_END
 
 /******************************************************************************/
 
-static void irqhandler(running_machine *machine, int linestate)
+static void irqhandler(const device_config *device, int linestate)
 {
-	cpu_set_input_line(machine->cpu[1],0,linestate);
+	cputag_set_input_line(device->machine, "audiocpu", 0, linestate);
 }
 
 static const ym3812_interface ym3812_config =
@@ -246,15 +222,15 @@ static const ym3812_interface ym3812_config =
 static MACHINE_DRIVER_START( stadhero )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000, 10000000)
-	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT("main", irq5_line_hold)/* VBL */
+	MDRV_CPU_ADD("maincpu", M68000, 10000000)
+	MDRV_CPU_PROGRAM_MAP(main_map)
+	MDRV_CPU_VBLANK_INT("screen", irq5_line_hold)/* VBL */
 
-	MDRV_CPU_ADD("audio", M6502, 1500000)
-	MDRV_CPU_PROGRAM_MAP(audio_map,0)
+	MDRV_CPU_ADD("audiocpu", M6502, 1500000)
+	MDRV_CPU_PROGRAM_MAP(audio_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(58)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -288,11 +264,11 @@ MACHINE_DRIVER_END
 /******************************************************************************/
 
 ROM_START( stadhero )
-	ROM_REGION( 0x20000, "main", 0 )	/* 6*64k for 68000 code */
+	ROM_REGION( 0x20000, "maincpu", 0 )	/* 6*64k for 68000 code */
 	ROM_LOAD16_BYTE( "ef15.bin",  0x00000, 0x10000, CRC(bbba364e) SHA1(552096102f402085596635f02096462c6b8e13a7) )
 	ROM_LOAD16_BYTE( "ef13.bin",  0x00001, 0x10000, CRC(97c6717a) SHA1(6c81260f49a59f70c71f520e51330a6833828684) )
 
-	ROM_REGION( 0x10000, "audio", 0 )	/* 6502 Sound */
+	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 6502 Sound */
 	ROM_LOAD( "ef18.bin",  0x8000, 0x8000, CRC(20fd9668) SHA1(058e34a0ebfc372aaa9230c2bc9164ee2e85e217) )
 
 	ROM_REGION( 0x18000, "gfx1", ROMREGION_DISPOSE )
