@@ -4,8 +4,12 @@ Thunder Hoop II: Strikes Back (c) 1994 Gaelco
 
 Driver by Manuel Abadia <manu@teleline.es>
 
+updated by Peter Ferrie <peter.ferrie@gmail.com>
+
 Very similar to maniacsq and biomtoy but protected :_(
 The DS5002FP has up to 128 KB undumped gameplay code
+pf: its presence might be a distraction, since the game runs at least partially without it
+pf: but some gameplay bugs - sprite positioning is incorrect, no enemies, jump animation never completes
 
 ***************************************************************************/
 
@@ -54,20 +58,6 @@ static GFXDECODE_START( thoop2 )
 GFXDECODE_END
 
 
-static ADDRESS_MAP_START( thoop2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)			/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_READ(SMH_RAM)			/* Video RAM */
-	AM_RANGE(0x200000, 0x2007ff) AM_READ(SMH_RAM)			/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SMH_RAM)			/* Sprite RAM */
-	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
-	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
-	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
-	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
-	AM_RANGE(0x700008, 0x700009) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0x70000e, 0x70000f) AM_READ(okim6295_status_0_lsb_r)/* OKI6295 status register */
-	AM_RANGE(0xfe0000, 0xfeffff) AM_READ(SMH_RAM)			/* Work RAM (partially shared with DS5002FP) */
-ADDRESS_MAP_END
-
 static WRITE16_HANDLER( OKIM6295_bankswitch_w )
 {
 	UINT8 *RAM = memory_region(space->machine, "oki");
@@ -96,17 +86,31 @@ static WRITE16_HANDLER( thoop2_coin_w )
 	/* 05b unknown */
 }
 
-static ADDRESS_MAP_START( thoop2_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)								/* ROM */
-	AM_RANGE(0x100000, 0x101fff) AM_WRITE(thoop2_vram_w) AM_BASE(&thoop2_videoram)		/* Video RAM */
-	AM_RANGE(0x108000, 0x108007) AM_WRITE(SMH_RAM) AM_BASE(&thoop2_vregs)				/* Video Registers */
-	AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset16_w)						/* INT 6 ACK/Watchdog timer */
-	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SMH_RAM) AM_BASE(&thoop2_spriteram)			/* Sprite RAM */
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)					/* OKI6295 bankswitch */
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(okim6295_data_0_lsb_w)					/* OKI6295 data register */
-	AM_RANGE(0x70000a, 0x70005b) AM_WRITE(thoop2_coin_w)							/* Coin Counters + Coin Lockout */
-	AM_RANGE(0xfe0000, 0xfeffff) AM_WRITE(SMH_RAM)								/* Work RAM (partially shared with DS5002FP) */
+/* pretend that it's there */
+
+static READ16_HANDLER( DS5002FP_R )
+{
+    return 0x55aa;
+}
+
+static ADDRESS_MAP_START( thoop2_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM													/* ROM */
+	AM_RANGE(0x100000, 0x101fff) AM_RAM_WRITE(thoop2_vram_w) AM_BASE(&thoop2_videoram)	/* Video RAM */
+	AM_RANGE(0x108000, 0x108007) AM_WRITEONLY AM_BASE(&thoop2_vregs)					/* Video Registers */
+	AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset16_w)							/* INT 6 ACK/Watchdog timer */
+	AM_RANGE(0x200000, 0x2007ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
+	AM_RANGE(0x440000, 0x440fff) AM_RAM AM_BASE(&thoop2_spriteram)						/* Sprite RAM */
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW2")
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("DSW1")
+	AM_RANGE(0x700004, 0x700005) AM_READ_PORT("P1")
+	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("P2")
+	AM_RANGE(0x700008, 0x700009) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)						/* OKI6295 bankswitch */
+	AM_RANGE(0x70000e, 0x70000f) AM_DEVREADWRITE8("oki", okim6295_r, okim6295_w, 0x00ff)					/* OKI6295 data register */
+	AM_RANGE(0x70000a, 0x70005b) AM_WRITE(thoop2_coin_w)								/* Coin Counters + Coin Lockout */
+	AM_RANGE(0xfeff00, 0xfeff01) AM_READ(DS5002FP_R)
+	AM_RANGE(0xfeff02, 0xfeff03) AM_WRITENOP  /* pf: 0xfeff02 and 0xfeff03 need to remain zero always */
+	AM_RANGE(0xfe0000, 0xfeffff) AM_RAM													/* Work RAM (partially shared with DS5002FP) */
 ADDRESS_MAP_END
 
 
@@ -194,12 +198,12 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( thoop2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M68000,24000000/2)			/* 12 MHz */
-	MDRV_CPU_PROGRAM_MAP(thoop2_readmem,thoop2_writemem)
-	MDRV_CPU_VBLANK_INT("main", irq6_line_hold)
+	MDRV_CPU_ADD("maincpu", M68000,24000000/2)			/* 12 MHz */
+	MDRV_CPU_PROGRAM_MAP(thoop2_map)
+	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -222,7 +226,7 @@ MACHINE_DRIVER_END
 
 
 ROM_START( thoop2 )
-	ROM_REGION( 0x100000, "main", 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, "maincpu", 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE(	"th2c23.040",	0x000000, 0x080000, CRC(3e465753) SHA1(1ea1173b9fe5d652e7b5fafb822e2535cecbc198) )
 	ROM_LOAD16_BYTE(	"th2c22.040",	0x000001, 0x080000, CRC(837205b7) SHA1(f78b90c2be0b4dddaba26f074ea00eff863cfdb2) )
 
@@ -236,4 +240,4 @@ ROM_START( thoop2 )
 	/* 0x00000-0x2ffff is fixed, 0x30000-0x3ffff is bank switched */
 ROM_END
 
-GAME( 1994, thoop2,  0, thoop2, thoop2,  0, ROT0, "Gaelco", "TH Strikes Back", GAME_UNEMULATED_PROTECTION )
+GAME( 1994, thoop2,  0, thoop2, thoop2,  0, ROT0, "Gaelco", "TH Strikes Back", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
