@@ -110,16 +110,16 @@ static const struct namcoio_interface intf2 =
 
 static DRIVER_INIT( 58c_56_56 )
 {
-	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0_coin);
-	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1);
-	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2);
+	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0_coin, NULL);
+	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1, NULL);
+	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2, NULL);
 }
 
 static DRIVER_INIT( 58_56_56 )
 {
-	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0);
-	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1);
-	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2);
+	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0, NULL);
+	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1, NULL);
+	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2, NULL);
 }
 
 
@@ -130,15 +130,15 @@ static int interrupt_enable_68k;
 static UINT8 *toypop_m68000_sharedram;
 
 
-static READ8_HANDLER( toypop_sound_sharedram_r )
+static READ8_DEVICE_HANDLER( toypop_sound_sharedram_r )
 {
 	return namco_soundregs[offset];
 }
 
-static WRITE8_HANDLER( toypop_sound_sharedram_w )
+static WRITE8_DEVICE_HANDLER( toypop_sound_sharedram_w )
 {
 	if (offset < 0x40)
-		namco_15xx_w(space,offset,data);
+		namco_15xx_w(device,offset,data);
 	else
 		namco_soundregs[offset] = data;
 }
@@ -156,68 +156,68 @@ static WRITE16_HANDLER( toypop_m68000_sharedram_w )
 
 static READ8_HANDLER( toypop_main_interrupt_enable_r )
 {
-	cpu_interrupt_enable(space->machine->cpu[0],1);
+	cpu_interrupt_enable(cputag_get_cpu(space->machine, "maincpu"), 1);
 	return 0;
 }
 
 static WRITE8_HANDLER( toypop_main_interrupt_enable_w )
 {
-	cpu_interrupt_enable(space->machine->cpu[0],1);
-	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
+	cpu_interrupt_enable(cputag_get_cpu(space->machine, "maincpu"), 1);
+	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_main_interrupt_disable_w )
 {
-	cpu_interrupt_enable(space->machine->cpu[0],0);
+	cpu_interrupt_enable(cputag_get_cpu(space->machine, "maincpu"), 0);
 }
 
 static WRITE8_HANDLER( toypop_sound_interrupt_enable_acknowledge_w )
 {
-	cpu_interrupt_enable(space->machine->cpu[1],1);
-	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
+	cpu_interrupt_enable(cputag_get_cpu(space->machine, "audiocpu"), 1);
+	cputag_set_input_line(space->machine, "audiocpu", 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_interrupt_disable_w )
 {
-	cpu_interrupt_enable(space->machine->cpu[1],0);
+	cpu_interrupt_enable(cputag_get_cpu(space->machine, "audiocpu"), 0);
 }
 
 static INTERRUPT_GEN( toypop_main_interrupt )
 {
 	irq0_line_assert(device);	// this also checks if irq is enabled - IMPORTANT!
-						// so don't replace with cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
+								// so don't replace with cputag_set_input_line(machine, "maincpu", 0, ASSERT_LINE);
 
-	namcoio_set_irq_line(device->machine,0,PULSE_LINE);
-	namcoio_set_irq_line(device->machine,1,PULSE_LINE);
-	namcoio_set_irq_line(device->machine,2,PULSE_LINE);
+	namcoio_set_irq_line(device->machine, 0, PULSE_LINE);
+	namcoio_set_irq_line(device->machine, 1, PULSE_LINE);
+	namcoio_set_irq_line(device->machine, 2, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_clear_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_assert_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( toypop_m68000_clear_w )
 {
-	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "sub", INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_m68000_assert_w )
 {
-	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, ASSERT_LINE);
+	cputag_set_input_line(space->machine, "sub", INPUT_LINE_RESET, ASSERT_LINE);
 }
 
 static TIMER_CALLBACK( disable_interrupts )
 {
-	cpu_interrupt_enable(machine->cpu[0],0);
-	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
-	cpu_interrupt_enable(machine->cpu[1],0);
-	cpu_set_input_line(machine->cpu[1], 0, CLEAR_LINE);
+	cpu_interrupt_enable(cputag_get_cpu(machine, "maincpu"), 0);
+	cputag_set_input_line(machine, "maincpu", 0, CLEAR_LINE);
+	cpu_interrupt_enable(cputag_get_cpu(machine, "audiocpu"), 0);
+	cputag_set_input_line(machine, "audiocpu", 0, CLEAR_LINE);
 	interrupt_enable_68k = 0;
 }
 
@@ -252,61 +252,45 @@ static WRITE16_HANDLER( toypop_m68000_interrupt_disable_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( readmem_mainCPU_liblrabl, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_RAM)								/* RAM everywhere else */
-	AM_RANGE(0x6000, 0x63ff) AM_READ(toypop_sound_sharedram_r)				/* shared RAM with sound CPU */
-	AM_RANGE(0x6800, 0x683f) AM_READ(namcoio_r)								/* custom I/O */
-	AM_RANGE(0x7800, 0x7800) AM_READ(watchdog_reset_r)						/* not sure; this is NOT irq enable (game crashes otherwise) */
-	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)								/* ROM code */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( readmem_mainCPU_toypop, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_RAM)								/* RAM everywhere else */
-	AM_RANGE(0x6000, 0x603f) AM_READ(namcoio_r)								/* custom I/O */
-	AM_RANGE(0x6800, 0x6bff) AM_READ(toypop_sound_sharedram_r)				/* shared RAM with sound CPU */
-	AM_RANGE(0x7000, 0x7000) AM_READ(toypop_main_interrupt_enable_r)			/* enable interrupt?? */
-	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)								/* ROM code */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem_mainCPU_liblrabl, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
-	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 1 */
-	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
-	AM_RANGE(0x1000, 0x177f) AM_WRITE(SMH_RAM)								/* general RAM, area 2 */
-	AM_RANGE(0x1780, 0x17ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
-	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 3 */
-	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
-	AM_RANGE(0x6000, 0x63ff) AM_WRITE(toypop_sound_sharedram_w)				/* shared RAM with sound CPU */
-	AM_RANGE(0x6800, 0x683f) AM_WRITE(namcoio_w)								/* custom I/O */
-	AM_RANGE(0x7000, 0x7000) AM_WRITE(toypop_main_interrupt_enable_w)			/* enable interrupt */
-	AM_RANGE(0x7800, 0x7800) AM_WRITE(toypop_main_interrupt_disable_w)		/* disable interrupt */
-	AM_RANGE(0x8000, 0x8000) AM_WRITE(toypop_m68000_clear_w)					/* reset 68000 */
-	AM_RANGE(0x8800, 0x8800) AM_WRITE(toypop_m68000_assert_w)					/* reset 68000 */
+static ADDRESS_MAP_START( liblrabl_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_RAM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
+	AM_RANGE(0x0800, 0x0f7f) AM_RAM											/* general RAM, area 1 */
+	AM_RANGE(0x0f80, 0x0fff) AM_RAM AM_BASE(&spriteram)						/* sprite RAM, area 1 */
+	AM_RANGE(0x1000, 0x177f) AM_RAM											/* general RAM, area 2 */
+	AM_RANGE(0x1780, 0x17ff) AM_RAM AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
+	AM_RANGE(0x1800, 0x1f7f) AM_RAM											/* general RAM, area 3 */
+	AM_RANGE(0x1f80, 0x1fff) AM_RAM AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
+	AM_RANGE(0x2800, 0x2fff) AM_RAM AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
+	AM_RANGE(0x6000, 0x63ff) AM_DEVREADWRITE("namco", toypop_sound_sharedram_r, toypop_sound_sharedram_w) /* shared RAM with sound CPU */
+	AM_RANGE(0x6800, 0x683f) AM_READWRITE(namcoio_r, namcoio_w)				/* custom I/O */
+	AM_RANGE(0x7000, 0x7000) AM_WRITE(toypop_main_interrupt_enable_w)		/* enable interrupt */
+	AM_RANGE(0x7800, 0x7800) AM_READWRITE(watchdog_reset_r, toypop_main_interrupt_disable_w) /* disable interrupt */
+	AM_RANGE(0x8000, 0x8000) AM_WRITE(toypop_m68000_clear_w)				/* reset 68000 */
+	AM_RANGE(0x8800, 0x8800) AM_WRITE(toypop_m68000_assert_w)				/* reset 68000 */
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(toypop_sound_clear_w)					/* sound CPU reset */
-	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)					/* sound CPU reset */
+	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)				/* sound CPU reset */
 	AM_RANGE(0xa000, 0xa001) AM_WRITE(toypop_palettebank_w)					/* background image palette */
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_ROM											/* ROM code */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writemem_mainCPU_toypop, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
-	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 1 */
-	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
-	AM_RANGE(0x1000, 0x177f) AM_WRITE(SMH_RAM)								/* general RAM, area 2 */
-	AM_RANGE(0x1780, 0x17ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
-	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 3 */
-	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
-	AM_RANGE(0x6000, 0x603f) AM_WRITE(namcoio_w)								/* custom I/O */
-	AM_RANGE(0x6800, 0x6bff) AM_WRITE(toypop_sound_sharedram_w)				/* shared RAM with sound CPU */
-	AM_RANGE(0x7000, 0x7000) AM_WRITE(toypop_main_interrupt_disable_w)		/* disable interrupt */
-	AM_RANGE(0x8000, 0x8000) AM_WRITE(toypop_m68000_clear_w)					/* reset 68000 */
-	AM_RANGE(0x8800, 0x8800) AM_WRITE(toypop_m68000_assert_w)					/* reset 68000 */
+static ADDRESS_MAP_START( toypop_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_RAM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
+	AM_RANGE(0x0800, 0x0f7f) AM_RAM											/* general RAM, area 1 */
+	AM_RANGE(0x0f80, 0x0fff) AM_RAM AM_BASE(&spriteram)						/* sprite RAM, area 1 */
+	AM_RANGE(0x1000, 0x177f) AM_RAM											/* general RAM, area 2 */
+	AM_RANGE(0x1780, 0x17ff) AM_RAM AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
+	AM_RANGE(0x1800, 0x1f7f) AM_RAM											/* general RAM, area 3 */
+	AM_RANGE(0x1f80, 0x1fff) AM_RAM AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
+	AM_RANGE(0x2800, 0x2fff) AM_RAM AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
+	AM_RANGE(0x6000, 0x603f) AM_READWRITE(namcoio_r, namcoio_w)				/* custom I/O */
+	AM_RANGE(0x6800, 0x6bff) AM_DEVREADWRITE("namco", toypop_sound_sharedram_r, toypop_sound_sharedram_w) /* shared RAM with sound CPU */
+	AM_RANGE(0x7000, 0x7000) AM_READWRITE(toypop_main_interrupt_enable_r, toypop_main_interrupt_disable_w) /* disable interrupt */
+	AM_RANGE(0x8000, 0x8000) AM_WRITE(toypop_m68000_clear_w)				/* reset 68000 */
+	AM_RANGE(0x8800, 0x8800) AM_WRITE(toypop_m68000_assert_w)				/* reset 68000 */
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(toypop_sound_clear_w)					/* sound CPU reset */
-	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)					/* sound CPU reset */
+	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)				/* sound CPU reset */
 	AM_RANGE(0xa000, 0xa001) AM_WRITE(toypop_palettebank_w)					/* background image palette */
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_ROM											/* ROM code */
 ADDRESS_MAP_END
 
 
@@ -316,17 +300,12 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( readmem_soundCPU, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_READ(toypop_sound_sharedram_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem_soundCPU, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_WRITE(toypop_sound_sharedram_w) AM_BASE(&namco_soundregs)	/* shared RAM with the main CPU + sound registers */
+static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x03ff) AM_DEVREADWRITE("namco", toypop_sound_sharedram_r, toypop_sound_sharedram_w) AM_BASE(&namco_soundregs)	/* shared RAM with the main CPU + sound registers */
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(toypop_sound_interrupt_disable_w)	/* ??? toypop doesn't write here */
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(toypop_sound_interrupt_enable_acknowledge_w)
 	AM_RANGE(0x6000, 0x6000) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 
@@ -337,23 +316,15 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( readmem_68k, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x007fff) AM_READ(SMH_ROM)				// ROM code
-	AM_RANGE(0x080000, 0x0bffff) AM_READ(SMH_RAM)				// RAM
-	AM_RANGE(0x100000, 0x100fff) AM_READ(toypop_m68000_sharedram_r)	// shared RAM with the main CPU
-	AM_RANGE(0x180000, 0x187fff) AM_READ(toypop_merged_background_r)	// RAM merged with the background image
-	AM_RANGE(0x190000, 0x1dffff) AM_READ(SMH_RAM)				// RAM containing the background image
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem_68k, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x007fff) AM_WRITE(SMH_ROM)						/* ROM code */
-	AM_RANGE(0x080000, 0x0bffff) AM_WRITE(SMH_RAM)						/* RAM */
-	AM_RANGE(0x100000, 0x100fff) AM_WRITE(toypop_m68000_sharedram_w)		/* shared RAM with the main CPU */
-	AM_RANGE(0x180000, 0x187fff) AM_WRITE(toypop_merged_background_w)		/* RAM that has to be merged with the background image */
-	AM_RANGE(0x18fffc, 0x18ffff) AM_WRITE(toypop_flipscreen_w)			/* flip mode */
-	AM_RANGE(0x190000, 0x1dffff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_bg_image)			/* RAM containing the background image */
-	AM_RANGE(0x300000, 0x300001) AM_WRITE(toypop_m68000_interrupt_enable_w)		/* interrupt enable */
-	AM_RANGE(0x380000, 0x380001) AM_WRITE(toypop_m68000_interrupt_disable_w)		/* interrupt disable */
+static ADDRESS_MAP_START( m68k_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x007fff) AM_ROM										/* ROM code */
+	AM_RANGE(0x080000, 0x0bffff) AM_RAM										/* RAM */
+	AM_RANGE(0x100000, 0x100fff) AM_READWRITE(toypop_m68000_sharedram_r, toypop_m68000_sharedram_w)	/* shared RAM with the main CPU */
+	AM_RANGE(0x180000, 0x187fff) AM_READWRITE(toypop_merged_background_r, toypop_merged_background_w) /* RAM that has to be merged with the background image */
+	AM_RANGE(0x18fffc, 0x18ffff) AM_WRITE(toypop_flipscreen_w)				/* flip mode */
+	AM_RANGE(0x190000, 0x1dffff) AM_RAM AM_BASE(&toypop_bg_image)			/* RAM containing the background image */
+	AM_RANGE(0x300000, 0x300001) AM_WRITE(toypop_m68000_interrupt_enable_w)	/* interrupt enable */
+	AM_RANGE(0x380000, 0x380001) AM_WRITE(toypop_m68000_interrupt_disable_w)/* interrupt disable */
 ADDRESS_MAP_END
 
 
@@ -570,24 +541,24 @@ static const namco_interface namco_config =
 static MACHINE_DRIVER_START( liblrabl )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("main", M6809, 1536000)	/* 1.536 MHz (measured on Libble Rabble board) */
-	MDRV_CPU_PROGRAM_MAP(readmem_mainCPU_liblrabl,writemem_mainCPU_liblrabl)
-	MDRV_CPU_VBLANK_INT("main", toypop_main_interrupt)
+	MDRV_CPU_ADD("maincpu", M6809, 1536000)	/* 1.536 MHz (measured on Libble Rabble board) */
+	MDRV_CPU_PROGRAM_MAP(liblrabl_map)
+	MDRV_CPU_VBLANK_INT("screen", toypop_main_interrupt)
 
-	MDRV_CPU_ADD("audio", M6809, 1536000)
-	MDRV_CPU_PROGRAM_MAP(readmem_soundCPU,writemem_soundCPU)
-	MDRV_CPU_VBLANK_INT("main", irq0_line_assert)
+	MDRV_CPU_ADD("audiocpu", M6809, 1536000)
+	MDRV_CPU_PROGRAM_MAP(sound_map)
+	MDRV_CPU_VBLANK_INT("screen", irq0_line_assert)
 
 	MDRV_CPU_ADD("sub", M68000, 6144000)	/* 6.144 MHz (measured on Libble Rabble board) */
-	MDRV_CPU_PROGRAM_MAP(readmem_68k,writemem_68k)
-	MDRV_CPU_VBLANK_INT("main", toypop_m68000_interrupt)
+	MDRV_CPU_PROGRAM_MAP(m68k_map)
+	MDRV_CPU_VBLANK_INT("screen", toypop_m68000_interrupt)
 
 	MDRV_QUANTUM_TIME(HZ(6000))    /* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
 	MDRV_MACHINE_RESET(toypop)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60.606060)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -613,8 +584,8 @@ static MACHINE_DRIVER_START( toypop )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(liblrabl)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(readmem_mainCPU_toypop,writemem_mainCPU_toypop)
+	MDRV_CPU_MODIFY("maincpu")
+	MDRV_CPU_PROGRAM_MAP(toypop_map)
 MACHINE_DRIVER_END
 
 
@@ -626,11 +597,11 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( liblrabl )
-	ROM_REGION( 0x10000, "main", 0 )	/* 64k for the first CPU */
+	ROM_REGION( 0x10000, "maincpu", 0 )	/* 64k for the first CPU */
 	ROM_LOAD( "5b.rom",   0x8000, 0x4000, CRC(da7a93c2) SHA1(fe4a02cdab66722eb7b8cf58825f899b1949a6a2) )
 	ROM_LOAD( "5c.rom",   0xc000, 0x4000, CRC(6cae25dc) SHA1(de74317a7d5de1865d096c377923a764be5e6879) )
 
-	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "2c.rom",   0xe000, 0x2000, CRC(7c09e50a) SHA1(5f004d60bbb7355e008a9cda137b28bc2192b8ef) )
 
 	ROM_REGION( 0x8000, "sub", 0 )		/* 32k for the third CPU */
@@ -656,11 +627,11 @@ ROM_START( liblrabl )
 ROM_END
 
 ROM_START( toypop )
-	ROM_REGION( 0x10000, "main", 0 )	/* 64k for the first CPU */
+	ROM_REGION( 0x10000, "maincpu", 0 )	/* 64k for the first CPU */
 	ROM_LOAD( "tp1-2.5b", 0x8000, 0x4000, CRC(87469620) SHA1(2ee257486c9c044386ac7d0cd4a90583eaeb3e97) )
 	ROM_LOAD( "tp1-1.5c", 0xc000, 0x4000, CRC(dee2fd6e) SHA1(b2c12008d6d3e7544ba3c12a52a6abf9181842c8) )
 
-	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "tp1-3.2c", 0xe000, 0x2000, CRC(5f3bf6e2) SHA1(d1b3335661b9b23cb10001416c515b77b5e783e9) )
 
 	ROM_REGION( 0x8000, "sub", 0 )		/* 32k for the third CPU */
