@@ -84,7 +84,7 @@ static READ32_HANDLER( vegaeo_custom_read )
 static ADDRESS_MAP_START( vega_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x001fffff) AM_RAM
 	AM_RANGE(0x80000000, 0x80013fff) AM_READWRITE(vega_vram_r, vega_vram_w)
-	AM_RANGE(0xfc000000, 0xfc0000ff) AM_DEVREADWRITE8(AT28C16, "at28c16", at28c16_r, at28c16_w, 0x000000ff)
+	AM_RANGE(0xfc000000, 0xfc0000ff) AM_DEVREADWRITE8("at28c16", at28c16_r, at28c16_w, 0x000000ff)
 	AM_RANGE(0xfc200000, 0xfc2003ff) AM_RAM_WRITE(vega_palette_w) AM_BASE(&paletteram32)
 	AM_RANGE(0xfc400000, 0xfc40005b) AM_WRITENOP // crt registers ?
 	AM_RANGE(0xfc600000, 0xfc600003) AM_WRITENOP // soundlatch
@@ -130,7 +130,7 @@ INPUT_PORTS_END
 
 static VIDEO_START( vega )
 {
-	vega_vram = auto_malloc(0x14000*2);
+	vega_vram = auto_alloc_array(machine, UINT32, 0x14000*2/4);
 }
 
 static VIDEO_UPDATE( vega )
@@ -164,13 +164,13 @@ static VIDEO_UPDATE( vega )
 
 static MACHINE_DRIVER_START( vega )
 	MDRV_CPU_ADD("cpu", GMS30C2132, 55000000)	/* 55 MHz */
-	MDRV_CPU_PROGRAM_MAP(vega_map,0)
+	MDRV_CPU_PROGRAM_MAP(vega_map)
 	MDRV_CPU_VBLANK_INT_HACK(eolith_speedup,262)
 
 	/* sound cpu */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_ADD("screen", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
