@@ -4,7 +4,6 @@
 
 *************************************************************************/
 
-#include "sound/custom.h"
 #include "machine/z80ctc.h"
 
 /*----------- defined in machine/cchasm.c -----------*/
@@ -13,10 +12,11 @@ WRITE16_HANDLER( cchasm_led_w );
 
 /*----------- defined in audio/cchasm.c -----------*/
 
-extern z80ctc_interface cchasm_ctc_intf;
+extern const z80ctc_interface cchasm_ctc_intf;
 
-READ8_HANDLER( cchasm_snd_io_r );
-WRITE8_HANDLER( cchasm_snd_io_w );
+READ8_HANDLER( cchasm_coin_sound_r );
+READ8_HANDLER( cchasm_soundlatch2_r );
+WRITE8_HANDLER( cchasm_soundlatch4_w );
 
 WRITE16_HANDLER( cchasm_io_w );
 READ16_HANDLER( cchasm_io_r );
