@@ -12,4 +12,7 @@ VIDEO_UPDATE( eprom );
 VIDEO_START( guts );
 VIDEO_UPDATE( guts );
 
-void eprom_scanline_update(running_machine *machine, int scrnum, int scanline);
+void eprom_scanline_update(const device_config *screen, int scanline);
+
+extern int eprom_screen_intensity;
+extern int eprom_video_disable;
