@@ -1,3 +1,5 @@
+/*----------- defined in video/ninjakd2.c -----------*/
+
 extern WRITE8_HANDLER( ninjakd2_bgvideoram_w );
 extern WRITE8_HANDLER( ninjakd2_fgvideoram_w );
 extern WRITE8_HANDLER( ninjakd2_bg_ctrl_w );
@@ -18,6 +20,7 @@ extern WRITE8_HANDLER( robokid_bg2_bank_w );
 
 extern VIDEO_START( ninjakd2 );
 extern VIDEO_START( mnight );
+extern VIDEO_START( arkarea );
 extern VIDEO_START( robokid );
 extern VIDEO_START( omegaf );
 extern VIDEO_UPDATE( ninjakd2 );
