@@ -25,7 +25,7 @@ VIDEO_START( taitof2_metalb );
 VIDEO_START( taitof2_qzchikyu );
 VIDEO_START( taitof2_yesnoj );
 VIDEO_START( taitof2_deadconx );
-VIDEO_START( taitof2_deadconj );
+VIDEO_START( taitof2_deadconxj );
 VIDEO_START( taitof2_dinorex );
 VIDEO_EOF( taitof2_no_buffer );
 VIDEO_EOF( taitof2_full_buffer_delayed );
@@ -46,10 +46,3 @@ WRITE16_HANDLER( taitof2_spritebank_w );
 READ16_HANDLER ( koshien_spritebank_r );
 WRITE16_HANDLER( koshien_spritebank_w );
 WRITE16_HANDLER( taitof2_sprite_extension_w );
-
-/*----------- defined in machine/cchip.c -----------*/
-
-extern UINT16 *cchip2_ram;
-READ16_HANDLER ( cchip2_word_r );
-WRITE16_HANDLER( cchip2_word_w );
-
