@@ -46,7 +46,7 @@ void jumpshot_decode(running_machine *machine)
 
 	/* CPU ROMs */
 
-	RAM = memory_region(machine, "main");
+	RAM = memory_region(machine, "maincpu");
 	for (i = 0; i < 0x4000; i++)
 	{
 		RAM[i] = decrypt(i,RAM[i]);
