@@ -28,7 +28,7 @@ static UINT8 gamma_irq_clock;
 
 static UINT8 has_gamma_cpu;
 
-
+static UINT8 speech_write_buffer;
 
 /*************************************
  *
@@ -44,7 +44,7 @@ static TIMER_CALLBACK( cpu_irq_clock )
 		alpha_irq_clock++;
 		if ((alpha_irq_clock & 0x0c) == 0x0c)
 		{
-			cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
+			cputag_set_input_line(machine, "alpha", 0, ASSERT_LINE);
 			alpha_irq_clock_enable = 0;
 		}
 	}
@@ -53,7 +53,7 @@ static TIMER_CALLBACK( cpu_irq_clock )
 	if (has_gamma_cpu)
 	{
 		gamma_irq_clock++;
-		cpu_set_input_line(machine->cpu[1], 0, (gamma_irq_clock & 0x08) ? ASSERT_LINE : CLEAR_LINE);
+		cputag_set_input_line(machine, "gamma", 0, (gamma_irq_clock & 0x08) ? ASSERT_LINE : CLEAR_LINE);
 	}
 }
 
@@ -61,7 +61,7 @@ static TIMER_CALLBACK( cpu_irq_clock )
 WRITE8_HANDLER( mhavoc_alpha_irq_ack_w )
 {
 	/* clear the line and reset the clock */
-	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "alpha", 0, CLEAR_LINE);
 	alpha_irq_clock = 0;
 	alpha_irq_clock_enable = 1;
 }
@@ -70,7 +70,7 @@ WRITE8_HANDLER( mhavoc_alpha_irq_ack_w )
 WRITE8_HANDLER( mhavoc_gamma_irq_ack_w )
 {
 	/* clear the line and reset the clock */
-	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine, "gamma", 0, CLEAR_LINE);
 	gamma_irq_clock = 0;
 }
 
@@ -84,8 +84,8 @@ WRITE8_HANDLER( mhavoc_gamma_irq_ack_w )
 
 MACHINE_RESET( mhavoc )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
-	has_gamma_cpu = (machine->cpu[1] != NULL);
+	const address_space *space = cputag_get_address_space(machine, "alpha", ADDRESS_SPACE_PROGRAM);
+	has_gamma_cpu = (cputag_get_cpu(machine, "gamma") != NULL);
 
 	memory_configure_bank(machine, 1, 0, 1, mhavoc_zram0, 0);
 	memory_configure_bank(machine, 1, 1, 1, mhavoc_zram1, 0);
@@ -126,6 +126,8 @@ MACHINE_RESET( mhavoc )
 	state_save_register_item(machine, "misc", NULL, 0, alpha_irq_clock);
 	state_save_register_item(machine, "misc", NULL, 0, alpha_irq_clock_enable);
 	state_save_register_item(machine, "misc", NULL, 0, gamma_irq_clock);
+
+	state_save_register_item(machine, "misc", NULL, 0, speech_write_buffer);
 }
 
 
@@ -144,7 +146,7 @@ static TIMER_CALLBACK( delayed_gamma_w )
 	alpha_data = param;
 
 	/* signal with an NMI pulse */
-	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(machine, "gamma", INPUT_LINE_NMI, PULSE_LINE);
 
 	/* the sound CPU needs to reply in 250microseconds (according to Neil Bradley) */
 	timer_set(machine, ATTOTIME_IN_USEC(250), NULL, 0, 0);
@@ -220,12 +222,12 @@ WRITE8_HANDLER( mhavoc_rom_banksel_w )
 
 CUSTOM_INPUT( tms5220_r )
 {
-	return tms5220_ready_r() ? 0 : 1;
+	return tms5220_ready_r(devtag_get_device(field->port->machine, "tms")) ? 0 : 1;
 }
 
 CUSTOM_INPUT( mhavoc_bit67_r )
 {
-	const char *tag1 = param;
+	const char *tag1 = (const char *)param;
 	const char *tag2 = tag1 + strlen(tag1) + 1;
 	return input_port_read(field->port->machine, player_1 ? tag2 : tag1) & 0x03;
 }
@@ -269,7 +271,7 @@ WRITE8_HANDLER( mhavoc_out_0_w )
 	player_1 = (data >> 5) & 1;
 
 	/* Bit 3 = Gamma reset */
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (data & 0x08) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(space->machine, "gamma", INPUT_LINE_RESET, (data & 0x08) ? CLEAR_LINE : ASSERT_LINE);
 	if (!(data & 0x08))
 	{
 		logerror("\t\t\t\t*** resetting gamma processor. ***\n");
@@ -310,3 +312,35 @@ WRITE8_HANDLER( mhavoc_out_1_w )
 	/* Bit 0 = right coin counter */
 	coin_counter_w(1, data & 0x01);
 }
+
+/*************************************
+ *
+ *  Speech access
+ *
+ *************************************/
+
+static WRITE8_HANDLER( mhavocrv_speech_data_w )
+{
+	speech_write_buffer = data;
+}
+
+
+static WRITE8_HANDLER( mhavocrv_speech_strobe_w )
+{
+	const device_config *tms = devtag_get_device(space->machine, "tms");
+	tms5220_data_w(tms, 0, speech_write_buffer);
+}
+
+/*************************************
+ *
+ *  Driver-specific init
+ *
+ *************************************/
+
+DRIVER_INIT( mhavocrv )
+{
+	/* install the speech support that was only optionally stuffed for use */
+	/* in the Return to Vax hack */
+	memory_install_write8_handler(cputag_get_address_space(machine, "gamma", ADDRESS_SPACE_PROGRAM), 0x5800, 0x5800, 0, 0, mhavocrv_speech_data_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "gamma", ADDRESS_SPACE_PROGRAM), 0x5900, 0x5900, 0, 0, mhavocrv_speech_strobe_w);
+}
