@@ -5,7 +5,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "debugger.h"
 #include "midwayic.h"
 #include "machine/idectrl.h"
@@ -70,11 +69,11 @@ struct ioasic_state
 	UINT32	reg[16];
 	UINT8	has_dcs;
 	UINT8	has_cage;
-	UINT8	dcs_cpu;
+	const device_config *dcs_cpu;
 	UINT8	shuffle_type;
 	UINT8	shuffle_active;
 	const UINT8 *	shuffle_map;
-	void 	(*irq_callback)(int);
+	void 	(*irq_callback)(running_machine *, int);
 	UINT8	irq_state;
 	UINT16	sound_irq_state;
 	UINT8	auto_ack;
@@ -108,9 +107,9 @@ static struct ioasic_state ioasic;
  *
  *************************************/
 
-static void generate_serial_data(int upper)
+static void generate_serial_data(running_machine *machine, int upper)
 {
-	int year = atoi(Machine->gamedrv->year), month = 12, day = 11;
+	int year = atoi(machine->gamedrv->year), month = 12, day = 11;
 	UINT32 serial_number, temp;
 	UINT8 serial_digit[9];
 
@@ -127,8 +126,8 @@ static void generate_serial_data(int upper)
 	serial_digit[7] = (serial_number / 10) % 10;
 	serial_digit[8] = (serial_number / 1) % 10;
 
-	serial.data[12] = mame_rand(Machine) & 0xff;
-	serial.data[13] = mame_rand(Machine) & 0xff;
+	serial.data[12] = mame_rand(machine) & 0xff;
+	serial.data[13] = mame_rand(machine) & 0xff;
 
 	serial.data[14] = 0; /* ??? */
 	serial.data[15] = 0; /* ??? */
@@ -171,21 +170,21 @@ static void generate_serial_data(int upper)
  *
  *************************************/
 
-static void serial_register_state(void)
+static void serial_register_state(running_machine *machine)
 {
-	state_save_register_global_array(serial.data);
-	state_save_register_global(serial.buffer);
-	state_save_register_global(serial.index);
-	state_save_register_global(serial.status);
-	state_save_register_global(serial.bits);
-	state_save_register_global(serial.ormask);
+	state_save_register_global_array(machine, serial.data);
+	state_save_register_global(machine, serial.buffer);
+	state_save_register_global(machine, serial.index);
+	state_save_register_global(machine, serial.status);
+	state_save_register_global(machine, serial.bits);
+	state_save_register_global(machine, serial.ormask);
 }
 
 
-void midway_serial_pic_init(int upper)
+void midway_serial_pic_init(running_machine *machine, int upper)
 {
-	serial_register_state();
-	generate_serial_data(upper);
+	serial_register_state(machine);
+	generate_serial_data(machine, upper);
 }
 
 
@@ -206,17 +205,17 @@ UINT8 midway_serial_pic_status_r(void)
 }
 
 
-UINT8 midway_serial_pic_r(void)
+UINT8 midway_serial_pic_r(const address_space *space)
 {
-	logerror("%08X:security R = %04X\n", safe_activecpu_get_pc(), serial.buffer);
+	logerror("%s:security R = %04X\n", cpuexec_describe_context(space->machine), serial.buffer);
 	serial.status = 1;
 	return serial.buffer;
 }
 
 
-void midway_serial_pic_w(UINT8 data)
+void midway_serial_pic_w(const address_space *space, UINT8 data)
 {
-	logerror("%08X:security W = %04X\n", safe_activecpu_get_pc(), data);
+	logerror("%s:security W = %04X\n", cpuexec_describe_context(space->machine), data);
 
 	/* status seems to reflect the clock bit */
 	serial.status = (data >> 4) & 1;
@@ -250,47 +249,41 @@ INLINE UINT8 make_bcd(UINT8 data)
 }
 
 
-INLINE UINT8 unmake_bcd(UINT8 data)
-{
-	return ((data & 0xf0) >> 4) * 10 + (data & 0x0f);
-}
-
-
 static TIMER_CALLBACK( reset_timer )
 {
 	pic.time_just_written = 0;
 }
 
 
-static void pic_register_state(void)
+static void pic_register_state(running_machine *machine)
 {
-	state_save_register_global(pic.latch);
-	state_save_register_global(pic.latch_expire_time.seconds);
-	state_save_register_global(pic.latch_expire_time.attoseconds);
-	state_save_register_global(pic.state);
-	state_save_register_global(pic.index);
-	state_save_register_global(pic.total);
-	state_save_register_global(pic.nvram_addr);
-	state_save_register_global_array(pic.buffer);
-	state_save_register_global_array(pic.nvram);
-	state_save_register_global_array(pic.default_nvram);
-	state_save_register_global_array(pic.time_buf);
-	state_save_register_global(pic.time_index);
-	state_save_register_global(pic.time_just_written);
-	state_save_register_global(pic.yearoffs);
+	state_save_register_global(machine, pic.latch);
+	state_save_register_global(machine, pic.latch_expire_time.seconds);
+	state_save_register_global(machine, pic.latch_expire_time.attoseconds);
+	state_save_register_global(machine, pic.state);
+	state_save_register_global(machine, pic.index);
+	state_save_register_global(machine, pic.total);
+	state_save_register_global(machine, pic.nvram_addr);
+	state_save_register_global_array(machine, pic.buffer);
+	state_save_register_global_array(machine, pic.nvram);
+	state_save_register_global_array(machine, pic.default_nvram);
+	state_save_register_global_array(machine, pic.time_buf);
+	state_save_register_global(machine, pic.time_index);
+	state_save_register_global(machine, pic.time_just_written);
+	state_save_register_global(machine, pic.yearoffs);
 }
 
 
-void midway_serial_pic2_init(int upper, int yearoffs)
+void midway_serial_pic2_init(running_machine *machine, int upper, int yearoffs)
 {
-	serial_register_state();
-	pic_register_state();
+	serial_register_state(machine);
+	pic_register_state(machine);
 
 	pic.yearoffs = yearoffs;
 	pic.time_just_written = 0;
-	pic.time_write_timer = timer_alloc(reset_timer, NULL);
+	pic.time_write_timer = timer_alloc(machine, reset_timer, NULL);
 	memset(pic.default_nvram, 0xff, sizeof(pic.default_nvram));
-	generate_serial_data(upper);
+	generate_serial_data(machine, upper);
 }
 
 
@@ -300,31 +293,31 @@ void midway_serial_pic2_set_default_nvram(const UINT8 *nvram)
 }
 
 
-UINT8 midway_serial_pic2_status_r(void)
+UINT8 midway_serial_pic2_status_r(const address_space *space)
 {
 	UINT8 result = 0;
 
 	/* if we're still holding the data ready bit high, do it */
 	if (pic.latch & 0xf00)
 	{
-		if (attotime_compare(timer_get_time(), pic.latch_expire_time) > 0)
+		if (attotime_compare(timer_get_time(space->machine), pic.latch_expire_time) > 0)
 			pic.latch &= 0xff;
 		else
 			pic.latch -= 0x100;
 		result = 1;
 	}
 
-	logerror("%06X:PIC status %d\n", safe_activecpu_get_pc(), result);
+	logerror("%s:PIC status %d\n", cpuexec_describe_context(space->machine), result);
 	return result;
 }
 
 
-UINT8 midway_serial_pic2_r(void)
+UINT8 midway_serial_pic2_r(const address_space *space)
 {
 	UINT8 result = 0;
 
 	/* PIC data register */
-	logerror("%06X:PIC data read (index=%d total=%d latch=%03X) =", safe_activecpu_get_pc(), pic.index, pic.total, pic.latch);
+	logerror("%s:PIC data read (index=%d total=%d latch=%03X) =", cpuexec_describe_context(space->machine), pic.index, pic.total, pic.latch);
 
 	/* return the current result */
 	if (pic.latch & 0xf00)
@@ -339,21 +332,22 @@ UINT8 midway_serial_pic2_r(void)
 }
 
 
-void midway_serial_pic2_w(UINT8 data)
+void midway_serial_pic2_w(const address_space *space, UINT8 data)
 {
+	running_machine *machine = space->machine;
 	static FILE *nvramlog;
 	if (LOG_NVRAM && !nvramlog)
 		nvramlog = fopen("nvram.log", "w");
 
 	/* PIC command register */
 	if (pic.state == 0)
-		logerror("%06X:PIC command %02X\n", safe_activecpu_get_pc(), data);
+		logerror("%s:PIC command %02X\n", cpuexec_describe_context(machine), data);
 	else
-		logerror("%06X:PIC data %02X\n", safe_activecpu_get_pc(), data);
+		logerror("%s:PIC data %02X\n", cpuexec_describe_context(machine), data);
 
 	/* store in the latch, along with a bit to indicate we have data */
 	pic.latch = (data & 0x00f) | 0x480;
-	pic.latch_expire_time = attotime_add(timer_get_time(), ATTOTIME_IN_MSEC(1));
+	pic.latch_expire_time = attotime_add(timer_get_time(machine), ATTOTIME_IN_MSEC(1));
 	if (data & 0x10)
 	{
 		int cmd = pic.state ? (pic.state & 0x0f) : (pic.latch & 0x0f);
@@ -375,7 +369,7 @@ void midway_serial_pic2_w(UINT8 data)
 					memcpy(pic.buffer, serial.data, 16);
 					pic.total = 16;
 					pic.index = 0;
-					DEBUGGER_BREAK;
+					debugger_break(machine);
 				}
 				break;
 
@@ -390,7 +384,7 @@ void midway_serial_pic2_w(UINT8 data)
 				if (!pic.time_just_written)
 				{
 					mame_system_time systime;
-					mame_get_base_datetime(Machine, &systime);
+					mame_get_base_datetime(machine, &systime);
 
 					pic.buffer[pic.total++] = make_bcd(systime.local_time.second);
 					pic.buffer[pic.total++] = make_bcd(systime.local_time.minute);
@@ -442,7 +436,7 @@ void midway_serial_pic2_w(UINT8 data)
 					/* otherwise, flag the time as having just been written for 1/2 second */
 					else
 					{
-						timer_adjust(pic.time_write_timer, ATTOTIME_IN_MSEC(500), 0, attotime_zero);
+						timer_adjust_oneshot(pic.time_write_timer, ATTOTIME_IN_MSEC(500), 0);
 						pic.time_just_written = 1;
 						pic.state = 0;
 					}
@@ -564,31 +558,31 @@ enum
 	IOASIC_INTCTL		/* f: interrupt control */
 };
 
-static UINT16 ioasic_fifo_r(void);
-static UINT16 ioasic_fifo_status_r(void);
-static void ioasic_input_empty(int state);
-static void ioasic_output_full(int state);
-static void update_ioasic_irq(void);
-static void cage_irq_handler(int state);
+static UINT16 ioasic_fifo_r(const device_config *device);
+static UINT16 ioasic_fifo_status_r(const device_config *device);
+static void ioasic_input_empty(running_machine *machine, int state);
+static void ioasic_output_full(running_machine *machine, int state);
+static void update_ioasic_irq(running_machine *machine);
+static void cage_irq_handler(running_machine *machine, int state);
 
 
-static void ioasic_register_state(void)
+static void ioasic_register_state(running_machine *machine)
 {
-	state_save_register_global_array(ioasic.reg);
-	state_save_register_global(ioasic.shuffle_active);
-	state_save_register_global(ioasic.irq_state);
-	state_save_register_global(ioasic.sound_irq_state);
-	state_save_register_global(ioasic.auto_ack);
-	state_save_register_global(ioasic.force_fifo_full);
-	state_save_register_global_array(ioasic.fifo);
-	state_save_register_global(ioasic.fifo_in);
-	state_save_register_global(ioasic.fifo_out);
-	state_save_register_global(ioasic.fifo_bytes);
-	state_save_register_global(ioasic.fifo_force_buffer_empty_pc);
+	state_save_register_global_array(machine, ioasic.reg);
+	state_save_register_global(machine, ioasic.shuffle_active);
+	state_save_register_global(machine, ioasic.irq_state);
+	state_save_register_global(machine, ioasic.sound_irq_state);
+	state_save_register_global(machine, ioasic.auto_ack);
+	state_save_register_global(machine, ioasic.force_fifo_full);
+	state_save_register_global_array(machine, ioasic.fifo);
+	state_save_register_global(machine, ioasic.fifo_in);
+	state_save_register_global(machine, ioasic.fifo_out);
+	state_save_register_global(machine, ioasic.fifo_bytes);
+	state_save_register_global(machine, ioasic.fifo_force_buffer_empty_pc);
 }
 
 
-void midway_ioasic_init(int shuffle, int upper, int yearoffs, void (*irq_callback)(int))
+void midway_ioasic_init(running_machine *machine, int shuffle, int upper, int yearoffs, void (*irq_callback)(running_machine *, int))
 {
 	static const UINT8 shuffle_maps[][16] =
 	{
@@ -603,26 +597,26 @@ void midway_ioasic_init(int shuffle, int upper, int yearoffs, void (*irq_callbac
 		{ 0x1,0x2,0x3,0x0,0x4,0x5,0x6,0x7,0xa,0xb,0x8,0x9,0xc,0xd,0xe,0xf },	/* Hyperdrive */
 	};
 
-	ioasic_register_state();
+	ioasic_register_state(machine);
 
 	/* do we have a DCS2 sound chip connected? (most likely) */
-	ioasic.has_dcs = (mame_find_cpu_index(Machine, "dcs2") != -1 || mame_find_cpu_index(Machine, "dsio") != -1 || mame_find_cpu_index(Machine, "denver") != -1);
-	ioasic.has_cage = (mame_find_cpu_index(Machine, "cage") != -1);
-	ioasic.dcs_cpu = mame_find_cpu_index(Machine, "dcs2");
-	if (ioasic.dcs_cpu == (UINT8)-1)
-		ioasic.dcs_cpu = mame_find_cpu_index(Machine, "dsio");
-	if (ioasic.dcs_cpu == (UINT8)-1)
-		ioasic.dcs_cpu = mame_find_cpu_index(Machine, "denver");
+	ioasic.has_dcs = (cputag_get_cpu(machine, "dcs2") != NULL || cputag_get_cpu(machine, "dsio") != NULL || cputag_get_cpu(machine, "denver") != NULL);
+	ioasic.has_cage = (cputag_get_cpu(machine, "cage") != NULL);
+	ioasic.dcs_cpu = cputag_get_cpu(machine, "dcs2");
+	if (ioasic.dcs_cpu == NULL)
+		ioasic.dcs_cpu = cputag_get_cpu(machine, "dsio");
+	if (ioasic.dcs_cpu == NULL)
+		ioasic.dcs_cpu = cputag_get_cpu(machine, "denver");
 	ioasic.shuffle_type = shuffle;
 	ioasic.shuffle_map = &shuffle_maps[shuffle][0];
 	ioasic.auto_ack = 0;
 	ioasic.irq_callback = irq_callback;
 
 	/* initialize the PIC */
-	midway_serial_pic2_init(upper, yearoffs);
+	midway_serial_pic2_init(machine, upper, yearoffs);
 
 	/* reset the chip */
-	midway_ioasic_reset();
+	midway_ioasic_reset(machine);
 	ioasic.reg[IOASIC_SOUNDCTL] = 0x0001;
 
 	/* configure the fifo */
@@ -631,7 +625,7 @@ void midway_ioasic_init(int shuffle, int upper, int yearoffs, void (*irq_callbac
 		dcs_set_fifo_callbacks(ioasic_fifo_r, ioasic_fifo_status_r);
 		dcs_set_io_callbacks(ioasic_output_full, ioasic_input_empty);
 	}
-	midway_ioasic_fifo_reset_w(1);
+	midway_ioasic_fifo_reset_w(machine, 1);
 
 	/* configure the CAGE IRQ */
 	if (ioasic.has_cage)
@@ -651,21 +645,21 @@ void midway_ioasic_set_shuffle_state(int state)
 }
 
 
-void midway_ioasic_reset(void)
+void midway_ioasic_reset(running_machine *machine)
 {
 	ioasic.shuffle_active = 0;
 	ioasic.sound_irq_state = 0x0080;
 	ioasic.reg[IOASIC_INTCTL] = 0;
 	if (ioasic.has_dcs)
-		midway_ioasic_fifo_reset_w(1);
-	update_ioasic_irq();
+		midway_ioasic_fifo_reset_w(machine, 1);
+	update_ioasic_irq(machine);
 	midway_serial_pic_reset_w(1);
 }
 
 
-static void update_ioasic_irq(void)
+static void update_ioasic_irq(running_machine *machine)
 {
-	UINT16 fifo_state = ioasic_fifo_status_r();
+	UINT16 fifo_state = ioasic_fifo_status_r(NULL);
 	UINT16 irqbits = 0x2000;
 	UINT8 new_state;
 
@@ -684,12 +678,12 @@ static void update_ioasic_irq(void)
 	{
 		ioasic.irq_state = new_state;
 		if (ioasic.irq_callback)
-			(*ioasic.irq_callback)(ioasic.irq_state ? ASSERT_LINE : CLEAR_LINE);
+			(*ioasic.irq_callback)(machine, ioasic.irq_state ? ASSERT_LINE : CLEAR_LINE);
 	}
 }
 
 
-static void cage_irq_handler(int reason)
+static void cage_irq_handler(running_machine *machine, int reason)
 {
 	logerror("CAGE irq handler: %d\n", reason);
 	ioasic.sound_irq_state = 0;
@@ -697,29 +691,29 @@ static void cage_irq_handler(int reason)
 		ioasic.sound_irq_state |= 0x0040;
 	if (reason & CAGE_IRQ_REASON_BUFFER_EMPTY)
 		ioasic.sound_irq_state |= 0x0080;
-	update_ioasic_irq();
+	update_ioasic_irq(machine);
 }
 
 
-static void ioasic_input_empty(int state)
+static void ioasic_input_empty(running_machine *machine, int state)
 {
 //  logerror("ioasic_input_empty(%d)\n", state);
 	if (state)
 		ioasic.sound_irq_state |= 0x0080;
 	else
 		ioasic.sound_irq_state &= ~0x0080;
-	update_ioasic_irq();
+	update_ioasic_irq(machine);
 }
 
 
-static void ioasic_output_full(int state)
+static void ioasic_output_full(running_machine *machine, int state)
 {
 //  logerror("ioasic_output_full(%d)\n", state);
 	if (state)
 		ioasic.sound_irq_state |= 0x0040;
 	else
 		ioasic.sound_irq_state &= ~0x0040;
-	update_ioasic_irq();
+	update_ioasic_irq(machine);
 }
 
 
@@ -730,7 +724,7 @@ static void ioasic_output_full(int state)
  *
  *************************************/
 
-static UINT16 ioasic_fifo_r(void)
+static UINT16 ioasic_fifo_r(const device_config *device)
 {
 	UINT16 result = 0;
 
@@ -740,7 +734,7 @@ static UINT16 ioasic_fifo_r(void)
 		/* fetch the data from the buffer and update the IOASIC state */
 		result = ioasic.fifo[ioasic.fifo_out++ % FIFO_SIZE];
 		ioasic.fifo_bytes--;
-		update_ioasic_irq();
+		update_ioasic_irq(device->machine);
 
 		if (LOG_FIFO && (ioasic.fifo_bytes < 4 || ioasic.fifo_bytes >= FIFO_SIZE - 4))
 			logerror("fifo_r(%04X): FIFO bytes = %d!\n", result, ioasic.fifo_bytes);
@@ -751,7 +745,7 @@ static UINT16 ioasic_fifo_r(void)
 		/* main CPU is handling the I/O ASIC interrupt */
 		if (ioasic.fifo_bytes == 0 && ioasic.has_dcs)
 		{
-			ioasic.fifo_force_buffer_empty_pc = safe_activecpu_get_pc();
+			ioasic.fifo_force_buffer_empty_pc = cpu_get_pc(ioasic.dcs_cpu);
 			if (LOG_FIFO)
 				logerror("fifo_r(%04X): FIFO empty, PC = %04X\n", result, ioasic.fifo_force_buffer_empty_pc);
 		}
@@ -765,7 +759,7 @@ static UINT16 ioasic_fifo_r(void)
 }
 
 
-static UINT16 ioasic_fifo_status_r(void)
+static UINT16 ioasic_fifo_status_r(const device_config *device)
 {
 	UINT16 result = 0;
 
@@ -779,9 +773,9 @@ static UINT16 ioasic_fifo_status_r(void)
 	/* kludge alert: if we're reading this from the DCS CPU itself, and we recently cleared */
 	/* the FIFO, and we're within 16 instructions of the read that cleared the FIFO, make */
 	/* sure the FIFO clear bit is set */
-	if (ioasic.fifo_force_buffer_empty_pc && cpu_getactivecpu() == ioasic.dcs_cpu)
+	if (ioasic.fifo_force_buffer_empty_pc && device == ioasic.dcs_cpu)
 	{
-		offs_t currpc = safe_activecpu_get_pc();
+		offs_t currpc = cpu_get_pc(ioasic.dcs_cpu);
 		if (currpc >= ioasic.fifo_force_buffer_empty_pc && currpc < ioasic.fifo_force_buffer_empty_pc + 0x10)
 		{
 			ioasic.fifo_force_buffer_empty_pc = 0;
@@ -795,7 +789,7 @@ static UINT16 ioasic_fifo_status_r(void)
 }
 
 
-void midway_ioasic_fifo_reset_w(int state)
+void midway_ioasic_fifo_reset_w(running_machine *machine, int state)
 {
 	/* on the high state, reset the FIFO data */
 	if (state)
@@ -804,21 +798,21 @@ void midway_ioasic_fifo_reset_w(int state)
 		ioasic.fifo_out = 0;
 		ioasic.fifo_bytes = 0;
 		ioasic.force_fifo_full = 0;
-		update_ioasic_irq();
+		update_ioasic_irq(machine);
 	}
 	if (LOG_FIFO)
-		logerror("%08X:fifo_reset(%d)\n", safe_activecpu_get_pc(), state);
+		logerror("%s:fifo_reset(%d)\n", cpuexec_describe_context(machine), state);
 }
 
 
-void midway_ioasic_fifo_w(UINT16 data)
+void midway_ioasic_fifo_w(running_machine *machine, UINT16 data)
 {
 	/* if we have room, add it to the FIFO buffer */
 	if (ioasic.fifo_bytes < FIFO_SIZE)
 	{
 		ioasic.fifo[ioasic.fifo_in++ % FIFO_SIZE] = data;
 		ioasic.fifo_bytes++;
-		update_ioasic_irq();
+		update_ioasic_irq(machine);
 		if (LOG_FIFO && (ioasic.fifo_bytes < 4 || ioasic.fifo_bytes >= FIFO_SIZE - 4))
 			logerror("fifo_w(%04X): FIFO bytes = %d!\n", data, ioasic.fifo_bytes);
 	}
@@ -831,12 +825,12 @@ void midway_ioasic_fifo_w(UINT16 data)
 }
 
 
-void midway_ioasic_fifo_full_w(UINT16 data)
+void midway_ioasic_fifo_full_w(running_machine *machine, UINT16 data)
 {
 	if (LOG_FIFO)
 		logerror("fifo_full_w(%04X)\n", data);
 	ioasic.force_fifo_full = 1;
-	update_ioasic_irq();
+	update_ioasic_irq(machine);
 	dcs_fifo_notify(ioasic.fifo_bytes, FIFO_SIZE);
 }
 
@@ -851,10 +845,10 @@ void midway_ioasic_fifo_full_w(UINT16 data)
 READ32_HANDLER( midway_ioasic_packed_r )
 {
 	UINT32 result = 0;
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
-		result |= midway_ioasic_r(offset*2, 0xffff0000) & 0xffff;
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
-		result |= (midway_ioasic_r(offset*2+1, 0xffff0000) & 0xffff) << 16;
+	if (ACCESSING_BITS_0_15)
+		result |= midway_ioasic_r(space, offset*2, 0x0000ffff) & 0xffff;
+	if (ACCESSING_BITS_16_31)
+		result |= (midway_ioasic_r(space, offset*2+1, 0x0000ffff) & 0xffff) << 16;
 	return result;
 }
 
@@ -869,7 +863,7 @@ READ32_HANDLER( midway_ioasic_r )
 	switch (offset)
 	{
 		case IOASIC_PORT0:
-			result = readinputport(0);
+			result = input_port_read(space->machine, "DIPS");
 			/* bit 0 seems to be a ready flag before shuffling happens */
 			if (!ioasic.shuffle_active)
 			{
@@ -881,15 +875,15 @@ READ32_HANDLER( midway_ioasic_r )
 			break;
 
 		case IOASIC_PORT1:
-			result = readinputport(1);
+			result = input_port_read(space->machine, "SYSTEM");
 			break;
 
 		case IOASIC_PORT2:
-			result = readinputport(2);
+			result = input_port_read(space->machine, "IN1");
 			break;
 
 		case IOASIC_PORT3:
-			result = readinputport(3);
+			result = input_port_read(space->machine, "IN2");
 			break;
 
 		case IOASIC_UARTIN:
@@ -902,7 +896,7 @@ READ32_HANDLER( midway_ioasic_r )
 			if (ioasic.has_dcs)
 			{
 				result |= ((dcs_control_r() >> 4) ^ 0x40) & 0x00c0;
-				result |= ioasic_fifo_status_r() & 0x0038;
+				result |= ioasic_fifo_status_r(space->cpu) & 0x0038;
 				result |= dcs_data2_r() & 0xff00;
 			}
 			else if (ioasic.has_cage)
@@ -922,7 +916,7 @@ READ32_HANDLER( midway_ioasic_r )
 					dcs_ack_w();
 			}
 			else if (ioasic.has_cage)
-				result = main_from_cage_r();
+				result = main_from_cage_r(space);
 			else
 			{
 				static UINT16 val = 0;
@@ -931,7 +925,7 @@ READ32_HANDLER( midway_ioasic_r )
 			break;
 
 		case IOASIC_PICIN:
-			result = midway_serial_pic2_r() | (midway_serial_pic2_status_r() << 8);
+			result = midway_serial_pic2_r(space) | (midway_serial_pic2_status_r(space) << 8);
 			break;
 
 		default:
@@ -939,7 +933,7 @@ READ32_HANDLER( midway_ioasic_r )
 	}
 
 	if (LOG_IOASIC && offset != IOASIC_SOUNDSTAT && offset != IOASIC_SOUNDIN)
-		logerror("%06X:ioasic_r(%d) = %08X\n", safe_activecpu_get_pc(), offset, result);
+		logerror("%06X:ioasic_r(%d) = %08X\n", cpu_get_pc(space->cpu), offset, result);
 
 	return result;
 }
@@ -947,10 +941,10 @@ READ32_HANDLER( midway_ioasic_r )
 
 WRITE32_HANDLER( midway_ioasic_packed_w )
 {
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
-		midway_ioasic_w(offset*2, data & 0xffff, 0xffff0000);
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
-		midway_ioasic_w(offset*2+1, data >> 16, 0xffff0000);
+	if (ACCESSING_BITS_0_15)
+		midway_ioasic_w(space, offset*2, data & 0xffff, 0x0000ffff);
+	if (ACCESSING_BITS_16_31)
+		midway_ioasic_w(space, offset*2+1, data >> 16, 0x0000ffff);
 }
 
 
@@ -964,7 +958,7 @@ WRITE32_HANDLER( midway_ioasic_w )
 	newreg = ioasic.reg[offset];
 
 	if (LOG_IOASIC && offset != IOASIC_SOUNDOUT)
-		logerror("%06X:ioasic_w(%d) = %08X\n", safe_activecpu_get_pc(), offset, data);
+		logerror("%06X:ioasic_w(%d) = %08X\n", cpu_get_pc(space->cpu), offset, data);
 
 	switch (offset)
 	{
@@ -991,7 +985,7 @@ WRITE32_HANDLER( midway_ioasic_w )
 			{
 				/* we're in loopback mode -- copy to the input */
 				ioasic.reg[IOASIC_UARTIN] = (newreg & 0x00ff) | 0x1000;
-				update_ioasic_irq();
+				update_ioasic_irq(space->machine);
 			}
 			else if (PRINTF_DEBUG)
 				mame_printf_debug("%c", data & 0xff);
@@ -1007,14 +1001,14 @@ WRITE32_HANDLER( midway_ioasic_w )
 			{
 				if ((oldreg ^ newreg) & 1)
 				{
-					cage_control_w(0);
+					cage_control_w(space->machine, 0);
 					if (!(~newreg & 1))
-						cage_control_w(3);
+						cage_control_w(space->machine, 3);
 				}
 			}
 
 			/* FIFO reset? */
-			midway_ioasic_fifo_reset_w(~newreg & 4);
+			midway_ioasic_fifo_reset_w(space->machine, ~newreg & 4);
 			break;
 
 		case IOASIC_SOUNDOUT:
@@ -1031,11 +1025,11 @@ WRITE32_HANDLER( midway_ioasic_w )
 
 		case IOASIC_PICOUT:
 			if (ioasic.shuffle_type == MIDWAY_IOASIC_VAPORTRX)
-				midway_serial_pic2_w(newreg ^ 0x0a);
+				midway_serial_pic2_w(space, newreg ^ 0x0a);
 			else if (ioasic.shuffle_type == MIDWAY_IOASIC_SFRUSHRK)
-				midway_serial_pic2_w(newreg ^ 0x05);
+				midway_serial_pic2_w(space, newreg ^ 0x05);
 			else
-				midway_serial_pic2_w(newreg);
+				midway_serial_pic2_w(space, newreg);
 			break;
 
 		case IOASIC_INTCTL:
@@ -1047,7 +1041,7 @@ WRITE32_HANDLER( midway_ioasic_w )
 			/* bit 14 = LED? */
 			if ((oldreg ^ newreg) & 0x3ff6)
 				logerror("IOASIC int control = %04X\n", data);
-			update_ioasic_irq();
+			update_ioasic_irq(space->machine);
 			break;
 
 		default:
@@ -1065,7 +1059,7 @@ WRITE32_HANDLER( midway_ioasic_w )
  *
  *************************************/
 
-READ32_HANDLER( midway_ide_asic_r )
+READ32_DEVICE_HANDLER( midway_ide_asic_r )
 {
 	/* convert to standard IDE offsets */
 	offs_t ideoffs = 0x1f0/4 + (offset >> 2);
@@ -1074,16 +1068,16 @@ READ32_HANDLER( midway_ide_asic_r )
 
 	/* offset 0 is a special case */
 	if (offset == 0)
-		result = ide_controller32_0_r(ideoffs, 0xffff0000);
+		result = ide_controller32_r(device, ideoffs, 0x0000ffff);
 
 	/* everything else is byte-sized */
 	else
-		result = ide_controller32_0_r(ideoffs, ~(0xff << shift)) >> shift;
+		result = ide_controller32_r(device, ideoffs, 0xff << shift) >> shift;
 	return result;
 }
 
 
-WRITE32_HANDLER( midway_ide_asic_w )
+WRITE32_DEVICE_HANDLER( midway_ide_asic_w )
 {
 	/* convert to standard IDE offsets */
 	offs_t ideoffs = 0x1f0/4 + (offset >> 2);
@@ -1091,9 +1085,9 @@ WRITE32_HANDLER( midway_ide_asic_w )
 
 	/* offset 0 is a special case */
 	if (offset == 0)
-		ide_controller32_0_w(ideoffs, data, 0xffff0000);
+		ide_controller32_w(device, ideoffs, data, 0x0000ffff);
 
 	/* everything else is byte-sized */
 	else
-		ide_controller32_0_w(ideoffs, data << shift, ~(0xff << shift));
+		ide_controller32_w(device, ideoffs, data << shift, 0xff << shift);
 }
