@@ -15,8 +15,10 @@
       Also contains 'S' (Text Layer) data on these games
       M1 (Z80) rom is also encrypted for CMC50
 
-     the M1 roms contain some additional data at 0xf800.  Some of this
+     The M1 roms contain some additional data at 0xf800.  Some of this
      is said to be related to the C rom encryption.
+     If CMC50 is used, data located at 0xff00 - 0xffff is required for
+     m1 encryption checksum?.
 
       Later games use additional basic scrambling on top of the standard
       CMC scramble.
@@ -535,7 +537,7 @@ static void neogeo_gfx_decrypt(running_machine *machine, int extra_xor)
 
 	rom_size = memory_region_length(machine, "sprites");
 
-	buf = malloc_or_die(rom_size);
+	buf = alloc_array_or_die(UINT8, rom_size);
 
 	rom = memory_region(machine, "sprites");
 
@@ -672,16 +674,16 @@ void cmc50_neogeo_gfx_decrypt(running_machine *machine, int extra_xor)
 /* ms5pcb and svcpcb have an additional scramble on top of the standard CMC scrambling */
 void svcpcb_gfx_decrypt(running_machine *machine)
 {
-	static const UINT8 xor[ 4 ] = { 0x34, 0x21, 0xc4, 0xe9 };
+	static const UINT8 xorval[ 4 ] = { 0x34, 0x21, 0xc4, 0xe9 };
 	int i;
 	int ofst;
 	int rom_size = memory_region_length( machine, "sprites" );
 	UINT8 *rom = memory_region( machine, "sprites" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for( i = 0; i < rom_size; i++ )
 	{
-		rom[ i ] ^= xor[ (i % 4) ];
+		rom[ i ] ^= xorval[ (i % 4) ];
 	}
 	for( i = 0; i < rom_size; i += 4 )
 	{
@@ -722,16 +724,16 @@ void svcpcb_s1data_decrypt(running_machine *machine)
 /* Thanks to Razoola & Halrin for the info */
 void kf2k3pcb_gfx_decrypt(running_machine *machine)
 {
-	static const UINT8 xor[ 4 ] = { 0x34, 0x21, 0xc4, 0xe9 };
+	static const UINT8 xorval[ 4 ] = { 0x34, 0x21, 0xc4, 0xe9 };
 	int i;
 	int ofst;
 	int rom_size = memory_region_length( machine, "sprites" );
 	UINT8 *rom = memory_region( machine, "sprites" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for ( i = 0; i < rom_size; i++ )
 	{
-		rom[ i ] ^= xor[ (i % 4) ];
+		rom[ i ] ^= xorval[ (i % 4) ];
 	}
 	for ( i = 0; i < rom_size; i+=4 )
 	{
@@ -887,9 +889,9 @@ void neogeo_cmc50_m1_decrypt(running_machine *machine)
 {
 	UINT8* rom = memory_region(machine, "audiocrypt");
 	size_t rom_size = 0x80000;
-	UINT8* rom2 = memory_region(machine, "audio");
+	UINT8* rom2 = memory_region(machine, "audiocpu");
 
-	UINT8* buffer = malloc_or_die(rom_size);
+	UINT8* buffer = alloc_array_or_die(UINT8, rom_size);
 
 	UINT32 i;
 
@@ -954,8 +956,8 @@ NeoGeo 'P' ROM encryption
 /* Kof98 uses an early encryption, quite different from the others */
 void kof98_decrypt_68k(running_machine *machine)
 {
-	UINT8 *src = memory_region(machine, "main");
-	UINT8 *dst = malloc_or_die(0x200000);
+	UINT8 *src = memory_region(machine, "maincpu");
+	UINT8 *dst = alloc_array_or_die(UINT8, 0x200000);
 	int i, j, k;
 	static const UINT32 sec[]={0x000000,0x100000,0x000004,0x100004,0x10000a,0x00000a,0x10000e,0x00000e};
 	static const UINT32 pos[]={0x000,0x004,0x00a,0x00e};
@@ -1004,7 +1006,7 @@ void kof99_decrypt_68k(running_machine *machine)
 	UINT16 *rom;
 	int i,j;
 
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	/* swap data lines on the whole ROMs */
 	for (i = 0;i < 0x800000/2;i++)
 	{
@@ -1023,7 +1025,7 @@ void kof99_decrypt_68k(running_machine *machine)
 	}
 
 	/* swap address lines & relocate fixed part */
-	rom = (UINT16 *)memory_region(machine, "main");
+	rom = (UINT16 *)memory_region(machine, "maincpu");
 	for (i = 0;i < 0x0c0000/2;i++)
 	{
 		rom[i] = rom[0x700000/2 + BITSWAP24(i,23,22,21,20,19,18,11,6,14,17,16,5,8,10,12,0,4,3,2,7,9,15,13,1)];
@@ -1037,7 +1039,7 @@ void garou_decrypt_68k(running_machine *machine)
 	int i,j;
 
 	/* thanks to Razoola and Mr K for the info */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	/* swap data lines on the whole ROMs */
 	for (i = 0;i < 0x800000/2;i++)
 	{
@@ -1045,14 +1047,14 @@ void garou_decrypt_68k(running_machine *machine)
 	}
 
 	/* swap address lines & relocate fixed part */
-	rom = (UINT16 *)memory_region(machine, "main");
+	rom = (UINT16 *)memory_region(machine, "maincpu");
 	for (i = 0;i < 0x0c0000/2;i++)
 	{
 		rom[i] = rom[0x710000/2 + BITSWAP24(i,23,22,21,20,19,18,4,5,16,14,7,9,6,13,17,15,3,1,2,12,11,8,10,0)];
 	}
 
 	/* swap address lines for the banked part */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	for (i = 0;i < 0x800000/2;i+=0x8000/2)
 	{
 		UINT16 buffer[0x8000/2];
@@ -1071,7 +1073,7 @@ void garouo_decrypt_68k(running_machine *machine)
 	int i,j;
 
 	/* thanks to Razoola and Mr K for the info */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	/* swap data lines on the whole ROMs */
 	for (i = 0;i < 0x800000/2;i++)
 	{
@@ -1079,14 +1081,14 @@ void garouo_decrypt_68k(running_machine *machine)
 	}
 
 	/* swap address lines & relocate fixed part */
-	rom = (UINT16 *)memory_region(machine, "main");
+	rom = (UINT16 *)memory_region(machine, "maincpu");
 	for (i = 0;i < 0x0c0000/2;i++)
 	{
 		rom[i] = rom[0x7f8000/2 + BITSWAP24(i,23,22,21,20,19,18,5,16,11,2,6,7,17,3,12,8,14,4,0,9,1,10,15,13)];
 	}
 
 	/* swap address lines for the banked part */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	for (i = 0;i < 0x800000/2;i+=0x8000/2)
 	{
 		UINT16 buffer[0x8000/2];
@@ -1105,7 +1107,7 @@ void mslug3_decrypt_68k(running_machine *machine)
 	int i,j;
 
 	/* thanks to Razoola and Mr K for the info */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	/* swap data lines on the whole ROMs */
 	for (i = 0;i < 0x800000/2;i++)
 	{
@@ -1113,14 +1115,14 @@ void mslug3_decrypt_68k(running_machine *machine)
 	}
 
 	/* swap address lines & relocate fixed part */
-	rom = (UINT16 *)memory_region(machine, "main");
+	rom = (UINT16 *)memory_region(machine, "maincpu");
 	for (i = 0;i < 0x0c0000/2;i++)
 	{
 		rom[i] = rom[0x5d0000/2 + BITSWAP24(i,23,22,21,20,19,18,15,2,1,13,3,0,9,6,16,4,11,5,7,12,17,14,10,8)];
 	}
 
 	/* swap address lines for the banked part */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	for (i = 0;i < 0x800000/2;i+=0x10000/2)
 	{
 		UINT16 buffer[0x10000/2];
@@ -1139,7 +1141,7 @@ void kof2000_decrypt_68k(running_machine *machine)
 	int i,j;
 
 	/* thanks to Razoola and Mr K for the info */
-	rom = (UINT16 *)(memory_region(machine, "main") + 0x100000);
+	rom = (UINT16 *)(memory_region(machine, "maincpu") + 0x100000);
 	/* swap data lines on the whole ROMs */
 	for (i = 0;i < 0x800000/2;i++)
 	{
@@ -1158,7 +1160,7 @@ void kof2000_decrypt_68k(running_machine *machine)
 	}
 
 	/* swap address lines & relocate fixed part */
-	rom = (UINT16 *)memory_region(machine, "main");
+	rom = (UINT16 *)memory_region(machine, "maincpu");
 	for (i = 0;i < 0x0c0000/2;i++)
 	{
 		rom[i] = rom[0x73a000/2 + BITSWAP24(i,23,22,21,20,19,18,8,4,15,13,3,14,16,2,6,17,7,12,10,0,5,11,1,9)];
@@ -1171,8 +1173,8 @@ void kof2002_decrypt_68k(running_machine *machine)
 {
 	int i;
 	static const int sec[]={0x100000,0x280000,0x300000,0x180000,0x000000,0x380000,0x200000,0x080000};
-	UINT8 *src = memory_region(machine, "main")+0x100000;
-	UINT8 *dst = malloc_or_die(0x400000);
+	UINT8 *src = memory_region(machine, "maincpu")+0x100000;
+	UINT8 *dst = alloc_array_or_die(UINT8, 0x400000);
 		memcpy( dst, src, 0x400000 );
 		for( i=0; i<8; ++i )
 		{
@@ -1186,8 +1188,8 @@ void matrim_decrypt_68k(running_machine *machine)
 {
 	int i;
 	static const int sec[]={0x100000,0x280000,0x300000,0x180000,0x000000,0x380000,0x200000,0x080000};
-	UINT8 *src = memory_region(machine, "main")+0x100000;
-	UINT8 *dst = malloc_or_die(0x400000);
+	UINT8 *src = memory_region(machine, "maincpu")+0x100000;
+	UINT8 *dst = alloc_array_or_die(UINT8, 0x400000);
 		memcpy( dst, src, 0x400000);
 		for( i=0; i<8; ++i )
 		{
@@ -1201,8 +1203,8 @@ void samsho5_decrypt_68k(running_machine *machine)
 {
 	int i;
 	static const int sec[]={0x000000,0x080000,0x700000,0x680000,0x500000,0x180000,0x200000,0x480000,0x300000,0x780000,0x600000,0x280000,0x100000,0x580000,0x400000,0x380000};
-	UINT8 *src = memory_region(machine, "main");
-	UINT8 *dst = malloc_or_die(0x800000);
+	UINT8 *src = memory_region(machine, "maincpu");
+	UINT8 *dst = alloc_array_or_die(UINT8, 0x800000);
 
 		memcpy( dst, src, 0x800000 );
 		for( i=0; i<16; ++i )
@@ -1217,8 +1219,8 @@ void samsh5sp_decrypt_68k(running_machine *machine)
 {
 	int i;
 	static const int sec[]={0x000000,0x080000,0x500000,0x480000,0x600000,0x580000,0x700000,0x280000,0x100000,0x680000,0x400000,0x780000,0x200000,0x380000,0x300000,0x180000};
-	UINT8 *src = memory_region(machine, "main");
-	UINT8 *dst = malloc_or_die(0x800000);
+	UINT8 *src = memory_region(machine, "maincpu");
+	UINT8 *dst = alloc_array_or_die(UINT8, 0x800000);
 
 		memcpy( dst, src, 0x800000 );
 		for( i=0; i<16; ++i )
@@ -1237,8 +1239,8 @@ void mslug5_decrypt_68k(running_machine *machine)
 	int i;
 	int ofst;
 	int rom_size = 0x800000;
-	UINT8 *rom = memory_region( machine, "main" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *rom = memory_region( machine, "maincpu" );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for( i = 0; i < 0x100000; i++ )
 	{
@@ -1282,8 +1284,8 @@ void svc_px_decrypt(running_machine *machine)
 	int i;
 	int ofst;
 	int rom_size = 0x800000;
-	UINT8 *rom = memory_region( machine, "main" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *rom = memory_region( machine, "maincpu" );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for( i = 0; i < 0x100000; i++ )
 	{
@@ -1326,8 +1328,8 @@ void kf2k3pcb_decrypt_68k(running_machine *machine)
 	int i;
 	int ofst;
 	int rom_size = 0x900000;
-	UINT8 *rom = memory_region( machine, "main" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *rom = memory_region( machine, "maincpu" );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for (i = 0; i < 0x100000; i++)
 	{
@@ -1369,8 +1371,8 @@ void kof2003_decrypt_68k(running_machine *machine)
 	int i;
 	int ofst;
 	int rom_size = 0x900000;
-	UINT8 *rom = memory_region( machine, "main" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *rom = memory_region( machine, "maincpu" );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for (i = 0; i < 0x100000; i++)
 	{
@@ -1409,6 +1411,7 @@ void kof2003_decrypt_68k(running_machine *machine)
 }
 
 
+// Thanks to IQ_132 for the info
 void kof2003h_decrypt_68k(running_machine *machine)
 {
 	static const UINT8 xor1[0x20] = { 0xc2, 0x4b, 0x74, 0xfd, 0x0b, 0x34, 0xeb, 0xd7, 0x10, 0x6d, 0xf9, 0xce, 0x5d, 0xd5, 0x61, 0x29, 0xf5, 0xbe, 0x0d, 0x82, 0x72, 0x45, 0x0f, 0x24, 0xb3, 0x34, 0x1b, 0x99, 0xea, 0x09, 0xf3, 0x03 };
@@ -1416,8 +1419,8 @@ void kof2003h_decrypt_68k(running_machine *machine)
 	int i;
 	int ofst;
 	int rom_size = 0x900000;
-	UINT8 *rom = memory_region( machine, "main" );
-	UINT8 *buf = malloc_or_die( rom_size );
+	UINT8 *rom = memory_region( machine, "maincpu" );
+	UINT8 *buf = alloc_array_or_die(UINT8,  rom_size );
 
 	for (i = 0; i < 0x100000; i++)
 	{
@@ -1472,7 +1475,7 @@ void neo_pcm2_snk_1999(running_machine *machine, int value)
 
 	if( rom != NULL )
 	{	/* swap address lines on the whole ROMs */
-		UINT16 *buffer = malloc_or_die((value / 2) * sizeof(UINT16));
+		UINT16 *buffer = alloc_array_or_die(UINT16, value / 2);
 
 		for( i = 0; i < size / 2; i += ( value / 2 ) )
 		{
@@ -1507,7 +1510,7 @@ void neo_pcm2_swap(running_machine *machine, int value)
 		{0x4b,0xa4,0x63,0x46,0xf0,0x91,0xea,0x62},
 		{0x4b,0xa4,0x63,0x46,0xf0,0x91,0xea,0x62}};
 	UINT8 *src = memory_region(machine, "ym");
-	UINT8 *buf = malloc_or_die(0x1000000);
+	UINT8 *buf = alloc_array_or_die(UINT8, 0x1000000);
 	int i, j, d;
 
 	memcpy(buf,src,0x1000000);
@@ -1551,7 +1554,7 @@ void kof2003biosdecode(running_machine *machine)
 		0xd3,0xd2,0x5c,0x5d,0x57,0x56,0xd8,0xd9,
 	};
 	UINT16*src= (UINT16*)memory_region( machine, "mainbios" );
-	UINT16*buf= malloc_or_die(0x80000);
+	UINT16*buf= alloc_array_or_die(UINT16, 0x80000/2);
 	int	a,addr;
 
 		for (a=0;a<0x80000/2;a++)
