@@ -20,41 +20,15 @@ MACHINE_RESET( scramble )
 {
 	MACHINE_RESET_CALL(galaxold);
 
-	if (machine->cpu[1] != NULL)
+	if (cputag_get_cpu(machine, "audiocpu") != NULL)
 		scramble_sh_init(machine);
 
   security_2B_counter = 0;
 }
 
-MACHINE_RESET( sfx )
-{
-	MACHINE_RESET_CALL(scramble);
-
-	sfx_sh_init(machine);
-}
-
-static int monsterz_count = 0;
-MACHINE_RESET( monsterz )
-{
-/*
-// patch rom crc
-    UINT8 *ROM = memory_region(machine, "main");
-    ROM[0x363f] = 0;
-    ROM[0x3640] = 0;
-    ROM[0x3641] = 0;
-
-    ROM[0xc5bc] = 0xaf;
-*/
-	MACHINE_RESET_CALL(scramble);
-
-	sfx_sh_init(machine);
-
-	monsterz_count = 0;
-}
-
 MACHINE_RESET( explorer )
 {
-	UINT8 *RAM = memory_region(machine, "main");
+	UINT8 *RAM = memory_region(machine, "maincpu");
 	RAM[0x47ff] = 0; /* If not set, it doesn't reset after the 1st time */
 
 	MACHINE_RESET_CALL(galaxold);
@@ -71,7 +45,7 @@ CUSTOM_INPUT( darkplnt_custom_r )
 							  0x2b, 0x2a, 0x28, 0x29, 0x09, 0x08, 0x0a, 0x0b,
 							  0x0f, 0x0e, 0x0c, 0x0d, 0x2d, 0x2c, 0x2e, 0x2f,
 							  0x27, 0x26, 0x24, 0x25, 0x05, 0x04, 0x06, 0x07 };
-	UINT8 val = input_port_read(field->port->machine, param);
+	UINT8 val = input_port_read(field->port->machine, (const char *)param);
 
 	return remap[val >> 2];
 }
@@ -86,7 +60,7 @@ static WRITE8_DEVICE_HANDLER( scramble_protection_w )
 
 static READ8_DEVICE_HANDLER( scramble_protection_r )
 {
-	switch (cpu_get_pc(device->machine->cpu[0]))
+	switch (cpu_get_pc(cputag_get_cpu(device->machine, "maincpu")))
 	{
 	case 0x00a8: return 0xf0;
 	case 0x00be: return 0xb0;
@@ -146,9 +120,9 @@ static READ8_HANDLER( cavelon_banksw_r )
 	cavelon_banksw(space->machine);
 
 	if      ((offset >= 0x0100) && (offset <= 0x0103))
-		return ppi8255_r((device_config*)devtag_get_device(space->machine, PPI8255, "ppi8255_0"), offset - 0x0100);
+		return ppi8255_r(devtag_get_device(space->machine, "ppi8255_0"), offset - 0x0100);
 	else if ((offset >= 0x0200) && (offset <= 0x0203))
-		return ppi8255_r((device_config*)devtag_get_device(space->machine, PPI8255, "ppi8255_1"), offset - 0x0200);
+		return ppi8255_r(devtag_get_device(space->machine, "ppi8255_1"), offset - 0x0200);
 
 	return 0xff;
 }
@@ -158,9 +132,9 @@ static WRITE8_HANDLER( cavelon_banksw_w )
 	cavelon_banksw(space->machine);
 
 	if      ((offset >= 0x0100) && (offset <= 0x0103))
-		ppi8255_w(devtag_get_device(space->machine, PPI8255, "ppi8255_0"), offset - 0x0100, data);
+		ppi8255_w(devtag_get_device(space->machine, "ppi8255_0"), offset - 0x0100, data);
 	else if ((offset >= 0x0200) && (offset <= 0x0203))
-		ppi8255_w(devtag_get_device(space->machine, PPI8255, "ppi8255_1"), offset - 0x0200, data);
+		ppi8255_w(devtag_get_device(space->machine, "ppi8255_1"), offset - 0x0200, data);
 }
 
 
@@ -174,63 +148,57 @@ WRITE8_HANDLER( hunchbks_mirror_w )
 	memory_write_byte(space, 0x1000+offset,data);
 }
 
-static WRITE8_DEVICE_HANDLER( sound_latch_w )
-{
-	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
-	soundlatch_w(space, offset, data);
-}
-
 const ppi8255_interface scramble_ppi_0_intf =
 {
-	DEVICE8_PORT("IN0"),		/* Port A read */
-	DEVICE8_PORT("IN1"),		/* Port B read */
-	DEVICE8_PORT("IN2"),		/* Port C read */
-	NULL,						/* Port A write */
-	NULL,						/* Port B write */
-	NULL 						/* Port C write */
+	DEVCB_INPUT_PORT("IN0"),		/* Port A read */
+	DEVCB_INPUT_PORT("IN1"),		/* Port B read */
+	DEVCB_INPUT_PORT("IN2"),		/* Port C read */
+	DEVCB_NULL,						/* Port A write */
+	DEVCB_NULL,						/* Port B write */
+	DEVCB_NULL 						/* Port C write */
 };
 
 const ppi8255_interface scramble_ppi_1_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	NULL,						/* Port C read */
-	sound_latch_w,				/* Port A write */
-	scramble_sh_irqtrigger_w,	/* Port B write */
-	NULL						/* Port C write */
+	DEVCB_NULL,												/* Port A read */
+	DEVCB_NULL,												/* Port B read */
+	DEVCB_NULL,												/* Port C read */
+	DEVCB_MEMORY_HANDLER("maincpu", PROGRAM, soundlatch_w),	/* Port A write */
+	DEVCB_HANDLER(scramble_sh_irqtrigger_w),				/* Port B write */
+	DEVCB_NULL												/* Port C write */
 };
 
 
 const ppi8255_interface stratgyx_ppi_1_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	DEVICE8_PORT("IN3"),		/* Port C read */
-	sound_latch_w,				/* Port A write */
-	scramble_sh_irqtrigger_w,	/* Port B write */
-	NULL						/* Port C write */
+	DEVCB_NULL,												/* Port A read */
+	DEVCB_NULL,												/* Port B read */
+	DEVCB_INPUT_PORT("IN3"),								/* Port C read */
+	DEVCB_MEMORY_HANDLER("maincpu", PROGRAM, soundlatch_w),	/* Port A write */
+	DEVCB_HANDLER(scramble_sh_irqtrigger_w),				/* Port B write */
+	DEVCB_NULL												/* Port C write */
 };
 
 
 const ppi8255_interface scramble_protection_ppi_1_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	scramble_protection_r,		/* Port C read */
-	sound_latch_w,				/* Port A write */
-	scramble_sh_irqtrigger_w,	/* Port B write */
-	scramble_protection_w		/* Port C write */
+	DEVCB_NULL,												/* Port A read */
+	DEVCB_NULL,												/* Port B read */
+	DEVCB_HANDLER(scramble_protection_r),					/* Port C read */
+	DEVCB_MEMORY_HANDLER("maincpu", PROGRAM, soundlatch_w),	/* Port A write */
+	DEVCB_HANDLER(scramble_sh_irqtrigger_w),				/* Port B write */
+	DEVCB_HANDLER(scramble_protection_w)					/* Port C write */
 };
 
 
 const ppi8255_interface mrkougar_ppi_1_intf =
 {
-	NULL,						/* Port A read */
-	NULL,						/* Port B read */
-	NULL,						/* Port C read */
-	sound_latch_w,				/* Port A write */
-	mrkougar_sh_irqtrigger_w,	/* Port B write */
-	NULL						/* Port C write */
+	DEVCB_NULL,												/* Port A read */
+	DEVCB_NULL,												/* Port B read */
+	DEVCB_NULL,												/* Port C read */
+	DEVCB_MEMORY_HANDLER("maincpu", PROGRAM, soundlatch_w),	/* Port A write */
+	DEVCB_HANDLER(mrkougar_sh_irqtrigger_w),				/* Port B write */
+	DEVCB_NULL												/* Port C write */
 };
 
 
@@ -240,12 +208,12 @@ DRIVER_INIT( scramble_ppi )
 
 DRIVER_INIT( scobra )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xa803, 0xa803, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xa803, 0xa803, 0, 0, scrambold_background_enable_w);
 }
 
 DRIVER_INIT( atlantis )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6803, 0x6803, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x6803, 0x6803, 0, 0, scrambold_background_enable_w);
 }
 
 DRIVER_INIT( scramble )
@@ -255,14 +223,14 @@ DRIVER_INIT( scramble )
 
 DRIVER_INIT( stratgyx )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb000, 0xb000, 0, 0, scrambold_background_green_w);
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb002, 0xb002, 0, 0, scrambold_background_blue_w);
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb00a, 0xb00a, 0, 0, scrambold_background_red_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb000, 0xb000, 0, 0, scrambold_background_green_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb002, 0xb002, 0, 0, scrambold_background_blue_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb00a, 0xb00a, 0, 0, scrambold_background_red_w);
 }
 
 DRIVER_INIT( tazmani2 )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb002, 0xb002, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb002, 0xb002, 0, 0, scrambold_background_enable_w);
 }
 
 DRIVER_INIT( ckongs )
@@ -272,14 +240,14 @@ DRIVER_INIT( ckongs )
 DRIVER_INIT( mariner )
 {
 	/* extra ROM */
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5800, 0x67ff, 0, 0, SMH_BANK1, SMH_UNMAP);
-	memory_set_bankptr(machine, 1, memory_region(machine, "main") + 0x5800);
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x5800, 0x67ff, 0, 0, (read8_space_func)SMH_BANK(1), (write8_space_func)SMH_UNMAP);
+	memory_set_bankptr(machine, 1, memory_region(machine, "maincpu") + 0x5800);
 
-	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x9008, 0x9008, 0, 0, mariner_protection_2_r);
-	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb401, 0xb401, 0, 0, mariner_protection_1_r);
+	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x9008, 0x9008, 0, 0, mariner_protection_2_r);
+	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb401, 0xb401, 0, 0, mariner_protection_1_r);
 
 	/* ??? (it's NOT a background enable) */
-	/*memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6803, 0x6803, 0, 0, SMH_NOP);*/
+	/*memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x6803, 0x6803, 0, 0, (write8_space_func)SMH_NOP);*/
 }
 
 DRIVER_INIT( frogger )
@@ -288,7 +256,7 @@ DRIVER_INIT( frogger )
 	UINT8 *ROM;
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
-	ROM = memory_region(machine, "audio");
+	ROM = memory_region(machine, "audiocpu");
 	for (A = 0;A < 0x0800;A++)
 		ROM[A] = BITSWAP8(ROM[A],7,6,5,4,3,2,0,1);
 
@@ -304,7 +272,7 @@ DRIVER_INIT( froggers )
 	UINT8 *ROM;
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
-	ROM = memory_region(machine, "audio");
+	ROM = memory_region(machine, "audiocpu");
 	for (A = 0;A < 0x0800;A++)
 		ROM[A] = BITSWAP8(ROM[A],7,6,5,4,3,2,0,1);
 }
@@ -321,7 +289,7 @@ DRIVER_INIT( devilfsh )
 	/* A2 -> A3 */
 	/* A3 -> A1 */
 
-	RAM = memory_region(machine, "main");
+	RAM = memory_region(machine, "maincpu");
 	for (i = 0; i < 0x10000; i += 16)
 	{
 		offs_t j;
@@ -329,9 +297,9 @@ DRIVER_INIT( devilfsh )
 
 		for (j = 0; j < 16; j++)
 		{
-			offs_t new = BITSWAP8(j,7,6,5,4,2,0,3,1);
+			offs_t newval = BITSWAP8(j,7,6,5,4,2,0,3,1);
 
-			swapbuffer[j] = RAM[i + new];
+			swapbuffer[j] = RAM[i + newval];
 		}
 
 		memcpy(&RAM[i], swapbuffer, 16);
@@ -347,23 +315,23 @@ DRIVER_INIT( hotshock )
 {
 	/* protection??? The game jumps into never-neverland here. I think
        it just expects a RET there */
-	memory_region(machine, "main")[0x2ef9] = 0xc9;
+	memory_region(machine, "maincpu")[0x2ef9] = 0xc9;
 }
 
 DRIVER_INIT( cavelon )
 {
-	UINT8 *ROM = memory_region(machine, "main");
+	UINT8 *ROM = memory_region(machine, "maincpu");
 
 	/* banked ROM */
-	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x0000, 0x3fff, 0, 0, SMH_BANK1);
+	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0000, 0x3fff, 0, 0, (read8_space_func)SMH_BANK(1));
 	memory_configure_bank(machine, 1, 0, 2, &ROM[0x00000], 0x10000);
 	cavelon_banksw(machine);
 
 	/* A15 switches memory banks */
-	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, cavelon_banksw_r, cavelon_banksw_w);
+	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, cavelon_banksw_r, cavelon_banksw_w);
 
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2000, 0x2000, 0, 0, SMH_NOP);	/* ??? */
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x3800, 0x3801, 0, 0, SMH_NOP);  /* looks suspicously like
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x2000, 0x2000, 0, 0, (write8_space_func)SMH_NOP);	/* ??? */
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x3800, 0x3801, 0, 0, (write8_space_func)SMH_NOP);  /* looks suspicously like
                                                                an AY8910, but not sure */
 	state_save_register_global(machine, cavelon_bank);
 }
@@ -372,7 +340,7 @@ DRIVER_INIT( cavelon )
 
 DRIVER_INIT( darkplnt )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xb00a, 0xb00a, 0, 0, darkplnt_bullet_color_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb00a, 0xb00a, 0, 0, darkplnt_bullet_color_w);
 }
 
 DRIVER_INIT( mimonkey )
@@ -397,7 +365,7 @@ DRIVER_INIT( mimonkey )
 		{ 0x80,0x87,0x81,0x87,0x83,0x00,0x84,0x01,0x01,0x86,0x86,0x80,0x86,0x00,0x86,0x86 }
 	};
 
-	UINT8 *ROM = memory_region(machine, "main");
+	UINT8 *ROM = memory_region(machine, "maincpu");
 	int A, ctr = 0, line, col;
 
 	for( A = 0; A < 0x4000; A++ )
@@ -408,17 +376,17 @@ DRIVER_INIT( mimonkey )
 		ctr++;
 	}
 
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xa804, 0xa804, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xa804, 0xa804, 0, 0, scrambold_background_enable_w);
 }
 
 DRIVER_INIT( mimonsco )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xa804, 0xa804, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xa804, 0xa804, 0, 0, scrambold_background_enable_w);
 }
 
 DRIVER_INIT( mimonscr )
 {
-	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6804, 0x6804, 0, 0, scrambold_background_enable_w);
+	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x6804, 0x6804, 0, 0, scrambold_background_enable_w);
 }
 
 
@@ -445,7 +413,7 @@ DRIVER_INIT( anteater )
 	RAM = memory_region(machine, "gfx1");
 	len = memory_region_length(machine, "gfx1");
 
-	scratch = malloc_or_die(len);
+	scratch = alloc_array_or_die(UINT8, len);
 
 		memcpy(scratch, RAM, len);
 
@@ -482,7 +450,7 @@ DRIVER_INIT( rescue )
 	RAM = memory_region(machine, "gfx1");
 	len = memory_region_length(machine, "gfx1");
 
-	scratch = malloc_or_die(len);
+	scratch = alloc_array_or_die(UINT8, len);
 
 		memcpy(scratch, RAM, len);
 
@@ -518,7 +486,7 @@ DRIVER_INIT( minefld )
 	RAM = memory_region(machine, "gfx1");
 	len = memory_region_length(machine, "gfx1");
 
-	scratch = malloc_or_die(len);
+	scratch = alloc_array_or_die(UINT8, len);
 
 		memcpy(scratch, RAM, len);
 
@@ -556,7 +524,7 @@ DRIVER_INIT( losttomb )
 	RAM = memory_region(machine, "gfx1");
 	len = memory_region_length(machine, "gfx1");
 
-	scratch = malloc_or_die(len);
+	scratch = alloc_array_or_die(UINT8, len);
 
 		memcpy(scratch, RAM, len);
 
@@ -580,7 +548,7 @@ DRIVER_INIT( losttomb )
 DRIVER_INIT( hustler )
 {
 	offs_t A;
-	UINT8 *rom = memory_region(machine, "main");
+	UINT8 *rom = memory_region(machine, "maincpu");
 
 
 	for (A = 0;A < 0x4000;A++)
@@ -608,7 +576,7 @@ DRIVER_INIT( hustler )
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
 	{
-		rom = memory_region(machine, "audio");
+		rom = memory_region(machine, "audiocpu");
 
 
 		for (A = 0;A < 0x0800;A++)
@@ -619,7 +587,7 @@ DRIVER_INIT( hustler )
 DRIVER_INIT( billiard )
 {
 	offs_t A;
-	UINT8 *rom = memory_region(machine, "main");
+	UINT8 *rom = memory_region(machine, "maincpu");
 
 
 	for (A = 0;A < 0x4000;A++)
@@ -649,7 +617,7 @@ DRIVER_INIT( billiard )
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
 	{
-		rom = memory_region(machine, "audio");
+		rom = memory_region(machine, "audiocpu");
 
 
 		for (A = 0;A < 0x0800;A++)
@@ -677,8 +645,8 @@ DRIVER_INIT( mrkougb )
 DRIVER_INIT( ad2083 )
 {
 	UINT8 c;
-	int i, len = memory_region_length(machine, "main");
-	UINT8 *ROM = memory_region(machine, "main");
+	int i, len = memory_region_length(machine, "maincpu");
+	UINT8 *ROM = memory_region(machine, "maincpu");
 
 	for (i=0; i<len; i++)
 	{
