@@ -38,8 +38,8 @@ static void nec_v25_cpu_decrypt(running_machine *machine)
 	int i;
 	const address_space *space = cputag_get_address_space(machine, "mcu", ADDRESS_SPACE_PROGRAM);
 	UINT8 *rom = memory_region(machine, "mcu");
-	UINT8* decrypted = auto_malloc(0x100000);
-	UINT8* temp = malloc_or_die(0x100000);
+	UINT8* decrypted = auto_alloc_array(machine, UINT8, 0x100000);
+	UINT8* temp = alloc_array_or_die(UINT8, 0x100000);
 
 	// set CPU3 opcode base
 	memory_set_decrypted_region(space, 0x00000, 0xfffff, decrypted);
@@ -134,7 +134,7 @@ WRITE16_HANDLER(sonic_level_load_protection)
 		}
 		else
 		{
-			const UINT8 *ROM = memory_region(space->machine, "main");
+			const UINT8 *ROM = memory_region(space->machine, "maincpu");
 			level =  *((ROM + LEVEL_ORDER_ARRAY) + (system32_workram[CLEARED_LEVELS / 2] * 2) - 1);
 			level |= *((ROM + LEVEL_ORDER_ARRAY) + (system32_workram[CLEARED_LEVELS / 2] * 2) - 2) << 8;
 		}
@@ -165,7 +165,6 @@ READ16_HANDLER(brival_protection_r)
 			case 2:
 			case 3:
 				return 0;
-				break;
 		}
 	}
 
@@ -185,7 +184,7 @@ WRITE16_HANDLER(brival_protection_w)
 	};
 	char ret[32];
 	int curProtType;
-	UINT8 *ROM = memory_region(space->machine, "main");
+	UINT8 *ROM = memory_region(space->machine, "maincpu");
 
 	switch (offset)
 	{
@@ -212,7 +211,6 @@ WRITE16_HANDLER(brival_protection_w)
 				return;
 			logerror("brival_protection_w: UNKNOWN WRITE: offset %x value %x\n", offset, data);
 			return;
-			break;
 	}
 
 	memcpy(ret, &ROM[protAddress[curProtType][0]], 16);
