@@ -5,8 +5,10 @@
 
 UINT16 tatsumi_control_word=0;
 static UINT16 tatsumi_last_control=0;
-static UINT16 tatsumi_last_irq=0;
 static UINT8 apache3_adc;
+UINT16 apache3_rotate_ctrl[12];
+static int apache3_rot_idx;
+
 
 UINT16 *tatsumi_68k_ram;
 UINT8 *apache3_z80_ram;
@@ -15,12 +17,11 @@ UINT8 *apache3_z80_ram;
 
 void tatsumi_reset(running_machine *machine)
 {
-	tatsumi_last_irq=0;
-	tatsumi_last_control=0;
-	tatsumi_control_word=0;
-	apache3_adc=0;
+	tatsumi_last_control = 0;
+	tatsumi_control_word = 0;
+	apache3_adc = 0;
+	apache3_rot_idx = 0;
 
-	state_save_register_global(machine, tatsumi_last_irq);
 	state_save_register_global(machine, tatsumi_last_control);
 	state_save_register_global(machine, tatsumi_control_word);
 	state_save_register_global(machine, apache3_adc);
@@ -45,131 +46,130 @@ WRITE16_HANDLER( apache3_bank_w )
 
 	COMBINE_DATA(&tatsumi_control_word);
 
-	if (tatsumi_control_word&0x7f00)
+	if (tatsumi_control_word & 0x7f00)
 	{
 		logerror("Unknown control Word: %04x\n",tatsumi_control_word);
-		cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_HALT, CLEAR_LINE); // ?
+		cputag_set_input_line(space->machine, "sub2", INPUT_LINE_HALT, CLEAR_LINE); // ?
 	}
-	if ((tatsumi_control_word&0x8)==0 && !(tatsumi_last_control&0x8))
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ4, ASSERT_LINE);
 
-	if (tatsumi_control_word&0x10)
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+	if (tatsumi_control_word & 0x10)
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, ASSERT_LINE);
 	else
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, CLEAR_LINE);
 
-	if (tatsumi_control_word&0x80)
-		cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_HALT, ASSERT_LINE);
+	if (tatsumi_control_word & 0x80)
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_HALT, ASSERT_LINE);
 	else
-		cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_HALT, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_HALT, CLEAR_LINE);
 
 	tatsumi_last_control=tatsumi_control_word;
 }
 
-WRITE16_HANDLER( apache3_irq_ack_w )
+// D1 = /ZBREQ  - Z80 bus request
+// D0 = /GRDACC - Allow 68000 access to road pattern RAM
+WRITE16_HANDLER( apache3_z80_ctrl_w )
 {
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ4, CLEAR_LINE);
-
-	if ((data&2) && (tatsumi_last_irq&2)==0)
-	{
-		cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_HALT, ASSERT_LINE);
-	}
-
-	if ((tatsumi_last_irq&2) && (data&2)==0)
-	{
-		cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_HALT, CLEAR_LINE);
-		cpu_set_input_line_and_vector(space->machine->cpu[3], 0, HOLD_LINE, 0xc7 | 0x10);
-	}
-
-	tatsumi_last_irq=data;
+	cputag_set_input_line(space->machine, "sub2", INPUT_LINE_HALT, data & 2 ? ASSERT_LINE : CLEAR_LINE);
 }
 
 READ16_HANDLER( apache3_v30_v20_r )
 {
-	const address_space *targetspace = cpu_get_address_space(space->machine->cpu[2], ADDRESS_SPACE_PROGRAM);
+	const address_space *targetspace = cputag_get_address_space(space->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
 	/* Each V20 byte maps to a V30 word */
-	if ((tatsumi_control_word&0xe0)==0xe0)
-		offset+=0xf8000; /* Upper half */
-	else if ((tatsumi_control_word&0xe0)==0xc0)
-		offset+=0xf0000;
-	else if ((tatsumi_control_word&0xe0)==0x80)
-		offset+=0x00000; // main ram
+	if ((tatsumi_control_word & 0xe0) == 0xe0)
+		offset += 0xf8000; /* Upper half */
+	else if ((tatsumi_control_word & 0xe0) == 0xc0)
+		offset += 0xf0000;
+	else if ((tatsumi_control_word & 0xe0) == 0x80)
+		offset += 0x00000; // main ram
 	else
-		logerror("%08x: unmapped read z80 rom %08x\n",cpu_get_pc(space->cpu),offset);
+		logerror("%08x: unmapped read z80 rom %08x\n", cpu_get_pc(space->cpu), offset);
 	return 0xff00 | memory_read_byte(targetspace, offset);
 }
 
 WRITE16_HANDLER( apache3_v30_v20_w )
 {
-	const address_space *targetspace = cpu_get_address_space(space->machine->cpu[2], ADDRESS_SPACE_PROGRAM);
+	const address_space *targetspace = cputag_get_address_space(space->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
-	if ((tatsumi_control_word&0xe0)!=0x80)
-		logerror("%08x: write unmapped v30 rom %08x\n",cpu_get_pc(space->cpu),offset);
+	if ((tatsumi_control_word & 0xe0) != 0x80)
+		logerror("%08x: write unmapped v30 rom %08x\n", cpu_get_pc(space->cpu), offset);
 
 	/* Only 8 bits of the V30 data bus are connected - ignore writes to the other half */
 	if (ACCESSING_BITS_0_7)
 	{
-		memory_write_byte(targetspace, offset, data&0xff);
+		memory_write_byte(targetspace, offset, data & 0xff);
 	}
 }
 
-READ16_HANDLER(apache3_z80_r)
+READ16_HANDLER( apache3_z80_r )
 {
 	return apache3_z80_ram[offset];
 }
 
-WRITE16_HANDLER(apache3_z80_w)
+WRITE16_HANDLER( apache3_z80_w )
 {
-	apache3_z80_ram[offset]=data&0xff;
+	apache3_z80_ram[offset] = data & 0xff;
 }
 
 READ8_HANDLER( apache3_adc_r )
 {
-	if (apache3_adc==0)
-		return input_port_read(space->machine, "STICKX");
-	return input_port_read(space->machine, "STICKY");
+	switch (apache3_adc)
+	{
+		case 0: return input_port_read(space->machine, "STICK_X");
+		case 1: return input_port_read(space->machine, "STICK_Y");
+		case 2: return 0; // VSP1
+		case 3: return 0;
+		case 4: return (UINT8)((255./100) * (100 - input_port_read(space->machine, "VR1")));
+		case 5: return input_port_read(space->machine, "THROTTLE");
+		case 6: return 0; // RPSNC
+		case 7: return 0; // LPSNC
+	}
+
+	return 0;
 }
 
 WRITE8_HANDLER( apache3_adc_w )
 {
-	apache3_adc=offset;
+	apache3_adc = offset;
 }
 
-UINT16 apache3_a0000[16]; // TODO
-static int a3counter=0; // TODO
-
-WRITE16_HANDLER( apache3_a0000_w )
+/* Ground/sky rotation control
+ *
+ * There are 12 16-bit values that are
+ * presumably loaded into the 8 TZ2213 custom
+ * accumulators and counters.
+ */
+WRITE16_HANDLER( apache3_rotate_w )
 {
-	if (a3counter>15) // TODO
-		return;
-	apache3_a0000[a3counter++]=data;
+	apache3_rotate_ctrl[apache3_rot_idx] = data;
+	apache3_rot_idx = (apache3_rot_idx + 1) % 12;
 }
 
 /******************************************************************************/
 
 READ16_HANDLER( roundup_v30_z80_r )
 {
-	const address_space *targetspace = cpu_get_address_space(space->machine->cpu[2], ADDRESS_SPACE_PROGRAM);
+	const address_space *targetspace = cputag_get_address_space(space->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
 	/* Each Z80 byte maps to a V30 word */
-	if (tatsumi_control_word&0x20)
-		offset+=0x8000; /* Upper half */
+	if (tatsumi_control_word & 0x20)
+		offset += 0x8000; /* Upper half */
 
 	return 0xff00 | memory_read_byte(targetspace, offset);
 }
 
 WRITE16_HANDLER( roundup_v30_z80_w )
 {
-	const address_space *targetspace = cpu_get_address_space(space->machine->cpu[2], ADDRESS_SPACE_PROGRAM);
+	const address_space *targetspace = cputag_get_address_space(space->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
 	/* Only 8 bits of the V30 data bus are connected - ignore writes to the other half */
 	if (ACCESSING_BITS_0_7)
 	{
-		if (tatsumi_control_word&0x20)
-			offset+=0x8000; /* Upper half of Z80 address space */
+		if (tatsumi_control_word & 0x20)
+			offset += 0x8000; /* Upper half of Z80 address space */
 
-		memory_write_byte(targetspace, offset, data&0xff);
+		memory_write_byte(targetspace, offset, data & 0xff);
 	}
 }
 
@@ -178,18 +178,18 @@ WRITE16_HANDLER( roundup5_control_w )
 {
 	COMBINE_DATA(&tatsumi_control_word);
 
-	if (tatsumi_control_word&0x10)
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+	if (tatsumi_control_word & 0x10)
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, ASSERT_LINE);
 	else
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, CLEAR_LINE);
 
-	if (tatsumi_control_word&0x4)
-		cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_HALT, ASSERT_LINE);
+	if (tatsumi_control_word & 0x4)
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_HALT, ASSERT_LINE);
 	else
-		cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_HALT, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_HALT, CLEAR_LINE);
 
-//  if (offset==1 && (tatsumi_control_w&0xfeff)!=(last_bank&0xfeff))
-//      logerror("%08x:  Changed bank to %04x (%d)\n",cpu_get_pc(space->cpu),tatsumi_control_w,offset);
+//  if (offset == 1 && (tatsumi_control_w & 0xfeff) != (last_bank & 0xfeff))
+//      logerror("%08x:  Changed bank to %04x (%d)\n", cpu_get_pc(space->cpu), tatsumi_control_w,offset);
 
 //todo - watchdog
 
@@ -211,8 +211,8 @@ WRITE16_HANDLER( roundup5_control_w )
         Changed bank to 0060 (0)
     */
 
-	if ((tatsumi_control_word&0x8)==0 && !(tatsumi_last_control&0x8))
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ4, ASSERT_LINE);
+	if ((tatsumi_control_word & 0x8) == 0 && !(tatsumi_last_control & 0x8))
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_IRQ4, ASSERT_LINE);
 //  if (tatsumi_control_w&0x200)
 //      cpu_set_reset_line(1, CLEAR_LINE);
 //  else
@@ -223,19 +223,19 @@ WRITE16_HANDLER( roundup5_control_w )
 //  if ((tatsumi_control_w&0x200)==0 && (last_bank&0x200)==0x200)
 //      logerror("68k reset\n");
 
-	if (tatsumi_control_word==0x3a00) {
+	if (tatsumi_control_word == 0x3a00)
+	{
 //      cpu_set_reset_line(1, CLEAR_LINE);
-	//  logerror("68k on\n");
-
+//      logerror("68k on\n");
 	}
 
-	tatsumi_last_control=tatsumi_control_word;
+	tatsumi_last_control = tatsumi_control_word;
 }
 
 WRITE16_HANDLER( roundup5_d0000_w )
 {
 	COMBINE_DATA(&roundup5_d0000_ram[offset]);
-//  logerror("d_68k_d0000_w %06x %04x\n",cpu_get_pc(space->cpu),data);
+//  logerror("d_68k_d0000_w %06x %04x\n", cpu_get_pc(space->cpu), data);
 }
 
 WRITE16_HANDLER( roundup5_e0000_w )
@@ -245,16 +245,16 @@ WRITE16_HANDLER( roundup5_e0000_w )
     */
 
 	COMBINE_DATA(&roundup5_e0000_ram[offset]);
-	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ4, CLEAR_LINE); // guess, probably wrong
+	cputag_set_input_line(space->machine, "sub", INPUT_LINE_IRQ4, CLEAR_LINE); // guess, probably wrong
 
-//  logerror("d_68k_e0000_w %06x %04x\n",cpu_get_pc(space->cpu),data);
+//  logerror("d_68k_e0000_w %06x %04x\n", cpu_get_pc(space->cpu), data);
 }
 
 /******************************************************************************/
 
 READ16_HANDLER(cyclwarr_control_r)
 {
-//  logerror("%08x:  control_r\n",cpu_get_pc(space->cpu));
+//  logerror("%08x:  control_r\n", cpu_get_pc(space->cpu));
 	return tatsumi_control_word;
 }
 
@@ -262,8 +262,8 @@ WRITE16_HANDLER(cyclwarr_control_w)
 {
 	COMBINE_DATA(&tatsumi_control_word);
 
-//  if ((tatsumi_control_word&0xfe)!=(tatsumi_last_control&0xfe))
-//      logerror("%08x:  control_w %04x\n",cpu_get_pc(space->cpu),data);
+//  if ((tatsumi_control_word&0xfe) != (tatsumi_last_control&0xfe))
+//      logerror("%08x:  control_w %04x\n", cpu_get_pc(space->cpu), data);
 
 /*
 
@@ -274,24 +274,27 @@ WRITE16_HANDLER(cyclwarr_control_w)
 
 */
 
-	if ((tatsumi_control_word&4)==4 && (tatsumi_last_control&4)==0) {
+	if ((tatsumi_control_word & 4) == 4 && (tatsumi_last_control & 4) == 0)
+	{
 //      logerror("68k 2 halt\n");
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, ASSERT_LINE);
 	}
 
-	if ((tatsumi_control_word&4)==0 && (tatsumi_last_control&4)==4) {
+	if ((tatsumi_control_word & 4) == 0 && (tatsumi_last_control & 4) == 4)
+	{
 //      logerror("68k 2 irq go\n");
-		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
+		cputag_set_input_line(space->machine, "sub", INPUT_LINE_HALT, CLEAR_LINE);
 	}
 
 
 	// hack
-	if (cpu_get_pc(space->cpu)==0x2c3c34) {
+	if (cpu_get_pc(space->cpu) == 0x2c3c34)
+	{
 //      cpu_set_reset_line(1, CLEAR_LINE);
-	//  logerror("hack 68k2 on\n");
+//      logerror("hack 68k2 on\n");
 	}
 
-	tatsumi_last_control=tatsumi_control_word;
+	tatsumi_last_control = tatsumi_control_word;
 }
 
 /******************************************************************************/
@@ -307,7 +310,7 @@ logerror("%05X:68000_r(%04X),cw=%04X\n", cpu_get_pc(space->cpu), offset*2, tatsu
 		// hack to make roundup 5 boot
 		if (cpu_get_pc(space->cpu)==0xec575)
 		{
-			UINT8 *dst = memory_region(space->machine, "main");
+			UINT8 *dst = memory_region(space->machine, "maincpu");
 			dst[BYTE_XOR_LE(0xec57a)]=0x46;
 			dst[BYTE_XOR_LE(0xec57b)]=0x46;
 
@@ -340,9 +343,10 @@ WRITE16_HANDLER( tatsumi_v30_68000_w )
 
 // Todo:  Current YM2151 doesn't seem to raise the busy flag quickly enough for the
 // self-test in Tatsumi games.  Needs fixed, but hack it here for now.
-READ8_HANDLER(tatsumi_hack_ym2151_r)
+READ8_DEVICE_HANDLER(tatsumi_hack_ym2151_r)
 {
-	int r=ym2151_status_port_0_r(space,0);
+	const address_space *space = cputag_get_address_space(device->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	int r=ym2151_status_port_r(device,0);
 
 	if (cpu_get_pc(space->cpu)==0x2aca || cpu_get_pc(space->cpu)==0x29fe
 		|| cpu_get_pc(space->cpu)==0xf9721
@@ -353,9 +357,10 @@ READ8_HANDLER(tatsumi_hack_ym2151_r)
 
 // Todo:  Tatsumi self-test fails if OKI doesn't respond (when sound off).
 // Mame really should emulate the OKI status reads even with Mame sound off.
-READ8_HANDLER(tatsumi_hack_oki_r)
+READ8_DEVICE_HANDLER(tatsumi_hack_oki_r)
 {
-	int r=okim6295_status_0_r(space,0);
+	const address_space *space = cputag_get_address_space(device->machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	int r=okim6295_r(device,0);
 
 	if (cpu_get_pc(space->cpu)==0x2b70 || cpu_get_pc(space->cpu)==0x2bb5
 		|| cpu_get_pc(space->cpu)==0x2acc
