@@ -45,16 +45,22 @@ static TIMER_CALLBACK( battles_nmi_generate )
 
 	battles_customio_prev_command = battles_customio_command;
 
-	if( battles_customio_command & 0x10 ){
-		if( battles_customio_command_count == 0 ){
-			cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, PULSE_LINE);
-		}else{
-			cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
-			cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, PULSE_LINE);
+	if( battles_customio_command & 0x10 )
+	{
+		if( battles_customio_command_count == 0 )
+		{
+			cputag_set_input_line(machine, "sub3", INPUT_LINE_NMI, PULSE_LINE);
 		}
-	}else{
-		cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
-		cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, PULSE_LINE);
+		else
+		{
+			cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
+			cputag_set_input_line(machine, "sub3", INPUT_LINE_NMI, PULSE_LINE);
+		}
+	}
+	else
+	{
+		cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
+		cputag_set_input_line(machine, "sub3", INPUT_LINE_NMI, PULSE_LINE);
 	}
 	battles_customio_command_count++;
 }
@@ -154,11 +160,12 @@ WRITE8_HANDLER( battles_noise_sound_w )
 {
 	logerror("CPU3 %04x: 50%02x Write = %02x\n",cpu_get_pc(space->cpu),offset,data);
 	if( (battles_sound_played == 0) && (data == 0xFF) ){
+		const device_config *samples = devtag_get_device(space->machine, "samples");
 		if( customio[0] == 0x40 ){
-			sample_start (0, 0, 0);
+			sample_start (samples, 0, 0, 0);
 		}
 		else{
-			sample_start (0, 1, 0);
+			sample_start (samples, 0, 1, 0);
 		}
 	}
 	battles_sound_played = data;
