@@ -119,13 +119,11 @@ static STATE_POSTLOAD( redraw_pixels )
 
 VIDEO_START( fortyl )
 {
-	fortyl_pixram1 = auto_malloc(0x4000);
-	fortyl_pixram2 = auto_malloc(0x4000);
-	memset(fortyl_pixram1,0,0x4000);
-	memset(fortyl_pixram2,0,0x4000);
+	fortyl_pixram1 = auto_alloc_array_clear(machine, UINT8, 0x4000);
+	fortyl_pixram2 = auto_alloc_array_clear(machine, UINT8, 0x4000);
 
-	pixel_bitmap1 = auto_bitmap_alloc(256,256,video_screen_get_format(machine->primary_screen));
-	pixel_bitmap2 = auto_bitmap_alloc(256,256,video_screen_get_format(machine->primary_screen));
+	pixel_bitmap1 = auto_bitmap_alloc(machine,256,256,video_screen_get_format(machine->primary_screen));
+	pixel_bitmap2 = auto_bitmap_alloc(machine,256,256,video_screen_get_format(machine->primary_screen));
 
 	background  = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8,8,64,32);
 
