@@ -14,16 +14,17 @@
     --- Supported Sets ---
 
     Set Name | Relation | Description
-    --------------------------------------------
-    ampoker2   parent     American Poker II.
-    ampkr2b1   clone      American Poker II (bootleg, set 1).
-    ampkr2b2   clone      American Poker II (bootleg, set 2).
-    ampkr2b3   clone      American Poker II (bootleg, set 3).
-    pkrdewin   clone      Poker De Win.
-    ampkr95    clone      American Poker 95.
-    videomat   clone      Videomat (polish bootleg).
-    sigmapkr   parent     Sigma Poker.
-    sigma2k    parent     Sigma Poker 2000.
+    ---------+----------+------------------------------------
+    ampoker2 |  parent  |  American Poker II.
+    ampkr2b1 |  clone   |  American Poker II (bootleg, set 1).
+    ampkr2b2 |  clone   |  American Poker II (bootleg, set 2).
+    ampkr2b3 |  clone   |  American Poker II (bootleg, set 3).
+    ampkr228 |  clone   |  American Poker II (iamp2 v28).
+    pkrdewin |  clone   |  Poker De Win.
+    ampkr95  |  clone   |  American Poker 95.
+    videomat |  clone   |  Videomat (polish bootleg).
+    sigmapkr |  parent  |  Sigma Poker.
+    sigma2k  |  parent  |  Sigma Poker 2000.
 
 
 *********************************************************************************
