@@ -10,12 +10,6 @@
 #include "includes/atari.h"
 #include "video/gtia.h"
 
-#ifdef	LSB_FIRST
-#define BYTE_XOR(n) (n)
-#else
-#define BYTE_XOR(n) ((n)^1)
-#endif
-
 #define VERBOSE 0
 
 #define LOG(x)	do { if (VERBOSE) logerror x; } while (0)
@@ -719,7 +713,7 @@ VIDEO_START( atari )
 	LOG(("atari antic_vh_start\n"));
     memset(&antic, 0, sizeof(antic));
 
-	antic.cclk_expand = auto_malloc(21 * 256 * sizeof(UINT32));
+	antic.cclk_expand = auto_alloc_array(machine, UINT32, 21 * 256);
 
 	antic.pf_21 	  = &antic.cclk_expand[ 0 * 256];
 	antic.pf_x10b	  = &antic.cclk_expand[ 1 * 256];
@@ -731,7 +725,7 @@ VIDEO_START( atari )
 	antic.pf_gtia2	  = &antic.cclk_expand[19 * 256];
 	antic.pf_gtia3	  = &antic.cclk_expand[20 * 256];
 
-	antic.used_colors = auto_malloc(21 * 256 * sizeof(UINT8));
+	antic.used_colors = auto_alloc_array(machine, UINT8, 21 * 256);
 
 	memset(antic.used_colors, 0, 21 * 256 * sizeof(UINT8));
 
@@ -754,7 +748,7 @@ VIDEO_START( atari )
 
 	for( i = 0; i < 64; i++ )
     {
-		antic.prio_table[i] = auto_malloc(8*256);
+		antic.prio_table[i] = auto_alloc_array(machine, UINT8, 8*256);
     }
 
 	LOG(("atari prio_init\n"));
@@ -762,8 +756,7 @@ VIDEO_START( atari )
 
 	for( i = 0; i < video_screen_get_height(machine->primary_screen); i++ )
     {
-		antic.video[i] = auto_malloc(sizeof(VIDEO));
-		memset(antic.video[i], 0, sizeof(VIDEO));
+		antic.video[i] = auto_alloc_clear(machine, VIDEO);
     }
 
     VIDEO_START_CALL(generic_bitmapped);
@@ -990,16 +983,16 @@ static void antic_linerefresh(running_machine *machine)
 	if ( (antic.cmd & ANTIC_HSCR) == 0  || (antic.pfwidth == 48) || (antic.pfwidth == 32))
 	{
 		/* no hscroll */
-		dst[3] = antic.color_lookup[src[BYTE_XOR(0)]] | antic.color_lookup[src[BYTE_XOR(1)]] << 16;
+		dst[3] = antic.color_lookup[src[BYTE_XOR_LE(0)]] | antic.color_lookup[src[BYTE_XOR_LE(1)]] << 16;
 		src += 2;
 		dst += 4;
 		for( x = 1; x < HCHARS-1; x++ )
 		{
-			*dst++ = antic.color_lookup[src[BYTE_XOR(0)]] | antic.color_lookup[src[BYTE_XOR(1)]] << 16;
-			*dst++ = antic.color_lookup[src[BYTE_XOR(2)]] | antic.color_lookup[src[BYTE_XOR(3)]] << 16;
+			*dst++ = antic.color_lookup[src[BYTE_XOR_LE(0)]] | antic.color_lookup[src[BYTE_XOR_LE(1)]] << 16;
+			*dst++ = antic.color_lookup[src[BYTE_XOR_LE(2)]] | antic.color_lookup[src[BYTE_XOR_LE(3)]] << 16;
 			src += 4;
 		}
-		dst[0] = antic.color_lookup[src[BYTE_XOR(0)]] | antic.color_lookup[src[BYTE_XOR(1)]] << 16;
+		dst[0] = antic.color_lookup[src[BYTE_XOR_LE(0)]] | antic.color_lookup[src[BYTE_XOR_LE(1)]] << 16;
 	}
 	else
 	{
@@ -1032,9 +1025,9 @@ static void antic_linerefresh(running_machine *machine)
 						}
 						else
 						{
-							*dst++ = antic.color_lookup[src[BYTE_XOR(0)]] | antic.color_lookup[src[BYTE_XOR(1)]] << 16;
+							*dst++ = antic.color_lookup[src[BYTE_XOR_LE(0)]] | antic.color_lookup[src[BYTE_XOR_LE(1)]] << 16;
 						}
-						*dst++ = antic.color_lookup[src[BYTE_XOR(2)]] | antic.color_lookup[src[BYTE_XOR(3)]] << 16;
+						*dst++ = antic.color_lookup[src[BYTE_XOR_LE(2)]] | antic.color_lookup[src[BYTE_XOR_LE(3)]] << 16;
 						src += 4;
 					}
 					for ( ; x < HCHARS-1; x++ )
@@ -1051,7 +1044,7 @@ static void antic_linerefresh(running_machine *machine)
 	dst[2] = antic.color_lookup[PBK] | antic.color_lookup[PBK] << 16;
 	dst[3] = antic.color_lookup[PBK] | antic.color_lookup[PBK] << 16;
 
-	draw_scanline8(tmpbitmap, 12, y, sizeof(scanline), (const UINT8 *) scanline, NULL, -1);
+	draw_scanline8(tmpbitmap, 12, y, MIN(tmpbitmap->width - 12, sizeof(scanline)), (const UINT8 *) scanline, NULL);
 }
 
 static int cycle(running_machine *machine)
@@ -1073,7 +1066,7 @@ static TIMER_CALLBACK( antic_issue_dli )
 	{
 		LOG(("           @cycle #%3d issue DLI\n", cycle(machine)));
 		antic.r.nmist |= DLI_NMI;
-		cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
+		cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 	}
 	else
 	{
@@ -1168,7 +1161,7 @@ static TIMER_CALLBACK( antic_steal_cycles )
 	LOG(("           @cycle #%3d steal %d cycles\n", cycle(machine), antic.steal_cycles));
 	after(machine, antic.steal_cycles, antic_line_done, "antic_line_done");
     antic.steal_cycles = 0;
-	cpu_spinuntil_trigger( machine->cpu[0], TRIGGER_STEAL );
+	cpu_spinuntil_trigger( cputag_get_cpu(machine, "maincpu"), TRIGGER_STEAL );
 }
 
 
@@ -1182,7 +1175,7 @@ static TIMER_CALLBACK( antic_steal_cycles )
  *****************************************************************************/
 static TIMER_CALLBACK( antic_scanline_render )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	VIDEO *video = antic.video[antic.scanline];
 	LOG(("           @cycle #%3d render mode $%X lines to go #%d\n", cycle(machine), (antic.cmd & 0x0f), antic.modelines));
@@ -1252,7 +1245,7 @@ INLINE void LMS(running_machine *machine, int new_cmd)
      **************************************************************/
     if( new_cmd & ANTIC_LMS )
     {
-    	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+    	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 		int addr = RDANTIC(space);
         antic.doffs = ++antic.doffs & DOFFS;
         addr += 256 * RDANTIC(space);
@@ -1277,7 +1270,7 @@ INLINE void LMS(running_machine *machine, int new_cmd)
  *****************************************************************************/
 static void antic_scanline_dma(running_machine *machine, int param)
 {
-   	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+   	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	LOG(("           @cycle #%3d DMA fetch\n", cycle(machine)));
 	if (antic.scanline == VBL_END)
 		antic.r.nmist &= ~VBL_NMI;
@@ -1535,7 +1528,7 @@ static void generic_atari_interrupt(running_machine *machine, void (*handle_keyb
 			LOG(("           cause VBL NMI\n"));
 			/* set the VBL NMI status bit */
 			antic.r.nmist |= VBL_NMI;
-			cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
+			cputag_set_input_line(machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 		}
     }
 
