@@ -243,7 +243,7 @@ VIDEO_UPDATE( bionicc )
 
 VIDEO_EOF( bionicc )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
-	buffer_spriteram16_w(space,0,0,0xffff);
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 }
