@@ -29,11 +29,11 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 VIDEO_START( bsktball )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
-		TILEMAP_TYPE_PEN, 8, 8, 32, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows,
+		 8, 8, 32, 32);
 }
 
-static void draw_sprites(running_machine *machine,  mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine,  bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int motion;
 
@@ -58,6 +58,6 @@ static void draw_sprites(running_machine *machine,  mame_bitmap *bitmap, const r
 VIDEO_UPDATE( bsktball )
 {
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
-	draw_sprites(machine, bitmap, cliprect);
+	draw_sprites(screen->machine, bitmap, cliprect);
 	return 0;
 }
