@@ -198,7 +198,7 @@ VIDEO_UPDATE( crash )
 static void ripcord_draw_skydiver(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	const gfx_element *gfx;
-	UINT8  *src_lineptr, *src_pixptr;
+	const UINT8  *src_lineptr, *src_pixptr;
 	UINT16 *dst_lineptr, *dst_lineend;
 	UINT32 code;
 	int sx, sy;
@@ -216,7 +216,7 @@ static void ripcord_draw_skydiver(running_machine *machine, bitmap_t *bitmap, co
 	edx = 1;
 
 	gfx = machine->gfx[1];
-	src_lineptr = gfx->gfxdata + code * gfx->char_modulo;
+	src_lineptr = gfx_element_get_data(gfx, code);
 	src_pitch = gfx->line_modulo;
 	dst_pitch = bitmap->rowpixels;
 
@@ -252,8 +252,8 @@ static void ripcord_draw_skydiver(running_machine *machine, bitmap_t *bitmap, co
 	// report collision only when the character is not blank and within display area
 	if (collision && code!=0xf && clown_x>0 && clown_x<240 && clown_y>-12 && clown_y<240)
 	{
-		cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE); // interrupt accuracy is critical in Ripcord
-		cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
+		cputag_set_input_line(machine, "maincpu", 0, ASSERT_LINE); // interrupt accuracy is critical in Ripcord
+		cputag_set_input_line(machine, "maincpu", 0, CLEAR_LINE);
 	}
 }
 
