@@ -60,6 +60,7 @@ Note:   if MAME_DEBUG is defined, pressing Z or X with:
 
 static int cischeat_ip_select;
 static int shift_ret = 1;
+static UINT8 drawmode_table[16];
 
 #ifdef MAME_DEBUG
 static int debugsprites;	// For debug purposes
@@ -129,10 +130,10 @@ static void prepare_shadows(void)
 {
 	int i;
 	for (i = 0;i < 16;i++)
-		gfx_drawmode_table[i] = DRAWMODE_SOURCE;
+		drawmode_table[i] = DRAWMODE_SOURCE;
 
-	gfx_drawmode_table[ 0] = DRAWMODE_SHADOW;
-	gfx_drawmode_table[15] = DRAWMODE_NONE;
+	drawmode_table[ 0] = DRAWMODE_SHADOW;
+	drawmode_table[15] = DRAWMODE_NONE;
 }
 
 /**************************************************************************
@@ -296,9 +297,9 @@ WRITE16_HANDLER( bigrun_vregs_w )
 		case 0x2208/2   : break;	// watchdog reset
 
 		/* Not sure about this one.. */
-		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cputag_set_input_line(space->machine, "cpu2", INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "cpu3", INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "soundcpu", INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default: SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -383,14 +384,14 @@ WRITE16_HANDLER( cischeat_vregs_w )
 		case 0x2208/2   : break;	// watchdog reset
 
 		case 0x2300/2   :	/* Sound CPU: reads latch during int 4, and stores command */
-							soundlatch_word_w(space,0,new_data,0xffff);
-							cpu_set_input_line(space->machine->cpu[3],4,HOLD_LINE);
+							soundlatch_word_w(space, 0, new_data, 0xffff);
+							cputag_set_input_line(space->machine, "soundcpu", 4, HOLD_LINE);
 							break;
 
 		/* Not sure about this one.. */
-		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cputag_set_input_line(space->machine, "cpu2", INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "cpu3", INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "soundcpu", INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default: SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -498,8 +499,8 @@ CPU #0 PC 00235C : Warning, vreg 0006 <- 0000
 		case 0x0014/2   :	break;
 
 		/* Usually written in sequence, but not always */
-		case 0x0008/2   :	soundlatch_word_w(space,0,new_data,0xffff);	break;
-		case 0x0018/2   :	cpu_set_input_line(space->machine->cpu[3],4,HOLD_LINE);	break;
+		case 0x0008/2   :	soundlatch_word_w(space, 0, new_data, 0xffff);	break;
+		case 0x0018/2   :	cputag_set_input_line(space->machine, "soundcpu", 4, HOLD_LINE);	break;
 
 		case 0x0010/2   :	break;
 
@@ -519,9 +520,9 @@ CPU #0 PC 00235C : Warning, vreg 0006 <- 0000
 		case 0x2208/2   : break;	// watchdog reset
 
 		/* Not sure about this one. Values: $10 then 0, $7 then 0 */
-		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 4) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cputag_set_input_line(space->machine, "cpu2", INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "cpu3", INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cputag_set_input_line(space->machine, "soundcpu", INPUT_LINE_RESET, (new_data & 4) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default:		SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -541,13 +542,13 @@ WRITE16_HANDLER( f1gpstr2_vregs_w )
 		case 0x0000/2   :
 			if (ACCESSING_BITS_0_7)
 			{
-				cpu_set_input_line(space->machine->cpu[4],4,(new_data & 4)?ASSERT_LINE:CLEAR_LINE);
-				cpu_set_input_line(space->machine->cpu[4],2,(new_data & 2)?ASSERT_LINE:CLEAR_LINE);
+				cputag_set_input_line(space->machine, "cpu5", 4, (new_data & 4) ? ASSERT_LINE : CLEAR_LINE);
+				cputag_set_input_line(space->machine, "cpu5", 2, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE);
 			}
 			break;
 
 		default:
-			f1gpstar_vregs_w(space,offset,data,mem_mask);
+			f1gpstar_vregs_w(space, offset, data, mem_mask);
 			break;
 	}
 }
@@ -923,18 +924,18 @@ if ( (debugsprites) && ( ((attr & 0x0300)>>8) != (debugsprites-1) ) ) 	{ continu
 		if (flipy)	{ ystart = ynum-1;  yend = -1;    yinc = -1; }
 		else		{ ystart = 0;       yend = ynum;  yinc = +1; }
 
+		drawmode_table[ 0] = shadow ? DRAWMODE_SHADOW : DRAWMODE_SOURCE;
+
 		for (y = ystart; y != yend; y += yinc)
 		{
 			for (x = xstart; x != xend; x += xinc)
 			{
-				drawgfxzoom(bitmap,machine->gfx[3],
+				drawgfxzoom_transtable(bitmap,cliprect,machine->gfx[3],
 							code++,
 							color,
 							flipx,flipy,
 							(sx + x * xdim) / 0x10000, (sy + y * ydim) / 0x10000,
-							cliprect,
-							shadow ? TRANSPARENCY_PEN_TABLE : TRANSPARENCY_PEN,15,
-							xscale, yscale );
+							xscale, yscale, drawmode_table, machine->shadow_table);
 			}
 		}
 #ifdef MAME_DEBUG
@@ -1077,18 +1078,18 @@ if ( (debugsprites) && ( ((attr & 0x0300)>>8) != (debugsprites-1) ) ) 	{ continu
 		if (flipy)	{ ystart = ynum-1;  yend = -1;    yinc = -1; }
 		else		{ ystart = 0;       yend = ynum;  yinc = +1; }
 
+		drawmode_table[ 0] = shadow ? DRAWMODE_SHADOW : DRAWMODE_SOURCE;
+
 		for (y = ystart; y != yend; y += yinc)
 		{
 			for (x = xstart; x != xend; x += xinc)
 			{
-				drawgfxzoom(bitmap,machine->gfx[3],
+				drawgfxzoom_transtable(bitmap,cliprect,machine->gfx[3],
 							code++,
 							color,
 							flipx,flipy,
 							(sx + x * xdim) / 0x10000, (sy + y * ydim) / 0x10000,
-							cliprect,
-							shadow ? TRANSPARENCY_PEN_TABLE : TRANSPARENCY_PEN,15,
-							xscale, yscale );
+							xscale, yscale, drawmode_table, machine->shadow_table);
 			}
 		}
 #ifdef MAME_DEBUG
@@ -1342,7 +1343,7 @@ if ( input_code_pressed(KEYCODE_Z) || input_code_pressed(KEYCODE_X) )
 	if (msk != 0) megasys1_active_layers &= msk;
 #if 1
 	{
-		const address_space *space = cpu_get_address_space(screen->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+		const address_space *space = cputag_get_address_space(screen->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 		popmessage("Cmd: %04X Pos:%04X Lim:%04X Inp:%04X",
 							scudhamm_motor_command,
