@@ -415,7 +415,7 @@ static const struct CPS1config *cps1_game_config;
 #define CPS_B_21_BT1 0x32,0x0800, 0x0e,0x0c,0x0a,0x08, 0x06,0x04,0x02,  0x28,{0x26,0x24,0x22,0x20},0x30, {0x20,0x04,0x08,0x12,0x12}
 #define CPS_B_21_BT2  -1,   -1,   0x1e,0x1c,0x1a,0x18,  -1, 0x0c,0x0a,  0x20,{0x2e,0x2c,0x2a,0x28},0x30, {0x30,0x08,0x30,0x00,0x00}
 #define CPS_B_21_BT3  -1,   -1,   0x06,0x04,0x02,0x00, 0x0e,0x0c,0x0a,  0x20,{0x2e,0x2c,0x2a,0x28},0x30, {0x20,0x12,0x12,0x00,0x00}
-#define CPS_B_21_BT4  -1,   -1,   0x06,0x04,0x02,0x00, 0x1e,0x1c,0x0a,  0x28,{0x26,0x24,0x22,0x20},0x30, {0x20,0x10,0x02,0x00,0x00}
+#define CPS_B_21_BT4  -1,   -1,   0x06,0x04,0x02,0x00, 0x1e,0x1c,0x1a,  0x28,{0x26,0x24,0x22,0x20},0x30, {0x20,0x10,0x02,0x00,0x00}
 #define CPS_B_21_BT5 0x32,  -1,   0x0e,0x0c,0x0a,0x08, 0x1e,0x1c,0x1a,  0x20,{0x2e,0x2c,0x2a,0x28},0x30, {0x20,0x04,0x02,0x00,0x00}
 #define CPS_B_21_BT6  -1,   -1,    -1,  -1,  -1,  -1,   -1,  -1,  -1,   0x20,{0x2e,0x2c,0x2a,0x28},0x30, {0x20,0x14,0x14,0x00,0x00}
 #define CPS_B_21_BT7  -1,   -1,    -1,  -1,  -1,  -1,   -1,  -1,  -1,   0x2c,{ -1,  -1,  -1,  -1 },0x12, {0x14,0x02,0x14,0x00,0x00}
@@ -1233,8 +1233,8 @@ static const struct gfx_range mapper_cps2_table[] =
 static const struct CPS1config cps1_config_table[]=
 {
 	/* name       CPSB         gfx mapper   in2  in3  out2   kludge */
-	{"forgottn", CPS_B_01,     mapper_LWCHR },
-	{"forgott1", CPS_B_01,     mapper_LW621 },
+	{"forgottn", CPS_B_01,     mapper_LW621 },
+	{"forgottu", CPS_B_01,     mapper_LWCHR },
 	{"lostwrld", CPS_B_01,     mapper_LWCHR },
 	{"ghouls",   CPS_B_01,     mapper_DM620 },
 	{"ghoulsu",  CPS_B_01,     mapper_DM620 },
@@ -1279,6 +1279,7 @@ static const struct CPS1config cps1_config_table[]=
 	{"cawingj",  CPS_B_16,     mapper_CA22B },	// equivalent to CA24B
 	{"sf2",      CPS_B_11,     mapper_STF29,  0x36 },
 	{"sf2eb",    CPS_B_17,     mapper_STF29,  0x36 },
+	{"sf2ebbl",  CPS_B_17,     mapper_STF29,  0x36, 0, 0, 1  },
 	{"sf2ua",    CPS_B_17,     mapper_STF29,  0x36 },
 	{"sf2ub",    CPS_B_17,     mapper_STF29,  0x36 },
 	{"sf2ud",    CPS_B_05,     mapper_STF29,  0x36 },
@@ -1500,13 +1501,13 @@ static MACHINE_RESET( cps )
 	if (strcmp(gamename, "sf2rb" )==0)
 	{
 		/* Patch out protection check */
-		UINT16 *rom = (UINT16 *)memory_region(machine, "main");
+		UINT16 *rom = (UINT16 *)memory_region(machine, "maincpu");
 		rom[0xe5464/2] = 0x6012;
 	}
 	if (strcmp(gamename, "sf2rb2" )==0)
 	{
 		/* Patch out protection check */
-		UINT16 *rom = (UINT16 *)memory_region(machine, "main");
+		UINT16 *rom = (UINT16 *)memory_region(machine, "maincpu");
 		rom[0xe5332/2] = 0x6014;
 	}
 
@@ -1517,13 +1518,13 @@ static MACHINE_RESET( cps )
            by the cpu core as a 32-bit branch. This branch would make the
            game crash (address error, since it would branch to an odd address)
            if location 180ca6 (outside ROM space) isn't 0. Protection check? */
-		UINT16 *rom = (UINT16 *)memory_region(machine, "main");
+		UINT16 *rom = (UINT16 *)memory_region(machine, "maincpu");
 		rom[0x11756/2] = 0x4e71;
 	}
 	else if (strcmp(gamename, "ghouls" )==0)
 	{
 		/* Patch out self-test... it takes forever */
-		UINT16 *rom = (UINT16 *)memory_region(machine, "main");
+		UINT16 *rom = (UINT16 *)memory_region(machine, "maincpu");
 		rom[0x61964/2] = 0x4ef9;
 		rom[0x61966/2] = 0x0000;
 		rom[0x61968/2] = 0x0400;
@@ -2055,13 +2056,11 @@ static VIDEO_START( cps )
 		palette_set_color(machine,i,MAKE_RGB(0,0,0));
 	}
 
-    cps1_buffered_obj = auto_malloc (cps1_obj_size);
-    memset(cps1_buffered_obj, 0x00, cps1_obj_size);
+    cps1_buffered_obj = auto_alloc_array_clear(machine, UINT16, cps1_obj_size/2);
 
 	if (cps_version==2)
 	{
-		cps2_buffered_obj = auto_malloc (cps2_obj_size);
-		memset(cps2_buffered_obj, 0x00, cps2_obj_size);
+		cps2_buffered_obj = auto_alloc_array_clear(machine, UINT16, cps2_obj_size/2);
 	}
 
 	memset(cps1_gfxram, 0, cps1_gfxram_size);   /* Clear GFX RAM */
