@@ -207,8 +207,8 @@ static void captaven_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
         Word 2:
             0xf000: Block height
             0x0f00: Block width
-            0x00c0: Unused?
-            0x0020: Priority
+            0x0080: Unused?
+            0x0040: Priority
             0x001f: Colour
         Word 3:
             0xffff: Sprite value
@@ -224,10 +224,23 @@ static void captaven_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 		if (sy==0x00000108 && !sprite)
 			continue; //fix!!!!!
 
-		if (spritedata[offs+2]&0x20)
-			prival=0;
+		if ((spritedata[offs+2]&0x60)==0x00)
+		{
+			prival = 0; // above everything
+		}
+		else if ((spritedata[offs+2]&0x60)==0x20)
+		{
+			prival = 0xfff0; // above the 2nd playfield
+		}
+		else if ((spritedata[offs+2]&0x60)==0x40)
+		{
+			prival = 0xfffc; // above the 1st playfield
+		}
 		else
-			prival=2;
+		{
+			// never used?
+			prival = 0xfffe; // under everything
+		}
 
 		sx = spritedata[offs+1];
 
@@ -272,6 +285,14 @@ static void captaven_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 						fx,fy,
 						sx + x_mult * (w-x),sy + y_mult * (h-y),
 						cliprect,TRANSPARENCY_PEN,0,prival);
+
+				// wrap-around y
+				pdrawgfx(bitmap,machine->gfx[gfxbank],
+						sprite + y + h * x,
+						colour,
+						fx,fy,
+						sx + x_mult * (w-x),sy + y_mult * (h-y) - 512,
+						cliprect,TRANSPARENCY_PEN,0,prival);
 			}
 		}
 	}
@@ -284,7 +305,7 @@ static void fghthist_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 	for (offs = 0x400 - 4; offs >= 0; offs -=4)
 	{
 		int x,y,sprite,colour,multi,fx,fy,inc,flash,mult,pri=0;
-		int trans;
+		int alpha = 0xff;
 
 		sprite = spritedata[offs+1] & 0xffff;
 
@@ -292,14 +313,13 @@ static void fghthist_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 		flash=y&0x1000;
 		if (flash && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
-		trans=TRANSPARENCY_PEN;
 		x = spritedata[offs+2];
 		colour = (x >>9) & colourmask;
 
 		if ((y&0x8000))
-			pri=8;
+			pri=1;
 		else
-			pri=128;
+			pri=4;
 
 		fx = y & 0x2000;
 		fy = y & 0x4000;
@@ -332,7 +352,7 @@ static void fghthist_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 					colour,
 					fx,fy,
 					x,y + mult * multi,
-					cliprect,trans,0,pri,1<<gfxbank, 1);
+					cliprect,0,pri,1<<gfxbank, 1, alpha);
 
 			multi--;
 		}
@@ -348,11 +368,10 @@ static void deco32_draw_sprite(bitmap_t *dest,const gfx_element *gfx,
 		UINT32 code,UINT32 priority,int flipx,int flipy,int sx,int sy,
 		const rectangle *clip)
 {
+	const UINT8 *code_base = gfx_element_get_data(gfx, code % gfx->total_elements);
 	int ox,oy,cx,cy;
 	int x_index,y_index,x,y;
 
-	int source_base = (code % gfx->total_elements) * gfx->height;
-
 	/* check bounds */
 	ox = sx;
 	oy = sy;
@@ -371,7 +390,7 @@ static void deco32_draw_sprite(bitmap_t *dest,const gfx_element *gfx,
 
 	for( y=0; y<16-cy; y++ )
 	{
-		UINT8 *source = gfx->gfxdata + ((source_base+y_index) * gfx->line_modulo);
+		const UINT8 *source = code_base + y_index * gfx->line_modulo;
 		UINT16 *destb = BITMAP_ADDR16(dest, sy, 0);
 
 		if (flipx) { source+=15-(sx-ox); x_index=-1; } else { x_index=1; source+=(sx-ox); }
@@ -401,7 +420,7 @@ static void nslasher_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 	for (offs = 0; offs<0x400; offs+=4)
 	{
 		int x,y,sprite,colour,multi,fx,fy,inc,flash,mult; /*,pri=0,spri=0;*/
-		int trans;
+		//int trans;
 
 		sprite = spritedata[offs+1] & 0xffff;
 
@@ -409,7 +428,7 @@ static void nslasher_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 		flash=y&0x1000;
 		if (flash && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
-		trans=TRANSPARENCY_PEN;
+		//trans=TRANSPARENCY_PEN;
 		x = spritedata[offs+2];
 
 		// Prepare colour, priority and alpha info
@@ -458,8 +477,8 @@ static void nslasher_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 INLINE void dragngun_drawgfxzoom( running_machine *machine,
 		bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
-		const rectangle *clip,int transparency,int transparent_color,
-		int scalex, int scaley,bitmap_t *pri_buffer,UINT32 pri_mask, int sprite_screen_width, int  sprite_screen_height )
+		const rectangle *clip,int transparent_color,
+		int scalex, int scaley,bitmap_t *pri_buffer,UINT32 pri_mask, int sprite_screen_width, int  sprite_screen_height, UINT8 alpha )
 {
 	rectangle myclip;
 
@@ -492,7 +511,7 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 		if( gfx )
 		{
 			const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
-			int source_base = (code % gfx->total_elements) * gfx->height;
+			const UINT8 *code_base = gfx_element_get_data(gfx, code % gfx->total_elements);
 
 			if (sprite_screen_width && sprite_screen_height)
 			{
@@ -558,13 +577,13 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 					int y;
 
 					/* case 1: TRANSPARENCY_PEN */
-					if (transparency == TRANSPARENCY_PEN)
+					if (alpha == 0xff)
 					{
 						if (pri_buffer)
 						{
 							for( y=sy; y<ey; y++ )
 							{
-								UINT8 *source = gfx->gfxdata + (source_base+(y_index>>16)) * gfx->line_modulo;
+								const UINT8 *source = code_base + (y_index>>16) * gfx->line_modulo;
 								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
 								UINT8 *pri = BITMAP_ADDR8(pri_buffer, y, 0);
 
@@ -588,7 +607,7 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 						{
 							for( y=sy; y<ey; y++ )
 							{
-								UINT8 *source = gfx->gfxdata + (source_base+(y_index>>16)) * gfx->line_modulo;
+								const UINT8 *source = code_base + (y_index>>16) * gfx->line_modulo;
 								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
 
 								int x, x_index = x_index_base;
@@ -604,14 +623,14 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 						}
 					}
 
-					/* case 6: TRANSPARENCY_ALPHA */
-					if (transparency == TRANSPARENCY_ALPHA)
+					/* alpha-blended */
+					else
 					{
 						if (pri_buffer)
 						{
 							for( y=sy; y<ey; y++ )
 							{
-								UINT8 *source = gfx->gfxdata + (source_base+(y_index>>16)) * gfx->line_modulo;
+								const UINT8 *source = code_base + (y_index>>16) * gfx->line_modulo;
 								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
 								UINT8 *pri = BITMAP_ADDR8(pri_buffer, y, 0);
 
@@ -622,7 +641,7 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 									if( c != transparent_color )
 									{
 										if (((1 << pri[x]) & pri_mask) == 0)
-											dest[x] = alpha_blend32(dest[x], pal[c]);
+											dest[x] = alpha_blend_r32(dest[x], pal[c], alpha);
 										pri[x] = 31;
 									}
 									x_index += dx;
@@ -635,14 +654,14 @@ INLINE void dragngun_drawgfxzoom( running_machine *machine,
 						{
 							for( y=sy; y<ey; y++ )
 							{
-								UINT8 *source = gfx->gfxdata + (source_base+(y_index>>16)) * gfx->line_modulo;
+								const UINT8 *source = code_base + (y_index>>16) * gfx->line_modulo;
 								UINT32 *dest = BITMAP_ADDR32(dest_bmp, y, 0);
 
 								int x, x_index = x_index_base;
 								for( x=sx; x<ex; x++ )
 								{
 									int c = source[x_index>>16];
-									if( c != transparent_color ) dest[x] = alpha_blend32(dest[x], pal[c]);
+									if( c != transparent_color ) dest[x] = alpha_blend_r32(dest[x], pal[c], alpha);
 									x_index += dx;
 								}
 
@@ -713,7 +732,7 @@ static void dragngun_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 
 	for (offs = 0;offs < 0x800;offs += 8)
 	{
-		int sx,sy,colour,fx,fy,w,h,x,y,bx,by,trans,scalex,scaley;
+		int sx,sy,colour,fx,fy,w,h,x,y,bx,by,alpha,scalex,scaley;
 		int zoomx,zoomy;
 		int xpos,ypos;
 
@@ -743,9 +762,9 @@ static void dragngun_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 		colour = spritedata[offs+6]&0x1f;
 
 		if (spritedata[offs+6]&0x80)
-			trans=TRANSPARENCY_ALPHA;
+			alpha=0x80;
 		else
-			trans=TRANSPARENCY_PEN;
+			alpha=0xff;
 
 		fx = spritedata[offs+4]&0x8000;
 		fy = spritedata[offs+5]&0x8000;
@@ -808,15 +827,15 @@ static void dragngun_draw_sprites(running_machine* machine, bitmap_t *bitmap, co
 						colour,
 						fx,fy,
 						xpos>>16,ypos>>16,
-						cliprect,trans,15,zoomx,zoomy,NULL,0,
-						((xpos+(zoomx<<4))>>16) - (xpos>>16), ((ypos+(zoomy<<4))>>16) - (ypos>>16) );
+						cliprect,15,zoomx,zoomy,NULL,0,
+						((xpos+(zoomx<<4))>>16) - (xpos>>16), ((ypos+(zoomy<<4))>>16) - (ypos>>16), alpha );
 				else
-					drawgfx(bitmap,machine->gfx[bank],
+					drawgfx_alpha(bitmap,cliprect,machine->gfx[bank],
 						sprite,
 						colour,
 						fx,fy,
 						xpos>>16,ypos>>16,
-						cliprect,trans,15);
+						15,alpha);
 
 				if (fx)
 					xpos-=zoomx<<4;
@@ -955,7 +974,7 @@ VIDEO_START( captaven )
 	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
 	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info,    deco16_scan_rows,16,16,64,32);
 	pf3_tilemap = tilemap_create(machine, get_ca_pf3_tile_info, tilemap_scan_rows,16,16,32,32);
-	deco32_raster_display_list=auto_malloc(10 * 256);
+	deco32_raster_display_list=auto_alloc_array(machine, UINT16, 10 * 256 / 2);
 	memset(deco32_raster_display_list, 0, 10 * 256);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
@@ -971,11 +990,11 @@ VIDEO_START( captaven )
 VIDEO_START( fghthist )
 {
 	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info, tilemap_scan_rows, 8, 8,64,32);
-	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info, deco16_scan_rows,16,16,64,32);
-	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info, deco16_scan_rows,16,16,64,32);
-	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info, deco16_scan_rows, 16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info, deco16_scan_rows, 16,16,64,32);
+	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info, deco16_scan_rows, 16,16,64,32);
 	pf1a_tilemap =0;
-	dirty_palette = auto_malloc(4096);
+	dirty_palette = auto_alloc_array(machine, UINT8, 4096);
 
 	deco_allocate_sprite_bitmap(machine);
 
@@ -995,8 +1014,8 @@ VIDEO_START( dragngun )
 	pf3_tilemap = tilemap_create(machine, get_ll_pf3_tile_info, deco16_scan_rows,16,16,64,32);
 	pf4_tilemap = tilemap_create(machine, get_ll_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
 	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
-	dirty_palette = auto_malloc(4096);
-	deco32_raster_display_list = auto_malloc(10 * 256);
+	dirty_palette = auto_alloc_array(machine, UINT8, 4096);
+	deco32_raster_display_list = auto_alloc_array(machine, UINT16, 10 * 256 / 2);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -1006,7 +1025,6 @@ VIDEO_START( dragngun )
 
 	deco32_pf2_colourbank=deco32_pf4_colourbank=0;
 
-	alpha_set_level(0x80);
 	state_save_register_global(machine, dragngun_sprite_ctrl);
 	has_ace_ram=0;
 }
@@ -1018,8 +1036,8 @@ VIDEO_START( lockload )
 	pf3_tilemap = tilemap_create(machine, get_ll_pf3_tile_info, deco16_scan_rows,16,16,32,32);
 	pf4_tilemap = tilemap_create(machine, get_ll_pf4_tile_info, deco16_scan_rows,     16,16,32,32);
 	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
-	dirty_palette = auto_malloc(4096);
-	deco32_raster_display_list = auto_malloc(10 * 256);
+	dirty_palette = auto_alloc_array(machine, UINT8, 4096);
+	deco32_raster_display_list = auto_alloc_array(machine, UINT16, 10 * 256 / 2);
 	memset(deco32_raster_display_list, 0, 10 * 256);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
@@ -1030,7 +1048,6 @@ VIDEO_START( lockload )
 
 	deco32_pf2_colourbank=deco32_pf4_colourbank=0;
 
-	alpha_set_level(0x80);
 	state_save_register_global(machine, dragngun_sprite_ctrl);
 	has_ace_ram=0;
 }
@@ -1044,13 +1061,13 @@ VIDEO_START( nslasher )
 	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info, deco16_scan_rows,16,16,64,32);
 	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
 	pf1a_tilemap =0;
-	dirty_palette = auto_malloc(4096);
+	dirty_palette = auto_alloc_array(machine, UINT8, 4096);
 
 	width = video_screen_get_width(machine->primary_screen);
 	height = video_screen_get_height(machine->primary_screen);
-	sprite0_mix_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
-	sprite1_mix_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
-	tilemap_alpha_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
+	sprite0_mix_bitmap=auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16 );
+	sprite1_mix_bitmap=auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16 );
+	tilemap_alpha_bitmap=auto_bitmap_alloc(machine, width, height, BITMAP_FORMAT_INDEXED16 );
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -1061,7 +1078,6 @@ VIDEO_START( nslasher )
 	deco32_pf2_colourbank=16;
 	deco32_pf4_colourbank=16;
 	state_save_register_global(machine, deco32_pri);
-	alpha_set_level(0x80);
 	has_ace_ram=1;
 }
 
@@ -1247,34 +1263,35 @@ VIDEO_UPDATE( captaven )
 	bitmap_fill(priority_bitmap,cliprect,0);
 	if ((deco32_pri&1)==0) {
 		if (pf3_enable)
-			tilemap_draw(bitmap,cliprect,pf3_tilemap,TILEMAP_DRAW_OPAQUE,0);
+			tilemap_draw(bitmap,cliprect,pf3_tilemap,TILEMAP_DRAW_OPAQUE,1);
 		else
 			bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 		if (deco32_raster_display_position)
-			tilemap_raster_draw(bitmap,cliprect,0,1);
+			tilemap_raster_draw(bitmap,cliprect,0,2);
 		else
-			tilemap_draw(bitmap,cliprect,pf2_tilemap,0,1);
+			tilemap_draw(bitmap,cliprect,pf2_tilemap,0,2);
 	} else {
 		if (pf2_enable) {
 			if (deco32_raster_display_position)
-				tilemap_raster_draw(bitmap,cliprect,TILEMAP_DRAW_OPAQUE,0);
+				tilemap_raster_draw(bitmap,cliprect,TILEMAP_DRAW_OPAQUE,1);
 			else
-				tilemap_draw(bitmap,cliprect,pf2_tilemap,0,0);
+				tilemap_draw(bitmap,cliprect,pf2_tilemap,0,1);
 		}
 		else
 			bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
-		tilemap_draw(bitmap,cliprect,pf3_tilemap,0,1);
+		tilemap_draw(bitmap,cliprect,pf3_tilemap,0,2);
 	}
 
-	captaven_draw_sprites(screen->machine,bitmap,cliprect,buffered_spriteram32,3);
-
 	/* PF1 can be in 8x8 mode or 16x16 mode */
 	if (deco32_pf12_control[6]&0x80)
-		tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,pf1_tilemap,0,4);
 	else
-		tilemap_draw(bitmap,cliprect,pf1a_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,pf1a_tilemap,0,4);
+
+	captaven_draw_sprites(screen->machine,bitmap,cliprect,buffered_spriteram32,3);
+
 	return 0;
 }
 
@@ -1402,9 +1419,17 @@ VIDEO_UPDATE( fghthist )
 	deco16_clear_sprite_priority_bitmap();
 	bitmap_fill(priority_bitmap,cliprect,0);
 	bitmap_fill(bitmap,cliprect,screen->machine->pens[0x000]); // Palette index not confirmed
-	tilemap_draw(bitmap,cliprect,pf4_tilemap,0,1);
-	tilemap_draw(bitmap,cliprect,pf3_tilemap,0,4);
-	tilemap_draw(bitmap,cliprect,pf2_tilemap,0,16);
+	tilemap_draw(bitmap,cliprect,pf4_tilemap,0,0);
+	if(deco32_pri&1)
+	{
+		tilemap_draw(bitmap,cliprect,pf2_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,pf3_tilemap,0,2);
+	}
+	else
+	{
+		tilemap_draw(bitmap,cliprect,pf3_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,pf2_tilemap,0,2);
+	}
 	fghthist_draw_sprites(screen->machine, bitmap, cliprect, buffered_spriteram32,3,0, 0xf);
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
 	return 0;
@@ -1483,13 +1508,11 @@ static void mixDualAlphaSprites(running_machine* machine, bitmap_t *bitmap, cons
                         Pri 2 -
                         Pri 3 -
                     */
-					alpha_set_level(0x80);
 
 					/* Alpha values are tied to ACE ram... */
 					//int alpha=((deco32_ace_ram[0x0 + (((priColAlphaPal1&0xf0)>>4)/2)]) * 8)-1;
 					//if (alpha<0)
 					//  alpha=0;
-					//alpha_set_level(255-alpha);
 
 					/* I don't really understand how object ACE ram is really hooked up,
                         the only obvious place in Night Slashers is the stagecoach in level 2 */
@@ -1497,14 +1520,14 @@ static void mixDualAlphaSprites(running_machine* machine, bitmap_t *bitmap, cons
 					if (pri1==0 && (((priColAlphaPal0&0xff)==0 || ((pri0&0x3)!=0 && (pri0&0x3)!=1 && (pri0&0x3)!=2))))
 					{
 						if ((deco32_pri&1)==0 || ((deco32_pri&1)==1 && tilemapPri[x]<4) || ((deco32_pri&1)==1 && mixAlphaTilemap))
-							destLine[x]=alpha_blend32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)]);
+							destLine[x]=alpha_blend_r32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)], 0x80);
 					}
 					else if (pri1==1 && ((priColAlphaPal0&0xff)==0 || ((pri0&0x3)!=0 && (pri0&0x3)!=1 && (pri0&0x3)!=2)))
-						destLine[x]=alpha_blend32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)]);
+						destLine[x]=alpha_blend_r32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)], 0x80);
 					else if (pri1==2)// TOdo
-						destLine[x]=alpha_blend32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)]);
+						destLine[x]=alpha_blend_r32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)], 0x80);
 					else if (pri1==3)// TOdo
-						destLine[x]=alpha_blend32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)]);
+						destLine[x]=alpha_blend_r32(destLine[x], pal1[(priColAlphaPal1&0xff) + (gfx1->color_granularity * col1)], 0x80);
 				}
 				else
 				{
@@ -1538,9 +1561,8 @@ static void mixDualAlphaSprites(running_machine* machine, bitmap_t *bitmap, cons
 						int alpha=((deco32_ace_ram[0x17 + (((p&0xf0)>>4)/2)]) * 8)-1;
 						if (alpha<0)
 							alpha=0;
-						alpha_set_level(255-alpha);
 
-						destLine[x]=alpha_blend32(destLine[x], pal2[p]);
+						destLine[x]=alpha_blend_r32(destLine[x], pal2[p], 255-alpha);
 					}
 				}
 			}
@@ -1594,7 +1616,6 @@ VIDEO_UPDATE( nslasher )
 	bitmap_fill(sprite0_mix_bitmap,cliprect,0);
 	bitmap_fill(sprite1_mix_bitmap,cliprect,0);
 	bitmap_fill(priority_bitmap,cliprect,0);
-	bitmap_fill(tilemap_alpha_bitmap,cliprect,0);
 	if ((deco32_pf34_control[5]&0x8000)==0)
 		bitmap_fill(bitmap,cliprect,screen->machine->pens[0x200]);
 
@@ -1603,8 +1624,7 @@ VIDEO_UPDATE( nslasher )
 	nslasher_draw_sprites(screen->machine,sprite1_mix_bitmap,cliprect,buffered_spriteram32_2,4);
 
 	/* Render alpha-blended tilemap to seperate buffer for proper mixing */
-	if (alphaTilemap)
-		bitmap_fill(tilemap_alpha_bitmap,cliprect,0);
+	bitmap_fill(tilemap_alpha_bitmap,cliprect,0);
 
 	/* Draw playfields & sprites */
 	if (deco32_pri&2)
