@@ -57,20 +57,20 @@ VIDEO_UPDATE( gbusters )
 	/* sprite priority 3 = disable */
 	if (gbusters_priority)
 	{
-//      K051960_sprites_draw(bitmap,cliprect,1,1);  /* are these used? */
+//      K051960_sprites_draw(screen->machine,bitmap,cliprect,1,1);  /* are these used? */
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[2],TILEMAP_DRAW_OPAQUE,0);
-		K051960_sprites_draw(bitmap,cliprect,2,2);
+		K051960_sprites_draw(screen->machine,bitmap,cliprect,2,2);
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[1],0,0);
-		K051960_sprites_draw(bitmap,cliprect,0,0);
+		K051960_sprites_draw(screen->machine,bitmap,cliprect,0,0);
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[0],0,0);
 	}
 	else
 	{
-//      K051960_sprites_draw(bitmap,cliprect,1,1);  /* are these used? */
+//      K051960_sprites_draw(screen->machine,bitmap,cliprect,1,1);  /* are these used? */
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[1],TILEMAP_DRAW_OPAQUE,0);
-		K051960_sprites_draw(bitmap,cliprect,2,2);
+		K051960_sprites_draw(screen->machine,bitmap,cliprect,2,2);
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[2],0,0);
-		K051960_sprites_draw(bitmap,cliprect,0,0);
+		K051960_sprites_draw(screen->machine,bitmap,cliprect,0,0);
 		tilemap_draw(bitmap,cliprect,K052109_tilemap[0],0,0);
 	}
 	return 0;
