@@ -8,6 +8,8 @@
 ***********************************************************************************************/
 
 #include "driver.h"
+#include "sound/sn76496.h"
+
 #include "genesis.h"
 
 /* in video/segasyse.c */
@@ -36,11 +38,7 @@ static const device_config *genesis_screen;
 #define VDP_VRAM_WORD(x)	((VDP_VRAM_BYTE(x) << 8) | VDP_VRAM_BYTE((x) + 1))
 #define VDP_VSRAM_WORD(x)	((VDP_VSRAM_BYTE(x) << 8) | VDP_VSRAM_BYTE((x) + 1))
 
-#ifdef LSB_FIRST
-#define EXTRACT_PIXEL(x,i)	(((x) >> (((i) ^ 1) * 4)) & 0x0f)
-#else
-#define EXTRACT_PIXEL(x,i)	(((x) >> (((i) ^ 7) * 4)) & 0x0f)
-#endif
+#define EXTRACT_PIXEL(x,i)	(((x) >> (((i) ^ NATIVE_ENDIAN_VALUE_LE_BE(1,7)) * 4)) & 0x0f)
 
 
 
@@ -138,9 +136,9 @@ static void start_genesis_vdp(const device_config *screen)
 	genesis_screen = screen;
 
 	/* allocate memory for the VDP, the lookup table, and the buffer bitmap */
-	vdp_vram			= auto_malloc(VRAM_SIZE);
-	vdp_vsram			= auto_malloc(VSRAM_SIZE);
-	transparent_lookup	= auto_malloc(0x1000 * sizeof(UINT16));
+	vdp_vram			= auto_alloc_array(screen->machine, UINT8, VRAM_SIZE);
+	vdp_vsram			= auto_alloc_array(screen->machine, UINT8, VSRAM_SIZE);
+	transparent_lookup	= auto_alloc_array(screen->machine, UINT16, 0x1000);
 
 	/* clear the VDP memory, prevents corrupt tile in Puyo Puyo 2 */
 	memset(vdp_vram, 0, VRAM_SIZE);
@@ -365,6 +363,7 @@ READ16_HANDLER( genesis_vdp_r )
 
 WRITE16_HANDLER( genesis_vdp_w )
 {
+	const device_config *device;
 	switch (offset)
 	{
 		case 0x00:	/* Write data */
@@ -397,8 +396,9 @@ WRITE16_HANDLER( genesis_vdp_w )
 		case 0x09:
 		case 0x0a:
 		case 0x0b:
-			if (ACCESSING_BITS_0_7 && sndti_exists(SOUND_SN76496, 0))
-				sn76496_0_w(space, 0, data & 0xff);
+			device = devtag_get_device(space->machine, "sn");
+			if (device != NULL && ACCESSING_BITS_0_7)
+				sn76496_w(device, 0, data & 0xff);
 			break;
 	}
 }
