@@ -33,8 +33,8 @@ static float uToF(UINT16 input) ;
 static void SetIdentity(float *matrix) ;
 
 
-//static void plot(INT32 x, INT32 y, INT32 color, mame_bitmap *bitmap) ;
-//static void drawline2d(INT32 x0, INT32 y0, INT32 x1, INT32 y1, INT32 color, mame_bitmap *bitmap) ;
+//static void plot(INT32 x, INT32 y, INT32 color, bitmap_t *bitmap) ;
+//static void drawline2d(INT32 x0, INT32 y0, INT32 x1, INT32 y1, INT32 color, bitmap_t *bitmap) ;
 
 static float *depthBuffer ;
 static struct polygon *polys ;
@@ -74,7 +74,7 @@ static struct polygon *polys ;
 /* xxxx---- | I think this part of UINT32 2 is interesting as more than just a list end marker (AJG)
  */
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	const gfx_element *gfx;
 	UINT32 *source = hng64_spriteram;
@@ -103,7 +103,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 		int xpos, ypos, tileno,chainx,chainy,xflip;
 		int xdrw,ydrw,pal,xinc,yinc,yflip;
 		UINT32 zoomx,zoomy;
-		float foomX, foomY;
+		//float foomX, foomY;
 		source-=8;
 
 		ypos = (source[0]&0xffff0000)>>16;
@@ -129,6 +129,8 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 		/* Calculate the zoom */
 		/* First, prevent any possible divide by zero errors */
+
+#if 0
 		if(!zoomx) zoomx=0x1000;
 		if(!zoomy) zoomy=0x1000;
 
@@ -140,7 +142,10 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 		zoomx += (int)((foomX - floor(foomX)) * (float)0x10000) ;
 		zoomy += (int)((foomY - floor(foomY)) * (float)0x10000) ;
+#endif
 
+		zoomx = 0x10000;
+		zoomy = 0x10000;
 
 		if (source[3]&0x00800000) // maybe ..
 		{
@@ -160,22 +165,27 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 		// Accomodate for chaining and flipping
 		if(xflip)
 		{
-			xinc=-(int)(16.0f*foomX);
+			//xinc=-(int)(16.0f*foomX);
+
+			xinc=-16;
 			xpos-=xinc*chainx;
 		}
 		else
 		{
-			xinc=(int)(16.0f*foomX);
+			//xinc=(int)(16.0f*foomX);
+			xinc = 16;
 		}
 
 		if(yflip)
 		{
-			yinc=-(int)(16.0f*foomY);
+			//yinc=-(int)(16.0f*foomY);
+			yinc = -16;
 			ypos-=yinc*chainy;
 		}
 		else
 		{
-			yinc=(int)(16.0f*foomY);
+			yinc = 16;
+			//yinc=(int)(16.0f*foomY);
 		}
 
 
@@ -225,7 +235,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
  *  Or maybe it switches from fading by scaling to fading using absolute addition and subtraction...
  *  Or maybe they set transition type (there seems to be a cute scaling-squares transition in there somewhere)...
  */
-static void transition_control(running_machine *machine, mame_bitmap *bitmap)
+static void transition_control(bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i, j ;
 
@@ -247,9 +257,9 @@ static void transition_control(running_machine *machine, mame_bitmap *bitmap)
 		brigG = (INT32)((hng64_tcram[0x0000000a] >> 8)  & 0xff) ;
 		brigB = (INT32)((hng64_tcram[0x0000000a] >> 16) & 0xff) ;
 
-		for (i = machine->screen[0].visarea.min_x; i < machine->screen[0].visarea.max_x; i++)
+		for (i = cliprect->min_x; i < cliprect->max_x; i++)
 		{
-			for (j = machine->screen[0].visarea.min_y; j < machine->screen[0].visarea.max_y; j++)
+			for (j = cliprect->min_y; j < cliprect->max_y; j++)
 			{
 				UINT32* thePixel = BITMAP_ADDR32(bitmap, j, i);
 
@@ -356,11 +366,11 @@ struct polygon
 
 static void PerformFrustumClip(struct polygon *p) ;
 
-//static void DrawWireframe(struct polygon *p, mame_bitmap *bitmap) ;
-static void DrawShaded(running_machine *machine, struct polygon *p, mame_bitmap *bitmap) ;
+//static void DrawWireframe(struct polygon *p, bitmap_t *bitmap) ;
+static void DrawShaded(running_machine *machine, struct polygon *p, bitmap_t *bitmap) ;
 
 
-static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw3d(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	int i,j,k,l,m ;
 
@@ -374,6 +384,7 @@ static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangl
 	UINT32 numPolys = 0 ;
 
 	struct polygon lastPoly = { 0 } ;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
 	// Set some matrices to the identity...
 	SetIdentity(projectionMatrix) ;
@@ -517,7 +528,7 @@ static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangl
 				// GEOMETRY
 				;
 
-				threeDRoms = memory_region(REGION_GFX4) ;
+				threeDRoms = memory_region(machine, "verts") ;
 
 				/////////////////////////
 				// GET THE HEADER INFO //
@@ -860,11 +871,11 @@ static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangl
 									ndCoords[3] = polys[numPolys].vert[m].clipCoords[3] ;
 
 									// Final pixel values are garnered here :
-									windowCoords[0] = (ndCoords[0]+1.0f) * ((float)(machine->screen[0].visarea.max_x) / 2.0f) + 0.0f ;
-									windowCoords[1] = (ndCoords[1]+1.0f) * ((float)(machine->screen[0].visarea.max_y) / 2.0f) + 0.0f ;
+									windowCoords[0] = (ndCoords[0]+1.0f) * ((float)(visarea->max_x) / 2.0f) + 0.0f ;
+									windowCoords[1] = (ndCoords[1]+1.0f) * ((float)(visarea->max_y) / 2.0f) + 0.0f ;
 									windowCoords[2] = (ndCoords[2]+1.0f) * 0.5f ;
 
-									windowCoords[1] = (float)machine->screen[0].visarea.max_y - windowCoords[1] ;		// Flip Y
+									windowCoords[1] = (float)visarea->max_y - windowCoords[1] ;		// Flip Y
 
 									// Store the points in a list for later use...
 									polys[numPolys].vert[m].clipCoords[0] = windowCoords[0] ;
@@ -913,7 +924,7 @@ static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangl
 	/////////////////////////////////////////////////
 
 	// Reset the depth buffer...
-	for (i = 0; i < (machine->screen[0].visarea.max_x)*(machine->screen[0].visarea.max_y); i++)
+	for (i = 0; i < (visarea->max_x)*(visarea->max_y); i++)
 		depthBuffer[i] = 100.0f ;
 
 	for (i = 0; i < numPolys; i++)
@@ -936,269 +947,145 @@ static void draw3d(running_machine *machine, mame_bitmap *bitmap, const rectangl
 }
 
 
-/* 8x8 tiles, 4bpp layer */
+/* 8x8x4bpp layer */
 static TILE_GET_INFO( get_hng64_tile0_info )
 {
-	int tileno,pal;
-	tileno = hng64_videoram[tile_index];
-	pal = hng64_videoram[tile_index]>>24;
-	SET_TILE_INFO((tileno&1)?0:1,(tileno&0x3fffff)>>1,pal,TILE_FLIPYX((tileno&0xc00000)>>22));
+	UINT16 tilemapinfo = (hng64_videoregs[0x02]&0xffff0000)>>16;
+	int tileno,pal, flip;
+
+	tileno = hng64_videoram[tile_index+(0x00000/4)];
+	// pppppppp ff--atttt tttttttt tttttttt
+
+	pal = (tileno&0xff000000)>>24;
+	flip =(tileno&0x00c00000)>>22;
+
+	if (tileno&0x200000)
+	{
+		tileno = (tileno & hng64_videoregs[0x0b]) | hng64_videoregs[0x0c];
+	}
+
+	tileno &= 0x1fffff;
+
+	if (tilemapinfo&0x400)
+	{
+		SET_TILE_INFO(1,tileno>>1,pal>>4,TILE_FLIPYX(flip));
+	}
+	else
+	{
+		SET_TILE_INFO(0,tileno, pal,TILE_FLIPYX(flip));
+	}
 }
 
 /* 16x16 tiles, 8bpp layer */
 static TILE_GET_INFO( get_hng64_tile1_info )
 {
-	int tileno,pal;
-	tileno = hng64_videoram[tile_index+(0x10000/4)];
-	pal = hng64_videoram[tile_index+(0x10000/4)]>>24;
+	UINT16 tilemapinfo = (hng64_videoregs[0x02]&0x0000ffff)>>0;
+	int tileno,pal, flip;
 
-	SET_TILE_INFO(3,(tileno&0x3fffff)>>3,pal>>4,  TILE_FLIPYX((tileno&0xc00000)>>22) );
+	tileno = hng64_videoram[tile_index+(0x10000/4)];
+	// pppppppp ff--atttt tttttttt tttttttt
+
+	pal = (tileno&0xff000000)>>24;
+	flip =(tileno&0x00c00000)>>22;
+
+	if (tileno&0x200000)
+	{
+		tileno = (tileno & hng64_videoregs[0x0b]) | hng64_videoregs[0x0c];
+	}
+
+	tileno &= 0x1fffff;
+
+	if (tilemapinfo&0x400)
+	{
+		SET_TILE_INFO(3,tileno>>3,pal>>4,TILE_FLIPYX(flip));
+	}
+	else
+	{
+		SET_TILE_INFO(2,tileno>>2, pal,TILE_FLIPYX(flip));
+	}
 }
 
 /* 16x16 tiles, 8bpp layer */
 static TILE_GET_INFO( get_hng64_tile2_info )
 {
-	int tileno,pal;
+	UINT16 tilemapinfo = (hng64_videoregs[0x03]&0xffff0000)>>16;
+	int tileno,pal, flip;
+
 	tileno = hng64_videoram[tile_index+(0x20000/4)];
-	pal = hng64_videoram[tile_index+(0x20000/4)]>>24;
-	SET_TILE_INFO(3,(tileno&0x3fffff)>>3,pal>>4,TILE_FLIPYX((tileno&0xc00000)>>22));
+	// pppppppp ff--atttt tttttttt tttttttt
+
+	pal = (tileno&0xff000000)>>24;
+	flip =(tileno&0x00c00000)>>22;
+
+	if (tileno&0x200000)
+	{
+		tileno = (tileno & hng64_videoregs[0x0b]) | hng64_videoregs[0x0c];
+	}
+
+	tileno &= 0x1fffff;
+
+	if (tilemapinfo&0x400)
+	{
+		SET_TILE_INFO(3,tileno>>3,pal>>4,TILE_FLIPYX(flip));
+	}
+	else
+	{
+		SET_TILE_INFO(2,tileno>>2, pal,TILE_FLIPYX(flip));
+	}
 }
 
 /* 16x16 tiles, 8bpp layer */
 static TILE_GET_INFO( get_hng64_tile3_info )
 {
-	int tileno,pal;
+	UINT16 tilemapinfo = (hng64_videoregs[0x03]&0x0000ffff)>>0;
+	int tileno,pal, flip;
+
 	tileno = hng64_videoram[tile_index+(0x30000/4)];
-	pal = hng64_videoram[tile_index+(0x30000/4)]>>24;
-	SET_TILE_INFO(3,(tileno&0x3fffff)>>3,pal>>4,TILE_FLIPYX((tileno&0xc00000)>>22));
-}
+	// pppppppp ff--atttt tttttttt tttttttt
 
+	pal = (tileno&0xff000000)>>24;
+	flip =(tileno&0x00c00000)>>22;
 
-
-/* Tilemaps zoom, and probably rotate.. they can have linescroll/lineselect,
-looks like the zoom center can move too..
-not sure how these features are enabled up yet */
-
-static int gatherPixelsForLine(mame_bitmap *tilemapBitmap,
-							   INT32 startX, INT32 startY, INT32 endX, INT32 endY,
-							   UINT16 *penList)
-{
-	int retVal = 0 ;
-
-	// !! BRESENHAM'S AGAIN - I REALLY SHOULD GENERALIZE THIS !!
-
-#define SWAP(a,b) tmpswap = a; a = b; b = tmpswap;
-
-	INT32 i;
-	INT32 steep = 1;
-	INT32 sx, sy;  /* step positive or negative (1 or -1) */
-	INT32 dx, dy;  /* delta (difference in X and Y between points) */
-	INT32 e;
-
-	/*
-    * inline swap. On some architectures, the XOR trick may be faster
-    */
-	INT32 tmpswap;
-
-	/*
-    * optimize for vertical and horizontal lines here
-    */
-
-	dx = abs(endX - startX);
-	sx = ((endX - startX) > 0) ? 1 : -1;
-	dy = abs(endY - startY);
-	sy = ((endY - startY) > 0) ? 1 : -1;
-
-	if (dy > dx)
+	if (tileno&0x200000)
 	{
-		steep = 0;
-		SWAP(startX, startY);
-		SWAP(dx, dy);
-		SWAP(sx, sy);
+		tileno = (tileno & hng64_videoregs[0x0b]) | hng64_videoregs[0x0c];
 	}
 
-	e = (dy << 1) - dx;
+	tileno &= 0x1fffff;
 
-	for (i = 0; i < dx; i++)
+	if (tilemapinfo&0x400)
 	{
-		if (steep)
-		{
-			penList[retVal] = *BITMAP_ADDR16(tilemapBitmap, startY, startX);
-			retVal++ ;
-		}
-		else
-		{
-			penList[retVal] = *BITMAP_ADDR16(tilemapBitmap, startX, startY) ;
-			retVal++ ;
-		}
-		while (e >= 0)
-		{
-			startY += sy;
-			e -= (dx << 1);
-		}
-
-		startX += sx;
-		e += (dy << 1);
+		SET_TILE_INFO(3,tileno>>3,pal>>4,TILE_FLIPYX(flip));
 	}
-#undef SWAP
-
-
-	return retVal ;
-}
-
-static void plotTilemap3Line(running_machine *machine,
-							 mame_bitmap *tilemapBitmap,
-							 INT32 startX, INT32 startY, INT32 endX, INT32 endY,
-							 INT32 screenY, mame_bitmap *bitmap)
-{
-	int i ;
-
-	int numPix ;
-	UINT16 penList[0x1000] ;			// 4k of pixels to be safe
-
-	float pixStride, pixOffset ;
-
-//  mame_printf_debug("(%d,%d) (%d,%d)\n", startX, startY, endX, endY) ;
-
-	// CLAMP - BUT I'M PRETTY SURE THIS ISN'T QUITE RIGHT !!! ???
-	startX += 1024 ; if (startX < 0) startX = 0 ; else if (startX >= 2048) startX = 2048-1 ;
-	startY += 1024 ; if (startY < 0) startY = 0 ; else if (startY >= 2048) startY = 2048-1 ;
-	endX += 1024 ; if (endX < 0) endX = 0 ; else if (endX >= 2048) endX = 2048-1 ;
-	endY += 1024 ; if (endY < 0) endY = 0 ; else if (endY >= 2048) endY = 2048-1 ;
-
-	numPix = gatherPixelsForLine(tilemapBitmap, startX, startY, endX, endY, penList) ;
-
-	pixStride = (float)numPix / (float)(machine->screen[0].visarea.max_x-1) ;
-	pixOffset = 0 ;
-
-	if (numPix == 0)
-		penList[0] = *BITMAP_ADDR16(tilemapBitmap, 1024, 1024);
-
-//  mame_printf_debug("numpix %d ps %f po %f s(%d,%d) e(%d,%d)\n", numPix, pixStride, pixOffset, startX, startY, endX, endY) ;
-
-	// Draw out the screen's line...
-	for (i = machine->screen[0].visarea.min_x; i < machine->screen[0].visarea.max_x; i++)
+	else
 	{
-		// Nearest-neighbor interpolation for now (but i doubt it does linear)
-		UINT16 tmPen = penList[(int)pixOffset] ;
-
-		*BITMAP_ADDR32(bitmap, screenY, i) = palette_get_color(machine, tmPen) | 0xff000000;
-
-		pixOffset += pixStride ;
+		SET_TILE_INFO(2,tileno>>2, pal,TILE_FLIPYX(flip));
 	}
 }
 
-static void hng64_drawtilemap3(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect )
+
+
+static void hng64_drawtilemap( bitmap_t *bitmap, const rectangle *cliprect, int scrollbase, tilemap* tilemap )
 {
-	int i ;
+	int xscroll,yscroll,xzoom,yzoom;
 
-	mame_bitmap *srcbitmap = tilemap_get_pixmap( hng64_tilemap3 );
-
-//  usrintf_showmessage("%d", hng64_hackTm3Count) ;
-
-	if (hng64_hackTm3Count/4 < machine->screen[0].visarea.max_y)
-	{
-		for (i = 0; i < hng64_hackTm3Count/4; i++)
-		{
-			UINT32 address = hng64_rowScrollOffset + 0xbf0 ;
-			address -= (i * 0x10) ;
-			address /= 4 ;
-			//mame_printf_debug("nums : %.4x %.4x %.4x %.4x\n", (INT16)((hng64_videoram[address+0x0]&0xffff0000) >> 16),
-			//                                     (INT16)((hng64_videoram[address+0x1]&0xffff0000) >> 16),
-			//                                     (INT16)((hng64_videoram[address+0x2]&0xffff0000) >> 16),
-			//                                     (INT16)((hng64_videoram[address+0x3]&0xffff0000) >> 16)) ;
-
-			plotTilemap3Line(machine, srcbitmap,
-							 (INT16)((hng64_videoram[address+0x0]&0xffff0000) >> 16),
-							 (INT16)((hng64_videoram[address+0x2]&0xffff0000) >> 16),
-							 (INT16)((hng64_videoram[address+0x1]&0xffff0000) >> 16),
-							 (INT16)((hng64_videoram[address+0x3]&0xffff0000) >> 16),
-							 (machine->screen[0].visarea.max_y-1)-i,
-							 bitmap) ;
-		}
-	}
-
-	// Maybe the scrollbase should be used instead of my hacky hng64_rowScrollOffset :)?
-//  scrollbase = (hng64_videoregs[0x05]&0x00003fff)>>0;
-
-//  xscroll = hng64_videoram[(0x40000+(scrollbase<<4))/4]>>16;
-//  yscroll = hng64_videoram[(0x40008+(scrollbase<<4))/4]>>16;
-//  xzoom   = hng64_videoram[(0x40010+(scrollbase<<4))/4]>>16;
-//  yzoom   = hng64_videoram[(0x4000c+(scrollbase<<4))/4]>>16;
-//  xzoom   = xzoom-xscroll;
-//  yzoom   = yzoom-yscroll;
-//  xzoom &=0xffff;
-//  yzoom &=0xffff;
-
-//  xscroll <<=16;
-//  yscroll <<=16;
-//  xzoom <<=8;
-//  yzoom <<=8;
-
-//  tilemap_set_scrollx(hng64_tilemap3,0, xscroll);
-//  tilemap_set_scrolly(hng64_tilemap3,0, yscroll);
-
-//  tilemap_draw(bitmap,cliprect,hng64_tilemap3,0,0);
-
-//  tilemap_draw_roz(bitmap,cliprect,hng64_tilemap3,xscroll,yscroll,
-//          xzoom,0,0,yzoom,
-//          1,
-//          0,0);
-}
-
-static void hng64_drawtilemap2( mame_bitmap *bitmap, const rectangle *cliprect )
-{
-	int scrollbase,xscroll,yscroll,xzoom,yzoom;
-
-	scrollbase = (hng64_videoregs[0x05]&0x3fff0000)>>16;
 	xscroll = (INT16)(hng64_videoram[(0x40000+(scrollbase<<4))/4]>>16);
 	// ???  = (INT16)(hng64_videoram[(0x40004+(scrollbase<<4))/4]>>16);
 	yscroll = (INT16)(hng64_videoram[(0x40008+(scrollbase<<4))/4]>>16);
-	yzoom   = (INT16)(hng64_videoram[(0x4000c+(scrollbase<<4))/4]>>16);
-	xzoom   = (INT16)(hng64_videoram[(0x40010+(scrollbase<<4))/4]>>16);
+//  xzoom   = (INT16)(hng64_videoram[(0x40010+(scrollbase<<4))/4]>>16);
+//  yzoom   = (INT16)(hng64_videoram[(0x4000c+(scrollbase<<4))/4]>>16);
 	// ???  = (INT16)(hng64_videoram[(0x40014+(scrollbase<<4))/4]>>16);
 	// ???  = (INT16)(hng64_videoram[(0x40018+(scrollbase<<4))/4]>>16);
 	// ???  = (INT16)(hng64_videoram[(0x4001c+(scrollbase<<4))/4]>>16);
-	xzoom   = xzoom-xscroll;
-	yzoom   = yzoom-yscroll;
-	xzoom &=0xffff;
-	yzoom &=0xffff;
 
 	xscroll <<=16;
 	yscroll <<=16;
-	xzoom <<=8;
-	yzoom <<=8;
 
-	tilemap_draw_roz(bitmap,cliprect,hng64_tilemap2,xscroll,yscroll,
-			xzoom,0,0,yzoom,
-			1,
-			0,0);
-}
+	xzoom = 0x10000;
+	yzoom = 0x10000;
 
-static void hng64_drawtilemap1( mame_bitmap *bitmap, const rectangle *cliprect )
-{
-	int scrollbase,xscroll,yscroll,xzoom,yzoom;
 
-	scrollbase = (hng64_videoregs[0x04]&0x00003fff)>>0;
-	xscroll = (INT16)(hng64_videoram[(0x40000+(scrollbase<<4))/4]>>16);
-	// ???  = (INT16)(hng64_videoram[(0x40004+(scrollbase<<4))/4]>>16);
-	yscroll = (INT16)(hng64_videoram[(0x40008+(scrollbase<<4))/4]>>16);
-	xzoom   = (INT16)(hng64_videoram[(0x40010+(scrollbase<<4))/4]>>16);
-	yzoom   = (INT16)(hng64_videoram[(0x4000c+(scrollbase<<4))/4]>>16);
-	// ???  = (INT16)(hng64_videoram[(0x40014+(scrollbase<<4))/4]>>16);
-	// ???  = (INT16)(hng64_videoram[(0x40018+(scrollbase<<4))/4]>>16);
-	// ???  = (INT16)(hng64_videoram[(0x4001c+(scrollbase<<4))/4]>>16);
-	xzoom   = xzoom-xscroll;
-	yzoom   = yzoom-yscroll;
-	xzoom &=0xffff;
-	yzoom &=0xffff;
-
-	xscroll <<=16;
-	yscroll <<=16;
-	xzoom <<=8;
-	yzoom <<=8;
-
-	tilemap_draw_roz(bitmap,cliprect,hng64_tilemap1,xscroll,yscroll,
+	tilemap_draw_roz(bitmap,cliprect,tilemap,xscroll,yscroll,
 			xzoom,0,0,yzoom,
 			1,
 			0,0);
@@ -1215,8 +1102,10 @@ static void hng64_drawtilemap1( mame_bitmap *bitmap, const rectangle *cliprect )
  *   0    | oooooooo | unknown - always seems to be 04060000 (fatfurwa) and 00060000 (buriki)
  *   1    | xxxx---- | looks like it's 0001 most (all) of the time - turns off in buriki intro
  *   1    | ----oooo | unknown - always seems to be 0000 (fatfurwa)
- *   2    | oooooooo | unknown - likes to change sometimes though... (looks like bit-flags)
- *   3    | oooooooo | unknown - change a lot - maybe mixer flags?
+ *   2    | xxxx---- | tilemap0 per layer flags
+ *   2    | ----xxxx | tilemap1 per layer flags
+ *   3    | xxxx---- | tilemap2 per layer flags
+ *   3    | ----xxxx | tilemap3 per layer flags
  *   4    | xxxx---- | tilemap0 offset into tilemap RAM?
  *   4    | ----xxxx | tilemap1 offset into tilemap RAM
  *   5    | xxxx---- | tilemap3 offset into tilemap RAM
@@ -1226,10 +1115,8 @@ static void hng64_drawtilemap1( mame_bitmap *bitmap, const rectangle *cliprect )
  *   8    | oooooooo | unknown - always seems to be 80008000 (fatfurwa)
  *   9    | oooooooo | unknown - always seems to be 00000000 (fatfurwa)
  *   a    | oooooooo | unknown - always seems to be 00000000 (fatfurwa)
- *   b    | oooooooo | unknown - 00000000 in intro - 00007ff8 when fight is going on (looks like &'ing it with 0x3fff is a good thing to do - tilemap stuff?)
- *   c    | xxxxxxxx | I'm almost positive this is some form of offset to produce animations in Tilemap1 - or maybe all tilemaps?
- *                     - 00xxx000 are used in fatfurwa during fights
- *                     - 00000?xx are used in buriki during the intro
+ *   b    | mmmmmmmm | auto animation mask for tilemaps, - use these bits from the original tile number
+ *   c    | xxxxxxxx | auto animation bits for tilemaps, - merge in these bits to auto animate the tilemap
  *   d    | oooooooo | not used ??
  *   e    | oooooooo | not used ??
  */
@@ -1237,80 +1124,92 @@ static void hng64_drawtilemap1( mame_bitmap *bitmap, const rectangle *cliprect )
 
 VIDEO_UPDATE( hng64 )
 {
-	fillbitmap(bitmap, get_black_pen(machine), 0);
+	bitmap_fill(bitmap, 0, get_black_pen(screen->machine));
 
-	// Debug
-//  for (int iii = 0; iii < 0x0f; iii++)
-//      mame_printf_debug("%.8x ", hng64_videoregs[iii]) ;
-//  mame_printf_debug("\n") ;
-//  usrintf_showmessage("%.8x %.8x %.8x %.8x", hng64_videoregs[0x1], hng64_videoregs[0x3], hng64_videoregs[0xb], hng64_videoregs[0xc]) ;
+	// the tilemap auto animation and moveable tilebases means that they end up
+	// dirty most frames anyway, even with manual tracking
+	tilemap_mark_all_tiles_dirty (hng64_tilemap3);
+	tilemap_mark_all_tiles_dirty (hng64_tilemap2);
+	tilemap_mark_all_tiles_dirty (hng64_tilemap1);
+	tilemap_mark_all_tiles_dirty (hng64_tilemap0);
 
-	// I think there's something to this, but I'm not doing it right...
-	// Interestingly enough, this turns the bootup screen blue :)
-	/*
-    if (hng64_videoregs[0xc] != tilemap2Offset)
-    {
-        tilemap2Offset = hng64_videoregs[0xc] ;
 
-        tilemap_dispose(hng64_tilemap1) ;
-        hng64_tilemap1 = tilemap_create(get_hng64_tile2_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 16, 16, 128,128); // 128x128x4 = 0x10000
-    }
-    */
+	hng64_drawtilemap(bitmap,cliprect, (hng64_videoregs[0x05]&0x00003fff)>>0,  hng64_tilemap3);
+	hng64_drawtilemap(bitmap,cliprect, (hng64_videoregs[0x05]&0x3fff0000)>>16, hng64_tilemap2);
+	hng64_drawtilemap(bitmap,cliprect, (hng64_videoregs[0x04]&0x00003fff)>>0,  hng64_tilemap1);
+	hng64_drawtilemap(bitmap,cliprect, (hng64_videoregs[0x04]&0x3fff0000)>>16, hng64_tilemap0);
 
-	// Rowscroll variables...
-	// usrintf_showmessage("%.8x %.8x x %.8x %.8x", hng64_videoram[0x00057bf0/4], hng64_videoram[0x00057bf4/4], hng64_videoram[0x00057bf8/4], hng64_videoram[0x00057bfc/4]) ;
-
-	// All of this priority stuff is probably done with some funky layer mixing chip -
-	//   (there are neato alpha effects on a real board, etc)
-	hng64_drawtilemap2(bitmap,cliprect);
-	hng64_drawtilemap1(bitmap,cliprect);
-	hng64_drawtilemap3(machine, bitmap,cliprect);						// Draw the ground last...
-
-	// !!! This tilemap has the same flags as the 'previous' three, but they're not used in fatfurwa !!!
-	//     (in other words, we should make a similar hng64_drawtilemap0() function for this tilemap)
-	tilemap_draw(bitmap,cliprect,hng64_tilemap0,0,0);
-
-	draw_sprites(machine, bitmap,cliprect);
+	draw_sprites(screen->machine, bitmap,cliprect);
 
 	// 3d really shouldn't be last, but you don't see some cool stuff right now if it's put before sprites :)...
-	draw3d(machine, bitmap, cliprect);
+	draw3d(screen->machine, bitmap, cliprect);
 
-	/* hack to enable 2nd cpu when key is pressed */
-//  if ( input_code_pressed_once(KEYCODE_L) )
-//  {
-//      cpunum_set_input_line(machine, 1, INPUT_LINE_HALT, CLEAR_LINE);
-//      cpunum_set_input_line(machine, 1, INPUT_LINE_RESET, CLEAR_LINE);
-//  }
+	transition_control(bitmap, cliprect) ;
+
+	/*
+    popmessage("%08x %08x %08x %08x %08x %08x %08x %08x %08x %08x %08x %08x %08x %08x %08x",
+    hng64_videoregs[0x00],
+    hng64_videoregs[0x01],
+    hng64_videoregs[0x02],
+    hng64_videoregs[0x03],
+    hng64_videoregs[0x04],
+    hng64_videoregs[0x05],
+    hng64_videoregs[0x06],
+    hng64_videoregs[0x07],
+    hng64_videoregs[0x08],
+    hng64_videoregs[0x09],
+    hng64_videoregs[0x0a],
+    hng64_videoregs[0x0b],
+    hng64_videoregs[0x0c],
+    hng64_videoregs[0x0d],
+    hng64_videoregs[0x0e]);
+    */
+
+	// tilemap0 per layer flags
+	// 0840 - startup tests, 8x8x4 layer
+	// 0cc0 - beast busters 2, 8x8x8 layer
+	// 0860 - fatal fury wa
+	// 08e0 - fatal fury wa during transitions
+	// 0940 - samurai shodown 64
+	// 0880 - buriki
+
+	// ---l rb?? ???? ????
+	// l = floor effects / linescroll enable  (buriki on tilemap1, fatal fury on tilemap3)
+	// r = tile size?
+	// b = 4bpp/8bpp ?  (beast busters, samsh64, sasm64 2 switch it for some screens)
+
+
+
+
+	popmessage("0: %04x  1: %04x   2: %04x  3: %04x\n", (hng64_videoregs[0x02]&0xffff0000)>>16, (hng64_videoregs[0x02]&0x0000ffff)>>0, (hng64_videoregs[0x03]&0xffff0000)>>16, (hng64_videoregs[0x03]&0x0000ffff)>>0);
 
-	/* AJG */
-	// if(input_code_pressed(KEYCODE_D))
 
-	transition_control(machine, bitmap) ;
 
 //  mame_printf_debug("FRAME DONE %d\n", frameCount) ;
 	frameCount++ ;
 
-	hng64_hackTilemap3 = hng64_rowScrollOffset = hng64_hackTm3Count = 0 ;
 	return 0;
 }
 
 VIDEO_START( hng64 )
 {
-	hng64_tilemap0 = tilemap_create(get_hng64_tile0_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,   8, 128,128); /* 128x128x4 = 0x10000 */
-	hng64_tilemap1 = tilemap_create(get_hng64_tile1_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 16, 16, 128,128); /* 128x128x4 = 0x10000 */
-	hng64_tilemap2 = tilemap_create(get_hng64_tile2_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 16, 16, 128,128); /* 128x128x4 = 0x10000 */
-	hng64_tilemap3 = tilemap_create(get_hng64_tile3_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 16, 16, 128,128); /* 128x128x4 = 0x10000 */
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
+
+	hng64_tilemap0 = tilemap_create(machine, get_hng64_tile0_info, tilemap_scan_rows,  8,   8, 128,128); /* 128x128x4 = 0x10000 */
+	hng64_tilemap1 = tilemap_create(machine, get_hng64_tile1_info, tilemap_scan_rows,  16, 16, 128,128); /* 128x128x4 = 0x10000 */
+	hng64_tilemap2 = tilemap_create(machine, get_hng64_tile2_info, tilemap_scan_rows,  16, 16, 128,128); /* 128x128x4 = 0x10000 */
+	hng64_tilemap3 = tilemap_create(machine, get_hng64_tile3_info, tilemap_scan_rows,  16, 16, 128,128); /* 128x128x4 = 0x10000 */
 	tilemap_set_transparent_pen(hng64_tilemap0,0);
 	tilemap_set_transparent_pen(hng64_tilemap1,0);
 	tilemap_set_transparent_pen(hng64_tilemap2,0);
 	tilemap_set_transparent_pen(hng64_tilemap3,0);
 
 	// 3d Buffer Allocation
-	depthBuffer = (float*)auto_malloc((machine->screen[0].visarea.max_x)*(machine->screen[0].visarea.max_y)*sizeof(float)) ;
+	depthBuffer = auto_alloc_array(machine, float, (visarea->max_x)*(visarea->max_y)) ;
 
 	// The general display list of polygons in the scene...
 	// !! This really should be a dynamic array !!
-	polys = auto_malloc(MAX_ONSCREEN_POLYS * sizeof(struct polygon))  ;
+	polys = auto_alloc_array(machine, struct polygon, MAX_ONSCREEN_POLYS)  ;
 }
 
 ///////////////
@@ -1435,10 +1334,10 @@ static int Inside(struct polyVert *v, int plane)
 
 	case HNG64_NEAR:
 		return (v->clipCoords[2] <=  v->clipCoords[3]) ? 1 : 0;
-		return 1 ;
+
 	case HNG64_FAR:
 		return (v->clipCoords[2] >= -v->clipCoords[3]) ? 1 : 0;
-		return 1 ;
+
 	}
 
 	return 0 ;
@@ -1569,13 +1468,13 @@ static void PerformFrustumClip(struct polygon *p)
 /////////////////////////
 
 #ifdef UNUSED_FUNCTION
-static void plot(INT32 x, INT32 y, INT32 color, mame_bitmap *bitmap)
+static void plot(INT32 x, INT32 y, INT32 color, bitmap_t *bitmap)
 {
 	*BITMAP_ADDR32(bitmap, y, x) = MAKE_ARGB((UINT8)255, (UINT8)color, (UINT8)color, (UINT8)color) ;
 }
 
 // Stolen from http://en.wikipedia.org/wiki/Bresenham's_line_algorithm (no copyright denoted) - the non-optimized version
-static void drawline2d(INT32 x0, INT32 y0, INT32 x1, INT32 y1, INT32 color, mame_bitmap *bitmap)
+static void drawline2d(INT32 x0, INT32 y0, INT32 x1, INT32 y1, INT32 color, bitmap_t *bitmap)
 {
 #define SWAP(a,b) tmpswap = a; a = b; b = tmpswap;
 
@@ -1632,7 +1531,7 @@ static void drawline2d(INT32 x0, INT32 y0, INT32 x1, INT32 y1, INT32 color, mame
 }
 
 
-static void DrawWireframe(struct polygon *p, mame_bitmap *bitmap)
+static void DrawWireframe(struct polygon *p, bitmap_t *bitmap)
 {
 	int j;
 	for (j = 0; j < p->n; j++)
@@ -1659,13 +1558,13 @@ static void DrawWireframe(struct polygon *p, mame_bitmap *bitmap)
 // polygon rendering //
 ///////////////////////
 
-static void RasterizeTriangle_SMOOTH_TEX_PC(running_machine *machine, mame_bitmap *Color,
+static void RasterizeTriangle_SMOOTH_TEX_PC(running_machine *machine, bitmap_t *Color,
                                      float A[4], float B[4], float C[4],
                                      float Ca[3], float Cb[3], float Cc[3], // PER-VERTEX RGB COLORS
                                      float Ta[2], float Tb[2], float Tc[2], // PER-VERTEX (S,T) TEX-COORDS
                                      int Wrapping, int Filtering, int Function) ;
 
-static void DrawShaded(running_machine *machine, struct polygon *p, mame_bitmap *bitmap)
+static void DrawShaded(running_machine *machine, struct polygon *p, bitmap_t *bitmap)
 {
 	// The perspective-correct texture divide...
 	// !!! There is a very good chance the HNG64 hardware does not do perspective-correct texture-mapping !!!
@@ -1701,16 +1600,16 @@ static void DrawShaded(running_machine *machine, struct polygon *p, mame_bitmap
 /**                                                                 **/
 /**     Output: none                                                **/
 /*********************************************************************/
-INLINE void FillSmoothTexPCHorizontalLine(running_machine *machine, mame_bitmap *Color,
+INLINE void FillSmoothTexPCHorizontalLine(running_machine *machine, bitmap_t *Color,
 					  int Wrapping, int Filtering, int Function,
 					  int x_start, int x_end, int y, float z_start, float z_delta,
 					  float w_start, float w_delta, float r_start, float r_delta,
 					  float g_start, float g_delta, float b_start, float b_delta,
 					  float s_start, float s_delta, float t_start, float t_delta)
 {
-	float *dp = &(depthBuffer[y*machine->screen[0].visarea.max_x+x_start]);
+	float *dp = &(depthBuffer[y*video_screen_get_visible_area(machine->primary_screen)->max_x+x_start]);
 
-	const UINT8 *gfx = memory_region(REGION_GFX3);
+	const UINT8 *gfx = memory_region(machine, "textures");
 	const UINT8 *textureOffset ;
 	UINT8 paletteEntry ;
 	float t_coord, s_coord ;
@@ -1792,7 +1691,7 @@ INLINE void FillSmoothTexPCHorizontalLine(running_machine *machine, mame_bitmap
 //   nearest and bilinear filtering: Filtering={0,1}
 //   replace and modulate application modes: Function={0,1}
 //---------------------------------------------------------------------------
-static void RasterizeTriangle_SMOOTH_TEX_PC(running_machine *machine, mame_bitmap *Color,
+static void RasterizeTriangle_SMOOTH_TEX_PC(running_machine *machine, bitmap_t *Color,
                                      float A[4], float B[4], float C[4],
                                      float Ca[3], float Cb[3], float Cc[3], // PER-VERTEX RGB COLORS
                                      float Ta[2], float Tb[2], float Tc[2], // PER-VERTEX (S,T) TEX-COORDS
