@@ -59,7 +59,7 @@ UINT8 m107_spritesystem;
 
 static TILE_GET_INFO( get_pf_tile_info )
 {
-	pf_layer_info *layer = param;
+	pf_layer_info *layer = (pf_layer_info *)param;
 	int tile, attrib;
 	tile_index = 2 * tile_index + layer->vram_base;
 
@@ -147,8 +147,7 @@ VIDEO_START( m107 )
 			tilemap_set_transparent_pen(layer->tmap, 0);
 	}
 
-	m107_spriteram = auto_malloc(0x1000);
-	memset(m107_spriteram,0,0x1000);
+	m107_spriteram = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 }
 
 /*****************************************************************************/
@@ -255,11 +254,11 @@ static void m107_update_scroll_positions(void)
 
 		if (m107_control[0x08 + laynum] & 0x02)
 		{
-			const UINT16 *scrolldata = m107_vram_data + (0xf000 + 0x400 * laynum) / 2;
+			const UINT16 *scrolldata = m107_vram_data + (0xe800 + 0x400 * laynum) / 2;
 
 			tilemap_set_scroll_rows(layer->tmap, 512);
 			for (i = 0; i < 512; i++)
-				tilemap_set_scrollx(layer->tmap, i, scrolldata[i]);
+				tilemap_set_scrollx(layer->tmap, i, scrolldata[i] + m107_control[1 + 2 * laynum]);
 		}
 		else
 		{
