@@ -390,11 +390,11 @@ WRITE16_HANDLER( metro_window_w )
 static int metro_sprite_xoffs, metro_sprite_yoffs;
 
 
-static void alloc_empty_tiles(void)
+static void alloc_empty_tiles(running_machine *machine)
 {
 	int code,i;
 
-	empty_tiles = auto_malloc(16*16*16);
+	empty_tiles = auto_alloc_array(machine, UINT8, 16*16*16);
 
 	for (code = 0;code < 0x10;code++)
 		for (i = 0;i < 16*16;i++)
@@ -407,9 +407,9 @@ VIDEO_START( metro_14100 )
 	support_16x16 = 0;
 	has_zoom = 0;
 
-	alloc_empty_tiles();
-	metro_tiletable_old = auto_malloc(metro_tiletable_size);
-	dirtyindex = auto_malloc(metro_tiletable_size/4);
+	alloc_empty_tiles(machine);
+	metro_tiletable_old = auto_alloc_array(machine, UINT16, metro_tiletable_size/2);
+	dirtyindex = auto_alloc_array(machine, UINT8, metro_tiletable_size/4);
 
 	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
@@ -436,9 +436,9 @@ VIDEO_START( metro_14220 )
 	support_16x16 = 0;
 	has_zoom = 0;
 
-	alloc_empty_tiles();
-	metro_tiletable_old = auto_malloc(metro_tiletable_size);
-	dirtyindex = auto_malloc(metro_tiletable_size/4);
+	alloc_empty_tiles(machine);
+	metro_tiletable_old = auto_alloc_array(machine, UINT16, metro_tiletable_size/2);
+	dirtyindex = auto_alloc_array(machine, UINT8, metro_tiletable_size/4);
 
 	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
@@ -468,9 +468,9 @@ VIDEO_START( metro_14300 )
 	support_16x16 = 1;
 	has_zoom = 0;
 
-	alloc_empty_tiles();
-	metro_tiletable_old = auto_malloc(metro_tiletable_size);
-	dirtyindex = auto_malloc(metro_tiletable_size/4);
+	alloc_empty_tiles(machine);
+	metro_tiletable_old = auto_alloc_array(machine, UINT16, metro_tiletable_size/2);
+	dirtyindex = auto_alloc_array(machine, UINT8, metro_tiletable_size/4);
 
 	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
@@ -621,6 +621,8 @@ void metro_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectan
 
 	for (i=0; i<0x20; i++)
 	{
+		gfx_element gfx;
+
 		if (!(metro_videoregs[0x02/2] & 0x8000))
 		{
 			src = spriteram16 + (sprites - 1) * (8/2);
@@ -689,27 +691,12 @@ void metro_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectan
 
 			if (support_8bpp && color == 0xf)	/* 8bpp */
 			{
-				/* prepare GfxElement on the fly */
-				gfx_element gfx;
-				gfx.machine = machine;
-				gfx.width = width;
-				gfx.height = height;
-				gfx.total_elements = 1;
-				gfx.color_depth = 256;
-				gfx.color_granularity = 256;
-				gfx.color_base = 0;
-				gfx.total_colors = 0x20;
-				gfx.pen_usage = NULL;
-				gfx.gfxdata = gfxdata;
-				gfx.line_modulo = width;
-				gfx.char_modulo = 0;	/* doesn't matter */
-				gfx.flags = 0;
-				gfx.machine = machine;
-
 				/* Bounds checking */
 				if ( (gfxdata + width * height - 1) >= gfx_max )
 					continue;
 
+				gfx_element_build_temporary(&gfx, machine, gfxdata, width, height, width, 0, 256, 0);
+
 				pdrawgfxzoom(	bitmap,&gfx,
 								0,
 								color_start >> 4,
@@ -721,27 +708,12 @@ void metro_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectan
 			}
 			else
 			{
-				/* prepare GfxElement on the fly */
-				gfx_element gfx;
-				gfx.machine = machine;
-				gfx.width = width;
-				gfx.height = height;
-				gfx.total_elements = 1;
-				gfx.color_depth = 16;
-				gfx.color_granularity = 16;
-				gfx.color_base = 0;
-				gfx.total_colors = 0x200;
-				gfx.pen_usage = NULL;
-				gfx.gfxdata = gfxdata;
-				gfx.line_modulo = width/2;
-				gfx.char_modulo = 0;	/* doesn't matter */
-				gfx.flags = GFX_ELEMENT_PACKED;
-				gfx.machine = machine;
-
 				/* Bounds checking */
 				if ( (gfxdata + width/2 * height - 1) >= gfx_max )
 					continue;
 
+				gfx_element_build_temporary(&gfx, machine, gfxdata, width, height, width/2, 0, 16, GFX_ELEMENT_PACKED);
+
 				pdrawgfxzoom(	bitmap,&gfx,
 								0,
 								color + color_start,
