@@ -59,14 +59,12 @@ VIDEO_START( pang )
 	/*
         OBJ RAM
     */
-	pang_objram=auto_malloc(pang_videoram_size);
-	memset(pang_objram, 0, pang_videoram_size);
+	pang_objram=auto_alloc_array_clear(machine, UINT8, pang_videoram_size);
 
 	/*
         Palette RAM
     */
-	paletteram = auto_malloc(2*machine->config->total_colors);
-	memset(paletteram, 0, 2*machine->config->total_colors);
+	paletteram = auto_alloc_array_clear(machine, UINT8, 2*machine->config->total_colors);
 }
 
 
@@ -152,6 +150,7 @@ static int paletteram_bank;
 
 WRITE8_HANDLER( pang_gfxctrl_w )
 {
+	const device_config *oki = devtag_get_device(space->machine, "oki");
 logerror("PC %04x: pang_gfxctrl_w %02x\n",cpu_get_pc(space->cpu),data);
 {
 #if 0
@@ -176,7 +175,7 @@ logerror("PC %04x: pang_gfxctrl_w %02x\n",cpu_get_pc(space->cpu),data);
 	/* bit 3 is unknown (used, e.g. marukin pulses it on the title screen) */
 
 	/* bit 4 selects OKI M6295 bank */
-	if (sndti_exists(SOUND_OKIM6295,0)) okim6295_set_bank_base(0, (data & 0x10) ? 0x40000 : 0x00000);
+	if (oki != NULL && sound_get_type(oki) == SOUND_OKIM6295) okim6295_set_bank_base(oki, (data & 0x10) ? 0x40000 : 0x00000);
 
 	/* bit 5 is palette RAM bank selector (doesn't apply to mgakuen) */
 	paletteram_bank = data & 0x20;
@@ -211,7 +210,7 @@ logerror("PC %04x: pang_gfxctrl_w %02x\n",cpu_get_pc(space->cpu),data);
 	/* bit 3 is unknown (used, e.g. marukin pulses it on the title screen) */
 
 	/* bit 4 selects OKI M6295 bank */
-//  okim6295_set_bank_base(0, (data & 0x10) ? 0x40000 : 0x00000);
+//  okim6295_set_bank_base(devtag_get_device(space->machine, "oki"), (data & 0x10) ? 0x40000 : 0x00000);
 	/* not here.. it has its own z80 + sound banking */
 
 	/* bit 5 is palette RAM bank selector (doesn't apply to mgakuen) */
