@@ -283,7 +283,6 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 	int xsize, ysize, xzoom, yzoom;
 	int code, attr, color, size, pri, pri_mask, trans;
 	gfx_element *gfx = machine->gfx[0];
-	gfx_element mygfx = *gfx;
 
 	UINT32		*source	= sprram_top;
 	const UINT32	*finish	= sprram_top + (sprram_size - 0x20) / 4;
@@ -346,11 +345,6 @@ static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const recta
 			flipy = !flipy;
 		}
 
-		/* change GfxElement parameters to draw only the needed part of the 256x256 tile */
-		mygfx.width = xsize;
-		mygfx.height = ysize;
-		mygfx.gfxdata = gfx->gfxdata + tx + ty * gfx->line_modulo;
-
 #if 0
 if (input_code_pressed(KEYCODE_A) && (pri & 8)) color = rand();
 if (input_code_pressed(KEYCODE_S) && (pri & 4)) color = rand();
@@ -368,7 +362,8 @@ if (input_code_pressed(KEYCODE_F) && (pri & 1)) color = rand();
 		else
 			pri_mask = 0xfe;
 
-		pdrawgfxzoom(bitmap, &mygfx,
+		gfx_element_set_source_clip(gfx, tx, xsize, ty, ysize);
+		pdrawgfxzoom(bitmap, gfx,
 				code,
 				color,
 				flipx, flipy,
