@@ -4,8 +4,8 @@
 UINT8* ninjakd2_bg_videoram;
 UINT8* ninjakd2_fg_videoram;
 
-static int sprite_overdraw_enabled;
 static int next_sprite_overdraw_enabled;
+static int (*stencil_compare_function) (UINT16 pal);
 static int sprites_updated;
 static bitmap_t *sp_bitmap;
 // in robokid and omegaf big sprites are laid out differently in ROM
@@ -25,6 +25,7 @@ static UINT8* robokid_bg0_videoram;
 static UINT8* robokid_bg1_videoram;
 static UINT8* robokid_bg2_videoram;
 
+#define TRANSPARENTCODE (15)
 
 /*************************************
  *
@@ -89,7 +90,7 @@ static TILEMAP_MAPPER( omegaf_bg_scan )
 	return (col & 0x0f) | ((row & 0x1f) << 4) | ((col & 0x70) << 5);
 }
 
-static void robokid_get_bg_tile_info(running_machine* const machine, tile_data* const tileinfo, tilemap_memory_index const tile_index, int const gfxnum, const UINT8* const videoram)
+static void robokid_get_bg_tile_info(running_machine* machine, tile_data* const tileinfo, tilemap_memory_index const tile_index, int const gfxnum, const UINT8* const videoram)
 {
 	int const lo = videoram[(tile_index << 1)];
 	int const hi = videoram[(tile_index << 1) | 1];
@@ -126,24 +127,25 @@ static TILE_GET_INFO( robokid_get_bg2_tile_info )
  *
  *************************************/
 
-static void videoram_alloc(const running_machine* const machine, int const size)
+static void videoram_alloc(running_machine* machine, int const size)
 {
 	if (size)
 	{
 		/* create video ram */
-		robokid_bg0_videoram = auto_malloc(size);
-		memset(robokid_bg0_videoram, 0x00, size);
-
-		robokid_bg1_videoram = auto_malloc(size);
-		memset(robokid_bg1_videoram, 0x00, size);
-
-		robokid_bg2_videoram = auto_malloc(size);
-		memset(robokid_bg2_videoram, 0x00, size);
+		robokid_bg0_videoram = auto_alloc_array_clear(machine, UINT8, size);
+		robokid_bg1_videoram = auto_alloc_array_clear(machine, UINT8, size);
+		robokid_bg2_videoram = auto_alloc_array_clear(machine, UINT8, size);
 	}
 
 	sp_bitmap = video_screen_auto_bitmap_alloc(machine->primary_screen);
 }
 
+static int stencil_ninjakd2( UINT16 pal );
+static int stencil_mnight(   UINT16 pal );
+static int stencil_arkarea(  UINT16 pal );
+static int stencil_robokid(  UINT16 pal );
+static int stencil_omegaf(   UINT16 pal );
+
 VIDEO_START( ninjakd2 )
 {
 	videoram_alloc(machine, 0);
@@ -151,9 +153,10 @@ VIDEO_START( ninjakd2 )
 	fg_tilemap = tilemap_create(         machine, get_fg_tile_info, tilemap_scan_rows,   8,  8, 32, 32);
 	bg_tilemap = tilemap_create(machine, ninjakd2_get_bg_tile_info, tilemap_scan_rows,  16, 16, 32, 32);
 
-	tilemap_set_transparent_pen(fg_tilemap, 15);
+	tilemap_set_transparent_pen(fg_tilemap, TRANSPARENTCODE);
 
 	robokid_sprites = 0;
+	stencil_compare_function = stencil_ninjakd2 ;
 }
 
 VIDEO_START( mnight )
@@ -163,9 +166,23 @@ VIDEO_START( mnight )
 	fg_tilemap = tilemap_create(       machine, get_fg_tile_info, tilemap_scan_rows,   8,  8, 32, 32);
 	bg_tilemap = tilemap_create(machine, mnight_get_bg_tile_info, tilemap_scan_rows,  16, 16, 32, 32);
 
-	tilemap_set_transparent_pen(fg_tilemap, 15);
+	tilemap_set_transparent_pen(fg_tilemap, TRANSPARENTCODE);
 
 	robokid_sprites = 0;
+	stencil_compare_function = stencil_mnight ;
+}
+
+VIDEO_START( arkarea )
+{
+	videoram_alloc(machine, 0);
+
+	fg_tilemap = tilemap_create(       machine, get_fg_tile_info, tilemap_scan_rows,   8,  8, 32, 32);
+	bg_tilemap = tilemap_create(machine, mnight_get_bg_tile_info, tilemap_scan_rows,  16, 16, 32, 32);
+
+	tilemap_set_transparent_pen(fg_tilemap, TRANSPARENTCODE);
+
+	robokid_sprites = 0;
+	stencil_compare_function = stencil_arkarea ;
 }
 
 VIDEO_START( robokid )
@@ -179,11 +196,12 @@ VIDEO_START( robokid )
 	bg1_tilemap = tilemap_create(machine, robokid_get_bg1_tile_info, robokid_bg_scan,    16, 16, 32, 32);
 	bg2_tilemap = tilemap_create(machine, robokid_get_bg2_tile_info, robokid_bg_scan,    16, 16, 32, 32);
 
-	tilemap_set_transparent_pen(fg_tilemap,  15);
-	tilemap_set_transparent_pen(bg1_tilemap, 15);
-	tilemap_set_transparent_pen(bg2_tilemap, 15);
+	tilemap_set_transparent_pen(fg_tilemap,  TRANSPARENTCODE);
+	tilemap_set_transparent_pen(bg1_tilemap, TRANSPARENTCODE);
+	tilemap_set_transparent_pen(bg2_tilemap, TRANSPARENTCODE);
 
 	robokid_sprites = 1;
+	stencil_compare_function = stencil_robokid ;
 }
 
 VIDEO_START( omegaf )
@@ -197,12 +215,13 @@ VIDEO_START( omegaf )
 	bg1_tilemap = tilemap_create(machine, robokid_get_bg1_tile_info, omegaf_bg_scan,     16, 16, 128, 32);
 	bg2_tilemap = tilemap_create(machine, robokid_get_bg2_tile_info, omegaf_bg_scan,     16, 16, 128, 32);
 
-	tilemap_set_transparent_pen(fg_tilemap,  15);
-	tilemap_set_transparent_pen(bg0_tilemap, 15);
-	tilemap_set_transparent_pen(bg1_tilemap, 15);
-	tilemap_set_transparent_pen(bg2_tilemap, 15);
+	tilemap_set_transparent_pen(fg_tilemap,  TRANSPARENTCODE);
+	tilemap_set_transparent_pen(bg0_tilemap, TRANSPARENTCODE);
+	tilemap_set_transparent_pen(bg1_tilemap, TRANSPARENTCODE);
+	tilemap_set_transparent_pen(bg2_tilemap, TRANSPARENTCODE);
 
 	robokid_sprites = 1;
+	stencil_compare_function = stencil_omegaf ;
 }
 
 
@@ -336,7 +355,7 @@ WRITE8_HANDLER( ninjakd2_sprite_overdraw_w )
  *
  *************************************/
 
-static void draw_sprites(running_machine* const machine, bitmap_t* const bitmap)
+static void draw_sprites(running_machine* machine, bitmap_t* bitmap)
 {
 	const gfx_element* const gfx = machine->gfx[1];
 	int const big_xshift = robokid_sprites ? 1 : 0;
@@ -366,7 +385,6 @@ static void draw_sprites(running_machine* const machine, bitmap_t* const bitmap)
 			int const color = sprptr[4] & 0x0f;
 			// Ninja Kid II doesn't use the 'big' feature so it might not be available on the board
 			int const big = (sprptr[2] & 0x04) >> 2;
-			int x,y;
 
 			if (flip_screen_get(machine))
 			{
@@ -383,22 +401,26 @@ static void draw_sprites(running_machine* const machine, bitmap_t* const bitmap)
 				code ^= flipy << big_yshift;
 			}
 
-			for (y = 0; y <= big; ++y)
 			{
-				for (x = 0; x <= big; ++x)
+				int y;
+				for (y = 0; y <= big; ++y)
 				{
-					int const tile = code ^ (x << big_xshift) ^ (y << big_yshift);
+					int x;
+					for (x = 0; x <= big; ++x)
+					{
+						int const tile = code ^ (x << big_xshift) ^ (y << big_yshift);
 
-					drawgfx(bitmap, gfx,
-							tile,
-							color,
-							flipx,flipy,
-							sx + 16*x, sy + 16*y,
-							0, TRANSPARENCY_PEN, 15);
+						drawgfx(bitmap, gfx,
+								tile,
+								color,
+								flipx,flipy,
+								sx + 16*x, sy + 16*y,
+								0, TRANSPARENCY_PEN, 15);
 
-					++sprites_drawn;
-					if (sprites_drawn >= 96)
-						return;
+						++sprites_drawn;
+						if (sprites_drawn >= 96)
+							return;
+					}
 				}
 			}
 		}
@@ -413,44 +435,54 @@ static void draw_sprites(running_machine* const machine, bitmap_t* const bitmap)
 	}
 }
 
+static int stencil_ninjakd2( UINT16 pal ) { return( (pal & 0xf0) == 0xf0 ); }
+static int stencil_mnight(   UINT16 pal ) { return( (pal & 0xf0) == 0xf0 ); }
+static int stencil_arkarea(  UINT16 pal ) { return( (pal & 0xf0) == 0xf0 ); }
+static int stencil_robokid(  UINT16 pal ) { return( (pal & 0xf0) <  0xe0 ); }
+static int stencil_omegaf(   UINT16 pal ) { return( TRUE ); }
+//////            OVERDRAW     STENCIL     UNKNOWN
+//////  NINJAKD2  023459ABCDE  F           1678
+//////    MNIGHT  0134568ABCDE F           279
+//////   ARKAREA  012345679BDE             8ACF
+//////   ROBOKID  EF           01236       45789ABCD
+//////    OMEGAF  -            -           -         (unused)
+// I could not find a port to select overdraw or stencil.
+// Temporarily, I compare with constant number.
+// This is very hackish.
+// (Is there a possibility that software can't select it but hardware can?)
 
-static void erase_sprites(running_machine* const machine, bitmap_t* const bitmap, const rectangle* const cliprect)
+static void erase_sprites(running_machine* machine, bitmap_t* bitmap, const rectangle* cliprect)
 {
 	// if sprite overdraw is disabled, clear the sprite framebuffer
-	// if sprite overdraw is enabled, only clear palettes 0-B and F, and leave C-E on screen
-	if (!sprite_overdraw_enabled)
-		bitmap_fill(sp_bitmap, cliprect, 15);
+	if (!next_sprite_overdraw_enabled)
+		bitmap_fill(sp_bitmap, cliprect, TRANSPARENTCODE);
 	else
 	{
-		int x,y;
-
+		int y;
 		for (y = 0; y < sp_bitmap->height; ++y)
 		{
+			int x;
 			for (x = 0; x < sp_bitmap->width; ++x)
 			{
 				UINT16* const ptr = BITMAP_ADDR16(sp_bitmap, y, x);
 
-				int pal = (*ptr & 0xf0) >> 4;
-
-				if (pal < 0xc || pal == 0xf)
-					*ptr = 15;
+				if ( (*stencil_compare_function)(*ptr) ) *ptr = TRANSPARENTCODE ;
 			}
 		}
 	}
 }
 
 
-static void update_sprites(running_machine* const machine)
+static void update_sprites(running_machine* machine)
 {
 	erase_sprites(machine, sp_bitmap, 0);
-
-	// we want to erase the sprites with the old setting and draw them with the
-	// new one. Not doing this causes a glitch in Ninja Kid II when taking the top
-	// exit from stage 3.
-	sprite_overdraw_enabled = next_sprite_overdraw_enabled;
-
 	draw_sprites(machine, sp_bitmap);
 }
+	////// Before modified, this was written.
+		// we want to erase the sprites with the old setting and draw them with the
+		// new one. Not doing this causes a glitch in Ninja Kid II when taking the top
+		// exit from stage 3.
+	////// The glitch is correct behavior.
 
 
 VIDEO_UPDATE( ninjakd2 )
@@ -464,7 +496,7 @@ VIDEO_UPDATE( ninjakd2 )
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 
-	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, 15);
+	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, TRANSPARENTCODE);
 
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 0);
 
@@ -482,7 +514,7 @@ VIDEO_UPDATE( robokid )
 
 	tilemap_draw(bitmap, cliprect, bg1_tilemap, 0, 0);
 
-	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, 15);
+	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, TRANSPARENTCODE);
 
 	tilemap_draw(bitmap, cliprect, bg2_tilemap, 0, 0);
 
@@ -504,7 +536,7 @@ VIDEO_UPDATE( omegaf )
 
 	tilemap_draw(bitmap, cliprect, bg2_tilemap, 0, 0);
 
-	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, 15);
+	copybitmap_trans(bitmap, sp_bitmap, 0, 0, 0, 0, cliprect, TRANSPARENTCODE);
 
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 0);
 
