@@ -8,10 +8,10 @@
 */
 
 #include "driver.h"
+#include "includes/nmk16.h"
 
 UINT16 *nmk_bgvideoram,*nmk_fgvideoram,*nmk_txvideoram;
-UINT16 *gunnail_scrollram;
-static UINT16 gunnail_scrolly;
+UINT16 *gunnail_scrollram, *gunnail_scrollramy;
 
 static int redraw_bitmap;
 
@@ -22,7 +22,7 @@ static int bioship_background_bank;
 static UINT8 bioship_scroll[4];
 
 static tilemap *bg_tilemap,*fg_tilemap,*tx_tilemap;
-static mame_bitmap *background_bitmap;
+static bitmap_t *background_bitmap;
 extern UINT16* nmk16_mainram;
 
 /***************************************************************************
@@ -99,70 +99,58 @@ static TILE_GET_INFO( bjtwin_get_bg_tile_info )
 
 VIDEO_START( bioship )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan,TILEMAP_TYPE_PEN,16,16,256,32);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,32,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
-	background_bitmap = auto_bitmap_alloc(8192,512,machine->screen[0].format);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan,16,16,256,32);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,32,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	background_bitmap = auto_bitmap_alloc(machine,8192,512,video_screen_get_format(machine->primary_screen));
 
 	tilemap_set_transparent_pen(bg_tilemap,15);
 	tilemap_set_transparent_pen(tx_tilemap,15);
 	bioship_background_bank=0;
 	redraw_bitmap = 1;
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift =  0;	/* 256x224 screen, no shift */
 }
 
 VIDEO_START( strahl )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan,TILEMAP_TYPE_PEN,16,16,256,32);
-	fg_tilemap = tilemap_create(strahl_get_fg_tile_info, bg_scan,TILEMAP_TYPE_PEN,16,16,256,32);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,32,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan,16,16,256,32);
+	fg_tilemap = tilemap_create(machine, strahl_get_fg_tile_info, bg_scan,16,16,256,32);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,32,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	tilemap_set_transparent_pen(fg_tilemap,15);
 	tilemap_set_transparent_pen(tx_tilemap,15);
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift =  0;	/* 256x224 screen, no shift */
 	background_bitmap = NULL;
 }
 
 VIDEO_START( macross )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan,TILEMAP_TYPE_PEN,16,16,256,32);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,32,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan,16,16,256,32);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,32,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	tilemap_set_transparent_pen(tx_tilemap,15);
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift =  0;	/* 256x224 screen, no shift */
 	background_bitmap = NULL;
 }
 
 VIDEO_START( gunnail )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan,TILEMAP_TYPE_PEN,16,16,256,32);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,64,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan,16,16,256,32);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,64,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	tilemap_set_transparent_pen(tx_tilemap,15);
 	tilemap_set_scroll_rows(bg_tilemap,512);
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift = 64;	/* 384x224 screen, leftmost 64 pixels have to be retrieved */
 						/* from the other side of the tilemap (!) */
 	background_bitmap = NULL;
@@ -170,16 +158,13 @@ VIDEO_START( gunnail )
 
 VIDEO_START( macross2 )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan,TILEMAP_TYPE_PEN,16,16,1024,128);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,64,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan,16,16,1024,128);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,64,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	tilemap_set_transparent_pen(tx_tilemap,15);
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift = 64;	/* 384x224 screen, leftmost 64 pixels have to be retrieved */
 						/* from the other side of the tilemap (!) */
 	background_bitmap = NULL;
@@ -187,16 +172,13 @@ VIDEO_START( macross2 )
 
 VIDEO_START( tdragon2 )
 {
-	bg_tilemap = tilemap_create(macross_get_bg_tile_info,bg_scan_td2,TILEMAP_TYPE_PEN,16,16,1024,32);
-	tx_tilemap = tilemap_create(macross_get_tx_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,64,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
+	bg_tilemap = tilemap_create(machine, macross_get_bg_tile_info,bg_scan_td2,16,16,1024,32);
+	tx_tilemap = tilemap_create(machine, macross_get_tx_tile_info,tilemap_scan_cols,8,8,64,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	tilemap_set_transparent_pen(tx_tilemap,15);
 
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
-
 	videoshift = 64;	/* 384x224 screen, leftmost 64 pixels have to be retrieved */
 						/* from the other side of the tilemap (!) */
 	background_bitmap = NULL;
@@ -204,12 +186,9 @@ VIDEO_START( tdragon2 )
 
 VIDEO_START( bjtwin )
 {
-	bg_tilemap = tilemap_create(bjtwin_get_bg_tile_info,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,64,32);
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
-
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
+	bg_tilemap = tilemap_create(machine, bjtwin_get_bg_tile_info,tilemap_scan_cols,8,8,64,32);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 	videoshift = 64;	/* 384x224 screen, leftmost 64 pixels have to be retrieved */
 						/* from the other side of the tilemap (!) */
@@ -224,38 +203,16 @@ VIDEO_START( bjtwin )
 
 ***************************************************************************/
 
-READ16_HANDLER( nmk_bgvideoram_r )
-{
-	return nmk_bgvideoram[offset];
-}
-
 WRITE16_HANDLER( nmk_bgvideoram_w )
 {
 	COMBINE_DATA(&nmk_bgvideoram[offset]);
 	tilemap_mark_tile_dirty(bg_tilemap,offset);
 }
 
-READ16_HANDLER( nmk_fgvideoram_r )
-{
-	return nmk_fgvideoram[offset];
-}
-
 WRITE16_HANDLER( nmk_fgvideoram_w )
 {
-	int oldword = nmk_fgvideoram[offset];
-	int newword = oldword;
-	COMBINE_DATA(&newword);
-
-	if (oldword != newword)
-	{
-		nmk_fgvideoram[offset] = newword;
-		tilemap_mark_tile_dirty(fg_tilemap,offset);
-	}
-}
-
-READ16_HANDLER( nmk_txvideoram_r )
-{
-	return nmk_txvideoram[offset];
+	COMBINE_DATA(&nmk_fgvideoram[offset]);
+	tilemap_mark_tile_dirty(fg_tilemap,offset);
 }
 
 WRITE16_HANDLER( nmk_txvideoram_w )
@@ -297,7 +254,7 @@ WRITE16_HANDLER( bioshipbg_scroll_w )
 {
 	static UINT8 scroll[4];
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		scroll[offset] = (data >> 8) & 0xff;
 
@@ -310,7 +267,7 @@ WRITE16_HANDLER( bioshipbg_scroll_w )
 
 WRITE16_HANDLER( nmk_scroll_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static UINT8 scroll[4];
 
@@ -325,7 +282,7 @@ WRITE16_HANDLER( nmk_scroll_w )
 
 WRITE16_HANDLER( nmk_scroll_2_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static UINT8 scroll[4];
 
@@ -369,13 +326,13 @@ WRITE16_HANDLER( manybloc_scroll_w )
 
 WRITE16_HANDLER( nmk_flipscreen_w )
 {
-	if (ACCESSING_LSB)
-		flip_screen_set(data & 0x01);
+	if (ACCESSING_BITS_0_7)
+		flip_screen_set(space->machine, data & 0x01);
 }
 
 WRITE16_HANDLER( nmk_tilebank_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		if (bgbank != (data & 0xff))
 		{
@@ -387,13 +344,13 @@ WRITE16_HANDLER( nmk_tilebank_w )
 
 WRITE16_HANDLER( bioship_scroll_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 		bioship_scroll[offset]=data>>8;
 }
 
 WRITE16_HANDLER( bioship_bank_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		if (bioship_background_bank != data)
 		{
@@ -403,16 +360,6 @@ WRITE16_HANDLER( bioship_bank_w )
 	}
 }
 
-WRITE16_HANDLER( gunnail_scrollx_w )
-{
-	COMBINE_DATA(&gunnail_scrollram[offset]);
-}
-
-WRITE16_HANDLER( gunnail_scrolly_w )
-{
-	COMBINE_DATA(&gunnail_scrolly);
-}
-
 /***************************************************************************
 
   Display refresh
@@ -423,7 +370,7 @@ WRITE16_HANDLER( gunnail_scrolly_w )
 
 // manybloc uses extra flip bits on the sprites, but these break other games
 
-static void nmk16_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static void nmk16_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 	int offs;
 
@@ -444,7 +391,7 @@ static void nmk16_draw_sprites(running_machine *machine, mame_bitmap *bitmap, co
 			if(pri != priority)
 				continue;
 
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				sx = 368 - sx;
 				sy = 240 - sy;
@@ -461,7 +408,7 @@ static void nmk16_draw_sprites(running_machine *machine, mame_bitmap *bitmap, co
 					drawgfx(bitmap,machine->gfx[2],
 							code,
 							color,
-							flip_screen, flip_screen,
+							flip_screen_get(machine), flip_screen_get(machine),
 							((x + 16) & 0x1ff) - 16,sy & 0x1ff,
 							cliprect,TRANSPARENCY_PEN,15);
 					code++;
@@ -474,7 +421,7 @@ static void nmk16_draw_sprites(running_machine *machine, mame_bitmap *bitmap, co
 	}
 }
 
-static void nmk16_draw_sprites_flipsupported(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static void nmk16_draw_sprites_flipsupported(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 	int offs;
 
@@ -498,10 +445,10 @@ static void nmk16_draw_sprites_flipsupported(running_machine *machine, mame_bitm
 			if(pri != priority)
 				continue;
 
-			flipx ^= flip_screen;
-			flipy ^= flip_screen;
+			flipx ^= flip_screen_get(machine);
+			flipy ^= flip_screen_get(machine);
 
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				sx = 368 - sx;
 				sy = 240 - sy;
@@ -544,151 +491,27 @@ VIDEO_UPDATE( macross )
 
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
 }
 
-/*coin setting MCU simulation*/
-static void mcu_run(UINT8 dsw_setting)
-{
-	static UINT8 read_coin;
-	static UINT8 old_value;
-	static UINT8 coina,coinb;
-	UINT8 dsw_a,dsw_b;
-	/*needed because of the uncompatibility of the dsw settings.*/
-	if(dsw_setting)
-	{
-		dsw_a = (readinputport(2+dsw_setting) & 0x7);
-		dsw_b = (readinputport(2+dsw_setting) & 0x38) >> 3;
-	}
-	else
-	{
-		dsw_a = (readinputport(2) & 0x0700) >> 8;
-		dsw_b = (readinputport(2) & 0x3800) >> 11;
-	}
-
-	read_coin = old_value;
-	old_value = readinputport(0);
-
-	if(dsw_a == 0 || dsw_b == 0)
-		nmk16_mainram[0x9000/2]|=0x4000; //free_play
-
-	if(read_coin != old_value)
-	{
-		if(!(readinputport(0) & 0x01))//COIN1
-		{
-			switch(dsw_a & 7)
-			{
-				case 1: nmk16_mainram[0xef00/2]+=4; break;
-				case 2: nmk16_mainram[0xef00/2]+=3; break;
-				case 3: nmk16_mainram[0xef00/2]+=2; break;
-				case 4:
-				coina++;
-				if(coina >= 4)
-				{
-					coina = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 5:
-				coina++;
-				if(coina >= 3)
-				{
-					coina = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 6:
-				coina++;
-				if(coina >= 2)
-				{
-					coina = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 7: nmk16_mainram[0xef00/2]++; break;
-			}
-		}
-
-		if(!(readinputport(0) & 0x02))//COIN2
-		{
-			switch(dsw_b & 7)
-			{
-				case 1: nmk16_mainram[0xef00/2]+=4; break;
-				case 2: nmk16_mainram[0xef00/2]+=3; break;
-				case 3: nmk16_mainram[0xef00/2]+=2; break;
-				case 4:
-				coinb++;
-				if(coinb >= 4)
-				{
-					coinb = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 5:
-				coinb++;
-				if(coinb >= 3)
-				{
-					coinb = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 6:
-				coinb++;
-				if(coinb >= 2)
-				{
-					coinb = 0;
-					nmk16_mainram[0xef00/2]++;
-				}
-				break;
-				case 7: nmk16_mainram[0xef00/2]++; break;
-			}
-		}
-
-		if(!(readinputport(0) & 0x04))//SERVICE_COIN
-			nmk16_mainram[0xef00/2]++;
-
-		if(nmk16_mainram[0xef00/2] >= 1 && (nmk16_mainram[0x9000/2] & 0x8000))/*enable start button*/
-		{
-			/*Start a 1-player game,but don't decrement if the player 1 is already playing*/
-			if((!(readinputport(0) & 0x08)) /*START1*/
-			&& (!(nmk16_mainram[0x9000/2] & 0x0200)) /*PLAYER-1 playing*/
-			)
-				nmk16_mainram[0xef00/2]--;
-
-			/*Start a 2-players game,but don't decrement if the player 2 is already playing*/
-			if((!(readinputport(0) & 0x10))
-			&& (!(nmk16_mainram[0x9000/2] & 0x0100))
-			)
-			{
-				if(!(nmk16_mainram[0x9000/2] & 0x0200) && nmk16_mainram[0xef00/2] >= 2)
-					nmk16_mainram[0xef00/2]-=2;
-				else
-					nmk16_mainram[0xef00/2]--;
-			}
-		}
-
-		if(nmk16_mainram[0xef00/2] > 99) nmk16_mainram[0xef00/2] = 99;
-	}
-}
-
 VIDEO_UPDATE( tdragon )
 {
-	mcu_run(1);
+//  mcu_run(screen->machine, 1);
 
 	tilemap_set_scrollx(tx_tilemap,0,-videoshift);
 
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -696,16 +519,16 @@ VIDEO_UPDATE( tdragon )
 
 VIDEO_UPDATE( hachamf )
 {
-	mcu_run(0);
+//  mcu_run(screen->machine, 0);
 
 	tilemap_set_scrollx(tx_tilemap,0,-videoshift);
 
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -717,10 +540,10 @@ VIDEO_UPDATE( manybloc )
 
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -735,10 +558,10 @@ VIDEO_UPDATE( tharrier )
 	tilemap_set_scrollx(bg_tilemap,0,tharrier_scroll);
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -746,21 +569,47 @@ VIDEO_UPDATE( tharrier )
 
 VIDEO_UPDATE( gunnail )
 {
-	int i;
+	int y1, i;
+	rectangle bgclip = *cliprect;
 
-	for (i = 0;i < 256;i++)
+	// the hardware supports per-scanline X *and* Y scroll which isn't
+	// supported by tilemaps so we have to draw the tilemap one line at a time
+	y1 = cliprect->min_y;
+	while (y1 <= cliprect->max_y)
 	{
-		tilemap_set_scrollx(bg_tilemap,(i+gunnail_scrolly) & 0x1ff,gunnail_scrollram[0] + gunnail_scrollram[i] - videoshift);
-	}
-	tilemap_set_scrolly(bg_tilemap,0,gunnail_scrolly);
+		int const yscroll = gunnail_scrollramy[0] + gunnail_scrollramy[y1];
+		int y2;
 
-	VIDEO_UPDATE_CALL(macross);
+		// group all consecutive lines with the same y scroll to reduce overhead
+		y2 = y1+1;
+		while (y2 <= cliprect->max_y && gunnail_scrollramy[y2] == gunnail_scrollramy[y1])
+			y2++;
+
+		bgclip.min_y = y1;
+		bgclip.max_y = y2-1;
+
+		tilemap_set_scrolly(bg_tilemap, 0, yscroll);
+		for (i = y1; i < y2; i++)
+			tilemap_set_scrollx(bg_tilemap,(i + yscroll) & 0x1ff, gunnail_scrollram[0] + gunnail_scrollram[i] - videoshift);
+
+		tilemap_draw(bitmap,&bgclip,bg_tilemap,0,0);
+
+		y1 = y2;
+	}
+
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
+
+	tilemap_set_scrollx(tx_tilemap,0,-videoshift);
+	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
 }
 
 VIDEO_UPDATE( bioship )
 {
-	UINT16 *tilerom = (UINT16 *)memory_region(REGION_GFX5);
+	UINT16 *tilerom = (UINT16 *)memory_region(screen->machine, "gfx5");
 	int scrollx=-(bioship_scroll[1] + bioship_scroll[0]*256);
 	int scrolly=-(bioship_scroll[3] + bioship_scroll[2]*256);
 
@@ -778,7 +627,7 @@ VIDEO_UPDATE( bioship )
 				int numtile = data&0xfff;
 				int color = (data&0xf000)>>12;
 
-				drawgfx(background_bitmap,machine->gfx[3],
+				drawgfx(background_bitmap,screen->machine->gfx[3],
 						numtile,
 						color,
 						0,0,   /* no flip */
@@ -788,7 +637,7 @@ VIDEO_UPDATE( bioship )
 				data = tilerom[offs+0x1000+bank];
 				numtile = data&0xfff;
 				color = (data&0xf000)>>12;
-				drawgfx(background_bitmap,machine->gfx[3],
+				drawgfx(background_bitmap,screen->machine->gfx[3],
 						numtile,
 						color,
 						0,0,   /* no flip */
@@ -803,10 +652,10 @@ VIDEO_UPDATE( bioship )
 	copyscrollbitmap(bitmap,background_bitmap,1,&scrollx,1,&scrolly,cliprect);
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -819,10 +668,10 @@ VIDEO_UPDATE( strahl )
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -834,10 +683,10 @@ VIDEO_UPDATE( bjtwin )
 
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	nmk16_draw_sprites(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites(screen->machine, bitmap,cliprect,0);
 
 	return 0;
 }
@@ -875,37 +724,6 @@ UINT16 *afega_vram_0, *afega_scroll_0;
 UINT16 *afega_vram_1, *afega_scroll_1;
 
 
-/***************************************************************************
-
-
-                        Palette - RRRRGGGGBBBB????
-
-
-***************************************************************************/
-
-#ifdef UNUSED_FUNCTION
-WRITE16_HANDLER( afega_palette_w )
-{
-	int r,g,b;
-	data = COMBINE_DATA(&paletteram16[offset]);
-	b = ((data & 0x00F0) >> 3 ) + ((data & 0x0002) >> 1);
-	g = ((data & 0x0F00) >> 7 ) + ((data & 0x0004) >> 2);
-	r = ((data & 0xF000) >> 11) + ((data & 0x0008) >> 3);
-	palette_set_color_rgb( Machine, offset, pal5bit(r) , pal5bit(g) , pal5bit(b) );
-}
-#endif
-
-/* This game uses 8 bit tiles, so it ignores the color codes and just
-   uses the same 256 colors for every tile */
-PALETTE_INIT( grdnstrm )
-{
-	int color, pen;
-	for( color = 0; color < 16; color++ )
-		for( pen = 0; pen < 256; pen++ )
-			colortable[color * 256 + pen + 256*3] = 256*0 + pen;
-}
-
-
 /***************************************************************************
 
                                 Tilemaps
@@ -949,7 +767,7 @@ static TILEMAP_MAPPER( firehawk_tilemap_scan_pages )
 
 static tilemap *tilemap_0, *tilemap_1;
 
-static TILE_GET_INFO( get_tile_info_0 )
+static TILE_GET_INFO( get_tile_info_0_4bit )
 {
 	UINT16 code = afega_vram_0[tile_index];
 	SET_TILE_INFO(
@@ -958,6 +776,15 @@ static TILE_GET_INFO( get_tile_info_0 )
 			(code & 0xf000) >> 12,
 			0);
 }
+static TILE_GET_INFO( get_tile_info_0_8bit )
+{
+	UINT16 code = afega_vram_0[tile_index];
+	SET_TILE_INFO(
+			0,
+			code,
+			0,
+			0);
+}
 static TILE_GET_INFO( get_tile_info_1 )
 {
 	UINT16 code = afega_vram_1[tile_index];
@@ -990,19 +817,16 @@ WRITE16_HANDLER( afega_vram_1_w )
 
 VIDEO_START( afega )
 {
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
+	tilemap_0 = tilemap_create(	machine, get_tile_info_0_4bit, afega_tilemap_scan_pages,
 
-	tilemap_0 = tilemap_create(	get_tile_info_0, afega_tilemap_scan_pages,
-								TILEMAP_TYPE_PEN,
 								16,16,
 								TILES_PER_PAGE_X*PAGES_PER_TMAP_X,TILES_PER_PAGE_Y*PAGES_PER_TMAP_Y);
 
-	tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_cols,
-								TILEMAP_TYPE_PEN,
+	tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_cols,
+
 								8,8,
 								32,32);
 
@@ -1010,22 +834,39 @@ VIDEO_START( afega )
 }
 
 
+VIDEO_START( grdnstrm )
+{
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+
+
+	tilemap_0 = tilemap_create(	machine, get_tile_info_0_8bit, afega_tilemap_scan_pages,
+
+								16,16,
+								TILES_PER_PAGE_X*PAGES_PER_TMAP_X,TILES_PER_PAGE_Y*PAGES_PER_TMAP_Y);
+
+	tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_cols,
+
+								8,8,
+								32,32);
+
+	tilemap_set_transparent_pen(tilemap_1,0xf);
+}
+
 
 VIDEO_START( firehawk )
 {
-	spriteram_old = auto_malloc(0x1000);
-	spriteram_old2 = auto_malloc(0x1000);
-	memset(spriteram_old,0,0x1000);
-	memset(spriteram_old2,0,0x1000);
+	spriteram_old = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
+	spriteram_old2 = auto_alloc_array_clear(machine, UINT16, 0x1000/2);
 
 
-	tilemap_0 = tilemap_create(	get_tile_info_0, firehawk_tilemap_scan_pages,
-								TILEMAP_TYPE_PEN,
+	tilemap_0 = tilemap_create(	machine, get_tile_info_0_8bit, firehawk_tilemap_scan_pages,
+
 								16,16,
 								TILES_PER_PAGE_X*FIREHAWK_PAGES_PER_TMAP_X,TILES_PER_PAGE_Y*FIREHAWK_PAGES_PER_TMAP_Y);
 
-	tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_cols,
-								TILEMAP_TYPE_PEN,
+	tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_cols,
+
 								8,8,
 								32,32);
 
@@ -1041,7 +882,7 @@ VIDEO_START( firehawk )
 
 ***************************************************************************/
 
-static void video_update(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect,
+static void video_update(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect,
 	int dsw_flipscreen,			// 1 = Horizontal and vertical screen flip are hardwired to 2 dip switches
 	int xoffset, int yoffset,	// tilemap_0 offsets
 	int attr_mask				// "sprite active" mask
@@ -1053,8 +894,8 @@ static void video_update(running_machine *machine, mame_bitmap *bitmap, const re
 	if (dsw_flipscreen)
 	{
 
-		flip_screen_x_set(~readinputport(2) & 0x0100);
-		flip_screen_y_set(~readinputport(2) & 0x0200);
+		flip_screen_x_set(machine, ~input_port_read(machine, "DSW1") & 0x0100);
+		flip_screen_y_set(machine, ~input_port_read(machine, "DSW1") & 0x0200);
 	}
 
 	tilemap_set_scrollx(tilemap_0, 0, afega_scroll_0[1] + xoffset);
@@ -1063,7 +904,6 @@ static void video_update(running_machine *machine, mame_bitmap *bitmap, const re
 	tilemap_set_scrollx(tilemap_1, 0, afega_scroll_1[1]);
 	tilemap_set_scrolly(tilemap_1, 0, afega_scroll_1[0]);
 
-
 	tilemap_draw(bitmap,cliprect,tilemap_0,0,0);
 
 	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,3);
@@ -1074,9 +914,25 @@ static void video_update(running_machine *machine, mame_bitmap *bitmap, const re
 	tilemap_draw(bitmap,cliprect,tilemap_1,0,0);
 }
 
-VIDEO_UPDATE( afega )		{	video_update(machine,bitmap,cliprect, 1, -0x100,+0x000, 0x0001);	return 0; }
-VIDEO_UPDATE( bubl2000 )	{	video_update(machine,bitmap,cliprect, 0, -0x100,+0x000, 0x0001);	return 0; }	// no flipscreen support, I really would confirmation from the schematics
-VIDEO_UPDATE( redhawkb )	{	video_update(machine,bitmap,cliprect, 0, +0x000,+0x100, 0x0001);	return 0; }
+static void redhawki_video_update(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect	)
+{
+
+
+	tilemap_set_scrollx(tilemap_0, 0, afega_scroll_1[0]&0xff);
+	tilemap_set_scrolly(tilemap_0, 0, afega_scroll_1[1]&0xff);
+
+	tilemap_draw(bitmap,cliprect,tilemap_0,0,0);
+
+	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,3);
+	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,2);
+	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,1);
+	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,0);
+}
+
+VIDEO_UPDATE( afega )		{	video_update(screen->machine,bitmap,cliprect, 1, -0x100,+0x000, 0x0001);	return 0; }
+VIDEO_UPDATE( bubl2000 )	{	video_update(screen->machine,bitmap,cliprect, 0, -0x100,+0x000, 0x0001);	return 0; }	// no flipscreen support, I really would confirmation from the schematics
+VIDEO_UPDATE( redhawkb )	{	video_update(screen->machine,bitmap,cliprect, 0, +0x000,+0x100, 0x0001);	return 0; }
+VIDEO_UPDATE( redhawki )	{	redhawki_video_update(screen->machine,bitmap,cliprect); return 0;} // strange scroll regs
 
 VIDEO_UPDATE( firehawk )
 {
@@ -1087,10 +943,10 @@ VIDEO_UPDATE( firehawk )
 
 	tilemap_draw(bitmap,cliprect,tilemap_0,0,0);
 
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,3);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,2);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,1);
-	nmk16_draw_sprites_flipsupported(machine, bitmap,cliprect,0);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,3);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,2);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,1);
+	nmk16_draw_sprites_flipsupported(screen->machine, bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,tilemap_1,0,0);
 	return 0;
