@@ -189,11 +189,7 @@
  *
  *************************************/
 
-#ifdef LSB_FIRST
-#define SWAP_HALVES(x)			(x)
-#else
-#define SWAP_HALVES(x)			(((x) >> 16) | ((x) << 16))
-#endif
+#define SWAP_HALVES(x)			NATIVE_ENDIAN_VALUE_LE_BE(x, ((x) >> 16) | ((x) << 16))
 
 
 
@@ -294,13 +290,13 @@ static void common_start(running_machine *machine, int multi32)
 	is_multi32 = multi32;
 
 	/* allocate a copy of spriteram in 32-bit format */
-	spriteram_32bit = auto_malloc(0x20000);
+	spriteram_32bit = auto_alloc_array(machine, UINT32, 0x20000/4);
 
 	/* allocate the tilemap cache */
 	cache_head = NULL;
 	for (tmap = 0; tmap < TILEMAP_CACHE_SIZE; tmap++)
 	{
-		struct cache_entry *entry = auto_malloc(sizeof(struct cache_entry));
+		struct cache_entry *entry = auto_alloc(machine, struct cache_entry);
 
 		entry->tmap = tilemap_create(machine, get_tile_info, tilemap_scan_rows,  16,16, 32,16);
 		entry->page = 0xff;
@@ -314,15 +310,14 @@ static void common_start(running_machine *machine, int multi32)
 	/* allocate the bitmaps (a few extra for multi32) */
 	for (tmap = 0; tmap < 9 + 2 * multi32; tmap++)
 	{
-		layer_data[tmap].bitmap = auto_bitmap_alloc(416, 224, BITMAP_FORMAT_INDEXED16);
-		layer_data[tmap].transparent = auto_malloc(sizeof(layer_data[tmap].transparent[0]) * 256);
-		memset(layer_data[tmap].transparent, 0, sizeof(layer_data[tmap].transparent[0]) * 256);
+		layer_data[tmap].bitmap = auto_bitmap_alloc(machine, 416, 224, BITMAP_FORMAT_INDEXED16);
+		layer_data[tmap].transparent = auto_alloc_array_clear(machine, UINT8, 256);
 	}
 
 	/* allocate pre-rendered solid lines of 0's and ffff's */
-	solid_0000 = auto_malloc(sizeof(solid_0000[0]) * 512);
+	solid_0000 = auto_alloc_array(machine, UINT16, 512);
 	memset(solid_0000, 0x00, sizeof(solid_0000[0]) * 512);
-	solid_ffff = auto_malloc(sizeof(solid_ffff[0]) * 512);
+	solid_ffff = auto_alloc_array(machine, UINT16, 512);
 	memset(solid_ffff, 0xff, sizeof(solid_ffff[0]) * 512);
 
 	/* initialize videoram */
@@ -588,7 +583,7 @@ READ16_HANDLER( system32_sprite_control_r )
 			/*  D1 : Seems to be '1' only during an erase in progress, this
                      occurs very briefly though.
                 D0 : Selected frame buffer (0= A, 1= B) */
-			return 0xfffc | (layer_data[MIXER_LAYER_SPRITES].bitmap < layer_data[MIXER_LAYER_SPRITES_2].bitmap);
+			return 0xfffc | (int)(layer_data[MIXER_LAYER_SPRITES].bitmap < layer_data[MIXER_LAYER_SPRITES_2].bitmap);
 
 		case 1:
 			/*  D1 : ?
@@ -797,7 +792,7 @@ static tilemap *find_cache_entry(int page, int bank)
 
 static TILE_GET_INFO( get_tile_info )
 {
-	struct cache_entry *entry = param;
+	struct cache_entry *entry = (struct cache_entry *)param;
 	UINT16 data = system32_videoram[(entry->page & 0x7f) * 0x200 + tile_index];
 	SET_TILE_INFO(0, (entry->bank << 13) + (data & 0x1fff), (data >> 4) & 0x1ff, (data >> 14) & 3);
 }
@@ -2629,7 +2624,7 @@ VIDEO_UPDATE( multi32 )
 {
 	UINT8 enablemask;
 
-	const device_config *left_screen  = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
+	const device_config *left_screen  = devtag_get_device(screen->machine, "lscreen");
 
 	/* update the visible area */
 	if (system32_videoram[0x1ff00/2] & 0x8000)
