@@ -17,7 +17,7 @@ static int width = 0;
 
 MACHINE_RESET( skydiver )
 {
-	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	/* reset all latches */
 	skydiver_start_lamp_1_w(space, 0, 0);
@@ -130,6 +130,7 @@ WRITE8_HANDLER( skydiver_lamp_d_w )
 
 WRITE8_HANDLER( skydiver_2000_201F_w )
 {
+	const device_config *discrete = devtag_get_device(space->machine, "discrete");
 	int bit = offset & 0x01;
 
 	watchdog_reset_w(space,0,0);
@@ -149,13 +150,13 @@ WRITE8_HANDLER( skydiver_2000_201F_w )
 			output_set_value("lampr", bit);
 			break;
 		case (0x0a):
-			discrete_sound_w(space, SKYDIVER_OCT1_EN, bit);
+			discrete_sound_w(discrete, SKYDIVER_OCT1_EN, bit);
 			break;
 		case (0x0c):
-			discrete_sound_w(space, SKYDIVER_OCT2_EN, bit);
+			discrete_sound_w(discrete, SKYDIVER_OCT2_EN, bit);
 			break;
 		case (0x0e):
-			discrete_sound_w(space, SKYDIVER_NOISE_RST, bit);
+			discrete_sound_w(discrete, SKYDIVER_NOISE_RST, bit);
 			break;
 	}
 }
