@@ -115,7 +115,7 @@ WRITE8_HANDLER( spdodgeb_scrollx_lo_w )
 
 WRITE8_HANDLER( spdodgeb_ctrl_w )
 {
-	UINT8 *rom = memory_region(space->machine, "main");
+	UINT8 *rom = memory_region(space->machine, "maincpu");
 
 	/* bit 0 = flip screen */
 	flip_screen_set(space->machine, data & 0x01);
