@@ -25,7 +25,6 @@ static int vdp1_sprite_log = 0;
 UINT32 *stv_vdp1_vram;
 static UINT32 *stv_vdp1_regs;
 UINT8* stv_vdp1_gfx_decode;
-extern UINT8 get_vblank(running_machine *machine);
 
 static UINT16	 *stv_framebuffer[2];
 static UINT16	 **stv_framebuffer_draw_lines;
@@ -294,7 +293,7 @@ WRITE32_HANDLER( stv_vdp1_regs_w )
 		else
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Access to register TVMR = %1X\n", STV_VDP1_TVMR );
-			if ( STV_VDP1_VBE && get_vblank(space->machine) )
+			if ( STV_VDP1_VBE && stv_get_vblank(space->machine) )
 			{
 				stv_vdp1_clear_framebuffer_on_next_frame = 1;
 			}
@@ -1988,7 +1987,7 @@ static void stv_vdp1_process_list(running_machine *machine)
 
 	/* not here! this is done every frame drawn even if the cpu isn't running eg in the debugger */
 //  if(!(stv_scu[40] & 0x2000)) /*Sprite draw end irq*/
-//      cpu_set_input_line_and_vector(machine->cpu[0], 2, HOLD_LINE , 0x4d);
+//      cputag_set_input_line_and_vector(machine, "maincpu", 2, HOLD_LINE , 0x4d);
 
 	if (vdp1_sprite_log) logerror ("End of list processing!\n");
 }
@@ -2096,20 +2095,17 @@ static STATE_POSTLOAD( stv_vdp1_state_save_postload )
 
 int stv_vdp1_start ( running_machine *machine )
 {
-	stv_vdp1_regs = auto_malloc ( 0x040000 );
-	stv_vdp1_vram = auto_malloc ( 0x100000 );
-	stv_vdp1_gfx_decode = auto_malloc( 0x100000 );
+	stv_vdp1_regs = auto_alloc_array_clear(machine, UINT32, 0x040000/4 );
+	stv_vdp1_vram = auto_alloc_array_clear(machine, UINT32, 0x100000/4 );
+	stv_vdp1_gfx_decode = auto_alloc_array(machine, UINT8, 0x100000 );
 
-	stv_vdp1_shading_data = auto_malloc( sizeof(struct stv_vdp1_poly_scanline_data) );
+	stv_vdp1_shading_data = auto_alloc(machine, struct stv_vdp1_poly_scanline_data);
 
-	memset(stv_vdp1_regs, 0, 0x040000);
-	memset(stv_vdp1_vram, 0, 0x100000);
+	stv_framebuffer[0] = auto_alloc_array(machine, UINT16, 1024 * 256 * 2 ); /* *2 is for double interlace */
+	stv_framebuffer[1] = auto_alloc_array(machine, UINT16, 1024 * 256 * 2 );
 
-	stv_framebuffer[0] = auto_malloc( 1024 * 256 * sizeof(UINT16) * 2 ); /* *2 is for double interlace */
-	stv_framebuffer[1] = auto_malloc( 1024 * 256 * sizeof(UINT16) * 2 );
-
-	stv_framebuffer_display_lines = auto_malloc( 512 * sizeof(UINT16*) );
-	stv_framebuffer_draw_lines = auto_malloc( 512 * sizeof(UINT16*) );
+	stv_framebuffer_display_lines = auto_alloc_array(machine, UINT16 *, 512);
+	stv_framebuffer_draw_lines = auto_alloc_array(machine, UINT16 *, 512);
 
 	stv_framebuffer_width = stv_framebuffer_height = 0;
 	stv_framebuffer_mode = -1;
