@@ -127,7 +127,8 @@ static UINT8 bright_v3_b_trans = 0x00, bright_v3_g_trans = 0x00, bright_v3_r_tra
 
 // This ignores the alpha values atm.
 static int spc_changed=0, v3_changed=0, palette_updated=0;
-int suprnova_alt_enable_background, suprnova_alt_enable_sprites;
+static int suprnova_alt_enable_background;
+int suprnova_alt_enable_sprites;
 
 WRITE32_HANDLER ( skns_pal_regs_w )
 {
@@ -911,13 +912,13 @@ VIDEO_START(skns)
 	skns_tilemap_B = tilemap_create(machine, get_tilemap_B_tile_info,tilemap_scan_rows,16,16,64, 64);
 		tilemap_set_transparent_pen(skns_tilemap_B,0);
 
-	sprite_bitmap = auto_bitmap_alloc(1024,1024,BITMAP_FORMAT_INDEXED16);
+	sprite_bitmap = auto_bitmap_alloc(machine,1024,1024,BITMAP_FORMAT_INDEXED16);
 
-	tilemap_bitmap_lower = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED16);
-	tilemap_bitmapflags_lower = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED8);
+	tilemap_bitmap_lower = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED16);
+	tilemap_bitmapflags_lower = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED8);
 
-	tilemap_bitmap_higher = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED16);
-	tilemap_bitmapflags_higher = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED8);
+	tilemap_bitmap_higher = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED16);
+	tilemap_bitmapflags_higher = auto_bitmap_alloc(machine,320,240,BITMAP_FORMAT_INDEXED8);
 
 	machine->gfx[2]->color_granularity=256;
 	machine->gfx[3]->color_granularity=256;
@@ -991,67 +992,8 @@ static void supernova_draw_b( bitmap_t *bitmap, bitmap_t* bitmap_flags, const re
 
 VIDEO_UPDATE(skns)
 {
-	int i, offset;
-
-	UINT8 *btiles;
-
-
 	palette_update(screen->machine);
 
-	btiles = memory_region (screen->machine, "gfx3");
-
-//  if (!(skns_v3_regs[0x0c/4] & 0x0100)); // if tilemap b is in 8bpp mode
-	{
-		if (skns_v3t_somedirty)
-		{
-			skns_v3t_somedirty = 0;
-
-			/* check if & where that tile is used in the tilemap */
-			for (offset=0;offset<0x4000/4;offset++)
-			{
-				int code = ((skns_tilemapB_ram[offset] & 0x001fffff) >> 0 );
-				if (skns_v3t_dirty[code&0x3ff])
-					tilemap_mark_tile_dirty(skns_tilemap_B,offset);
-			}
-
-			for (i = 0; i < 0x0400; i++)
-			{
-				if (skns_v3t_dirty[i] == 1)
-				{
-					decodechar(screen->machine->gfx[1], i, (UINT8*)btiles);
-
-					skns_v3t_dirty[i] = 0;
-				}
-			}
-		}
-	}
-
-//  if (skns_v3_regs[0x0c/4] & 0x0100); // if tilemap b is in 4bpp mode
-	{
-		if (skns_v3t_4bpp_somedirty)
-		{
-			skns_v3t_4bpp_somedirty = 0;
-
-			/* check if & where that tile is used in the tilemap */
-			for (offset=0;offset<0x4000/4;offset++)
-			{
-				int code = ((skns_tilemapB_ram[offset] & 0x001fffff) >> 0 );
-				if (skns_v3t_4bppdirty[code&0x7ff])
-					tilemap_mark_tile_dirty(skns_tilemap_B,offset);
-			}
-
-			for (i = 0; i < 0x0800; i++)
-			{
-				if (skns_v3t_4bppdirty[i] == 1)
-				{
-					decodechar(screen->machine->gfx[3], i, (UINT8*)btiles);
-
-					skns_v3t_4bppdirty[i] = 0;
-				}
-			}
-		}
-	}
-
 	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 	bitmap_fill(tilemap_bitmap_lower, NULL, 0);
 	bitmap_fill(tilemap_bitmapflags_lower, NULL, 0);
