@@ -89,9 +89,9 @@ static void taitof2_core_vh_start (running_machine *machine, int sprite_type,int
 	f2_hide_pixels = hide;
 	f2_flip_hide_pixels = flip_hide;
 
-	spriteram_delayed = auto_malloc(spriteram_size);
-	spriteram_buffered = auto_malloc(spriteram_size);
-	spritelist = auto_malloc(0x400 * sizeof(*spritelist));
+	spriteram_delayed = auto_alloc_array(machine, UINT16, spriteram_size/2);
+	spriteram_buffered = auto_alloc_array(machine, UINT16, spriteram_size/2);
+	spritelist = auto_alloc_array(machine, struct tempsprite, 0x400);
 
 	chips = TC0100SCN_count(machine);
 
@@ -243,7 +243,7 @@ VIDEO_START( taitof2_deadconx )
 	taitof2_core_vh_start(machine, 0,3,3,0,0,0,0,0,0);
 }
 
-VIDEO_START( taitof2_deadconj )
+VIDEO_START( taitof2_deadconxj )
 {
 	f2_tilemap_xoffs = 0x34;
 	f2_tilemap_yoffs = - 0x05;
@@ -372,7 +372,7 @@ static void taito_f2_tc360_spritemixdraw( bitmap_t *dest_bmp,const gfx_element *
 		const rectangle *clip,int scalex, int scaley)
 {
 	int pal_base = gfx->color_base + gfx->color_granularity * (color % gfx->total_colors);
-	UINT8 *source_base = gfx->gfxdata + (code % gfx->total_elements) * gfx->char_modulo;
+	const UINT8 *source_base = gfx_element_get_data(gfx, code % gfx->total_elements);
 
 	int sprite_screen_height = (scaley*gfx->height+0x8000)>>16;
 	int sprite_screen_width = (scalex*gfx->width+0x8000)>>16;
@@ -445,7 +445,7 @@ static void taito_f2_tc360_spritemixdraw( bitmap_t *dest_bmp,const gfx_element *
 
 			for( y=sy; y<ey; y++ )
 			{
-				UINT8 *source = source_base + (y_index>>16) * gfx->line_modulo;
+				const UINT8 *source = source_base + (y_index>>16) * gfx->line_modulo;
 				UINT16 *dest = BITMAP_ADDR16(dest_bmp, y, 0);
 				UINT8 *pri = BITMAP_ADDR8(priority_bitmap, y, 0);
 
