@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "includes/tubep.h"
 #include "video/resnet.h"
 
@@ -39,8 +38,8 @@ static UINT32	romHI_addr_msb = 0;
 static UINT8	DISP = 0;
 static UINT8	background_romsel = 0;
 static UINT8	color_A4 = 0;
-static UINT8	ls175_b7 = 0x0f | 0xf0;
-static UINT8	ls175_e8 = 0x0f;
+static UINT8	ls175_b7;
+static UINT8	ls175_e8;
 static UINT8	ls377_data = 0;
 static UINT32	page = 0;
 
@@ -170,9 +169,6 @@ PALETTE_INIT( tubep )
 {
 	int i,r,g,b;
 
-	#define TOTAL_COLORS(gfxn) (machine->gfx[gfxn]->total_colors * machine->gfx[gfxn]->color_granularity)
-	#define COLOR(gfxn,offs) (colortable[machine->drv->gfxdecodeinfo[gfxn].color_codes_start + offs])
-
 	/* background/sprites palette variables */
 
 	static const int resistors_0[6] = { 33000, 15000, 8200, 4700, 2200, 1000 };
@@ -187,7 +183,7 @@ PALETTE_INIT( tubep )
 	double weights_g[3*6];
 	double weights_b[2*6];
 
-	double output_scaler;
+	//double output_scaler;
 
 	/* text palette variables */
 
@@ -227,13 +223,6 @@ PALETTE_INIT( tubep )
 		color_prom++;
 	}
 
-	/* text lookup */
-	for (i = 0; i < TOTAL_COLORS(0)/2; i++)
-	{
-		COLOR(0, 2*i+0 ) = 0;		/* transparent "black" */
-		COLOR(0, 2*i+1 ) = i;
-	}
-
 	/* sprites use the second PROM to control 8 x LS368. We copy content of this PROM over here */
 	for (i = 0; i < 32; i++)
 	{
@@ -262,10 +251,12 @@ PALETTE_INIT( tubep )
 	for (i=0; i<6; i++) active_resistors_b[ 6+i] = resistors_2[i];
 
 	/* calculate and store the scaler */
-	output_scaler = compute_resistor_weights(0,	255,	-1.0,
-				3*6,	active_resistors_r,	weights_r,	470,	0,
-				3*6,	active_resistors_g,	weights_g,	470,	0,
-				2*6,	active_resistors_b,	weights_b,	470,	0);
+/*
+    output_scaler = compute_resistor_weights(0, 255,    -1.0,
+                3*6,    active_resistors_r, weights_r,  470,    0,
+                3*6,    active_resistors_g, weights_g,  470,    0,
+                2*6,    active_resistors_b, weights_b,  470,    0);
+*/
 
 /*  compute_resistor_weights(0, 255,    output_scaler,
                 3*6,    active_resistors_r, weights_r,  470,    0,
@@ -289,9 +280,9 @@ PALETTE_INIT( tubep )
 			double out;
 			int c;
 
-			int active_r = 3*6;
-			int active_g = 3*6;
-			int active_b = 2*6;
+			//int active_r = 3*6;
+			//int active_g = 3*6;
+			//int active_b = 2*6;
 
 			for (c=0; c<6; c++)
 			{
@@ -313,46 +304,46 @@ PALETTE_INIT( tubep )
 			if ((j >> 0) & 0x01)	/* if LS368 @E9  is disabled */
 			{
 				for (c=0; c<6; c++) bits_r[0 +c] = 0;
-				active_r-=6;
+				//active_r-=6;
 			}
 			if ((j >> 1) & 0x01)	/* if LS368 @E10 is disabled */
 			{
 				for (c=0; c<6; c++) bits_r[6 +c] = 0;
-				active_r-=6;
+				//active_r-=6;
 			}
 			if ((j >> 2) & 0x01)	/* if LS368 @E11 is disabled */
 			{
 				for (c=0; c<6; c++) bits_r[12 +c] = 0;
-				active_r-=6;
+				//active_r-=6;
 			}
 
 			/* green component */
 			if ((j >> 3) & 0x01)	/* if LS368 @E12 is disabled */
 			{
 				for (c=0; c<6; c++) bits_g[0 +c] = 0;
-				active_g-=6;
+				//active_g-=6;
 			}
 			if ((j >> 4) & 0x01)	/* if LS368 @E13 is disabled */
 			{
 				for (c=0; c<6; c++) bits_g[6 +c] = 0;
-				active_g-=6;
+				//active_g-=6;
 			}
 			if ((j >> 5) & 0x01)	/* if LS368 @E14 is disabled */
 			{
 				for (c=0; c<6; c++) bits_g[12+c] = 0;
-				active_g-=6;
+				//active_g-=6;
 			}
 
 			/* blue component */
 			if ((j >> 6) & 0x01)	/* if LS368 @E15 is disabled */
 			{
 				for (c=0; c<6; c++) bits_b[0 +c] = 0;
-				active_b-=6;
+				//active_b-=6;
 			}
 			if ((j >> 7) & 0x01)	/* if LS368 @E16 is disabled */
 			{
 				for (c=0; c<6; c++) bits_b[6 +c] = 0;
-				active_b-=6;
+				//active_b-=6;
 			}
 
 			out = 0.0;
@@ -378,31 +369,58 @@ PALETTE_INIT( tubep )
 
 VIDEO_START( tubep )
 {
-	spritemap = auto_malloc(256*256*2);
-	memset(spritemap,0,256*256*2);
+	spritemap = auto_alloc_array(machine, UINT8, 256*256*2);
 
 	/* Set up save state */
-	state_save_register_global(romD_addr);
-	state_save_register_global(romEF_addr);
-	state_save_register_global(E16_add_b);
-	state_save_register_global(HINV);
-	state_save_register_global(VINV);
-	state_save_register_global(XSize);
-	state_save_register_global(YSize);
-	state_save_register_global(mark_1);
-	state_save_register_global(mark_2);
-	state_save_register_global(colorram_addr_hi);
-	state_save_register_global(ls273_g6);
-	state_save_register_global(ls273_j6);
-	state_save_register_global(romHI_addr_mid);
-	state_save_register_global(romHI_addr_msb);
-	state_save_register_global(DISP);
-	state_save_register_global(background_romsel);
-	state_save_register_global(color_A4);
-	state_save_register_global(ls175_b7);
-	state_save_register_global(ls175_e8);
-	state_save_register_global(ls377_data);
-	state_save_register_global(page);
+	state_save_register_global(machine, romD_addr);
+	state_save_register_global(machine, romEF_addr);
+	state_save_register_global(machine, E16_add_b);
+	state_save_register_global(machine, HINV);
+	state_save_register_global(machine, VINV);
+	state_save_register_global(machine, XSize);
+	state_save_register_global(machine, YSize);
+	state_save_register_global(machine, mark_1);
+	state_save_register_global(machine, mark_2);
+	state_save_register_global(machine, colorram_addr_hi);
+	state_save_register_global(machine, ls273_g6);
+	state_save_register_global(machine, ls273_j6);
+	state_save_register_global(machine, romHI_addr_mid);
+	state_save_register_global(machine, romHI_addr_msb);
+	state_save_register_global(machine, DISP);
+	state_save_register_global(machine, background_romsel);
+	state_save_register_global(machine, color_A4);
+	state_save_register_global(machine, ls175_b7);
+	state_save_register_global(machine, ls175_e8);
+	state_save_register_global(machine, ls377_data);
+	state_save_register_global(machine, page);
+}
+
+
+VIDEO_RESET( tubep )
+{
+	memset(spritemap,0,256*256*2);
+
+	romD_addr = 0;
+	romEF_addr = 0;
+	E16_add_b = 0;
+	HINV = 0;
+	VINV = 0;
+	XSize = 0;
+	YSize = 0;
+	mark_1 = 0;
+	mark_2 = 0;
+	colorram_addr_hi = 0;
+	ls273_g6 = 0;
+	ls273_j6 = 0;
+	romHI_addr_mid = 0;
+	romHI_addr_msb = 0;
+	DISP = 0;
+	background_romsel = 0;
+	color_A4 = 0;
+	ls175_b7 = 0x0f | 0xf0;
+	ls175_e8 = 0x0f;
+	ls377_data = 0;
+	page = 0;
 }
 
 
@@ -426,30 +444,30 @@ WRITE8_HANDLER( tubep_colorproms_A4_line_w )
 
 WRITE8_HANDLER( tubep_background_a000_w )
 {
-	ls175_b7 = ((data&0x0f)^0x0f) | 0xf0;
+	ls175_b7 = ((data & 0x0f) ^ 0x0f) | 0xf0;
 }
 
 
 WRITE8_HANDLER( tubep_background_c000_w )
 {
-	ls175_e8 = ((data&0x0f)^0x0f);
+	ls175_e8 = ((data & 0x0f) ^ 0x0f);
 }
 
 
 static TIMER_CALLBACK( sprite_timer_callback )
 {
-	cpunum_set_input_line(machine, 3,0,ASSERT_LINE);
+	cputag_set_input_line(machine, "mcu", 0, ASSERT_LINE);
 }
 
 
-static void draw_sprite(void)
+static void draw_sprite(running_machine *machine)
 {
 	UINT32	XDOT;
 	UINT32	YDOT;
-	UINT8 * romCxx  = memory_region(REGION_USER2)+0x00000;
-	UINT8 * romD10  = memory_region(REGION_USER2)+0x10000;
-	UINT8 * romEF13 = memory_region(REGION_USER2)+0x12000;
-	UINT8 * romHI2  = memory_region(REGION_USER2)+0x14000;
+	UINT8 * romCxx  = memory_region(machine, "user2")+0x00000;
+	UINT8 * romD10  = romCxx+0x10000;
+	UINT8 * romEF13 = romCxx+0x12000;
+	UINT8 * romHI2  = romCxx+0x14000;
 
 
 	for (YDOT=0; (YDOT^YSize) != 0x00; YDOT++)
@@ -567,13 +585,13 @@ WRITE8_HANDLER( tubep_sprite_control_w )
             /SINT line will be reasserted in XSize * YSize cycles (RH0 signal cycles)
             */
 			/* 1.clear the /SINT interrupt line */
-			cpunum_set_input_line(Machine, 3,0,CLEAR_LINE);
+			cputag_set_input_line(space->machine, "mcu", 0, CLEAR_LINE);
 
 			/* 2.assert /SINT again after this time */
-			timer_set( attotime_mul(ATTOTIME_IN_HZ(19968000/8), (XSize+1)*(YSize+1)), NULL, 0, sprite_timer_callback);
+			timer_set( space->machine, attotime_mul(ATTOTIME_IN_HZ(19968000/8), (XSize+1)*(YSize+1)), NULL, 0, sprite_timer_callback);
 
 			/* 3.clear of /SINT starts sprite drawing circuit */
-			draw_sprite();
+			draw_sprite(space->machine);
 			break;
 		}
 	}
@@ -590,26 +608,40 @@ void tubep_vblank_end(void)
 
 VIDEO_UPDATE( tubep )
 {
-	int offs;
 	int DISP_ = DISP^1;
 
-	/* draw background ram */
+	pen_t pen_base = 32; //change it later
+
+	UINT32 v;
+	UINT8 *text_gfx_base = memory_region(screen->machine, "gfx1");
+	UINT8 *romBxx = memory_region(screen->machine, "user1") + 0x2000*background_romsel;
+
+	/* logerror(" update: from DISP=%i y_min=%3i y_max=%3i\n", DISP_, cliprect->min_y, cliprect->max_y+1); */
+
+	for (v = cliprect->min_y; v <= cliprect->max_y; v++)	/* only for current scanline */
 	{
-		const pen_t *pens = &machine->pens[ 32 ]; //change it later
-
-		UINT32 h,v;
-		UINT8 * romBxx = memory_region(REGION_USER1) + 0x2000*background_romsel;
-
-		/* logerror(" update: from DISP=%i y_min=%3i y_max=%3i\n", DISP_, cliprect->min_y, cliprect->max_y+1); */
-
-		for (v = cliprect->min_y; v <= cliprect->max_y; v++)	/* only for current scanline */
+		UINT32 h;
+		UINT32 sp_data0=0,sp_data1=0,sp_data2=0;
+		for (h = 0*8; h < 32*8; h++)
 		{
-			UINT32 sp_data0=0,sp_data1=0,sp_data2=0;
-			for (h = 0*8; h < 32*8; h++)
+			offs_t text_offs;
+			UINT8 text_code;
+			UINT8 text_gfx_data;
+
+			sp_data2 = sp_data1;
+			sp_data1 = sp_data0;
+			sp_data0 = spritemap[ h + v*256 +(DISP_*256*256) ];
+
+			text_offs = ((v >> 3) << 6) | ((h >> 3) << 1);
+			text_code = tubep_textram[text_offs];
+			text_gfx_data = text_gfx_base[(text_code << 3) | (v & 0x07)];
+
+			if (text_gfx_data & (0x80 >> (h & 0x07)))
+				*BITMAP_ADDR16(bitmap, v, h) = (tubep_textram[text_offs + 1] & 0x0f) | color_A4;
+			else
 			{
 				UINT32 bg_data;
 				UINT32 sp_data;
-				UINT32 sel0,sel1,sel2;
 
 				UINT32 romB_addr = (((h>>1)&0x3f)^((h&0x80)?0x00:0x3f)) | (((v&0x7f)^((v&0x80)?0x00:0x7f))<<6);
 
@@ -638,56 +670,19 @@ VIDEO_UPDATE( tubep )
 
 				romB_data_h>>=2;
 
-				sp_data2 = sp_data1;
-				sp_data1 = sp_data0;
-				sp_data0 = spritemap[ h + v*256 +(DISP_*256*256) ];
-				sel0 = 0;
-				if (sp_data0 != 0x0f)
-					sel0 = 1;
-
-				sel1 = 1;
-				if (sp_data1 != 0x0f)
-					sel1 = 0;
-
-				sel2 = 0;
-				if (sp_data2 != 0x0f)
-					sel2 = 1;
-
-				if (sel0&sel1&sel2)
+				if ((sp_data0 != 0x0f) && (sp_data1 == 0x0f) && (sp_data2 != 0x0f))
 					sp_data = sp_data2;
 				else
 					sp_data = sp_data1;
 
-				if (sp_data!=0x0f)
+				if (sp_data != 0x0f)
 					bg_data = prom2[sp_data | color_A4];
 
-				*BITMAP_ADDR16(bitmap, v, h) = pens[ bg_data*64 + romB_data_h ];
+				*BITMAP_ADDR16(bitmap, v, h) = pen_base + bg_data*64 + romB_data_h;
 			}
 		}
 	}
 
-	/* draw the character mapped graphics */
-	for (offs = 0;offs < 0x800; offs+=2)
-	{
-		int sx,sy;
-
-		sx = (offs/2) % 32;
-		//if (flipscreen[0]) sx = 31 - sx;
-		sy = (offs/2) / 32;
-		//if (flipscreen[1]) sy = 31 - sy;
-
-		if ((cliprect->min_y&(~0x07)) == 8*sy)
-		{
-			drawgfx(bitmap,machine->gfx[0],
-				tubep_textram[offs],
-				((tubep_textram[offs+1]) & 0x0f) | color_A4,
-				0,0, /*flipscreen[0],flipscreen[1],*/
-				8*sx,8*sy,
-				cliprect, TRANSPARENCY_PEN, machine->pens[0]);
-		}
-	}
-
-
 	return 0;
 }
 
@@ -717,8 +712,6 @@ VIDEO_UPDATE( tubep )
 PALETTE_INIT( rjammer )
 {
 	int i;
-	#define TOTAL_COLORS(gfxn) (machine->gfx[gfxn]->total_colors * machine->gfx[gfxn]->color_granularity)
-	#define COLOR(gfxn,offs) (colortable[machine->drv->gfxdecodeinfo[gfxn].color_codes_start + offs])
 
 	static const int resistors_rg[3] = { 1000, 470, 220 };
 	static const int resistors_b [2] = { 470, 220 };
@@ -730,7 +723,7 @@ PALETTE_INIT( rjammer )
 			2,	resistors_b,	weights_b,	470,	0,
 			0,	0,	0,	0,	0	);
 
-	for (i = 0;i < machine->drv->total_colors;i++)
+	for (i = 0;i < machine->config->total_colors;i++)
 	{
 		int bit0,bit1,bit2,r,g,b;
 
@@ -753,14 +746,6 @@ PALETTE_INIT( rjammer )
 
 		color_prom++;
 	}
-
-
-	/* text: colors 0, 17-31 from PROM @16B */
-	for (i = 0; i < TOTAL_COLORS(0)/2; i++)
-	{
-		COLOR(0, 2*i + 0) = 0;		/* transparent "black" */
-		COLOR(0, 2*i + 1) = i+16;	/* /SOFF is on the A4 line */
-	}
 }
 
 
@@ -778,66 +763,60 @@ WRITE8_HANDLER( rjammer_background_page_w )
 
 VIDEO_UPDATE( rjammer )
 {
-	int offs;
 	int DISP_ = DISP^1;
 
-	/* draw background ram */
-	{
-		const pen_t *pens = &machine->pens[ 0x00 ];
-
-		UINT32 h,v;
-		UINT8 * rom13D  = memory_region(REGION_USER1);
-		UINT8 * rom11BD = memory_region(REGION_USER1)+0x1000;
-		UINT8 * rom19C  = memory_region(REGION_USER1)+0x5000;
-
+	UINT32 v;
+	UINT8 *text_gfx_base = memory_region(screen->machine, "gfx1");
+	UINT8 *rom13D  = memory_region(screen->machine, "user1");
+	UINT8 *rom11BD = rom13D+0x1000;
+	UINT8 *rom19C  = rom13D+0x5000;
 
 	/* this can be optimized further by extracting constants out of the loop */
 	/* especially read from ROM19C can be done once per 8 pixels*/
 	/* and the data could be bitswapped beforehand */
 
-		for (v = cliprect->min_y; v <= cliprect->max_y; v++)	/* only for current scanline */
+	for (v = cliprect->min_y; v <= cliprect->max_y; v++)	/* only for current scanline */
+	{
+		UINT32 h;
+		UINT32 sp_data0=0,sp_data1=0,sp_data2=0;
+		UINT8 pal14h4_pin19;
+		UINT8 pal14h4_pin18;
+		UINT8 pal14h4_pin13;
+
+		UINT32 addr = (v*2) | page;
+		UINT32 ram_data = rjammer_backgroundram[ addr ] + 256*(rjammer_backgroundram[ addr+1 ]&0x2f);
+
+		addr = (v>>3) | ((ls377_data&0x1f)<<5);
+		pal14h4_pin13 = (rom19C[addr] >> ((v&7)^7) ) &1;
+		pal14h4_pin19 = (ram_data>>13) & 1;
+
+		for (h = 0*8; h < 32*8; h++)
 		{
-			UINT32 sp_data0=0,sp_data1=0,sp_data2=0;
-			UINT8 pal14h4_pin19;
-			UINT8 pal14h4_pin18;
-			UINT8 pal14h4_pin13;
+			offs_t text_offs;
+			UINT8 text_code;
+			UINT8 text_gfx_data;
 
-			UINT32 addr = (v*2) | page;
-			UINT32 ram_data = rjammer_backgroundram[ addr ] + 256*(rjammer_backgroundram[ addr+1 ]&0x2f);
+			sp_data2 = sp_data1;
+			sp_data1 = sp_data0;
+			sp_data0 = spritemap[ h + v*256 +(DISP_*256*256) ];
 
-			addr = (v>>3) | ((ls377_data&0x1f)<<5);
-			pal14h4_pin13 = (rom19C[addr] >> ((v&7)^7) ) &1;
-			pal14h4_pin19 = (ram_data>>13) & 1;
+			text_offs = ((v >> 3) << 6) | ((h >> 3) << 1);
+			text_code = tubep_textram[text_offs];
+			text_gfx_data = text_gfx_base[(text_code << 3) | (v & 0x07)];
 
-			for (h = 0*8; h < 32*8; h++)
+			if (text_gfx_data & (0x80 >> (h & 0x07)))
+				*BITMAP_ADDR16(bitmap, v, h) = 0x10 | (tubep_textram[text_offs + 1] & 0x0f);
+			else
 			{
 				UINT32 sp_data;
-				UINT32 sel0,sel1,sel2;
 
-				sp_data2 = sp_data1;
-				sp_data1 = sp_data0;
-				sp_data0 = spritemap[ h + v*256 +(DISP_*256*256) ];
-				sel0 = 0;
-				if (sp_data0 != 0x0f)
-					sel0 = 1;
-
-				sel1 = 1;
-				if (sp_data1 != 0x0f)
-					sel1 = 0;
-
-				sel2 = 0;
-				if (sp_data2 != 0x0f)
-					sel2 = 1;
-
-				if (sel0&sel1&sel2)
+				if ((sp_data0 != 0x0f) && (sp_data1 == 0x0f) && (sp_data2 != 0x0f))
 					sp_data = sp_data2;
 				else
 					sp_data = sp_data1;
 
-				if (sp_data!=0x0f)
-				{
-					*BITMAP_ADDR16(bitmap, v, h) = pens[0x00+ sp_data ];
-				}
+				if (sp_data != 0x0f)
+					*BITMAP_ADDR16(bitmap, v, h) = 0x00 + sp_data;
 				else
 				{
 					UINT32 bg_data;
@@ -864,64 +843,37 @@ VIDEO_UPDATE( rjammer )
 					addr = (h>>3) | (ls377_data<<5);
 					pal14h4_pin18 = (rom19C[addr] >> ((h&7)^7) ) &1;
 
-/*
-    PAL14H4 @15A functions:
+					/*
+                        PAL14H4 @15A funct
 
-        PIN6 = disable color on offscreen area
+                        PIN6 = disable color on offscreen area
+                        PIN19,PIN18,PIN13 = arguments for PIN17 function
+                        PIN17 = background color bank (goes to A4 line on PROM @16A)
+                                formula for PIN17 is:
 
-        PIN19,PIN18,PIN13 = arguments for PIN17 function
+                                PIN17 =  ( PIN13 & PIN8 & PIN9 & !PIN11 &  PIN12 )
+                                       | ( PIN18 & PIN8 & PIN9 &  PIN11 & !PIN12 )
+                                       | ( PIN19 )
+                                where:
+                                PIN 8 = bit 3 of bg_data
+                                PIN 9 = bit 2 of bg_data
+                                PIN 11= bit 1 of bg_data
+                                PIN 12= bit 0 of bg_data
 
-        PIN17 = background color bank (goes to A4 line on PROM @16A)
-        formula for PIN17 is:
+                        not used by now, but for the record:
 
-        PIN17 =  ( PIN13 & PIN8 & PIN9 & !PIN11 &  PIN12 )
-               | ( PIN18 & PIN8 & PIN9 &  PIN11 & !PIN12 )
-               | ( PIN19 )
-
-            where:
-        PIN 8 = bit 3 of bg_data
-        PIN 9 = bit 2 of bg_data
-        PIN 11= bit 1 of bg_data
-        PIN 12= bit 0 of bg_data
-
-
-        not used by now, but for the record:
-
-        PIN15 = select prom @16B (active low)
-        PIN16 = select prom @16A (active low)
-        PINs: 1,2,3,4,5 and 7,14 are used for priority system
-
-*/
+                        PIN15 = select prom @16B (active low)
+                        PIN16 = select prom @16A (active low)
+                        PINs: 1,2,3,4,5 and 7,14 are used for priority system
+                    */
 					color_bank =  (pal14h4_pin13 & ((bg_data&0x08)>>3) & ((bg_data&0x04)>>2) & (((bg_data&0x02)>>1)^1) &  (bg_data&0x01)    )
 								| (pal14h4_pin18 & ((bg_data&0x08)>>3) & ((bg_data&0x04)>>2) &  ((bg_data&0x02)>>1)    & ((bg_data&0x01)^1) )
 								| (pal14h4_pin19);
-					*BITMAP_ADDR16(bitmap, v, h) = pens[0x20+ color_bank*0x10 + bg_data ];
+					*BITMAP_ADDR16(bitmap, v, h) = 0x20 + color_bank*0x10 + bg_data;
 				}
 			}
 		}
 	}
 
-	/* draw the character mapped graphics */
-	for (offs = 0;offs < 0x800; offs+=2)
-	{
-		int sx,sy;
-
-		sx = (offs/2) % 32;
-		//if (flipscreen[0]) sx = 31 - sx;
-		sy = (offs/2) / 32;
-		//if (flipscreen[1]) sy = 31 - sy;
-
-		if ((cliprect->min_y&(~0x07)) == 8*sy)
-		{
-			drawgfx(bitmap,machine->gfx[0],
-				tubep_textram[offs],
-				(tubep_textram[offs+1]) & 0x0f,
-				0,0, /*flipscreen[0],flipscreen[1],*/
-				8*sx,8*sy,
-				cliprect, TRANSPARENCY_PEN, machine->pens[0]);
-		}
-	}
-
 	return 0;
 }
-
