@@ -9,6 +9,7 @@ UINT8 *wc90b_scroll2x;
 UINT8 *wc90b_scroll1y;
 UINT8 *wc90b_scroll2y;
 
+UINT8 *wc90b_scroll_x_lo;
 
 static tilemap *tx_tilemap,*fg_tilemap,*bg_tilemap;
 
@@ -104,45 +105,47 @@ WRITE8_HANDLER( wc90b_txvideoram_w )
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority ){
-  int offs;
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority )
+{
+	int offs, sx, sy;
 
-  /* draw all visible sprites of specified priority */
-	for ( offs = spriteram_size - 8;offs >= 0;offs -= 8 ){
+	/* draw all visible sprites of specified priority */
+	for ( offs = spriteram_size - 8 ; offs >= 0 ; offs -= 8 )
+	{
+		if ( ( ~( spriteram[offs+3] >> 7 ) & 1 ) == priority )
+		{
+			int code = ( spriteram[offs + 3] & 0x3f ) << 4;
+			int bank = spriteram[offs + 0];
+			int flags = spriteram[offs + 4];
 
-		if ( ( ~( spriteram[offs+3] >> 6 ) & 3 ) == priority ) {
+			code += ( bank & 0xf0 ) >> 4;
+			code <<= 2;
+			code += ( bank & 0x0f ) >> 2;
 
-			if ( spriteram[offs+1] > 16 ) { /* visible */
-				int code = ( spriteram[offs+3] & 0x3f ) << 4;
-				int bank = spriteram[offs+0];
-				int flags = spriteram[offs+4];
+			sx = spriteram[offs + 2];
+			if (!(spriteram[offs + 3] & 0x40)) sx -= 0x0100;
 
-				code += ( bank & 0xf0 ) >> 4;
-				code <<= 2;
-				code += ( bank & 0x0f ) >> 2;
+			sy = 240 - spriteram[offs + 1];
 
-				drawgfx( bitmap,machine->gfx[ 17 ], code,
-						flags >> 4, /* color */
-						bank&1, /* flipx */
-						bank&2, /* flipy */
-						spriteram[offs + 2], /* sx */
-						240 - spriteram[offs + 1], /* sy */
-						cliprect,TRANSPARENCY_PEN,15 );
-			}
+			drawgfx( bitmap, machine->gfx[17], code,
+					flags >> 4, /* color */
+					bank & 1,   /* flipx */
+					bank & 2,   /* flipy */
+					sx,
+					sy,
+					cliprect,TRANSPARENCY_PEN,15 );
 		}
 	}
 }
 
 VIDEO_UPDATE( wc90b )
 {
-	tilemap_set_scrollx(bg_tilemap,0,8 * wc90b_scroll2x[0] + 256);
-	tilemap_set_scrolly(bg_tilemap,0,wc90b_scroll2y[0] + ((wc90b_scroll2y[0] < 0x10 || wc90b_scroll2y[0] == 0xff) ? 256 : 0));
-	tilemap_set_scrollx(fg_tilemap,0,8 * wc90b_scroll1x[0] + 256);
-	tilemap_set_scrolly(fg_tilemap,0,wc90b_scroll1y[0] + ((wc90b_scroll1y[0] < 0x10 || wc90b_scroll1y[0] == 0xff) ? 256 : 0));
+	tilemap_set_scrollx(bg_tilemap,0,8 * (wc90b_scroll2x[0] & 0x7f) + 256 - 4 + (wc90b_scroll_x_lo[0] & 0x07));
+	tilemap_set_scrolly(bg_tilemap,0,wc90b_scroll2y[0] + 1 + ((wc90b_scroll2x[0] & 0x80) ? 256 : 0));
+	tilemap_set_scrollx(fg_tilemap,0,8 * (wc90b_scroll1x[0] & 0x7f) + 256 - 6 + ((wc90b_scroll_x_lo[0] & 0x38) >> 3));
+	tilemap_set_scrolly(fg_tilemap,0,wc90b_scroll1y[0] + 1 + ((wc90b_scroll1x[0] & 0x80) ? 256 : 0));
 
-//  draw_sprites(screen->machine, bitmap,cliprect, 3 );
 	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
-	draw_sprites(screen->machine, bitmap,cliprect, 2 );
 	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 	draw_sprites(screen->machine, bitmap,cliprect, 1 );
 	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
