@@ -121,15 +121,6 @@ int sdlvideo_init(running_machine *machine)
 	// we need the beam width in a float, contrary to what the core does.
 	video_config.beamwidth = options_get_float(mame_options(), OPTION_BEAM);
 
-	if (machine->config->video_attributes & SCREEN_TYPE_VECTOR)
-	{
-		video_config.isvector = 1;
-	}
-	else
-	{
-		video_config.isvector = 0;
-	}
-
 	// initialize the window system so we can make windows
 	if (sdlwindow_init(machine))
 		goto error;
@@ -374,7 +365,7 @@ static void add_primary_monitor(void *data)
 	sdl_monitor_info *monitor;
 
 	// allocate a new monitor info
-	monitor = malloc_or_die(sizeof(*monitor));
+	monitor = alloc_or_die(sdl_monitor_info);
 	memset(monitor, 0, sizeof(*monitor));
 
 	// copy in the data
@@ -413,7 +404,7 @@ static BOOL CALLBACK monitor_enum_callback(HMONITOR handle, HDC dc, LPRECT rect,
 	assert(result);
 
 	// allocate a new monitor info
-	monitor = malloc_or_die(sizeof(*monitor));
+	monitor = alloc_or_die(sdl_monitor_info);
 	memset(monitor, 0, sizeof(*monitor));
 
 	// copy in the data
@@ -830,7 +821,7 @@ static void extract_video_config(running_machine *machine)
 static void load_effect_overlay(running_machine *machine, const char *filename)
 {
 	const device_config *screen;
-	char *tempstr = malloc_or_die(strlen(filename) + 5);
+	char *tempstr = alloc_array_or_die(char, strlen(filename) + 5);
 	char *dest;
 
 	// append a .PNG extension
@@ -841,7 +832,7 @@ static void load_effect_overlay(running_machine *machine, const char *filename)
 	strcpy(dest, ".png");
 
 	// load the file
-	effect_bitmap = render_load_png(NULL, tempstr, NULL, NULL);
+	effect_bitmap = render_load_png(OPTION_ARTPATH, NULL, tempstr, NULL, NULL);
 	if (effect_bitmap == NULL)
 	{
 		mame_printf_error("Unable to load PNG file '%s'\n", tempstr);
