@@ -99,7 +99,6 @@ typedef struct _mouse_state mouse_state;
 struct _mouse_state
 {
 	DIMOUSESTATE2			state;
-	mouse_state *			partner;
 	LONG					raw_x, raw_y, raw_z;
 };
 
@@ -433,7 +432,7 @@ INLINE input_item_id keyboard_map_scancode_to_itemid(int scancode)
 	// scan the table for a match
 	for (tablenum = 0; tablenum < ARRAY_LENGTH(win_key_trans_table); tablenum++)
 		if (win_key_trans_table[tablenum][DI_KEY] == scancode)
-			return win_key_trans_table[tablenum][MAME_KEY];
+			return (input_item_id)win_key_trans_table[tablenum][MAME_KEY];
 
 	// default to an "other" switch
 	return ITEM_ID_OTHER_SWITCH;
@@ -657,7 +656,7 @@ BOOL wininput_handle_raw(HANDLE device)
 	// if necessary, allocate a temporary buffer and fetch the data
 	if (size > sizeof(small_buffer))
 	{
-		data = malloc(size);
+		data = (LPBYTE)malloc(size);
 		if (data == NULL)
 			return result;
 	}
@@ -795,8 +794,7 @@ static device_info *generic_device_alloc(running_machine *machine, device_info *
 	device_info *devinfo;
 
 	// allocate memory for the device object
-	devinfo = malloc_or_die(sizeof(*devinfo));
-	memset(devinfo, 0, sizeof(*devinfo));
+	devinfo = alloc_clear_or_die(device_info);
 	devinfo->head = devlist_head_ptr;
 	devinfo->machine = machine;
 
@@ -890,8 +888,8 @@ static void generic_device_reset(device_info *devinfo)
 
 static INT32 generic_button_get_state(void *device_internal, void *item_internal)
 {
-	device_info *devinfo = device_internal;
-	BYTE *itemdata = item_internal;
+	device_info *devinfo = (device_info *)device_internal;
+	BYTE *itemdata = (BYTE *)item_internal;
 
 	// return the current state
 	poll_if_necessary(devinfo->machine);
@@ -905,8 +903,8 @@ static INT32 generic_button_get_state(void *device_internal, void *item_internal
 
 static INT32 generic_axis_get_state(void *device_internal, void *item_internal)
 {
-	device_info *devinfo = device_internal;
-	LONG *axisdata = item_internal;
+	device_info *devinfo = (device_info *)device_internal;
+	LONG *axisdata = (LONG *)item_internal;
 
 	// return the current state
 	poll_if_necessary(devinfo->machine);
@@ -948,7 +946,7 @@ static void win32_init(running_machine *machine)
 		for (axisnum = 0; axisnum < 2; axisnum++)
 		{
 			const char *name = utf8_from_tstring(default_axis_name[axisnum]);
-			input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+			input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 			free((void *)name);
 		}
 
@@ -956,7 +954,7 @@ static void win32_init(running_machine *machine)
 		for (butnum = 0; butnum < 2; butnum++)
 		{
 			const char *name = utf8_from_tstring(default_button_name(butnum));
-			input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], ITEM_ID_BUTTON1 + butnum, generic_button_get_state);
+			input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], (input_item_id)(ITEM_ID_BUTTON1 + butnum), generic_button_get_state);
 			free((void *)name);
 		}
 	}
@@ -1176,12 +1174,12 @@ static device_info *dinput_device_create(running_machine *machine, device_info *
 	devinfo = generic_device_alloc(machine, devlist_head_ptr, instance->tszInstanceName);
 
 	// attempt to create a device
-	result = IDirectInput_CreateDevice(dinput, &instance->guidInstance, &devinfo->dinput.device, NULL);
+	result = IDirectInput_CreateDevice(dinput, WRAP_REFIID(instance->guidInstance), &devinfo->dinput.device, NULL);
 	if (result != DI_OK)
 		goto error;
 
 	// try to get a version 2 device for it
-	result = IDirectInputDevice_QueryInterface(devinfo->dinput.device, &IID_IDirectInputDevice2, (void **)&devinfo->dinput.device2);
+	result = IDirectInputDevice_QueryInterface(devinfo->dinput.device, WRAP_REFIID(IID_IDirectInputDevice2), (void **)&devinfo->dinput.device2);
 	if (result != DI_OK)
 		devinfo->dinput.device2 = NULL;
 
@@ -1268,7 +1266,7 @@ static const char *dinput_device_item_name(device_info *devinfo, int offset, con
 		return utf8_from_tstring(namestring);
 
 	// otherwise, allocate space to add the suffix
-	combined = malloc_or_die(sizeof(TCHAR) * (_tcslen(namestring) + 1 + _tcslen(suffix) + 1));
+	combined = alloc_array_or_die(TCHAR, _tcslen(namestring) + 1 + _tcslen(suffix) + 1);
 	_tcscpy(combined, namestring);
 	_tcscat(combined, TEXT(" "));
 	_tcscat(combined, suffix);
@@ -1311,7 +1309,7 @@ static HRESULT dinput_device_poll(device_info *devinfo)
 
 static BOOL CALLBACK dinput_keyboard_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 {
-	running_machine *machine = ref;
+	running_machine *machine = (running_machine *)ref;
 	device_info *devinfo;
 	int keynum;
 
@@ -1367,7 +1365,7 @@ static void dinput_keyboard_poll(device_info *devinfo)
 static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 {
 	device_info *devinfo, *guninfo = NULL;
-	running_machine *machine = ref;
+	running_machine *machine = (running_machine *)ref;
 	int axisnum, butnum;
 	HRESULT result;
 
@@ -1412,9 +1410,9 @@ static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 		const char *name = dinput_device_item_name(devinfo, offsetof(DIMOUSESTATE, lX) + axisnum * sizeof(LONG), default_axis_name[axisnum], NULL);
 
 		// add to the mouse device and optionally to the gun device as well
-		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 		if (guninfo != NULL && axisnum < 2)
-			input_device_item_add(guninfo->device, name, &guninfo->mouse.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+			input_device_item_add(guninfo->device, name, &guninfo->mouse.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 
 		free((void *)name);
 	}
@@ -1422,13 +1420,14 @@ static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 	// populate the buttons
 	for (butnum = 0; butnum < devinfo->dinput.caps.dwButtons; butnum++)
 	{
-		const char *name = dinput_device_item_name(devinfo, offsetof(DIMOUSESTATE, rgbButtons[butnum]), default_button_name(butnum), NULL);
+		FPTR offset = (FPTR)(&((DIMOUSESTATE *)NULL)->rgbButtons[butnum]);
+		const char *name = dinput_device_item_name(devinfo, offset, default_button_name(butnum), NULL);
 
 		// add to the mouse device and optionally to the gun device as well
 		// note that the gun device points to the mouse buttons rather than its own
-		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], ITEM_ID_BUTTON1 + butnum, generic_button_get_state);
+		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], (input_item_id)(ITEM_ID_BUTTON1 + butnum), generic_button_get_state);
 		if (guninfo != NULL)
-			input_device_item_add(guninfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], ITEM_ID_BUTTON1 + butnum, generic_button_get_state);
+			input_device_item_add(guninfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], (input_item_id)(ITEM_ID_BUTTON1 + butnum), generic_button_get_state);
 
 		free((void *)name);
 	}
@@ -1469,7 +1468,7 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 {
 	DWORD cooperative_level = (HAS_WINDOW_MENU ? DISCL_BACKGROUND : DISCL_FOREGROUND) | DISCL_EXCLUSIVE;
 	int axisnum, axiscount, povnum, butnum;
-	running_machine *machine = ref;
+	running_machine *machine = (running_machine *)ref;
 	device_info *devinfo;
 	HRESULT result;
 
@@ -1521,7 +1520,7 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 
 		// populate the item description as well
 		name = dinput_device_item_name(devinfo, offsetof(DIJOYSTATE2, lX) + axisnum * sizeof(LONG), default_axis_name[axisnum], NULL);
-		input_device_item_add(devinfo->device, name, &devinfo->joystick.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+		input_device_item_add(devinfo->device, name, &devinfo->joystick.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 		free((void *)name);
 
 		axiscount++;
@@ -1556,8 +1555,9 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 	// populate the buttons
 	for (butnum = 0; butnum < devinfo->dinput.caps.dwButtons; butnum++)
 	{
-		const char *name = dinput_device_item_name(devinfo, offsetof(DIJOYSTATE2, rgbButtons[butnum]), default_button_name(butnum), NULL);
-		input_device_item_add(devinfo->device, name, &devinfo->joystick.state.rgbButtons[butnum], (butnum < 16) ? (ITEM_ID_BUTTON1 + butnum) : ITEM_ID_OTHER_SWITCH, generic_button_get_state);
+		FPTR offset = (FPTR)(&((DIJOYSTATE2 *)NULL)->rgbButtons[butnum]);
+		const char *name = dinput_device_item_name(devinfo, offset, default_button_name(butnum), NULL);
+		input_device_item_add(devinfo->device, name, &devinfo->joystick.state.rgbButtons[butnum], (butnum < 16) ? (input_item_id)(ITEM_ID_BUTTON1 + butnum) : ITEM_ID_OTHER_SWITCH, generic_button_get_state);
 		free((void *)name);
 	}
 
@@ -1592,7 +1592,7 @@ static void dinput_joystick_poll(device_info *devinfo)
 
 static INT32 dinput_joystick_pov_get_state(void *device_internal, void *item_internal)
 {
-	device_info *devinfo = device_internal;
+	device_info *devinfo = (device_info *)device_internal;
 	int povnum = (FPTR)item_internal / 4;
 	int povdir = (FPTR)item_internal % 4;
 	INT32 result = 0;
@@ -1651,7 +1651,7 @@ static void rawinput_init(running_machine *machine)
 		goto error;
 	if (device_count == 0)
 		goto error;
-	devlist = malloc_or_die(device_count * sizeof(*devlist));
+	devlist = alloc_array_or_die(RAWINPUTDEVICELIST, device_count);
 	if ((*get_rawinput_device_list)(devlist, &device_count, sizeof(*devlist)) == -1)
 		goto error;
 
@@ -1731,7 +1731,7 @@ static device_info *rawinput_device_create(running_machine *machine, device_info
 	// determine the length of the device name, allocate it, and fetch it
 	if ((*get_rawinput_device_info)(device->hDevice, RIDI_DEVICENAME, NULL, &name_length) != 0)
 		goto error;
-	tname = malloc_or_die(name_length * sizeof(*tname));
+	tname = alloc_array_or_die(TCHAR, name_length);
 	if ((*get_rawinput_device_info)(device->hDevice, RIDI_DEVICENAME, tname, &name_length) == -1)
 		goto error;
 
@@ -1769,7 +1769,7 @@ static void rawinput_device_release(device_info *devinfo)
 
 
 //============================================================
-//  rawinput_device_name
+//  rawinput_device_improve_name
 //============================================================
 
 static TCHAR *rawinput_device_improve_name(TCHAR *name)
@@ -1785,12 +1785,17 @@ static TCHAR *rawinput_device_improve_name(TCHAR *name)
 	TCHAR *chdst;
 	LONG result;
 
+	// The RAW name received is formatted as:
+	//   \??\type-id#hardware-id#instance-id#{DeviceClasses-id}
+	// XP starts with "\??\"
+	// Vista64 starts with "\\?\"
+
 	// ensure the name is something we can handle
-	if (_tcsncmp(name, TEXT("\\\\?\\"), 4) != 0)
+	if (_tcsncmp(name, TEXT("\\\\?\\"), 4) != 0 && _tcsncmp(name, TEXT("\\??\\"), 4) != 0)
 		return name;
 
 	// allocate a temporary string and concatenate the base path plus the name
-	regpath = malloc_or_die(sizeof(*regpath) * (_tcslen(basepath) + 1 + _tcslen(name)));
+	regpath = alloc_array_or_die(TCHAR, _tcslen(basepath) + 1 + _tcslen(name));
 	_tcscpy(regpath, basepath);
 	chdst = regpath + _tcslen(regpath);
 
@@ -1902,7 +1907,7 @@ convert:
 		chsrc++;
 	else
 		chsrc = regstring;
-	name = malloc_or_die(sizeof(*name) * (_tcslen(chsrc) + 1));
+	name = alloc_array_or_die(TCHAR, _tcslen(chsrc) + 1);
 	_tcscpy(name, chsrc);
 
 exit:
@@ -2009,8 +2014,7 @@ static void rawinput_mouse_enum(running_machine *machine, PRAWINPUTDEVICELIST de
 	if (guninfo != NULL)
 	{
 		guninfo->device = input_device_add(machine, DEVICE_CLASS_LIGHTGUN, guninfo->name, guninfo);
-		guninfo->poll = (guninfo == lightgun_list) ? win32_lightgun_poll : NULL;
-		guninfo->mouse.partner = &devinfo->mouse;
+		guninfo->poll = NULL;
 	}
 
 	// populate the axes
@@ -2019,9 +2023,9 @@ static void rawinput_mouse_enum(running_machine *machine, PRAWINPUTDEVICELIST de
 		const char *name = utf8_from_tstring(default_axis_name[axisnum]);
 
 		// add to the mouse device and optionally to the gun device as well
-		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 		if (guninfo != NULL && axisnum < 2)
-			input_device_item_add(guninfo->device, name, &guninfo->mouse.state.lX + axisnum, ITEM_ID_XAXIS + axisnum, generic_axis_get_state);
+			input_device_item_add(guninfo->device, name, &guninfo->mouse.state.lX + axisnum, (input_item_id)(ITEM_ID_XAXIS + axisnum), generic_axis_get_state);
 
 		free((void *)name);
 	}
@@ -2032,10 +2036,9 @@ static void rawinput_mouse_enum(running_machine *machine, PRAWINPUTDEVICELIST de
 		const char *name = utf8_from_tstring(default_button_name(butnum));
 
 		// add to the mouse device and optionally to the gun device as well
-		// note that the gun device points to the mouse buttons rather than its own
-		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], ITEM_ID_BUTTON1 + butnum, generic_button_get_state);
+		input_device_item_add(devinfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], (input_item_id)(ITEM_ID_BUTTON1 + butnum), generic_button_get_state);
 		if (guninfo != NULL)
-			input_device_item_add(guninfo->device, name, &devinfo->mouse.state.rgbButtons[butnum], ITEM_ID_BUTTON1 + butnum, generic_button_get_state);
+			input_device_item_add(guninfo->device, name, &guninfo->mouse.state.rgbButtons[butnum], (input_item_id)(ITEM_ID_BUTTON1 + butnum), generic_button_get_state);
 
 		free((void *)name);
 	}
@@ -2055,8 +2058,6 @@ static void rawinput_mouse_update(HANDLE device, RAWMOUSE *data)
 	for (devinfo = devlist; devinfo != NULL; devinfo = devinfo->next)
 		if (devinfo->rawinput.device == device)
 		{
-			mouse_state *mouseinfo = (devinfo->mouse.partner != NULL) ? devinfo->mouse.partner : &devinfo->mouse;
-
 			// if we got relative data, update it as a mouse
 			if (!(data->usFlags & MOUSE_MOVE_ABSOLUTE))
 			{
@@ -2073,22 +2074,19 @@ static void rawinput_mouse_update(HANDLE device, RAWMOUSE *data)
 			{
 				devinfo->mouse.state.lX = normalize_absolute_axis(data->lLastX, 0, 0xffff);
 				devinfo->mouse.state.lY = normalize_absolute_axis(data->lLastY, 0, 0xffff);
-
-				// also clear the polling function so win32_lightgun_poll isn't called
-				devinfo->poll = NULL;
 			}
 
 			// update the button states; always update the corresponding mouse buttons
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_1_DOWN) mouseinfo->state.rgbButtons[0] = 0x80;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_1_UP)   mouseinfo->state.rgbButtons[0] = 0x00;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_2_DOWN) mouseinfo->state.rgbButtons[1] = 0x80;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_2_UP)   mouseinfo->state.rgbButtons[1] = 0x00;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_3_DOWN) mouseinfo->state.rgbButtons[2] = 0x80;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_3_UP)   mouseinfo->state.rgbButtons[2] = 0x00;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_4_DOWN) mouseinfo->state.rgbButtons[3] = 0x80;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_4_UP)   mouseinfo->state.rgbButtons[3] = 0x00;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_5_DOWN) mouseinfo->state.rgbButtons[4] = 0x80;
-			if (data->usButtonFlags & RI_MOUSE_BUTTON_5_UP)   mouseinfo->state.rgbButtons[4] = 0x00;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_1_DOWN) devinfo->mouse.state.rgbButtons[0] = 0x80;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_1_UP)   devinfo->mouse.state.rgbButtons[0] = 0x00;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_2_DOWN) devinfo->mouse.state.rgbButtons[1] = 0x80;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_2_UP)   devinfo->mouse.state.rgbButtons[1] = 0x00;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_3_DOWN) devinfo->mouse.state.rgbButtons[2] = 0x80;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_3_UP)   devinfo->mouse.state.rgbButtons[2] = 0x00;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_4_DOWN) devinfo->mouse.state.rgbButtons[3] = 0x80;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_4_UP)   devinfo->mouse.state.rgbButtons[3] = 0x00;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_5_DOWN) devinfo->mouse.state.rgbButtons[4] = 0x80;
+			if (data->usButtonFlags & RI_MOUSE_BUTTON_5_UP)   devinfo->mouse.state.rgbButtons[4] = 0x00;
 			break;
 		}
 }
@@ -2130,7 +2128,7 @@ static TCHAR *reg_query_string(HKEY key, const TCHAR *path)
 		return NULL;
 
 	// allocate a buffer
-	buffer = malloc_or_die(datalen + sizeof(*buffer));
+	buffer = alloc_array_or_die(TCHAR, datalen + sizeof(*buffer));
 	buffer[datalen / sizeof(*buffer)] = 0;
 
 	// now get the actual data
