@@ -81,6 +81,18 @@
 
 
 
+//============================================================
+//  MACROS
+//============================================================
+
+#ifdef __cplusplus
+#define WRAP_REFIID(x)		x
+#else
+#define WRAP_REFIID(x)		&x
+#endif
+
+
+
 //============================================================
 //  GLOBAL VARIABLES
 //============================================================
