@@ -129,8 +129,8 @@ static int chd_allocate_buffers(movie_info *info)
 	}
 
 	/* allocate sound buffers */
-	info->lsound = malloc(info->samplerate * sizeof(*info->lsound));
-	info->rsound = malloc(info->samplerate * sizeof(*info->rsound));
+	info->lsound = (INT16 *)malloc(info->samplerate * sizeof(*info->lsound));
+	info->rsound = (INT16 *)malloc(info->samplerate * sizeof(*info->rsound));
 	if (info->lsound == NULL || info->rsound == NULL)
 	{
 		fprintf(stderr, "Out of memory allocating sound buffers of %d bytes\n", (INT32)(info->samplerate * sizeof(*info->rsound)));
@@ -177,7 +177,7 @@ static chd_file *open_chd(const char *filename, movie_info *info)
 	}
 
 	/* get the metadata */
-	chderr = chd_get_metadata(chd, AV_METADATA_TAG, 0, metadata, sizeof(metadata), NULL, NULL);
+	chderr = chd_get_metadata(chd, AV_METADATA_TAG, 0, metadata, sizeof(metadata), NULL, NULL, NULL);
 	if (chderr != CHDERR_NONE)
 	{
 		fprintf(stderr, "Error getting A/V metadata: %s\n", chd_error_string(chderr));
